import { BehaviorSubject } from 'rxjs';
import { IFilterAttributesInput } from '../shared/interfaces/filter-attributes-input.interface';
import { IFilterAttribute, ISelectionFilterValue } from '../shared/interfaces/filter-attribute.interface';
import { IIconInput } from '../shared/interfaces/icon-input.interface';
import { IAttributeItem } from '../shared/interfaces/attribute-item.interface';
import * as i0 from "@angular/core";
/**
 * FilterToolbarService is used to share data between the filter toolbar and other components in the library.
 * The calculation of each filter is also done here.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { FilterToolbarService } from '@talenra/ngx-inbox';
 * ```
 */
export declare class FilterToolbarService {
    /**
     * The filtered and sorted data items.
     * @internal
     */
    readonly filteredSortedDataItems$: BehaviorSubject<any[]>;
    /**
     * The original list of data items inputted by the consuming application.
     * @internal
     */
    readonly originalDataItems$: BehaviorSubject<any[]>;
    /**
     * Value for the active expert filter. If true, the expert filter is active.
     * Tag should be displayed and the expert filter should be shown.
     */
    activeExpertFilter: import("@angular/core").WritableSignal<boolean>;
    /**
     * Map with all identifiers and the possible selections for the filter.
     */
    identifierWithPossibleSelection?: Map<string, ISelectionFilterValue[]>;
    /**
     * Sets the selectedDataItems subject.
     * @param key The value of the selected data items.
     * @internal
     */
    setFilteredSortedDataItems(key: any[]): void;
    /**
     * Sets the dataItemsSubject subject.
     * @param key The value of the unchanged list of data items.
     * @internal
     */
    setOriginalDataItems(key: any[]): void;
    /**
     * Transforms the active filter to the filter attribute interface.
     * @param activeFilter The active filter.
     * @param selectedAttributes The selected attributes.
     */
    transformFilterAttributeIntoInboxInterface(activeFilter: IFilterAttributesInput[], selectedAttributes: IAttributeItem[]): IFilterAttribute[];
    /**
     * Transforms the active filter to the filter attribute interface.
     * @param activeFilter The active filter.
     * @param selectedAttributes The selected attributes.
     */
    transformFilterAttributeIntoPresetInterface(activeFilter: IFilterAttribute[], selectedAttributes: IAttributeItem[]): IFilterAttributesInput[];
    /**
     * Get the filter value key from the possible options.
     * @param filterIdentifier
     * @param filterValue
     */
    getFilterValueKeyFromPossibleOptions(filterIdentifier: string, filterValue: string): string;
    /**
     * Gets the combined icon filter key.
     * @param iconInput The icon input to construct the key.
     */
    getIconFilterCombinedKey(iconInput: IIconInput): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterToolbarService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FilterToolbarService>;
}
