import { BehaviorSubject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Provides control and state of the publicly available subjects of the inbox data items.
 *
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { DataItemsService } from '@talenra/ngx-inbox';
 * ```
 */
export declare class DataItemsService {
    /**
     * Provides the state for the active data item (current item).
     */
    readonly activeDataItem$: BehaviorSubject<any>;
    /**
     * Provides the state for the selected data items in data items list.
     * @internal
     */
    readonly selectedDataItemsIdList$: BehaviorSubject<string[]>;
    /**
     * Provides the height of the scrollable content, all the items cumulated.
     * @internal
     */
    readonly virtualScrollerScrollableContentHeight$: BehaviorSubject<number>;
    /**
     * Provides the height of the virtual scroller, the possible space.
     * @internal
     */
    readonly virtualScrollerHeight$: BehaviorSubject<number>;
    /**
     * Provides whether the data-items-list is compressed.
     */
    readonly compressedDataItem$: BehaviorSubject<boolean>;
    /**
     * Updates the current state for the active data item.
     * @param selection The selected data item.
     * @internal
     */
    setActiveDataItem(selection: any): void;
    /**
     * Updates the current state for the selected data-items-list.
     * @param selection The selected data items.
     */
    setSelectedIdDataItemsList(selection: string[]): void;
    /**
     * Sets the height of the cumulated items of the virtual scroller.
     * @param value The cumulated height of the virtual scroller content.
     * @internal
     */
    setVirtualScrollerScrollableContentHeight(value: number): void;
    /**
     * Sets the height of the virtual scroller, the possible space.
     * @param value The height of the possible space for the virtual scroller.
     * @internal
     */
    setVirtualScrollerHeight(value: number): void;
    /**
     * Compress or inflate data-items-list
     * @param isCompressed Whether the data-items-list is compressed or not.
     */
    setCompressedDataItem(isCompressed: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataItemsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DataItemsService>;
}
