import { BehaviorSubject } from 'rxjs';
import { IResizeEvent } from 'angular2-draggable/lib/models/resize-event';
import { InboxDetailViewService } from './inbox-detail-view/inbox-detail-view.service';
import { DataItemsService } from './data-items-list/data-items.service';
import { KeyboardService } from '../inbox/services/keyboard.service';
import { InboxState } from '../inbox/state/inbox.state';
import { IInboxTabBarItem } from '../shared/interfaces/inbox-tab-bar-item.interface';
import * as i0 from "@angular/core";
/**
 * Parent component of data items list and inbox detail view for better structure and handling.
 *
 * ```html
 * <talenra-inbox-layout
 *   [detailViewInformationTabBarItems]="dataItemInformationTabBarItems"
 *   [usePagination]="usePagination">
 *   <talenra-data-items-list>
 *     <div further-actions-menu>...</div>
 *   </talenra-data-items-list>
 * </talenra-inbox-layout>
 * ```
 */
export declare class InboxLayoutComponent {
    /**
     * List of all data item information tab bar items
     */
    detailViewInformationTabBarItems: import("@angular/core").InputSignal<IInboxTabBarItem[]>;
    /**
     * If true, the pagination feature is enabled.
     *
     * ```html
     * <talenra-inbox [attributes]="attributes" usePagination>...</talenra-inbox>
     * ```
     */
    usePagination: boolean;
    /**
     * Vertical width of sidePanel, when opened.
     */
    detailViewWidth: number;
    /**
     * Vertical width of sidePanel, when closed.
     */
    panelWidth: {
        width: string;
    };
    /**
     Vertical default width of sidePanel.
     */
    defaultPanelWidth: {
        left: string;
    };
    /**
     * Controls the time frame in which resizing is used.
     */
    readonly isResizing$: BehaviorSubject<boolean>;
    /**
     * The state of the inbox.
     */
    inboxState: InboxState;
    /**
     * Injected inbox detail view service.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * The data items service.
     */
    dataItemsService: DataItemsService;
    /**
     * The keyboard service.
     */
    keyboardService: KeyboardService;
    /**
     * Vertical width of sidePanel, when closed.
     */
    private minPanelWidth;
    /**
     * Setter for the controls.
     * @param {boolean} isResizing True if resizing is used, false if not.
     */
    setResizing(isResizing: boolean): void;
    /**
     * Closes the side panel after half of the minimum width has been reached
     * @param event Event of the resizing.
     * @internal
     */
    onResizing(event: IResizeEvent): void;
    /**
     * Shuts down slow transition (lag), while resizing.
     * @internal
     */
    onResizeStart(): void;
    /**
     * Normalizes slow transition (lag), after Resizing for closing the smooth closing transition.
     * @internal
     */
    onResizeStop(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InboxLayoutComponent, "talenra-inbox-layout", never, { "detailViewInformationTabBarItems": { "alias": "detailViewInformationTabBarItems"; "required": true; "isSignal": true; }; "usePagination": { "alias": "usePagination"; "required": false; }; }, {}, never, ["*", "[inbox-paginator]", "[data-item-information-outlet]", "[inbox-note-box]"], true, never>;
    static ngAcceptInputType_usePagination: unknown;
}
