import { BehaviorSubject } from 'rxjs';
import { InboxState } from '../../inbox/state/inbox.state';
import * as i0 from "@angular/core";
/**
 * Provides control and state of the publicly available subjects of the presets.
 *
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { PresetsService } from '@talenra/ngx-inbox';
 * ```
 */
export declare class PresetsService {
    /**
     * The drag drop group and preset subject.
     * TODO: check what this does
     * @internal
     */
    dragDropGroupAndPreset$: BehaviorSubject<[]>;
    /**
     * The boolean if the view menu is open.
     */
    readonly presetMenuOpen: BehaviorSubject<boolean>;
    /**
     * The inbox state service.
     * @internal
     */
    inboxState: InboxState;
    /**
     * The setter for the drag drop group and preset.
     * @param event the event
     * @internal
     */
    setDragDropPresetAndGroup(event: any): void;
    /**
     * Setter for the view menu state.
     * @param state The state of the view menu.
     * @internal
     */
    setPresetMenuState(state: boolean): void;
    /**
     * Find all preset names that are already used
     * @param groupName the name of the group
     * @param presetName the name of the preset
     * @returns all preset names that are already used
     * @internal
     */
    presetNamesThatAreAlreadyUsed(groupName?: string, presetName?: string): string[];
    /**
     * Find the index of the first changeable preset inside a group
     * @returns the index of the first changeable preset
     * @internal
     */
    findIndexOfFirstChangeablePreset(groupName: string): number;
    /**
     * Find the index of the last changeable preset.
     * @internal
     */
    findIndexOfLastChangeablePreset(groupName: string): number;
    /**
     * Find the index of a preset inside a group
     * @param groupName the name of the group
     * @param presetName the name of the preset
     * @returns the index of the preset
     * @internal
     */
    findPositionOfPreset(groupName: string, presetName: string): number;
    /**
     * Check if a group is changeable
     * @param groupName the name of the group
     * @returns true if the group is changeable
     * MOST GROUPS ARE NOT CHANGEABLE
     * @internal
     */
    hasChangeablePreset(groupName: string): boolean;
    /**
     * To check if the preset is changeable or not.
     * @param groupName the name of the group
     * @param presetName the name of the preset
     * @returns true if the preset is changeable
     * @internal
     */
    checkIfChangeablePreset(groupName: string, presetName: string): boolean;
    /**
     * Find a whole group with all presets by the name of the group
     * @param groupName the name of the group
     * @returns the whole group
     * @internal
     */
    private findPresetGroupByName;
    /**
     * Remove a preset from a group
     * @param presetNamesGroup the presetNamesGroup of the presets in the group
     * @param presetName the name of the preset to remove
     * @internal
     */
    private removePresetName;
    /**
     * Find only the presets of a group
     * @param groupName the name of the group
     * @returns the presets of the group
     * @internal
     */
    private getPresetsForGroup;
    static ɵfac: i0.ɵɵFactoryDeclaration<PresetsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PresetsService>;
}
