import { IQueryBuilderQuery } from '@talenra/ngx-base/query-builder';
import { IAttributeItem } from '../../shared/interfaces/attribute-item.interface';
import * as i0 from "@angular/core";
/**
 * The service to check if the values of the filter and sort are changed in comparison to the default values of the preset.
 */
export declare class ExpertFilterService {
    /**
     * Adds the simple filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param value The value to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     */
    addSimpleFilterToExpertFilter(queryToAddTo: IQueryBuilderQuery, value: [string, string | boolean | string[] | number[] | Date[]] | undefined, attribute: IAttributeItem): void;
    /**
     * Generates a UUID.
     */
    private generateUUID;
    /**
     * Adds a single select filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    private addSingleSelectFilter;
    /**
     * Adds a multi select filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    private addMultiSelectFilter;
    /**
     * Adds a date range filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    private addDateRangeFilter;
    /**
     * Adds a char range filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    private addCharRangeFilter;
    /**
     * Adds a number range filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    private addNumberRangeFilter;
    /**
     * Adds a range sub group to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param condition The condition to add to the expert filter.
     * @param type The type to add to the expert filter.
     * @param values The values to add to the expert filter.
     * @param firstOperator The first operator to add to the expert filter.
     * @param secondOperator The second operator to add to the expert filter.
     */
    private addRangeSubGroup;
    static ɵfac: i0.ɵɵFactoryDeclaration<ExpertFilterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ExpertFilterService>;
}
