import { BehaviorSubject } from 'rxjs';
import { KeyboardService } from './keyboard.service';
import { MainFacadeSetterService } from './main-facade-setter.service';
import { INoteBoxItem } from '../../shared/interfaces/note-box-item.interface';
import { DataItemsService } from '../../inbox-layout/data-items-list/data-items.service';
import * as i0 from "@angular/core";
/**
 * Service containing helper methods for the inbox main facade usage.
 */
export declare class InboxHelperService {
    /**
     * First Index of data-items-list.
     */
    readonly startIndexDataItemsListSubject$: BehaviorSubject<number>;
    /**
     * Service to handle the data items.
     */
    dataItemsService: DataItemsService;
    /**
     * Service to handle the keyboard.
     */
    keyboardService: KeyboardService;
    /**
     * Service to handle the inbox configuration.
     */
    setInboxConfigurationService: MainFacadeSetterService;
    /**
     * Boolean to check if the current header is in an edge case loop (e.g. when the user scrolls down header is hidden and the available space is enough to show the header again (no scrolling needed)).
     */
    private headerEdgeCase;
    /**
     * Boolean to check the virtual scroll has no scroll bar.
     */
    private noScroll;
    /**
     * Setter for the first index of the data items list.
     * @param {number} value The value to set.
     * @internal
     */
    setStartIndexDataItemsListSubject(value: number): void;
    /**
     * Getter for the list of data items which are chosen in the data items list.
     * @param {any[]} dataItems The list of dataItems.
     * @param {string[]} dataItemsListId The list of data items ids.
     * @internal
     */
    getBulkDataItemsList(dataItems: any, dataItemsListId: string[]): any[];
    /**
     * Handler to get the notes from the selected data item.
     * @param noteInput The note input.
     */
    getSelectedDataItemNotes(noteInput: INoteBoxItem[] | undefined): INoteBoxItem[];
    /**
     * Method to handle scroll change.
     * @param {number} scrollPosition Clicked data item.
     */
    onScrollChange(scrollPosition: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxHelperService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InboxHelperService>;
}
