import { EventEmitter } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Menu for configuration of the inbox, able to show and alter any flattened object data.
 *
 * ```html
 * <talenra-configuration-menu
 *   [positionBottom]="'18'"
 *   [positionRight]="'0'"
 *   [title]="'Konfiguration'"
 *   [data]="inboxConfiguration"
 *   (dataChange)="configChange($event)">
 * </talenra-configuration-menu>
 * ```
 */
export declare class ConfigurationMenuComponent {
    /**
     * The title of the dialog
     */
    title: string;
    /**
     * The position of the dialog for the top value
     */
    positionTop: string;
    /**
     * The position of the dialog for the left value
     */
    positionLeft: string;
    /**
     * The position of the dialog for the bottom value
     */
    positionBottom: string;
    /**
     * The position of the dialog for the right value
     */
    positionRight: string;
    /**
     * The data which is passed to the dialog
     */
    data: any;
    /**
     * The data which is passed from the dialog
     */
    dataChange: EventEmitter<any>;
    /**
     * The boolean which controls the opening and closing of the dialog
     */
    open: boolean;
    /**
     * Opens the dialog
     * @param event
     */
    openDialog(event: Event): void;
    /**
     * Closes the dialog
     */
    closeDialog(): void;
    /**
     * Saves the configurations
     */
    saveConfigurations(): void;
    /**
     * Changes the value of the data
     * @param event
     * @param key
     */
    changeValue(event: Event, key: any): void;
    /**
     * Returns the type of the value
     * @param value
     */
    typeof(value: unknown): string;
    /**
     * Closes the dialog when clicking outside of it
     */
    clickOutside(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ConfigurationMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ConfigurationMenuComponent, "talenra-configuration-menu", never, { "title": { "alias": "title"; "required": false; }; "positionTop": { "alias": "positionTop"; "required": false; }; "positionLeft": { "alias": "positionLeft"; "required": false; }; "positionBottom": { "alias": "positionBottom"; "required": false; }; "positionRight": { "alias": "positionRight"; "required": false; }; "data": { "alias": "data"; "required": false; }; }, { "dataChange": "dataChange"; }, never, never, true, never>;
}
