import { FormGroup } from '@angular/forms';
import { IIconInput } from './icon-input.interface';
import { ISelectionFilterValue } from './filter-attribute.interface';
/**
 * Attribute filter modes
 */
export declare const AttributeFilterModes: {
    readonly MultiSelect: "multi-select";
    readonly SingleSelect: "single-select";
    readonly DateRange: "date-range";
    readonly CharRange: "char-range";
    readonly NumberRange: "number-range";
    readonly TextField: "text-field";
};
/**
 * Type of attribute filter modes
 */
export type TAttributeFilterModes = (typeof AttributeFilterModes)[keyof typeof AttributeFilterModes];
/**
 * Attribute filter modes
 */
export declare const DateFilterRestrictions: {
    readonly Birthday: "birthday";
    readonly OnlyFuture: "only-future";
    readonly OnlyPast: "only-past";
};
/**
 * Type of attribute filter modes
 */
export type TDateFilterRestrictions = (typeof DateFilterRestrictions)[keyof typeof DateFilterRestrictions];
/**
 * AttributeItem is used to further define the attributes that are displayed in the inbox
 */
export interface IAttributeItem {
    /**
     * the name of the attribute used internally
     */
    identifier: string;
    /**
     * the name of the attribute that is displayed in the inbox
     */
    label: string;
    /**
     * defines if the attribute is displayed in the inbox or not
     */
    checked: FormGroup;
    /**
     * which type of filter is used for this attribute
     */
    filterMode?: TAttributeFilterModes;
    /**
     * Restrictions that apply to the filterMode = `date-range`.
     */
    dateFilterRestriction?: TDateFilterRestrictions;
    /**
     * The sortable attribute defines if the attribute is sortable.
     */
    sortable?: boolean;
    /**
     * the icon filter is used to define an icon for a specific data item.
     */
    iconFilter?: IIconInput;
    /**
     * Defines the options for the single and multi select filter for the specific attribute
     */
    filterSelectionOptions?: ISelectionFilterValue[];
    /**
     * Defines if the options for the filter should contain the not available option '–'.
     * If set to true, the options will contain the '–' option (default).
     * If set to false, the options will not contain the '–' option.
     * If not set, the options will contain the '–' option.
     * The '–' option is used to filter for items that have no value for the specific attribute.
     */
    allowEmptyDataItemFilter?: boolean;
}
