/**
 * IFilterAttributesInput is used to define which attribute identifiers are used to filter the items in the inbox.
 *
 * **Important Information:**
 *
 * 1. **The identifier must already be used in selectedAttributes (SelectedAttributesInput[]).**
 *
 * @example
 * import { IFilterAttributesInput } from '@talenra/ngx-inbox';
 *
 * const selectedAttributeInput: IFilterAttributesInput = { identifier: 'insureelastNameOrgName', value: ['8001', '8041', '8011'] };
 */
export interface IFilterAttributesInput {
    /**
     * As the filter types are already defined in AttributeItemInput, only the identifier and values for the filter are necessary to set.
     */
    identifier: string;
    /**
     * The values are defined as string[] or number[] as the filter types are defined as 'multi-select' | 'single-select'
     *
     * single-select: string (e.g. '8001')
     * multi-select: string[] (e.g. ['8001', '8041', '8011'])
     * char-range: string[] (e.g. ['A', 'J'])
     * number-range: number[] (e.g. [1, 6])
     * text-field: string (e.g. 'John Doe')
     *
     * // The date range format is new Date('MM.DD.YYYY')
     * date-range: Date[] (e.g. [new Date('01.14.2023'), new Date('01.14.2024')])
     *
     */
    value: string[] | number[] | string | boolean | Date[];
}
