/**
 * The message types emitted by the IInteractedDataItems.
 */
export declare const InteractedDataItemsMessageTypes: {
    readonly Process: "process";
    readonly More: "more";
    readonly Example: "example";
};
/**
 * Type of attribute filter modes
 */
export type TInteractedDataItemsMessageTypes = (typeof InteractedDataItemsMessageTypes)[keyof typeof InteractedDataItemsMessageTypes];
/**
 * IInteractedDataItems is emitted to the parent component, to notify the user which data items have been interacted with.
 *
 * @example
 * import { IInteractedDataItems } from '@talenra/ngx-inbox';
 *
 * interactedDataItems: IInteractedDataItems = {
 *   dataItems: [
 *   {
 *   caseId: '1234352',
 *   caseTypeName: 'Case Type 1',
 *   },
 *   ],
 *   message: 'process',
 *   };
 */
export interface IInteractedDataItems {
    /**
     * Data items which have been interacted with. If interacted with one data item, the array will contain one data item.
     */
    dataItems: any[];
    /**
     * Message type emitted.
     */
    message: TInteractedDataItemsMessageTypes;
}
