import { OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { SelectComponent } from '@talenra/ngx-base/select';
import { ISelectedFilterAttribute } from '../../shared/interfaces/selected-filter-attribute.interface';
import { ISelectionFilterValue } from '../../shared/interfaces/filter-attribute.interface';
import * as i0 from "@angular/core";
/**
 * The selection filter component is a component to show a selected item from a pool of items.
 * There is a multiple selection possible.
 *
 * '''html
 *   <talenra-selection-filter
 *     (filterSelection)="onFilterSelection($event)" [attribute]="selectedAttribute" [possibleValues]="possibleSelection">
 *   </talenra-selection-filter>
 *  '''
 */
export declare class SelectionFilterComponent implements OnInit, OnChanges {
    /**
     * The attribute to identify which filter is selected.
     */
    attribute: import("@angular/core").InputSignal<ISelectedFilterAttribute>;
    /**
     * The filterSelection output is used to emit the filter values.
     */
    filterSelection: import("@angular/core").OutputEmitterRef<ISelectedFilterAttribute>;
    /**
     * The possible values of the filter.
     */
    possibleValues: import("@angular/core").InputSignal<ISelectionFilterValue[]>;
    /**
     * The select component.
     */
    select: SelectComponent | null;
    /**
     * The selected values.
     */
    selectionForm: FormGroup;
    /**
     * The inboxState is used to get the active view name.
     * @private
     */
    private inboxState;
    /**
     * The inboxToolbarService is used to get if the attribute settings are closed
     */
    private inboxToolbarService;
    /**
     * The destroyRef is used to destroy the component.
     * @private
     */
    private destroyRef;
    constructor();
    /**
     * @internal
     */
    ngOnInit(): void;
    /**
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Function is necessary to delete the filter from the filter toolbar.
     * Furthermore, the previous filterings with the deleted filter will be ignored.
     * @param mouseEvent The mouse event.
     */
    resetValues(mouseEvent?: MouseEvent): void;
    /**
     * All selected filters will be saved in the map with there definition and values
     * @param value The value of the filter.
     */
    private onValuesSelected;
    /**
     * Function is necessary to initialize the filter values.
     */
    private initializeFilterValues;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectionFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SelectionFilterComponent, "talenra-selection-filter", never, { "attribute": { "alias": "attribute"; "required": true; "isSignal": true; }; "possibleValues": { "alias": "possibleValues"; "required": false; "isSignal": true; }; }, { "filterSelection": "filterSelection"; }, never, never, true, never>;
}
