import { BehaviorSubject } from 'rxjs';
import { IIconInput } from '../../shared/interfaces/icon-input.interface';
import { IFilterAttribute } from '../../shared/interfaces/filter-attribute.interface';
import { ISortAttributesInput } from '../../shared/interfaces/sort-attributes-input.interface';
import * as i0 from "@angular/core";
export declare class FilterStateService {
    /**
     * The simple filter subject.
     */
    readonly simpleFilterSubject$: BehaviorSubject<IFilterAttribute[]>;
    /**
     * The sort subject.
     */
    readonly sortSubject$: BehaviorSubject<ISortAttributesInput[]>;
    /**
     * The icon filter subject.
     */
    readonly iconFilterSubject$: BehaviorSubject<IIconInput[]>;
    /**
     * The filter and sort changed in comparison to emitted state signal.
     */
    readonly filterAndSortChangedInComparisonToEmittedState: import("@angular/core").WritableSignal<boolean>;
    /**
     * Contains the signal if any range filter has a false order.
     * Contains the key of each range filter with a false order.
     */
    readonly falseOrderRangeFilter: BehaviorSubject<string[]>;
    /**
     * Sets the simple filter subject.
     * @param key The simple filter subject.
     */
    setSimpleFilterSubject(key: IFilterAttribute[]): void;
    /**
     * Sets the sort subject.
     * @param key The sort subject.
     */
    setSortSubject(key: ISortAttributesInput[]): void;
    /**
     * Sets the icon filter subject.
     * @param key The icon filter subject.
     */
    setIconFilterSubject(key: IIconInput[]): void;
    /**
     * Sets the filter and sort changed in comparison to emitted state.
     * @param key The filter and sort changed in comparison to emitted state.
     */
    setFilterAndSortChangedInComparisonToEmittedState(key: boolean): void;
    /**
     * Adds a false order range filter.
     * @param key The key of the range filter to add.
     */
    addFalseOrderRangeFilter(key: string): void;
    /**
     * Removes a false order range filter.
     * @param key The key of the range filter to remove.
     */
    removeFalseOrderRangeFilter(key: string): void;
    /**
     * Checks if a false order range filter is contained.
     * @param key The key of the range filter to check.
     */
    containsFalseOrderRangeFilter(key: string): boolean;
    /**
     * Resets the simple filter selection.
     */
    resetSimpleFilterSelection(): void;
    /**
     * Resets the sort selection.
     */
    resetSortSelection(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterStateService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FilterStateService>;
}
