import { OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { SelectChange } from '@talenra/ngx-base/select';
import { ISelectedSortAttribute } from '../shared/interfaces/selected-sort-attribute.interface';
import { ISortAttributesInput } from '../shared/interfaces/sort-attributes-input.interface';
import { IAttributeItem } from '../shared/interfaces/attribute-item.interface';
import * as i0 from "@angular/core";
export declare class SortSelectionComponent implements OnInit, OnChanges {
    /**
     * The availableAttributes input is an array of AttributeItem that contains the available sortable attributes.
     */
    availableAttributes: import("@angular/core").InputSignal<IAttributeItem[]>;
    /**
     * The sortSelections input is an array of strings that contains the selected sorts.
     */
    sortSelections: import("@angular/core").InputSignal<ISortAttributesInput[]>;
    /**
     * The sortSelections output is an array of strings that contains the selected sorts.
     */
    sortSelectionsChange: import("@angular/core").OutputEmitterRef<ISortAttributesInput[]>;
    /**
     * The availableAttributes output is an array of AttributeItem that contains the available filters.
     */
    copyAvailableAttributes: import("@angular/core").Signal<IAttributeItem[]>;
    /**
     * The availableSortAttributes computed property is an array of strings that contains the available sort attributes.
     */
    availableSortAttributes: ISelectedSortAttribute[];
    /**
     * The selectedAttributes input is an array of AttributeItem that contains the selected sorts.
     */
    selectedAttributes: ISelectedSortAttribute[];
    /**
     * The selected values.
     */
    selectionForm: FormGroup;
    /**
     * @internal
     */
    ngOnInit(): void;
    /**
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Removes the sort from the selection.
     * @param sortIndex The sort index.
     */
    deleteSortAttribute(sortIndex: number): void;
    /**
     * Called when the user selects a sort.
     * @param selectChange The select change.
     */
    onSortSelectionAdd(selectChange: SelectChange): void;
    /**
     * Called when the user changes a filter attribute.
     * @param selectChange The select change.
     * @param index The index.
     */
    onSortSelectionChange(selectChange: SelectChange, index: number): void;
    /**
     * Called when the user clicks the x button in the sort attribute selection.
     * @param value The value of the attribute selector.
     * @param index The index.
     */
    onAttributeSelectionModelChange(value: SelectChange, index: number): void;
    /**
     * Changes the sort direction.
     * @param attributesIndex The sort index.
     */
    onSortChange(attributesIndex: number): void;
    /**
     * Called when the user drops an element.
     * @param dropElement The drop element.
     */
    onDrop(dropElement: CdkDragDrop<ISelectedSortAttribute[]>): void;
    /**
     * Initializes the sort attributes.
     */
    private initializeSortAttributes;
    /**
     * Emits the sort selections.
     */
    private emitSortSelections;
    /**
     * Auxiliary method to create the attribute options for the selected Attributes.
     * @param selectedAttributeIdentifier The selected attribute identifier.
     */
    private createAttributeOptions;
    /**
     * Auxiliary method to create the attribute options for the selected Attributes.
     * @param selectedAttributeIdentifier The selected attribute identifier.
     */
    private createInitialAttributeOptions;
    /**
     * Resets the copy available attributes.
     */
    private resetCopyAvailableAttributes;
    static ɵfac: i0.ɵɵFactoryDeclaration<SortSelectionComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SortSelectionComponent, "talenra-sort-selection", never, { "availableAttributes": { "alias": "availableAttributes"; "required": false; "isSignal": true; }; "sortSelections": { "alias": "sortSelections"; "required": false; "isSignal": true; }; }, { "sortSelectionsChange": "sortSelectionsChange"; }, never, never, true, never>;
}
