import * as i0 from '@angular/core';
import { signal, Injectable, inject, EventEmitter, input, Component, HostBinding, Input, ChangeDetectorRef, Output, ViewChild, ElementRef, NgZone, numberAttribute, model, DestroyRef, booleanAttribute, output, ChangeDetectionStrategy, computed, effect, NgModule } from '@angular/core';
import { NgTemplateOutlet, AsyncPipe, NgStyle, KeyValuePipe, NgSwitch, NgIf, NgForOf, NgSwitchCase } from '@angular/common';
import * as i1 from '@angular/forms';
import { FormGroup, FormControl, ReactiveFormsModule, FormsModule } from '@angular/forms';
import { IconComponent } from '@talenra/ngx-base/icons';
import * as i1$3 from '@angular/cdk/drag-drop';
import { DragDropModule, moveItemInArray, transferArrayItem, CdkDropListGroup, CdkDrag, CdkDropList, CdkDragHandle, CdkDragPlaceholder } from '@angular/cdk/drag-drop';
import { TooltipDirective } from '@talenra/ngx-base/tooltip';
import { ButtonComponent } from '@talenra/ngx-base/button';
import { CopyContentDirective } from '@talenra/ngx-base/copy-content';
import { PaginatorComponent } from '@talenra/ngx-base/paginator';
import { MatMenuTrigger, MatMenu } from '@angular/material/menu';
import { CheckboxComponent } from '@talenra/ngx-base/checkbox';
import { MessageComponent } from '@talenra/ngx-base/message';
import { QueryBuilderValueType, QueryBuilderOptionOperator, QueryBuilderCondition, QueryBuilderComponent } from '@talenra/ngx-base/query-builder';
import * as i1$2 from 'angular2-draggable';
import { AngularDraggableModule } from 'angular2-draggable';
import { ToggleComponent } from '@talenra/ngx-base/toggle';
import { MenuAnchorDirective, MenuComponent, MenuTitleComponent, MenuSeparatorComponent, MenuLinkComponent } from '@talenra/ngx-base/menu';
import { FormFieldComponent, FormErrorComponent } from '@talenra/ngx-base/form-field';
import { SelectComponent, OptionComponent } from '@talenra/ngx-base/select';
import { MatAccordion, MatExpansionPanel, MatExpansionPanelHeader, MatExpansionPanelTitle } from '@angular/material/expansion';
import * as i1$1 from '@iharbeck/ngx-virtual-scroller';
import { VirtualScrollerModule } from '@iharbeck/ngx-virtual-scroller';
import { InputComponent } from '@talenra/ngx-base/input';
import { validateDate, dateInTheFutureFilter, dateInThePastFilter, DateComponent } from '@talenra/ngx-base/date';
import { BadgeComponent } from '@talenra/ngx-base/badge';
import { ScrollContainerComponent } from '@talenra/ngx-base/scroll-container';
import { deprecationWarning, ClickOutsideDirective } from '@talenra/ngx-base/dev-kit';
import { BehaviorSubject, Subscription, fromEvent, Observable, throttleTime, tap } from 'rxjs';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { SearchFieldComponent, SearchInputComponent } from '@talenra/ngx-base/search';
import { CustomValidators } from '@talenra/ngx-base/user-input-common';
import { MatSnackBar } from '@angular/material/snack-bar';

/**
 * FilterToolbarService is used to share data between the filter toolbar and other components in the library.
 * The calculation of each filter is also done here.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { FilterToolbarService } from '@talenra/ngx-inbox';
 * ```
 */
class FilterToolbarService {
    constructor() {
        /**
         * The filtered and sorted data items.
         * @internal
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.filteredSortedDataItems$ = new BehaviorSubject([]);
        /**
         * The original list of data items inputted by the consuming application.
         * @internal
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.originalDataItems$ = new BehaviorSubject([]);
        /**
         * Value for the active expert filter. If true, the expert filter is active.
         * Tag should be displayed and the expert filter should be shown.
         */
        this.activeExpertFilter = signal(false);
    }
    /**
     * Sets the selectedDataItems subject.
     * @param key The value of the selected data items.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setFilteredSortedDataItems(key) {
        this.filteredSortedDataItems$.next(key);
    }
    /**
     * Sets the dataItemsSubject subject.
     * @param key The value of the unchanged list of data items.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setOriginalDataItems(key) {
        this.originalDataItems$.next(key);
    }
    /**
     * Transforms the active filter to the filter attribute interface.
     * @param activeFilter The active filter.
     * @param selectedAttributes The selected attributes.
     */
    transformFilterAttributeIntoInboxInterface(activeFilter, selectedAttributes) {
        const filterAttributes = [];
        activeFilter.forEach((filter) => {
            // get the filter type
            const filterMode = selectedAttributes.find((elem) => elem.identifier === filter.identifier);
            // single-select
            if (filterMode === undefined) {
                return;
            }
            switch (filterMode.filterMode) {
                case 'text-field':
                    if (typeof filter.value === 'string') {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            operator: 'equal',
                            value: filter.value,
                        });
                    }
                    break;
                case 'single-select':
                    if (typeof filter.value === 'string') {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            operator: 'equal',
                            value: {
                                key: this.getFilterValueKeyFromPossibleOptions(filter.identifier, filter.value),
                                label: filter.value,
                            },
                        });
                    }
                    break;
                case 'multi-select':
                    if (Array.isArray(filter.value)) {
                        const values = [];
                        filter.value.forEach((value) => {
                            if (typeof value === 'string') {
                                values.push({
                                    key: this.getFilterValueKeyFromPossibleOptions(filter.identifier, value),
                                    label: value,
                                });
                            }
                        });
                        filterAttributes.push({
                            identifier: filter.identifier,
                            operator: 'equal',
                            value: values,
                        });
                    }
                    break;
                case 'char-range':
                    if (Array.isArray(filter.value) &&
                        typeof filter.value[0] === 'string' &&
                        typeof filter.value[1] === 'string') {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            operator: 'equal',
                            value: {
                                start: filter.value[0],
                                end: filter.value[1],
                            },
                        });
                    }
                    break;
                case 'number-range':
                    if (Array.isArray(filter.value) &&
                        (typeof filter.value[0] === 'string' || typeof filter.value[0] === 'number') &&
                        (typeof filter.value[1] === 'string' || typeof filter.value[1] === 'number')) {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            operator: 'equal',
                            value: {
                                start: Number(filter.value[0]),
                                end: Number(filter.value[1]),
                            },
                        });
                    }
                    break;
                case 'date-range':
                    if (Array.isArray(filter.value) && filter.value[0] instanceof Date && filter.value[1] instanceof Date) {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            operator: 'equal',
                            value: {
                                start: filter.value[0],
                                end: filter.value[1],
                            },
                        });
                    }
                    break;
                default:
                    break;
            }
        });
        return filterAttributes;
    }
    /**
     * Transforms the active filter to the filter attribute interface.
     * @param activeFilter The active filter.
     * @param selectedAttributes The selected attributes.
     */
    transformFilterAttributeIntoPresetInterface(activeFilter, selectedAttributes) {
        const filterAttributes = [];
        activeFilter.forEach((filter) => {
            // get the filter type
            const filterMode = selectedAttributes.find((elem) => elem.identifier === filter.identifier);
            // single-select
            if (filterMode === undefined) {
                return;
            }
            switch (filterMode.filterMode) {
                case 'text-field':
                    if (typeof filter.value === 'string') {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            value: filter.value,
                        });
                    }
                    break;
                case 'single-select':
                    if (typeof filter.value === 'string') {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            value: filter.value,
                        });
                    }
                    break;
                case 'multi-select':
                    if (Array.isArray(filter.value)) {
                        const values = [];
                        filter.value.forEach((value) => {
                            values.push(value.label);
                        });
                        filterAttributes.push({
                            identifier: filter.identifier,
                            value: values,
                        });
                    }
                    break;
                case 'char-range':
                    const filterValueChar = filter.value;
                    if (typeof filterValueChar !== 'string' &&
                        filterValueChar &&
                        'start' in filterValueChar &&
                        'end' in filterValueChar &&
                        typeof filterValueChar.start === 'string' &&
                        typeof filterValueChar.end === 'string') {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            value: [filterValueChar.start, filterValueChar.end],
                        });
                    }
                    break;
                case 'number-range':
                    const filterValueNumber = filter.value;
                    if (typeof filterValueNumber !== 'string' &&
                        filterValueNumber &&
                        'start' in filterValueNumber &&
                        'end' in filterValueNumber &&
                        typeof filterValueNumber.start === 'number' &&
                        typeof filterValueNumber.end === 'number') {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            value: [filterValueNumber.start, filterValueNumber.end],
                        });
                    }
                    break;
                case 'date-range':
                    const filterValueDate = filter.value;
                    if (typeof filterValueDate !== 'string' &&
                        filterValueDate &&
                        'start' in filterValueDate &&
                        'end' in filterValueDate &&
                        filterValueDate.start instanceof Date &&
                        filterValueDate.end instanceof Date) {
                        filterAttributes.push({
                            identifier: filter.identifier,
                            value: [filterValueDate.start, filterValueDate.end],
                        });
                    }
                    break;
                default:
                    break;
            }
        });
        return filterAttributes;
    }
    /**
     * Get the filter value key from the possible options.
     * @param filterIdentifier
     * @param filterValue
     */
    getFilterValueKeyFromPossibleOptions(filterIdentifier, filterValue) {
        const possibleOptions = this.identifierWithPossibleSelection?.get(filterIdentifier);
        if (possibleOptions) {
            const option = possibleOptions.find((elem) => elem.label === filterValue);
            if (option) {
                return option.key;
            }
        }
        return '';
    }
    /**
     * Gets the combined icon filter key.
     * @param iconInput The icon input to construct the key.
     */
    getIconFilterCombinedKey(iconInput) {
        return 'icon_' + iconInput.icon + '_' + iconInput.identifier;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterToolbarService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterToolbarService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterToolbarService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Provides control and state of the publicly available subjects of the inbox state.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { InboxState } from '@talenra/ngx-inbox';
 * ```
 */
class InboxState {
    constructor() {
        /**
         * Provides the inbox configuration.
         */
        this.inboxConfiguration$ = new BehaviorSubject({});
        /**
         * Provides whether the action menu (mat-menu) is expanded or not.
         * @Usage data items and inbox toolbar
         */
        this.actionMenuExpanded$ = new BehaviorSubject(false);
        /**
         * The actions menu click flag.
         * This flag is used to prevent an infinite loop of the actions menu opening, when the inbox is setting it to true.
         * @internal
         */
        this.actionsMenuClickFlag = new BehaviorSubject(false);
        /**
         * Provides the selected main attributes.
         */
        this.selectedMainAttributesSubject$ = new BehaviorSubject([]);
        /**
         * Provides the selected detail attributes.
         */
        this.selectedDetailAttributesSubject$ = new BehaviorSubject([]);
        /**
         * Provides  all selected attributes.
         */
        this.selectedAllAttributesSubject$ = new BehaviorSubject([]);
        /**
         * Provides the active preset.
         */
        this.activePreset$ = new BehaviorSubject({});
        /**
         * Data items which are filtered and sorted.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.filteredDataItemsSubject$ = new BehaviorSubject([]);
        /**
         * All preSetOptionsGroups which are available.
         * @internal
         */
        this.presetGroups$ = new BehaviorSubject([]);
        /**
         * The preset name of the active view.
         * @internal
         */
        this.activePresetName$ = new BehaviorSubject(['', '']);
        /**
         * The selected tab.
         * @internal
         */
        this.selectedSidePanelTab = signal('attribute-settings');
        /**
         * The active filters, sort and search information.
         */
        this.activeFilterSortSearch = new BehaviorSubject({
            selectedMainAttributes: [],
            selectedDetailAttributes: [],
            filterAttributes: [],
            iconAttributes: [],
            searchText: '',
            sortAttributes: [],
        });
        /**
         * The buffer filters and sort filters which are not saved in the presets.
         * @internal
         */
        this.bufferFilterSort = new BehaviorSubject({
            filterAttributes: [],
            iconFilterAttributes: [],
            sortAttributes: [],
        });
    }
    /**
     * Updates the inbox configuration.
     *
     * @param configuration The new inbox configuration.
     */
    setInboxConfiguration(configuration) {
        this.inboxConfiguration$.next(configuration);
    }
    /**
     * Collapses or expands the side-navigation
     *
     * @param isExpanded Whether the action-menu is expanded or not.
     */
    setActionMenuExpanded(isExpanded) {
        this.actionMenuExpanded$.next(isExpanded);
    }
    /**
     * Sets the actions menu click flag.
     * @param value The value to set.
     * @internal
     */
    setActionsMenuClickFlag(value) {
        this.actionsMenuClickFlag.next(value);
    }
    /**
     * Sets the selected main attributes for the filter toolbar.
     * @param selectedMainAttributes The selected main attributes.
     * @internal
     */
    setSelectedMainAttributesSubject(selectedMainAttributes) {
        this.selectedMainAttributesSubject$.next(selectedMainAttributes);
    }
    /**
     * Sets the selected detail attributes for the filter toolbar.
     * @param selectedDetailAttributes The selected detail attributes.
     * @internal
     */
    setSelectedDetailAttributesSubject(selectedDetailAttributes) {
        this.selectedDetailAttributesSubject$.next(selectedDetailAttributes);
    }
    /**
     * Sets the selected all attributes for the filter toolbar.
     * @param selectedAllAttributes The selected all attributes.
     * @internal
     */
    setSelectedAllAttributesSubject(selectedAllAttributes) {
        this.selectedAllAttributesSubject$.next(selectedAllAttributes);
    }
    /**
     * Sets the active view for the filter toolbar.
     * @param activeView The active view.
     * @internal
     */
    setActivePreset(activeView) {
        this.activePreset$.next(activeView);
    }
    /**
     * Sets the filtered data items.
     * @param filteredDataItems The filtered data items.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setFilteredDataItemsSubject(filteredDataItems) {
        this.filteredDataItemsSubject$.next(filteredDataItems);
    }
    /**
     * Sets the preSetOptionsGroups.
     * @param key The preSetOptionsGroups.
     * @internal
     */
    setPresetGroups(key) {
        this.presetGroups$.next(key);
    }
    /**
     * Sets the active view name.
     * @param key The active view name.
     * @internal
     */
    setActivePresetName(key) {
        this.activePresetName$.next(key);
    }
    /**
     * Sets the active filter sort search.
     * @param key The active filter sort search.
     * @internal
     */
    setActiveFilterSortSearch(key) {
        this.activeFilterSortSearch.next(key);
    }
    /**
     * Sets the buffer filter and sort.
     * @param key The buffer filter and sort.
     * @internal
     */
    setBufferFilterSort(key) {
        this.bufferFilterSort.next(key);
    }
    /**
     * Resets the buffer filter and sort to contain empty maps and arrays.
     * @internal
     */
    resetBufferFilterSort() {
        this.setBufferFilterSort({
            filterAttributes: [],
            iconFilterAttributes: [],
            sortAttributes: [],
        });
    }
    /**
     * Sets the selected side panel tab.
     * @param tab The selected side panel tab.
     */
    setSelectedSidePanelTab(tab) {
        this.selectedSidePanelTab.set(tab);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxState, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxState, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxState, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * DataItemClass necessary to check:
 * - if a string value is contained in all the string attributes of a data item
 * - if a data item is a duplicate
 * - to create the notes from a data item
 * - to get a property from a data item
 * - to format a date to MM/DD/YYYY
 * - to check if a date is invalid
 *
 */
class DataItemsClass {
    /**
     * The charRangeAlphabet is the alphabet that is used for the char range filter.
     * @internal
     */
    static { this.charRangeAlphabet = 'AÀÁÂÃÄÅÆBCÇDÐEÈÉÊËFGHIÌÍÎÏJKLMNÑOÒÓÔÕÖPQRSTUÙÚÛÜVWXYÝÿZ0123456789!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~€‚ƒ„…†‡ˆ‰Š‹ŒŽ‘’“”•–—˜™š›œžŸ¡¢£¤¥¦§¨©ª«¬®¯°±²³´µ¶·¸¹º»¼½¾¿×ØÞßð÷þ'; }
    /**
     * This method is used to create the notes from a data item.
     * @param dataItem The data item to create the notes from.
     * @param iconAttributes The icon attributes to create the notes from.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    createNotesFromDataItem(dataItem, iconAttributes) {
        const notes = [];
        // set custom notes
        if (iconAttributes && iconAttributes.length > 0) {
            iconAttributes.forEach((iconAttribute) => {
                if (iconAttribute.assignmentCondition(dataItem)) {
                    notes.push({
                        identifier: 'icon' + '_' + iconAttribute.icon + '_' + iconAttribute.identifier,
                        note: iconAttribute.displayedString(dataItem),
                        icon: iconAttribute.icon,
                        activeIconColor: iconAttribute.activeIconColor,
                    });
                }
            });
        }
        return notes;
    }
    /**
     * This method is used to get a property from a data item.
     * @param specificDataItem The data item to get the property from.
     * @param label The label of the property to get.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getElemFromDataItemDisplayed(specificDataItem, label) {
        if (!label ||
            this.getProp(specificDataItem, label.split('.')) === null ||
            this.getProp(specificDataItem, label.split('.')) === undefined ||
            this.getProp(specificDataItem, label.split('.')) === '' ||
            this.getProp(specificDataItem, label.split('.')) === ' ') {
            return '–';
        }
        else if (this.getProp(specificDataItem, label.split('.')) instanceof Date) {
            return this.getProp(specificDataItem, label.split('.'))
                .toLocaleDateString('en-GB', { day: 'numeric', month: 'numeric', year: 'numeric' })
                .replace(/\//g, '.');
        }
        return this.getProp(specificDataItem, label.split('.'));
    }
    /**
     * Auxiliary method to get the value of a property from a data item.
     * Returns null, Number, Date or string values.
     * @param specificDataItem The data item to get the property from.
     * @param label The label of the property to get.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getElemFromDataItemValue(specificDataItem, label) {
        if (!label ||
            this.getProp(specificDataItem, label.split('.')) === null ||
            this.getProp(specificDataItem, label.split('.')) === undefined) {
            return null;
        }
        else if (Number(this.getProp(specificDataItem, label.split('.')))) {
            return Number(this.getProp(specificDataItem, label.split('.')));
        }
        else if (!this.isDateInvalid(this.formatDate(this.getProp(specificDataItem, label.split('.'))))) {
            return new Date(this.formatDate(this.getProp(specificDataItem, label.split('.'))));
        }
        return this.getProp(specificDataItem, label.split('.'));
    }
    /**
     * This method is used to set a property from a data item.
     * @param specificDataItem The data item to set the property from.
     * @param label The label of the property to set.
     * @param value The value to set.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setElemFromDataItemValue(specificDataItem, label, value) {
        if (label) {
            this.setProp(specificDataItem, label.split('.'), value);
        }
    }
    /**
     * This method is used to get a property from a data item.
     * @param object The object to get the property from.
     * @param keys The keys of the property to get.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getProp(object, keys) {
        let item = object;
        let index = 0;
        while (index < keys.length && item) {
            item = item[keys[index++]];
        }
        return item;
    }
    /**
     * This method is used to set a property from a data item.
     * @param object
     * @param keys
     * @param value
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setProp(object, keys, value) {
        let item = object;
        let index = 0;
        while (index < keys.length - 1 && item) {
            item = item[keys[index++]];
        }
        if (item) {
            item[keys[index]] = value;
        }
    }
    /**
     * Format a date to MM/DD/YYYY from DD.MM.YYYY.
     * @param date The date to format.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    formatDate(date) {
        if (typeof date === 'string') {
            const dateParts = date.split('.');
            return `${dateParts[1]}/${dateParts[0]}/${dateParts[2]}`;
        }
        return date;
    }
    /**
     * Check if a date is invalid.
     * @param dateString The date to check.
     */
    isDateInvalid(dateString) {
        const date = new Date(dateString);
        return isNaN(date.getTime());
    }
    static startBeforeEnd(startId, endId, allowSame = false) {
        return (control) => {
            let isErrorIf;
            if (control.value[startId] === '' || control.value[endId] === '') {
                isErrorIf = false;
            }
            else if (typeof control.value[startId] === 'number' || typeof control.value[endId] === 'number') {
                if (allowSame) {
                    isErrorIf = Number(control.value[endId]) < Number(control.value[startId]);
                }
                else {
                    isErrorIf = Number(control.value[endId]) <= Number(control.value[startId]);
                }
            }
            else {
                if (allowSame) {
                    isErrorIf = this.sortString(control.value[startId], control.value[endId]) !== 1;
                }
                else {
                    isErrorIf = this.sortString(control.value[startId], control.value[endId]) !== 1;
                }
            }
            if (control.value[startId] && control.value[endId] && isErrorIf) {
                control.get(startId)?.setErrors({ invalidOrder: true });
                control.get(endId)?.setErrors({ invalidOrder: true });
                return { invalidOrder: true };
            }
            control.get(startId)?.setErrors({ invalidOrder: null });
            control.get(endId)?.setErrors({ invalidOrder: null });
            control.get(startId)?.updateValueAndValidity({ onlySelf: true });
            control.get(endId)?.updateValueAndValidity({ onlySelf: true });
            return null;
        };
    }
    /**
     * Sorts the string values.
     * Returns -1 if a is smaller than b.
     * @param a String to compare.
     * @param b String to compare.
     * @internal
     */
    static sortString(a, b) {
        if (a === '' || b === '') {
            return 1;
        }
        if (a === b) {
            return 1;
        }
        // cast null and undefined to empty string
        a = a || '';
        b = b || '';
        // cast the values to upper case
        a = a.toUpperCase();
        b = b.toUpperCase();
        //if the first characters matching the data item attribute and check if start value length is bigger or same as end (e.g. 'ik11' - 'ik115'), return -1
        if (a.length > b.length && a.startsWith(b)) {
            return -1;
        }
        // check if value is after the start range
        // checking via condition (e.g. 'BAU' -> 'BA9' -> 'B9' -> 'b.firstLetter - 1' is not in start of the string)
        // start with last char in string and work to the front
        for (let i = a.length - 1; i > -1; i--) {
            // get position of the char in the alphabet
            const charPositionAlphabet = this.charRangeAlphabet.indexOf(a.charAt(i));
            // create a working string to be able to manipulate it for startWith() function
            let workingString = a;
            if (workingString.substring(0, i + 1) === b) {
                return 1;
            }
            // break loop if first letter of b is reached or if a partial value of b is reached and the second loop has to check
            if (workingString.substring(0, i + 1) === b.substring(0, 1) || b.startsWith(workingString.substring(0, i + 1))) {
                break;
            }
            // iterate through the alphabet from the char position to the front
            for (let j = charPositionAlphabet + 1; j < this.charRangeAlphabet.length; j++) {
                // construct the working string of the previous values to check if the value starts with it
                // removing the last char if all possible values are checked of alphabet are checked
                workingString = this.replaceCharAt(workingString, i, this.charRangeAlphabet[j]);
                // break loop if first letter of b is reached or if a partial value of b is reached and the second loop has to check
                if (workingString.substring(0, i + 1) === b.substring(0, 1) ||
                    b.startsWith(workingString.substring(0, i + 1))) {
                    return 1;
                }
            }
        }
        // check if value is before the end range
        // checking via condition (e.g. 'THEO' -> 'THEA' -> 'THA' -> 'TA')
        // start with last char in string and work to the front
        for (let i = b.length - 1; i > 0; i--) {
            // get position of the char in the alphabet
            const charPositionAlphabet = this.charRangeAlphabet.indexOf(b.charAt(i));
            // create a working string to be able to manipulate it for startWith() function
            let workingString = b;
            if (workingString.substring(0, i + 1) === a) {
                return 1;
            }
            // break loop if first letter of a is reached or if a partial value of a is reached and the first loop checked it
            if (workingString.substring(0, i + 1) === a.substring(0, 1) || a.startsWith(workingString.substring(0, i + 1))) {
                break;
            }
            // iterate through the alphabet from the char position to the back
            for (let j = charPositionAlphabet - 1; j > -1; j--) {
                // construct the working string of the previous values to check if the value starts with it
                // removing the last char if all possible values are checked of alphabet are checked
                workingString = this.replaceCharAt(workingString, i, this.charRangeAlphabet[j]);
                // break loop if first letter of a is reached or if a partial value of a is reached and the first loop checked it
                if (workingString.substring(0, i + 1) === a.substring(0, 1) ||
                    a.startsWith(workingString.substring(0, i + 1))) {
                    return 1;
                }
            }
        }
        return -1;
    }
    /**
     * Replaces specific char in a string at a specific index.
     * @param str String to replace char in.
     * @param index Index where to replace in str.
     * @param replacement Replacement char.
     * @internal
     */
    static replaceCharAt(str, index, replacement) {
        return str.substring(0, index) + replacement + str.substring(index + replacement.length);
    }
}

/**
 * The message types emitted by the IInteractedDataItems.
 */
const InteractedDataItemsMessageTypes = {
    Process: 'process',
    More: 'more',
    Example: 'example',
};

/**
 * Provides control and state of the publicly available subjects of the inbox detail view.
 *
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { InboxDetailViewService } from '@talenra/ngx-inbox';
 * ```
 */
class InboxDetailViewService {
    constructor() {
        /**
         * Provides whether the inbox detail view side panel is expanded. Note that the state
         * (collapsed or expanded) is kept even if the current layout does not involve
         * the inbox detail view side panel.
         */
        this.detailViewExpanded$ = new BehaviorSubject(false);
        /**
         * Provides the selectedItem's state (current item).
         */
        this.selectedDetailViewTab$ = new BehaviorSubject('1');
        /**
         * Provides the state whether the inbox note box is expanded.
         */
        this.noteBoxExpanded$ = new BehaviorSubject(true);
    }
    /**
     * Collapses or expands the inbox detail view.
     *
     * @param isExpanded Whether the inbox detail view is expanded or not.
     */
    setDetailViewExpanded(isExpanded) {
        this.detailViewExpanded$.next(isExpanded);
    }
    /**
     * Updates the current selected item.
     *
     * @param key The key of the selected item (has to be a string from '1','2', '3' ... to the last tab).
     */
    setSelectedDetailViewTab(key) {
        this.selectedDetailViewTab$.next(key);
    }
    /**
     * Collapses or expands the inbox note box.
     *
     * @param isExpanded Whether the note box is expanded or not.
     */
    setNoteBoxExpanded(isExpanded) {
        this.noteBoxExpanded$.next(isExpanded);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxDetailViewService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxDetailViewService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxDetailViewService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Provides control and state of the publicly available subjects of the inbox data items.
 *
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { DataItemsService } from '@talenra/ngx-inbox';
 * ```
 */
class DataItemsService {
    constructor() {
        /**
         * Provides the state for the active data item (current item).
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.activeDataItem$ = new BehaviorSubject(null);
        /**
         * Provides the state for the selected data items in data items list.
         * @internal
         */
        this.selectedDataItemsIdList$ = new BehaviorSubject([]);
        /**
         * Provides the height of the scrollable content, all the items cumulated.
         * @internal
         */
        this.virtualScrollerScrollableContentHeight$ = new BehaviorSubject(0);
        /**
         * Provides the height of the virtual scroller, the possible space.
         * @internal
         */
        this.virtualScrollerHeight$ = new BehaviorSubject(0);
        /**
         * Provides whether the data-items-list is compressed.
         */
        this.compressedDataItem$ = new BehaviorSubject(false);
    }
    /**
     * Updates the current state for the active data item.
     * @param selection The selected data item.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setActiveDataItem(selection) {
        this.activeDataItem$.next(selection);
    }
    /**
     * Updates the current state for the selected data-items-list.
     * @param selection The selected data items.
     */
    setSelectedIdDataItemsList(selection) {
        this.selectedDataItemsIdList$.next(selection);
    }
    /**
     * Sets the height of the cumulated items of the virtual scroller.
     * @param value The cumulated height of the virtual scroller content.
     * @internal
     */
    setVirtualScrollerScrollableContentHeight(value) {
        this.virtualScrollerScrollableContentHeight$.next(value);
    }
    /**
     * Sets the height of the virtual scroller, the possible space.
     * @param value The height of the possible space for the virtual scroller.
     * @internal
     */
    setVirtualScrollerHeight(value) {
        this.virtualScrollerHeight$.next(value);
    }
    /**
     * Compress or inflate data-items-list
     * @param isCompressed Whether the data-items-list is compressed or not.
     */
    setCompressedDataItem(isCompressed) {
        this.compressedDataItem$.next(isCompressed);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DataItemsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DataItemsService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DataItemsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

var CheckboxState;
(function (CheckboxState) {
    CheckboxState["Indeterminate"] = "indeterminate";
    CheckboxState["Outline"] = "outline";
    CheckboxState["Checked"] = "checked";
})(CheckboxState || (CheckboxState = {}));

/**
 * Provides control and state of the publicly available subjects of the inbox toolbar.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { InboxToolbarService } from '@talenra/ngx-inbox';
 * ```
 */
class InboxToolbarService {
    constructor() {
        /**
         * Number of data items which are currently selected.
         * Used to display the number of selected items in the toolbar as badge for the checkbox.
         * The value overwrites the default badge value.
         *
         * If default badge value should be used set the value to -1.
         * The value is set to 0 if no items are selected.
         * If the value is greater than 0 the badge is displayed with the value.
         * If the value is greater than 1 the ellipsis and arrow buttons are enabled.
         * If the value is greater than 99 the badge will display the value 99+.
         */
        this.selectedItemsCount$ = new BehaviorSubject(-1);
        /**
         * Determines whether configuration panel is expanded.
         * @internal
         */
        this.configurationPanelExpanded$ = new BehaviorSubject(false);
        /**
         * The input is used to change the state of the toolbar checkbox. The input is an object of `CheckboxState`.
         * If inputted the checkbox functionality of the default data items list gets disabled and the checkboxes are set to the state of the input.
         * To activate the default checkboxes again, set the input to `undefined`.
         */
        this.checkboxState$ = new BehaviorSubject(CheckboxState.Outline);
    }
    /**
     * Setter for the selected items count.
     * @param count The number of selected items.
     */
    setSelectedItemsCount(count) {
        this.selectedItemsCount$.next(count);
    }
    /**
     * Setter for configuration panel state.
     * @param state The state of the configuration panel.
     */
    setConfigurationPanelState(state) {
        this.configurationPanelExpanded$.next(state);
    }
    /**
     * Setter for the checkbox State.
     * @param state The state for the checkbox.
     */
    setCheckboxState(state) {
        this.checkboxState$.next(state);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxToolbarService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxToolbarService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxToolbarService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Provides control and state of the publicly available subjects of the presets.
 *
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { PresetsService } from '@talenra/ngx-inbox';
 * ```
 */
class PresetsService {
    constructor() {
        /**
         * The drag drop group and preset subject.
         * TODO: check what this does
         * @internal
         */
        this.dragDropGroupAndPreset$ = new BehaviorSubject([]);
        /**
         * The boolean if the view menu is open.
         */
        this.presetMenuOpen = new BehaviorSubject(false);
        /**
         * The inbox state service.
         * @internal
         */
        this.inboxState = inject(InboxState);
    }
    /**
     * The setter for the drag drop group and preset.
     * @param event the event
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setDragDropPresetAndGroup(event) {
        this.dragDropGroupAndPreset$.next(event);
    }
    /**
     * Setter for the view menu state.
     * @param state The state of the view menu.
     * @internal
     */
    setPresetMenuState(state) {
        this.presetMenuOpen.next(state);
    }
    /**
     * Find all preset names that are already used
     * @param groupName the name of the group
     * @param presetName the name of the preset
     * @returns all preset names that are already used
     * @internal
     */
    presetNamesThatAreAlreadyUsed(groupName, presetName) {
        if (!groupName || !presetName) {
            return [];
        }
        const group = this.findPresetGroupByName(groupName);
        if (!group) {
            return [];
        }
        const allNames = group.presets.map((preset) => preset.name);
        this.removePresetName(allNames, presetName);
        return allNames;
    }
    /**
     * Find the index of the first changeable preset inside a group
     * @returns the index of the first changeable preset
     * @internal
     */
    findIndexOfFirstChangeablePreset(groupName) {
        const presetsOfGroup = this.getPresetsForGroup(groupName);
        return presetsOfGroup.findIndex((preset) => preset.changeable === true);
    }
    /**
     * Find the index of the last changeable preset.
     * @internal
     */
    findIndexOfLastChangeablePreset(groupName) {
        const presetGroup = this.getPresetsForGroup(groupName);
        const reversedOptions = [...presetGroup].reverse();
        const preIndex = reversedOptions.findIndex((preset) => preset.changeable === true);
        return presetGroup.length - preIndex - 1;
    }
    /**
     * Find the index of a preset inside a group
     * @param groupName the name of the group
     * @param presetName the name of the preset
     * @returns the index of the preset
     * @internal
     */
    findPositionOfPreset(groupName, presetName) {
        const presetGroup = this.getPresetsForGroup(groupName);
        return presetGroup.findIndex((preset) => preset.name === presetName);
    }
    /**
     * Check if a group is changeable
     * @param groupName the name of the group
     * @returns true if the group is changeable
     * MOST GROUPS ARE NOT CHANGEABLE
     * @internal
     */
    hasChangeablePreset(groupName) {
        const presetGroup = this.inboxState.presetGroups$.value.find((group) => group.groupName === groupName);
        return !!presetGroup?.presets.some((preset) => preset.changeable);
    }
    /**
     * To check if the preset is changeable or not.
     * @param groupName the name of the group
     * @param presetName the name of the preset
     * @returns true if the preset is changeable
     * @internal
     */
    checkIfChangeablePreset(groupName, presetName) {
        const presetToCheck = this.inboxState.presetGroups$.value
            .find((group) => group.groupName === groupName)
            ?.presets.find((preset) => preset.name === presetName && (preset.changeable === false || preset.changeable === undefined));
        return !presetToCheck;
    }
    /**
     * Find a whole group with all presets by the name of the group
     * @param groupName the name of the group
     * @returns the whole group
     * @internal
     */
    findPresetGroupByName(groupName) {
        return this.inboxState.presetGroups$.value.find((group) => group.groupName === groupName);
    }
    /**
     * Remove a preset from a group
     * @param presetNamesGroup the presetNamesGroup of the presets in the group
     * @param presetName the name of the preset to remove
     * @internal
     */
    removePresetName(presetNamesGroup, presetName) {
        const index = presetNamesGroup.indexOf(presetName);
        if (index !== -1) {
            presetNamesGroup.splice(index, 1);
        }
    }
    /**
     * Find only the presets of a group
     * @param groupName the name of the group
     * @returns the presets of the group
     * @internal
     */
    getPresetsForGroup(groupName) {
        const group = this.inboxState.presetGroups$.value.find((group) => group.groupName === groupName);
        return group?.presets || [];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: PresetsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: PresetsService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: PresetsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Service to handle keyboard events.
 * Specific key are registered and propagated to the components.
 * Specific keys are subscribable.
 */
class KeyboardService {
    /**
     * Constructor of the service.
     * @internal
     */
    constructor() {
        /**
         * Class to interact with data-items-list-data.
         */
        this.dataItemsClass = new DataItemsClass();
        /**
         * Data Items which are filtered by the search
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.searchedDataItems = [];
        /**
         *  Value to what value is to be scrolled in the data-item-list
         */
        this.scrollToIndex = 0;
        /**
         * Some icon buttons are disabled at the moment
         */
        this.disabledButtonNoDataItemFound = false;
        /**
         * The boolean if the shift key is pressed.
         */
        this.shiftKeyPressed = new BehaviorSubject(false);
        /**
         * The boolean if the meta key is pressed.
         */
        this.metaKeyPressed = new BehaviorSubject(false);
        /**
         * The boolean if the control key is pressed.
         */
        this.controlKeyPressed = new BehaviorSubject(false);
        /**
         * The boolean if the escape key is pressed.
         */
        this.escapeKeyPressed = new BehaviorSubject(false);
        /**
         * The boolean if the enter key is pressed.
         */
        this.enterKeyPressed = new BehaviorSubject(false);
        /**
         * The boolean if the v key is pressed.
         */
        this.vKeyPressed = new BehaviorSubject(false);
        /**
         * Determines whether arrowLeft key is pressed.
         */
        // Has to be behaviorSubject and not signal because of infinite loop in effect.
        this.arrowLeftKeyPressed = new BehaviorSubject(false);
        /**
         * The boolean if the arrowRight key is pressed.
         */
        // Has to be behaviorSubject and not signal because of infinite loop in effect.
        this.arrowRightKeyPressed = new BehaviorSubject(false);
        /**
         * The boolean if the big detail view is shown.
         */
        this.bigDetailViewScreen = new BehaviorSubject(false);
        /**
         * The boolean if data item list is refreshing.
         */
        this.refreshing = false;
        /**
         * The state of the inbox.
         */
        this.inboxState = inject(InboxState);
        /**
         * The public service of the inbox detail viewe.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
        /**
         * The public service of the data items.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * The public service of the inbox toolbar.
         */
        this.inboxToolbarService = inject(InboxToolbarService);
        /**
         * The public service of the filter toolbar.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        /**
         * The public service of the presets.
         */
        this.presetsService = inject(PresetsService);
        /**
         * The timeout length for the keys.
         * Used to set the timeout for the keys.
         */
        this.timeOutLength = 3000;
        /**
         * The subscriptions of the service.
         * @internal
         */
        this.subscriptions = new Subscription();
        const keyDown$ = fromEvent(document, 'keydown');
        const keyUp$ = fromEvent(document, 'keyup');
        this.subscriptions.add(keyDown$.subscribe((event) => this.keyDownEvent(event)));
        this.subscriptions.add(keyUp$.subscribe((event) => this.keyUpEvent(event)));
        // handler for view menu state
        this.subscriptions.add(this.presetsService.presetMenuOpen.subscribe((state) => {
            if (state) {
                this.closeAllMenus('view');
            }
        }));
        // Handler for configuration panel state
        this.subscriptions.add(this.inboxToolbarService.configurationPanelExpanded$.subscribe((state) => {
            if (state) {
                this.closeAllMenus('attribute');
            }
        }));
        // handler for action menu state
        this.subscriptions.add(this.inboxState.actionMenuExpanded$.subscribe((state) => {
            if (state) {
                this.closeAllMenus('action');
            }
        }));
    }
    /**
     * Unsubscribes all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
    }
    /**
     * Registers key click and propagate to components.
     * @param {KeyboardEvent} event Clicked Key.
     */
    keyUpEvent(event) {
        const isInput = document.activeElement?.tagName === 'INPUT' || document.activeElement?.tagName === 'TEXTAREA';
        if (!isInput && !this.inboxState.inboxConfiguration$.value.disableKeyBoardInputInbox && !this.refreshing) {
            switch (event.key) {
                case 'Escape':
                    this.escapeKeyPressed.next(false);
                    break;
                case 'Enter':
                    this.enterKeyPressed.next(false);
                    break;
                case 'Meta':
                    this.metaKeyPressed.next(false);
                    // clear the timeout for the control key, to prevent multiple control key timeouts
                    clearTimeout(this.timeoutMetaId);
                    break;
                case 'Shift':
                    this.shiftKeyPressed.next(false);
                    // clear the timeout for the control key, to prevent multiple control key timeouts
                    clearTimeout(this.timeoutShiftId);
                    break;
                case 'Control':
                    this.controlKeyPressed.next(false);
                    // clear the timeout for the control key, to prevent multiple control key timeouts
                    clearTimeout(this.timeoutControlId);
                    break;
                case 'ArrowRight':
                    this.arrowRightKeyPressed.next(false);
                    break;
                case 'ArrowLeft':
                    this.arrowLeftKeyPressed.next(false);
                    break;
                case 'y':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        !this.inboxState.actionMenuExpanded$.value &&
                        !this.inboxState.inboxConfiguration$.value.disableDetailView &&
                        !this.inboxToolbarService.configurationPanelExpanded$.value) {
                        if (!this.disabledButtonNoDataItemFound) {
                            this.closeAllMenus();
                            if (this.inboxDetailViewService.detailViewExpanded$.value && this.iconBtnFunction) {
                                this.iconBtnFunction('vertical-split');
                            }
                            else if (this.iconBtnFunction) {
                                this.iconBtnFunction('reorder');
                            }
                        }
                    }
                    break;
                case 'i':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        !this.inboxState.actionMenuExpanded$.value &&
                        !this.inboxToolbarService.configurationPanelExpanded$.value) {
                        this.dataItemsService.setCompressedDataItem(!this.dataItemsService.compressedDataItem$.value);
                    }
                    break;
                case 'v':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        this.vKeyPressed.value &&
                        !this.inboxState.inboxConfiguration$.value.disablePresetMenuToolbar &&
                        !this.inboxToolbarService.configurationPanelExpanded$.value) {
                        this.vKeyPressed.next(false);
                    }
                    break;
                case 'b':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        !this.inboxState.actionMenuExpanded$.value &&
                        !this.inboxToolbarService.configurationPanelExpanded$.value) {
                        if (this.inboxDetailViewService.detailViewExpanded$.value &&
                            !this.inboxState.inboxConfiguration$.value.disableDetailView) {
                            this.closeAllMenus();
                            this.bigDetailViewScreen.next(!this.bigDetailViewScreen.value);
                        }
                    }
                    break;
            }
        }
    }
    /**
     * Registers key click and propagate to components.
     * @param {KeyboardEvent} event Clicked Key.
     */
    keyDownEvent(event) {
        const isInput = document.activeElement?.tagName === 'INPUT' || document.activeElement?.tagName === 'TEXTAREA';
        if (!isInput && !this.inboxState.inboxConfiguration$.value.disableKeyBoardInputInbox && !this.refreshing) {
            switch (event.key) {
                case 'ArrowRight':
                    this.arrowRightKeyPressed.next(true);
                    break;
                case 'ArrowLeft':
                    this.arrowLeftKeyPressed.next(true);
                    break;
                case 'ArrowDown':
                    if (!this.inboxToolbarService.configurationPanelExpanded$.value) {
                        this.escapeKeyPressed.next(true);
                        this.escapeKeyPressed.next(false);
                        let indexDown = this.searchedDataItems.findIndex((x) => x['inboxId'] === this.dataItemsService.activeDataItem$.value['inboxId']) + 1;
                        indexDown > this.searchedDataItems.length - 1 && (indexDown = this.searchedDataItems.length - 1);
                        const toIndexDown = this.getNextDataItemIndex(indexDown, 1);
                        // check if the next data item is selectable
                        if (toIndexDown !== -2 && this.dataItemSelectedFunction) {
                            this.dataItemSelectedFunction(this.searchedDataItems[toIndexDown]);
                            this.scrollToIndex = toIndexDown;
                        }
                    }
                    break;
                case 'ArrowUp':
                    if (!this.inboxToolbarService.configurationPanelExpanded$.value) {
                        this.escapeKeyPressed.next(true);
                        this.escapeKeyPressed.next(false);
                        let indexUp = this.searchedDataItems.findIndex((x) => x['inboxId'] === this.dataItemsService.activeDataItem$.value['inboxId']) - 1;
                        indexUp < 0 && (indexUp = 0);
                        const toIndexUp = this.getNextDataItemIndex(indexUp, -1);
                        // check if the next data item is selectable
                        if (toIndexUp !== -2 && this.dataItemSelectedFunction) {
                            this.dataItemSelectedFunction(this.searchedDataItems[toIndexUp]);
                            this.scrollToIndex = toIndexUp;
                        }
                    }
                    break;
                case 'Escape':
                    this.escapeKeyPressed.next(true);
                    break;
                case 'Meta':
                    this.metaKeyPressed.next(true);
                    // clear the timeout for the meta key and set a new one, to prevent the meta key from being stuck (e.g. when the window is not focused)
                    clearTimeout(this.timeoutMetaId);
                    this.timeoutMetaId = setTimeout(() => {
                        this.metaKeyPressed.next(false);
                    }, this.timeOutLength);
                    break;
                case 'Shift':
                    this.shiftKeyPressed.next(true);
                    // clear the timeout for the shift key and set a new one, to prevent the shift key from being stuck (e.g. when the window is not focused)
                    clearTimeout(this.timeoutShiftId);
                    this.timeoutShiftId = setTimeout(() => {
                        this.shiftKeyPressed.next(false);
                    }, this.timeOutLength);
                    break;
                case 'Enter':
                    this.enterKeyPressed.next(true);
                    if (!this.presetsService.presetMenuOpen.value &&
                        !this.inboxToolbarService.configurationPanelExpanded$.value) {
                        if (this.dataItemsService.selectedDataItemsIdList$.value.length > 0 && this.dataItemsInteractions) {
                            this.dataItemsInteractions.emit({
                                dataItems: this.getBulkDataItemsList(this.searchedDataItems, this.dataItemsService.selectedDataItemsIdList$.value),
                                message: InteractedDataItemsMessageTypes.Process,
                            });
                        }
                        else if (this.iconBtnFunction) {
                            this.iconBtnFunction('arrow-forward');
                        }
                    }
                    break;
                case 'Control':
                    this.controlKeyPressed.next(true);
                    // clear the timeout for the control key and set a new one, to prevent the control key from being stuck (e.g. when the window is not focused)
                    clearTimeout(this.timeoutControlId);
                    this.timeoutControlId = setTimeout(() => {
                        this.controlKeyPressed.next(false);
                    }, this.timeOutLength);
                    break;
                case 'y':
                    if (this.metaKeyPressed.value && !this.inboxToolbarService.configurationPanelExpanded$.value) {
                        this.metaKeyPressed.next(false);
                    }
                    break;
                case 'v':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        !this.vKeyPressed.value &&
                        !this.inboxState.actionMenuExpanded$.value &&
                        !this.inboxState.inboxConfiguration$.value.disablePresetMenuToolbar &&
                        !this.inboxToolbarService.configurationPanelExpanded$.value) {
                        this.vKeyPressed.next(true);
                    }
                    break;
                case 'x':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        !this.inboxState.actionMenuExpanded$.value &&
                        !this.inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {
                        this.handleSidePanel('attribute-settings');
                    }
                    break;
                case 'f':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        !this.inboxState.actionMenuExpanded$.value &&
                        !this.inboxState.inboxConfiguration$.value.disableFilterSelection) {
                        this.handleSidePanel('filter');
                    }
                    break;
                case 's':
                    if (!this.metaKeyPressed.value &&
                        !this.controlKeyPressed.value &&
                        !this.inboxState.actionMenuExpanded$.value &&
                        !this.inboxState.inboxConfiguration$.value.disableSortSelection) {
                        this.handleSidePanel('sort');
                    }
                    break;
            }
        }
    }
    /**
     * Get the next possible selected data item.
     * If returned -2 the next data item is not selectable.
     * @param index The index of the current selected data item.
     * @param direction The direction of the next data item (1 = down, -1 = up).
     */
    getNextDataItemIndex(index, direction) {
        let newIndex = index;
        // check for locked data items
        if (this.lockedDataItems &&
            this.lockedDataItems.filter((item) => this.dataItemsClass.getElemFromDataItemDisplayed(this.searchedDataItems[index], item.identifier) ===
                item.value).length > 0) {
            newIndex = this.getNextDataItemIndex(index + direction, direction);
        }
        // check for the start of the list
        if (index < 0) {
            // check for positive index
            return -2;
        }
        // check for the end of the list
        if (index > this.searchedDataItems.length - direction) {
            // check for negative index
            return -2;
        }
        return newIndex;
    }
    /**
     * Getter for the list of data items which are chosen in the data items list.
     * @param {any[]} dataItems The list of dataItems.
     * @param {string[]} dataItemsListId The list of data items ids.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getBulkDataItemsList(dataItems, dataItemsListId) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        return dataItems.filter((elem) => {
            let included = false;
            dataItemsListId.forEach((value) => {
                if (elem['inboxId'] === value) {
                    included = true;
                }
            });
            return included;
        });
    }
    /**
     * Closes all mat-menus, attribute-settings and action menu.
     * @param notClose The menu that should not be closed.
     */
    closeAllMenus(notClose) {
        if (notClose !== 'view') {
            this.presetsService.setPresetMenuState(false);
        }
        if (notClose !== 'action') {
            this.inboxState.setActionMenuExpanded(false);
        }
        if (notClose !== 'attribute') {
            this.inboxToolbarService.setConfigurationPanelState(false);
        }
    }
    /**
     * Opens or closes the side panel and sets the correct tab.
     * @param tab The tab to open or close.
     */
    handleSidePanel(tab) {
        // if to close, check if the tab just has to be changed
        if (this.inboxToolbarService.configurationPanelExpanded$.value && tab !== this.inboxState.selectedSidePanelTab()) {
            this.inboxState.setSelectedSidePanelTab(tab);
        }
        else if (this.inboxToolbarService.configurationPanelExpanded$.value &&
            tab === this.inboxState.selectedSidePanelTab()) {
            this.inboxToolbarService.setConfigurationPanelState(!this.inboxToolbarService.configurationPanelExpanded$.value);
        }
        // if not open yet, open the side panel with the tab
        else if (!this.inboxToolbarService.configurationPanelExpanded$.value) {
            this.inboxState.setSelectedSidePanelTab(tab);
            this.inboxToolbarService.setConfigurationPanelState(!this.inboxToolbarService.configurationPanelExpanded$.value);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: KeyboardService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: KeyboardService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: KeyboardService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [] });

class FilterStateService {
    constructor() {
        /**
         * The simple filter subject.
         */
        this.simpleFilterSubject$ = new BehaviorSubject([]);
        /**
         * The sort subject.
         */
        this.sortSubject$ = new BehaviorSubject([]);
        /**
         * The icon filter subject.
         */
        this.iconFilterSubject$ = new BehaviorSubject([]);
        /**
         * The filter and sort changed in comparison to emitted state signal.
         */
        this.filterAndSortChangedInComparisonToEmittedState = signal(false);
        /**
         * Contains the signal if any range filter has a false order.
         * Contains the key of each range filter with a false order.
         */
        this.falseOrderRangeFilter = new BehaviorSubject([]);
    }
    /**
     * Sets the simple filter subject.
     * @param key The simple filter subject.
     */
    setSimpleFilterSubject(key) {
        this.simpleFilterSubject$.next(key);
    }
    /**
     * Sets the sort subject.
     * @param key The sort subject.
     */
    setSortSubject(key) {
        this.sortSubject$.next(key);
    }
    /**
     * Sets the icon filter subject.
     * @param key The icon filter subject.
     */
    setIconFilterSubject(key) {
        this.iconFilterSubject$.next(key);
    }
    /**
     * Sets the filter and sort changed in comparison to emitted state.
     * @param key The filter and sort changed in comparison to emitted state.
     */
    setFilterAndSortChangedInComparisonToEmittedState(key) {
        this.filterAndSortChangedInComparisonToEmittedState.set(key);
    }
    /**
     * Adds a false order range filter.
     * @param key The key of the range filter to add.
     */
    addFalseOrderRangeFilter(key) {
        this.falseOrderRangeFilter.next([...this.falseOrderRangeFilter.value, key]);
    }
    /**
     * Removes a false order range filter.
     * @param key The key of the range filter to remove.
     */
    removeFalseOrderRangeFilter(key) {
        this.falseOrderRangeFilter.next([...this.falseOrderRangeFilter.value.filter((x) => x !== key)]);
    }
    /**
     * Checks if a false order range filter is contained.
     * @param key The key of the range filter to check.
     */
    containsFalseOrderRangeFilter(key) {
        return this.falseOrderRangeFilter.value.includes(key);
    }
    /**
     * Resets the simple filter selection.
     */
    resetSimpleFilterSelection() {
        this.simpleFilterSubject$.next([]);
    }
    /**
     * Resets the sort selection.
     */
    resetSortSelection() {
        this.sortSubject$.next([]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterStateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterStateService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterStateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * The service to check if the values of the filter and sort are changed in comparison to the default values of the preset.
 * @ignore
 */
class ChangedPresetValuesService {
    constructor() {
        /**
         * The state of the inbox.
         */
        this.inboxState = inject(InboxState);
        /**
         * The state of the inbox.
         */
        this.filterState = inject(FilterStateService);
        /**
         * The state of the inbox.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        /**
         * The subject to check if the attributes are changed in comparison to the active preset.
         */
        this.attributesMainChangedSubject$ = new BehaviorSubject({
            identifier: 'attributesMain',
            changed: false,
        });
        /**
         * The subject to check if the attributes details are changed in comparison to the active preset.
         */
        this.attributesDetailChangedSubject$ = new BehaviorSubject({
            identifier: 'attributesDetail',
            changed: false,
        });
        /**
         * The subject to check if the number of main attributes chosen by the user is changed in comparison to the active preset.
         */
        this.numberMainAttributesChosenByUserChangedSubject$ = new BehaviorSubject({
            identifier: 'numberMainAttributesChosenByUser',
            changed: false,
        });
        /**
         * The subject to check if the sort is changed in comparison to the active preset.
         */
        this.sortChangedSubject$ = new BehaviorSubject({
            identifier: 'sort',
            changed: false,
        });
        /**
         * The subject to check if the icon filter is changed in comparison to the active preset.
         */
        this.iconFilterChangedSubject$ = new BehaviorSubject({
            identifier: 'iconFilter',
            changed: false,
        });
        /**
         * The subject to check if the filter is changed in comparison to the active preset.
         */
        this.filterChangedSubject$ = new BehaviorSubject({
            identifier: 'filter',
            changed: false,
        });
        /**
         * Value if there are changes of the filter and sort from the default values of the preset.
         */
        this.filterSortChangedSubject$ = new BehaviorSubject(false);
    }
    /**
     * Set the attributes changed subject.
     * @param key The key to set the attributes changed subject.
     */
    setAttributesMainChangedSubject(key) {
        this.attributesMainChangedSubject$.next(key);
    }
    /**
     * Set the attributes details changed subject.
     * @param key The key to set the attributes details changed subject.
     */
    setAttributesDetailChangedSubject(key) {
        this.attributesDetailChangedSubject$.next(key);
    }
    /**
     * Set the number of main attributes chosen by the user changed subject.
     * @param key The key to set the number of main attributes chosen by the user changed subject.
     */
    setNumberMainAttributesChosenByUserChangedSubject(key) {
        this.numberMainAttributesChosenByUserChangedSubject$.next(key);
    }
    /**
     * Set the sort changed subject.
     * @param key The key to set the sort changed subject.
     */
    setSortChangedSubject(key) {
        this.sortChangedSubject$.next(key);
    }
    /**
     * Set the icon filter changed subject.
     * @param key The key to set the icon filter changed subject.
     */
    setIconFilterChangedSubject(key) {
        this.iconFilterChangedSubject$.next(key);
    }
    /**
     * Set the filter changed subject.
     * @param key The key to set the filter changed subject.
     */
    setFilterChangedSubject(key) {
        this.filterChangedSubject$.next(key);
    }
    /**
     * Set the filter and sort changed subject.
     * @param key The key to set the filter and sort changed subject.
     */
    setFilterSortChangedSubject$(key) {
        this.filterSortChangedSubject$.next(key);
    }
    /**
     * Checks if icon filter are changed in comparison to the active preset.
     */
    setPresetGroupsAndCompareIfChangedIconFilter() {
        const presetIconFilters = [];
        const selectedIconFiltersOutputType = [];
        // transform selectIconFilters to other type
        this.filterState.iconFilterSubject$.value.forEach((iconFilter) => {
            if (iconFilter.active) {
                selectedIconFiltersOutputType.push({
                    identifier: 'icon_' + iconFilter.icon + '_' + iconFilter.identifier,
                    icon: iconFilter.icon,
                });
            }
        });
        //load preset group to attributes settings
        const matchingGroup = this.inboxState.presetGroups$.value.find((preSetOptionGroup) => preSetOptionGroup.groupName === this.inboxState.activePresetName$.value[0]);
        if (matchingGroup) {
            const filteredPreSetOption = matchingGroup.presets.find((preSetOption) => preSetOption.name === this.inboxState.activePresetName$.value[1]);
            // add preset icon filters to working array
            filteredPreSetOption?.iconAttributes?.forEach((presetIconFilter) => {
                presetIconFilters.push(presetIconFilter);
            });
            // order preset icon filters in order of selected icon filters
            presetIconFilters.sort((a, b) => selectedIconFiltersOutputType.indexOf(a) - selectedIconFiltersOutputType.indexOf(b));
            // compare selected and preset icon filters
            this.setIconFilterChangedSubject({
                identifier: 'iconFilter',
                changed: JSON.stringify(presetIconFilters) !== JSON.stringify(selectedIconFiltersOutputType),
            });
        }
    }
    /**
     * Checks if attributes are changed in comparison to the active preset.
     */
    setPresetGroupsAndCompareIfChangedAttributes(selectedMainAttributes, selectedDetailAttributes, numberMainAttributesChosenByUser, presetGroups) {
        const preSetOptionAttributes = [];
        const preSetOptionAttributesDetail = [];
        const selectedAttributesArray = [];
        const selectedAttributesDetailArray = [];
        let preSetOptionNumberMainAttributesChosenByUser = 0;
        selectedMainAttributes.forEach((selectedAttribute) => {
            selectedAttributesArray.push(selectedAttribute.identifier);
        });
        selectedDetailAttributes.forEach((selectedAttributeDetails) => {
            selectedAttributesDetailArray.push(selectedAttributeDetails.identifier);
        });
        //load preset group to attributes settings
        const matchingGroup = presetGroups?.find((preSetOptionGroup) => preSetOptionGroup.groupName === this.inboxState.activePresetName$.value[0]);
        if (matchingGroup) {
            const filteredPreSetOption = matchingGroup.presets.find((preSetOption) => preSetOption.name === this.inboxState.activePresetName$.value[1]);
            filteredPreSetOption?.selectedAttributes.forEach((selectedAttribute) => {
                if (selectedAttribute.defaultAttribute === 'main') {
                    preSetOptionAttributes.push(selectedAttribute.identifier);
                }
                else if (selectedAttribute.defaultAttribute === 'detail') {
                    preSetOptionAttributesDetail.push(selectedAttribute.identifier);
                }
            });
            if (!filteredPreSetOption?.numberMainAttributesChosenByUser)
                return;
            preSetOptionNumberMainAttributesChosenByUser = filteredPreSetOption?.numberMainAttributesChosenByUser;
        }
        if (JSON.stringify(preSetOptionAttributes) !== JSON.stringify(selectedAttributesArray)) {
            this.setAttributesMainChangedSubject({
                identifier: 'attributesMain',
                changed: true,
            });
        }
        else {
            this.setAttributesMainChangedSubject({
                identifier: 'attributesMain',
                changed: false,
            });
        }
        if (JSON.stringify(preSetOptionAttributesDetail) !== JSON.stringify(selectedAttributesDetailArray)) {
            this.setAttributesDetailChangedSubject({
                identifier: 'attributesDetail',
                changed: true,
            });
        }
        else {
            this.setAttributesDetailChangedSubject({
                identifier: 'attributesDetail',
                changed: false,
            });
        }
        if (numberMainAttributesChosenByUser !== preSetOptionNumberMainAttributesChosenByUser) {
            this.setNumberMainAttributesChosenByUserChangedSubject({
                identifier: 'numberMainAttributesChosenByUser',
                changed: true,
            });
        }
        else {
            this.setNumberMainAttributesChosenByUserChangedSubject({
                identifier: 'numberMainAttributesChosenByUser',
                changed: false,
            });
        }
    }
    /**
     * Function to check if the filter values have changed compared to the values in the preset.
     * If the values have changed, the attributeSortOrFilterUsedSubject$ is set to true.
     */
    checkFilterValuesChangedComparedToValuesInPreset() {
        // check preset groups are available
        if (this.inboxState.activePresetName$ && this.inboxState.activePresetName$.value.length >= 1) {
            // get the active preset groups
            const activePresetGroup = this.inboxState.presetGroups$.value.find((elem) => elem.groupName === (this.inboxState.activePresetName$ && this.inboxState.activePresetName$.value[0]));
            if (activePresetGroup) {
                // get the active preset
                const activePreset = activePresetGroup?.presets?.find((elem) => elem.name === (this.inboxState.activePresetName$ && this.inboxState.activePresetName$.value[1]));
                if (activePreset) {
                    // get all filter attributes from the active preset
                    const transformedFilterAttributesFromPreset = this.filterToolbarService.transformFilterAttributeIntoInboxInterface(activePreset.filterAttributes || [], this.inboxState.selectedAllAttributesSubject$.value);
                    const filterUsedFlag = false;
                    // check if filter values are changed compared to the values in the preset
                    // if the length of the filter attributes is different, the filter values have changed
                    if (transformedFilterAttributesFromPreset.length !== this.filterState.simpleFilterSubject$.value.length) {
                        this.setFilterChangedSubject({
                            identifier: 'filter',
                            changed: true,
                        });
                        return;
                    }
                    // order presets of filter selection to order of presets
                    transformedFilterAttributesFromPreset.sort((a, b) => this.filterState.simpleFilterSubject$.value.indexOf(a) -
                        this.filterState.simpleFilterSubject$.value.indexOf(b));
                    // check if the filter values are changed compared to the values in the preset
                    if (JSON.stringify(transformedFilterAttributesFromPreset) !==
                        JSON.stringify(this.filterState.simpleFilterSubject$.value)) {
                        this.setFilterChangedSubject({
                            identifier: 'filter',
                            changed: true,
                        });
                        return;
                    }
                    this.setFilterChangedSubject({
                        identifier: 'filter',
                        changed: filterUsedFlag,
                    });
                }
            }
        }
    }
    /**
     * Function to check if the sort values have changed compared to the values in the preset.
     */
    checkSortValuesChangedComparedToValuesInPreset() {
        if (this.inboxState.presetGroups$.value && this.inboxState.presetGroups$.value.length > 0) {
            // get the presetGroups of the active preset
            const activeGroup = this.inboxState.presetGroups$.value.find((group) => group.groupName === this.inboxState.activePresetName$.value[0]);
            if (activeGroup) {
                const activePreset = activeGroup.presets.find((option) => option.name === this.inboxState.activePresetName$.value[1]);
                if (JSON.stringify(activePreset?.sortAttributes) !== JSON.stringify(this.filterState.sortSubject$.value)) {
                    this.setSortChangedSubject({
                        identifier: 'sort',
                        changed: true,
                    });
                }
                else {
                    this.setSortChangedSubject({
                        identifier: 'sort',
                        changed: false,
                    });
                }
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ChangedPresetValuesService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ChangedPresetValuesService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ChangedPresetValuesService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class MainFacadeSetterService {
    constructor() {
        /**
         * The emitter for the clicked data item.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.clickedDataItemEmitter = new EventEmitter();
        /**
         * EventEmitter to emit the filter, sort and search values to the consuming application.
         */
        this.filterSortSearchEmitter = new EventEmitter();
        /**
         * The form-group defines the search field, gets passed into the component.
         */
        this.searchField = new FormGroup({
            searchField: new FormControl(''),
        });
        /**
         * The maximum Attributes, which are to be shown in the data-items-list.
         * Further they are divided in the ui.
         * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings.
         * Default value is 12, like chosen in the requirements.
         */
        this.maxMainAttributes = 12;
        /**
         * The maximum Attributes, which are to be shown in the detail-view.
         * Default value is 100, like chosen in the requirements.
         */
        this.maxAttributesDetail = 100;
        /**
         * The list of all attributes generated by the attributes input supplied by the consuming app or generated by the data
         * items if the attributes are not supplied by the consuming application.
         */
        this.allAttributes$ = new BehaviorSubject([]);
        /**
         * The list of all attributes supplied by the consuming app.
         */
        this.allUntransformedAttributes$ = new BehaviorSubject([]);
        /**
         * The number of main attributes chosen by the user.
         * Default value is 12, like chosen in the requirements. Will be overwritten by the consuming app through the view  or inbox configuration.
         */
        this.numberMainAttributesChosenByUser$ = new BehaviorSubject(12);
        /**
         * The selection of icons that are to be used to filter and flag the data items.
         */
        this.iconSelection = [];
        /**
         * The filter selection get from the presets.
         */
        this.filterSelection = [];
        /**
         * The sort selection get from the presets.
         */
        this.sortSelection = [];
        /**
         * The position of the virtual scroller.
         */
        this.virtualScrollerPosition$ = new BehaviorSubject(0);
        /**
         * Flag to check if the detail view is expanded or not and should be opened after data items refresh.
         */
        this.reOpenDetailViewAfterRefresh = undefined;
        /**
         * Filter, Sort and Search emitter buffer element.
         * Saves the previous state of the filter, sort and search.
         * Used to recognize changes in the filter, sort and search and not emit the same state again.
         */
        this.filterSortSearchEmitterBuffer = {
            selectedMainAttributes: [],
            selectedDetailAttributes: [],
            filterAttributes: [],
            iconAttributes: [],
            searchText: '',
            sortAttributes: [],
        };
        /**
         * The subscription for the inbox.
         * @internal
         */
        this.subscriptions = new Subscription();
        /**
         * The subscriptions of the detail view.
         * @internal
         */
        this.detailViewSubscriptions = new Subscription();
        /**
         * The service of the data items.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * The service of the keyboard.
         */
        this.keyboardService = inject(KeyboardService);
        /**
         * The service of the filter toolbar.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        /**
         * The state of the inbox.
         */
        this.inboxState = inject(InboxState);
        /**
         * The state of the inbox.
         */
        this.filterState = inject(FilterStateService);
        /**
         * The service of the inbox detail view.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
        /**
         * Class to interact with data items.
         */
        this.dataItemsClass = new DataItemsClass();
        /**
         * The value if the side panel is to be shown after no results found.
         */
        this.reopenInboxDetailView = undefined;
        /**
         * Data items which are filtered by the search.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.searchedDataItems = [];
        /**
         * Initial Attributes for the detail-view.
         * Used to initialize the attribute to the correct list (detail).
         */
        this.dataItemsListAttributesDetail = [];
        /**
         * Initial Attributes for the data-items-list.
         * Used to initialize the attribute to the correct list (main).
         */
        this.dataItemsListAttributesMain = [];
    }
    /**
     * Set the filter, sort and search emitter.
     * @param filterSortSearchEmitter
     */
    setFilterSortSearchEmitter(filterSortSearchEmitter) {
        this.filterSortSearchEmitter = filterSortSearchEmitter;
    }
    /**
     * Sets the attribute list.
     * @param attributeList The attribute list.
     */
    setAllAttributes(attributeList) {
        this.allAttributes$.next(attributeList);
    }
    /**
     * Sets the untransformed attribute list.
     * @param dataItemAttributes The untransformed attribute list.
     */
    setAllUntransformedAttributes(dataItemAttributes) {
        this.allUntransformedAttributes$.next(dataItemAttributes);
    }
    /**
     * Sets the number of main attributes chosen by the user.
     * @param numberMainAttributesChosenByUser The number of main attributes chosen by the user.
     */
    setNumberMainAttributesChosenByUser(numberMainAttributesChosenByUser) {
        this.numberMainAttributesChosenByUser$.next(numberMainAttributesChosenByUser);
    }
    /**
     * Sets the icon selection.
     * @param iconAttribute The icon selection.
     */
    setIconSelection(iconAttribute) {
        this.iconSelection = iconAttribute;
    }
    /**
     * Sets the virtual scroller position.
     * @param virtualScrollerPosition The virtual scroller position.
     */
    setVirtualScrollerPosition(virtualScrollerPosition) {
        this.virtualScrollerPosition$.next(virtualScrollerPosition);
    }
    /**
     * Sets the detail view tabs after view init of the consuming app.
     * @param detailViewTabsChanges Changes of the detail view tabs.
     */
    resetDetailViewTabs(detailViewTabsChanges) {
        // unsubscribe detailViewTabsSubscriptions
        this.detailViewSubscriptions.unsubscribe();
        this.detailViewSubscriptions.closed = false;
        // working array for the detail view tabs
        let detailViewTabs = [];
        // reset detail view tabs and check if the configuration for the first tab is set
        if (!this.inboxState.inboxConfiguration$.value.disableDetailViewMainTab) {
            detailViewTabs = [
                {
                    icon: 'assignment',
                    key: '1',
                    label: 'attributesSettings',
                    counter: new BehaviorSubject(this.inboxState.selectedDetailAttributesSubject$.value.length),
                    useScroll: true,
                },
            ];
            // updates the badge in the main detail view tab, if no contradicting configuration is set
            this.detailViewSubscriptions.add(this.inboxState.selectedDetailAttributesSubject$.subscribe((value) => {
                detailViewTabs[0].counter?.next(value.length);
            }));
            // set icon for main detail view tab
            if (this.inboxState.inboxConfiguration$.value.detailViewMainTabIcon !== undefined) {
                if (this.inboxState.inboxConfiguration$.value.detailViewMainTabIcon !== '') {
                    detailViewTabs[0].icon = this.inboxState.inboxConfiguration$.value.detailViewMainTabIcon;
                }
                else {
                    detailViewTabs[0].icon = 'assignment';
                }
            }
        }
        // add values to detail view tabs
        detailViewTabsChanges.forEach((value) => {
            const newArray = [...detailViewTabs];
            newArray.push({
                icon: value.icon,
                key: String(detailViewTabs.length + 1),
                counter: value.counter,
                maxCounter: value.maxCounter,
                label: value.label,
                useScroll: value.useScroll,
                detailViewTabContentTemplate: value.detailViewTabContentTemplate,
            });
            detailViewTabs = newArray;
        });
        return detailViewTabs;
    }
    /**
     * Sets the picked attributes for the attributes-settings.
     * Used to initialize the attributeList, if attributes are defined by consuming app.
     */
    setPickedAttributes() {
        // reset the auxiliary iconSelection array
        this.setIconSelection([]);
        // reset state of selected icon filters
        this.filterState.setIconFilterSubject([]);
        // set maxMainAttributes and maxAttributesDetail, if provided by consuming app
        if (this.inboxState.inboxConfiguration$.value.maxAttributesList) {
            this.maxMainAttributes = this.inboxState.inboxConfiguration$.value.maxAttributesList;
        }
        if (this.inboxState.inboxConfiguration$.value.maxAttributesDetailView) {
            this.maxAttributesDetail = this.inboxState.inboxConfiguration$.value.maxAttributesDetailView;
        }
        // set the attributes
        this.allUntransformedAttributes$.value.forEach((value) => {
            const newArray = [...this.allAttributes$.value];
            // reset icon filter state, because of the icon filter is not active
            // later changed in preset
            // important because of call by reference
            value.iconFilter?.active && (value.iconFilter.active = false);
            newArray.push({
                identifier: value.identifier,
                label: value.label,
                checked: new FormGroup({
                    check: new FormControl({ value: false, disabled: false }),
                }),
                filterMode: value.filterMode,
                dateFilterRestriction: value.dateFilterRestriction,
                sortable: value.sortable,
                iconFilter: value.iconFilter,
                filterSelectionOptions: value.filterSelectionOptions,
                allowEmptyDataItemFilter: value.allowEmptyDataItemFilter,
            });
            // set transformed attributes
            this.setAllAttributes(newArray);
            // set string array of data-item-list labels (auxiliary array)
            // decide if attribute is in main list or detail list
            if (value.defaultAttribute &&
                value.defaultAttribute == 'main' &&
                this.dataItemsListAttributesMain.length < this.maxMainAttributes) {
                this.dataItemsListAttributesMain.push(value.identifier);
            }
            else if ((value.defaultAttribute && value.defaultAttribute == 'detail') ||
                (value.defaultAttribute == 'main' && this.dataItemsListAttributesMain.length >= this.maxMainAttributes)) {
                this.dataItemsListAttributesDetail.push(value.identifier);
            }
            // dataItemListAttributes which have an icon filter property are added to the iconAttribute array
            // used to display the correct icons in the filter toolbar and the data items
            if (value.iconFilter && !this.iconSelection.some((elem) => elem.identifier === value.iconFilter?.identifier)) {
                this.setIconSelection([...this.iconSelection, value.iconFilter]);
            }
        });
        // if presets are used the placement of the attributes is set by the presets
        // if no selection in preset is given the default selection is used
        if (this.inboxState.activePreset$.value &&
            this.inboxState.activePreset$.value.selectedAttributes &&
            this.inboxState.activePreset$.value.selectedAttributes?.length !== 0) {
            // reset default selection
            this.dataItemsListAttributesMain = [];
            this.dataItemsListAttributesDetail = [];
            // set string array of data-item-list labels (auxiliary array)
            // decide if attribute is in main list or detail list
            this.inboxState.activePreset$.value.selectedAttributes?.forEach((selectedAttribute) => {
                if (selectedAttribute.defaultAttribute &&
                    selectedAttribute.defaultAttribute === 'main' &&
                    this.dataItemsListAttributesMain.length < this.maxMainAttributes) {
                    this.dataItemsListAttributesMain.push(selectedAttribute.identifier);
                }
                else if (selectedAttribute.defaultAttribute &&
                    (selectedAttribute.defaultAttribute == 'detail' ||
                        (selectedAttribute.defaultAttribute == 'main' &&
                            this.dataItemsListAttributesMain.length >= this.maxMainAttributes))) {
                    this.dataItemsListAttributesDetail.push(selectedAttribute.identifier);
                }
            });
        }
    }
    /**
     * Sets the selected dataItemListAttributes in the attributes-settings-service (SELECTED = CHECKED).
     * The attributes-settings-service is used to communicate with the attributes-settings (main and detail attributes).
     */
    setSelectedAttributeListInsideAttributesSettingsService() {
        // set the selected attributes in the attributes-settings service
        const mainAttributesData = [];
        const detailsAttributesData = [];
        // get values from attribute list which correspond with the picked attributes for main and detail
        this.allAttributes$.value.forEach((value) => {
            if (this.dataItemsListAttributesMain.indexOf(value.identifier) > -1) {
                mainAttributesData.push(value);
            }
            else if (this.dataItemsListAttributesDetail.indexOf(value.identifier) > -1) {
                detailsAttributesData.push(value);
            }
        });
        // sort values of attributes to get set order
        this.determineOrderOfPickedAttributes(mainAttributesData, detailsAttributesData);
        // reset the auxiliary arrays with string labels
        this.dataItemsListAttributesMain = [];
        this.dataItemsListAttributesDetail = [];
        // set the selected attributes in the attributes-settings service
        this.inboxState.setSelectedMainAttributesSubject(mainAttributesData);
        this.inboxState.setSelectedDetailAttributesSubject(detailsAttributesData);
        this.inboxState.setSelectedAllAttributesSubject([...mainAttributesData, ...detailsAttributesData]);
        if (this.inboxState.activePreset$.value.numberMainAttributesChosenByUser) {
            // set the number of main attributes chosen by the user
            this.setNumberMainAttributesChosenByUser(this.inboxState.activePreset$.value.numberMainAttributesChosenByUser);
        }
        else {
            // set the number of main attributes chosen by the user to the value chosen by the consuming app or default value
            this.setNumberMainAttributesChosenByUser(this.inboxState.inboxConfiguration$.value.maxAttributesList
                ? this.inboxState.inboxConfiguration$.value.maxAttributesList
                : 12);
        }
    }
    /**
     * Determines the order of the picked data-item-list attributes.
     * @param mainAttributesData Main attributes.
     * @param detailsAttributesData Detail attributes.
     */
    determineOrderOfPickedAttributes(mainAttributesData, detailsAttributesData) {
        // sort values of attributes to get set order
        mainAttributesData.sort((a, b) => this.dataItemsListAttributesMain.indexOf(a.identifier) - this.dataItemsListAttributesMain.indexOf(b.identifier));
        detailsAttributesData.sort((a, b) => this.dataItemsListAttributesDetail.indexOf(a.identifier) -
            this.dataItemsListAttributesDetail.indexOf(b.identifier));
    }
    /**
     * All changes through the filter-toolbar are subscribed.
     * The displayed data-item-list adept to the filter changes.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setFilterAndSearchSubscriptions(clickedDataItemEmitter) {
        // reset the filter and sort state
        this.filterState.resetSimpleFilterSelection();
        this.filterState.resetSortSelection();
        this.filterSelection = [];
        this.sortSelection = [];
        // reset the active filter, sort and search
        this.inboxState.setActiveFilterSortSearch({
            selectedMainAttributes: [],
            selectedDetailAttributes: [],
            filterAttributes: [],
            iconAttributes: [],
            searchText: '',
            sortAttributes: [],
        });
        // reset search field and subscriptions
        this.searchField.get('searchField')?.setValue('');
        this.subscriptions.unsubscribe();
        this.subscriptions.closed = false;
        this.clickedDataItemEmitter = clickedDataItemEmitter;
        // apply filter changes
        this.subscriptions.add(this.filterToolbarService.filteredSortedDataItems$.subscribe((result) => {
            this.inboxState.setFilteredDataItemsSubject(result);
            // get index of selected data item before filter change
            let itemIndexBefore = 0;
            if (this.dataItemsService.activeDataItem$.value) {
                this.searchedDataItems.find((elem, index) => {
                    if (elem['inboxId'] === this.dataItemsService.activeDataItem$.value['inboxId']) {
                        itemIndexBefore = index;
                    }
                });
            }
            // set the filtered data items as searched data items
            this.searchedDataItems = result;
            this.keyboardService.searchedDataItems = result;
            // get the next available data item index
            let itemIndex = this.keyboardService.getNextDataItemIndex(0, 1);
            // check if the current selected data item is still available
            if (this.dataItemsService.activeDataItem$.value) {
                result.find((elem, index) => {
                    if (elem['inboxId'] === this.dataItemsService.activeDataItem$.value['inboxId']) {
                        itemIndex = index;
                    }
                });
            }
            // if just the index changed, set the new index (only gets accessed if the item is filtered or sorted)
            // sets the first available data item as selected, after filter or sort
            if (itemIndexBefore !== itemIndex) {
                itemIndex = this.keyboardService.getNextDataItemIndex(0, 1);
            }
            // set the new selected data item
            this.clickedDataItemFunction(result[itemIndex], clickedDataItemEmitter);
            // scrolls to the first available data item as selected, after filter or sort
            if (itemIndexBefore !== itemIndex) {
                this.keyboardService.scrollToIndex = itemIndex;
            }
            // handling zero found items
            this.noDataItemsFound();
            // virtual scroller handling to set the position to the top, because no scroll bar is available
            // emits the position of the virtual scroller
            if (this.dataItemsService.virtualScrollerHeight$.value >
                this.dataItemsService.virtualScrollerScrollableContentHeight$.value) {
                this.setVirtualScrollerPosition(-1);
            }
        }));
        this.subscriptions.add(this.searchField.get('searchField')?.valueChanges.subscribe((value) => {
            // check if the search value is null or empty, because of the search field detection
            // if null or empty reset search
            if (!value) {
                this.onSearchFieldChange(value);
            }
        }));
    }
    /**
     * Initializes the data items list.
     * @param dataItems The data items.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    initializeDataItemsList(dataItems) {
        dataItems.forEach((value, index) => {
            value.inboxId = index;
        });
        dataItems.forEach((value) => {
            if (!value.notes) {
                value.notes = this.dataItemsClass.createNotesFromDataItem(value, this.iconSelection);
            }
        });
    }
    /**
     * Handler for the data items when no data items are found.
     * @internal
     */
    noDataItemsFound() {
        // sets the value if no data items are found, to stop interaction with the keyboard
        this.keyboardService.disabledButtonNoDataItemFound = false;
        // check if data items are available
        if (this.keyboardService.dataItemsAvailable && !this.inboxState.inboxConfiguration$.value.disableDataItemsList) {
            // check if the detail view is to be reopened after no data items are found
            if (this.reopenInboxDetailView !== undefined && this.inboxState.filteredDataItemsSubject$.value.length > 0) {
                // if data items are found and the detail view was closed before, the detail view is closed
                if (!this.reopenInboxDetailView) {
                    this.inboxDetailViewService.detailViewExpanded$.value &&
                        this.inboxDetailViewService.setDetailViewExpanded(false);
                }
                // if data items are found and the detail view was opened before, the detail view is opened
                else {
                    !this.inboxDetailViewService.detailViewExpanded$.value &&
                        this.inboxDetailViewService.setDetailViewExpanded(true);
                    this.inboxDetailViewService.detailViewExpanded$.value &&
                        this.inboxDetailViewService.setSelectedDetailViewTab('1');
                }
                // reset the value if the detail view is to be reopened after no data items are found
                this.reopenInboxDetailView = undefined;
            }
            else if (this.inboxState.filteredDataItemsSubject$.value.length === 0) {
                // if no data items are found, the detail view is closed
                this.keyboardService.disabledButtonNoDataItemFound = true;
                // if no data items are found, the detail view state is saved
                if (this.reopenInboxDetailView === undefined) {
                    this.reopenInboxDetailView = this.inboxDetailViewService.detailViewExpanded$.value;
                }
                // if no data items are found, the detail view is closed
                this.inboxDetailViewService.setDetailViewExpanded(false);
            }
        }
    }
    /**
     * Sets the necessary properties in the keyboard-service.
     * Allows the keyboard-service to access the properties of the inbox-component.
     */
    setKeyboardServiceConfiguration(iconBtnFunction, dataItemsInteractions, dataItemsAvailable, 
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    dataItemSelectedFunction, 
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    clickedDataItemEmitter, lockedDataItems) {
        // set the initial attributes and services
        this.keyboardService.iconBtnFunction = iconBtnFunction;
        this.keyboardService.dataItemsInteractions = dataItemsInteractions;
        this.keyboardService.dataItemsAvailable = dataItemsAvailable;
        this.keyboardService.dataItemSelectedFunction = dataItemSelectedFunction;
        this.keyboardService.clickedDataItemEmitter = clickedDataItemEmitter;
        this.keyboardService.lockedDataItems = lockedDataItems;
    }
    /**
     * Sets the default value of expanded detailView, selectedDataItem and selectedItem of detailView.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    setDefaultStateOfInboxLayout(dataItems, clickedDataItemEmitter) {
        // reset set active data item
        this.dataItemsService.setActiveDataItem(undefined);
        // set first available data item as selected if data items are available
        if (dataItems !== undefined && dataItems !== null && dataItems.length > 0) {
            this.clickedDataItemFunction(dataItems[this.keyboardService.getNextDataItemIndex(0, 1)], clickedDataItemEmitter);
        }
        // set the default state of the detail view
        if (!this.inboxState.inboxConfiguration$.value.disableDetailView) {
            // check if detail view is to be expanded after refresh
            if (this.reOpenDetailViewAfterRefresh || this.reOpenDetailViewAfterRefresh === undefined) {
                this.inboxDetailViewService.setDetailViewExpanded(true);
                this.inboxDetailViewService.setSelectedDetailViewTab('1');
                this.reOpenDetailViewAfterRefresh = false;
            }
            else {
                this.reOpenDetailViewAfterRefresh = false;
            }
        }
    }
    /**
     * Handler for the clicked data item.
     * @param dataItem The clicked data item.
     * @param clickedDataItemEmitter The clicked data item emitter.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    clickedDataItemFunction(dataItem, clickedDataItemEmitter) {
        if (dataItem &&
            this.dataItemsService.activeDataItem$.value &&
            dataItem['inboxId'] !== undefined &&
            this.dataItemsService.activeDataItem$.value['inboxId'] !== undefined &&
            dataItem['inboxId'] !== this.dataItemsService.activeDataItem$.value['inboxId']) {
            clickedDataItemEmitter.emit(dataItem);
        }
        else if (dataItem === undefined && this.dataItemsService.activeDataItem$.value !== undefined) {
            clickedDataItemEmitter.emit(dataItem);
        }
        else if (dataItem !== undefined && this.dataItemsService.activeDataItem$.value === undefined) {
            clickedDataItemEmitter.emit(dataItem);
        }
        this.dataItemsService.setActiveDataItem(dataItem);
    }
    /**
     * Function to handle the search field input.
     * @param search The search value.
     */
    onSearchFieldChange(search) {
        // set the active search value in the inbox-state
        const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
        if (search !== activeFilterSortSearch.searchText) {
            if (search === null) {
                activeFilterSortSearch.searchText = '';
            }
            else {
                activeFilterSortSearch.searchText = search;
            }
            this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
            this.publishFilterSortSearch(activeFilterSortSearch);
        }
    }
    /**
     * Emit the filter, sort and search values to the consuming application.
     * Sets buffer element to the current value.
     */
    publishFilterSortSearch(value) {
        // check if the filter, sort and search are changed and the value is not the same as the buffer value
        if (!this.compareFilterSortSearch(value, this.filterSortSearchEmitterBuffer)) {
            // emit the changes in filter, sort and search to the consuming application
            const filterSortSearch = {
                selectedMainAttributes: this.inboxState.selectedMainAttributesSubject$.value,
                selectedDetailAttributes: this.inboxState.selectedDetailAttributesSubject$.value,
                filterAttributes: value.filterAttributes,
                iconAttributes: value.iconAttributes,
                searchText: value.searchText,
                sortAttributes: value.sortAttributes,
            };
            this.filterSortSearchEmitter.emit(filterSortSearch);
            // set the buffer value to the current value
            this.filterSortSearchEmitterBuffer = {
                selectedMainAttributes: this.inboxState.selectedMainAttributesSubject$.value,
                selectedDetailAttributes: this.inboxState.selectedDetailAttributesSubject$.value,
                filterAttributes: value.filterAttributes,
                iconAttributes: value.iconAttributes,
                sortAttributes: value.sortAttributes,
                searchText: value.searchText,
            };
        }
    }
    /**
     * CompareElem is used to compare two elements of the IFilterSortSearch or IInboxFilterSortSearch interface.
     * @param a First element to compare.
     * @param b Second element to compare.
     */
    compareFilterSortSearch(a, b) {
        // compare null values
        if (a === b)
            return true;
        if (a == null || b == null)
            return false;
        // compare search string
        if (a.searchText !== b.searchText)
            return false;
        // compare length of arrays
        if (a.iconAttributes.length !== b.iconAttributes.length)
            return false;
        if ('selectedMainAttributes' in a &&
            'selectedMainAttributes' in b &&
            a.selectedMainAttributes.length !== b.selectedMainAttributes.length)
            return false;
        if ('selectedDetailAttributes' in a &&
            'selectedDetailAttributes' in b &&
            a.selectedDetailAttributes.length !== b.selectedDetailAttributes.length)
            return false;
        // compare icon attributes
        for (let i = 0; i < a.iconAttributes.length; ++i) {
            if (a.iconAttributes[i] !== b.iconAttributes[i])
                return false;
        }
        // compare selectedMainAttributes attributes
        if ('selectedMainAttributes' in a && 'selectedMainAttributes' in b) {
            for (let i = 0; i < a.selectedMainAttributes.length; ++i) {
                if (a.selectedMainAttributes[i] !== b.selectedMainAttributes[i])
                    return false;
            }
        }
        // compare selectedDetailAttributes attributes
        if ('selectedDetailAttributes' in a && 'selectedDetailAttributes' in b) {
            for (let i = 0; i < a.selectedDetailAttributes.length; ++i) {
                if (a.selectedDetailAttributes[i] !== b.selectedDetailAttributes[i])
                    return false;
            }
        }
        // get the filter and sort values, outsourced to a separate function
        const filterSortState = this.compareFilterSort(a, b);
        // set the filter and sort values in flag
        this.filterState.setFilterAndSortChangedInComparisonToEmittedState(filterSortState);
        // check last, compare the filter and sort values, outsourced to a separate function
        return filterSortState;
    }
    /**
     * Compares the filter and sort values between two values.
     * @param a First element to compare.
     * @param b Second element to compare.
     */
    compareFilterSort(a, b) {
        // compare null values
        if (a === b)
            return true;
        if (a == null || b == null)
            return false;
        // compare type of filterAttributes
        if ((Array.isArray(a.filterAttributes) && !Array.isArray(b.filterAttributes)) ||
            (!Array.isArray(a.filterAttributes) && Array.isArray(b.filterAttributes)))
            return false;
        // compare length of arrays
        if (Array.isArray(a.filterAttributes) &&
            Array.isArray(b.filterAttributes) &&
            a.filterAttributes.length !== b.filterAttributes.length)
            return false;
        if (a.sortAttributes.length !== b.sortAttributes.length)
            return false;
        // compare filter attributes
        if (Array.isArray(a.filterAttributes) && Array.isArray(b.filterAttributes)) {
            for (let i = 0; i < a.filterAttributes.length; ++i) {
                const valueA = a.filterAttributes[i].value;
                const valueB = b.filterAttributes[i].value;
                if (!valueA || !valueB) {
                    return false;
                }
                if (a.filterAttributes[i].operator !== b.filterAttributes[i].operator ||
                    a.filterAttributes[i].identifier !== b.filterAttributes[i].identifier) {
                    return false;
                }
                if (JSON.stringify(valueA) !== JSON.stringify(valueB))
                    return false;
            }
        }
        // compare expert filter query
        else {
            // compare query objects
            if (JSON.stringify(a.filterAttributes) !== JSON.stringify(b.filterAttributes))
                return false;
        }
        // compare sort attributes
        for (let i = 0; i < a.sortAttributes.length; ++i) {
            if (a.sortAttributes[i].sort !== b.sortAttributes[i].sort ||
                a.sortAttributes[i].identifier !== b.sortAttributes[i].identifier)
                return false;
        }
        return true;
    }
    /**
     * Initializes the filter and sort state from the preset.
     */
    initializeFilterSortStateFromPreset() {
        // reset the filter and sort state
        this.filterState.resetSimpleFilterSelection();
        this.filterState.resetSortSelection();
        this.filterSelection = [];
        this.sortSelection = [];
        // reset state of selected icon filters
        // not reset icon filter because reset in setPickedAttributes
        this.filterState.setIconFilterSubject([]);
        // reset the active filter, sort and search
        this.inboxState.setActiveFilterSortSearch({
            selectedMainAttributes: [],
            selectedDetailAttributes: [],
            filterAttributes: [],
            iconAttributes: [],
            searchText: '',
            sortAttributes: [],
        });
        // set the filter state from the preset
        if (this.inboxState.activePreset$.value && this.inboxState.activePreset$.value.filterAttributes) {
            const filterAttributesInbox = this.filterToolbarService.transformFilterAttributeIntoInboxInterface(this.inboxState.activePreset$.value.filterAttributes, this.inboxState.selectedAllAttributesSubject$.value);
            // set the filter attributes in the filter state
            this.filterSelection = filterAttributesInbox;
            this.filterState.setSimpleFilterSubject(filterAttributesInbox);
            // set the active filter in FilterSortSearch
            const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
            activeFilterSortSearch.filterAttributes = filterAttributesInbox;
            this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
        }
        // set the sort state from the preset
        if (this.inboxState.activePreset$.value && this.inboxState.activePreset$.value.sortAttributes) {
            const sortAttributes = [];
            // TODO: check for ng100 error when major undo is clicked
            this.inboxState.activePreset$.value.sortAttributes.forEach((sortAttribute) => {
                sortAttributes.push(sortAttribute);
            });
            // set the sort attributes in the filter state
            this.sortSelection = sortAttributes;
            this.filterState.setSortSubject(sortAttributes);
            // set the active sort in FilterSortSearch
            const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
            activeFilterSortSearch.sortAttributes = this.sortSelection;
            this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
        }
        // set the icon filter state from the preset
        if (this.inboxState.activePreset$.value && this.inboxState.activePreset$.value.iconAttributes) {
            const iconAttributes = [];
            this.inboxState.activePreset$.value.iconAttributes.forEach((iconFilterAttribute) => {
                this.iconSelection.forEach((elem) => {
                    // check if the icon filter attribute is active in preset, has to check combined key, because identifier from preset is combined key
                    if ('icon' + '_' + elem.icon + '_' + elem.identifier === iconFilterAttribute.identifier) {
                        elem.active = true;
                        iconAttributes.push(elem);
                    }
                });
            });
            // set the icon filter attributes in the filter state
            this.filterState.setIconFilterSubject(iconAttributes);
            // set the active icon filter in FilterSortSearch
            const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
            activeFilterSortSearch.iconAttributes = this.iconSelection;
            this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: MainFacadeSetterService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: MainFacadeSetterService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: MainFacadeSetterService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Service to update the presets and check if the inbox has changed.
 */
class UpdatePresetsService {
    constructor() {
        /**
         * Containing the current preset action which is to emit to the consuming application.
         */
        this.currentPresetAction$ = new BehaviorSubject({
            operation: 'none',
            groupName: '',
            presetName: '',
            newPresetName: '',
        });
        /**
         * The presets group that are to be emitted to the consuming application.
         */
        this.currentPresetGroup$ = new BehaviorSubject([]);
        /**
         * The preset that is to be renamed.
         * [groupName, presetName, newPresetName]
         */
        this.currentRenamedPreset$ = new BehaviorSubject([]);
        /**
         * The name of the new preset is saved here.
         * [groupName, presetName]
         */
        this.newPresetName$ = new BehaviorSubject([]);
        /**
         * All preset names are saved here.
         */
        this.presetNames$ = new BehaviorSubject([]);
        /**
         * all selected attributes are saved here.
         */
        this.selectedAttributes = [];
        /**
         * The filter toolbar service.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        /**
         * Injected filter state.
         */
        this.filterState = inject(FilterStateService);
        /**
         * Injected changed preset value service.
         */
        this.changeValuePresetService = inject(ChangedPresetValuesService);
        /**
         * The main facade setter service.
         */
        this.mainFacadeSetterService = inject(MainFacadeSetterService);
        /**
         * The inbox state.
         */
        this.inboxState = inject(InboxState);
        /**
         * The selected sort Subjects.
         * TODO: check if value has to be initialized a second time in the service
         * @private
         */
        this.sortSubject = [];
        /**
         * The selected filter Subjects.
         * TODO: check if value can be obtained from the state, not via subscription
         * @private
         */
        this.filterSubject = [];
        /**
         * The selected icon filter Subjects.
         */
        this.iconFilterSubject = [];
    }
    /**
     * Set the current preset action.
     * @param presetAction
     */
    setCurrentPresetAction(presetAction) {
        this.currentPresetAction$.next(presetAction);
    }
    /**
     * Set the current preset action.
     */
    resetCurrentPresetAction() {
        this.currentPresetAction$.next({
            operation: 'none',
            groupName: '',
            presetName: '',
            newPresetName: '',
        });
    }
    /**
     * Set the preset groups.
     * @param presetGroups The presets group.
     */
    setCurrentPresetGroup(presetGroups) {
        this.currentPresetGroup$.next(presetGroups);
    }
    /**
     * Set the current renamed preset.
     * @param renamedPreset The renamed preset. [groupName, presetName, newPresetName]
     */
    setCurrentRenamedPreset(renamedPreset) {
        this.currentRenamedPreset$.next(renamedPreset);
    }
    /**
     * Set the new preset name.
     * @param newPresetName The new preset name. [groupName, presetName]
     */
    setNewPresetName(newPresetName) {
        this.newPresetName$.next(newPresetName);
    }
    /**
     * Set the preset names.
     * @param presetNames The preset names.
     * @private
     */
    setPresetNames(presetNames) {
        this.presetNames$.next(presetNames);
    }
    /**
     * Method to change visibility of preset in preset groups.
     * @param presetName The [groupName, presetName]
     * @param visibility boolean
     */
    changeVisibilityOfPresetInPresets(presetName, visibility) {
        const operation = visibility ? 'visibility-on' : 'visibility-off';
        this.setCurrentPresetAction({ operation, groupName: presetName[0], presetName: presetName[1] });
        this.updatePresetInPresets(presetName, (presets) => ({
            ...presets,
            visible: visibility,
        }));
    }
    /**
     * Method to delete a preset in preset groups.
     * @param presetName The [groupName, presetName]
     */
    deletePresetInPresets(presetName) {
        const newPresets = this.inboxState.presetGroups$.value.map((element) => {
            if (element.groupName === presetName[0]) {
                element.presets = element.presets.filter((preset) => preset.name !== presetName[1]);
            }
            return element;
        });
        const newPresetNames = newPresets.flatMap((element) => element.presets.map((preset) => [element.groupName, preset.name]));
        this.setPresetNames(newPresetNames);
        this.setCurrentPresetAction({
            operation: 'delete',
            groupName: presetName[0],
            presetName: presetName[1],
        });
        this.updatePresetGroupAndNotify(newPresets);
    }
    /**
     * Change the name of a preset.
     * @param presetName The [groupName, presetName, newPresetName]
     */
    renamePresetInPresets(presetName) {
        this.setCurrentPresetAction({
            operation: 'rename',
            groupName: presetName[0],
            presetName: presetName[1],
            newPresetName: presetName[2],
        });
        this.updatePresetInPresets(presetName, (preset) => ({
            ...preset,
            name: presetName[2],
        }));
    }
    /**
     * Method to change the position of presets in preset groups.
     * @param groupName The group name.
     * @param presetName The preset name.
     * @param upOrDown Boolean to indicate if the preset should be moved up or down.
     */
    changePositionOfPresetInPresets(groupName, presetName, upOrDown) {
        const operation = upOrDown ? 'position-down' : 'position-up';
        this.setCurrentPresetAction({ operation, groupName, presetName: presetName });
        const presetGroups = this.inboxState.presetGroups$.value.find((group) => group.groupName === groupName);
        const index = presetGroups?.presets.findIndex((preset) => preset.name === presetName);
        if (index !== undefined && presetGroups?.presets.length) {
            const adjacentIndex = upOrDown ? index + 1 : index - 1;
            const adjacentPresetName = presetGroups?.presets[adjacentIndex]?.name;
            if (adjacentPresetName !== undefined) {
                this.swapPresetInPresets(groupName, presetName, adjacentPresetName);
            }
        }
    }
    /**
     * Method to swap presets in preset groups.
     * @param groupName The group name.
     * @param presetNameOne The first preset name.
     * @param presetNameTwo The second preset name.
     */
    swapPresetInPresets(groupName, presetNameOne, presetNameTwo) {
        const presetGroups = this.inboxState.presetGroups$.value;
        const groupIndex = presetGroups.findIndex((group) => group.groupName === groupName);
        if (groupIndex !== -1) {
            const group = presetGroups[groupIndex];
            const indexPresetOne = group.presets.findIndex((preset) => preset.name === presetNameOne);
            const indexPresetTwo = group.presets.findIndex((preset) => preset.name === presetNameTwo);
            if (indexPresetOne !== -1 && indexPresetTwo !== -1) {
                [group.presets[indexPresetOne], group.presets[indexPresetTwo]] = [
                    group.presets[indexPresetTwo],
                    group.presets[indexPresetOne],
                ];
                this.inboxState.setPresetGroups(presetGroups);
                this.setCurrentPresetGroup(presetGroups);
            }
        }
    }
    /**
     * Method to change the position of presets in preset groups.
     * @param event The position change event. [groupName, presetName, upOrDown]
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    dragDropPresetInPresets(event) {
        this.setCurrentPresetAction({
            operation: 'dragDrop',
            groupName: event[0].groupName,
            presetName: event[1],
        });
        this.inboxState.presetGroups$.value.forEach((group) => {
            if (group.groupName === event[0].groupName) {
                group.presets = event[0].presets;
            }
        });
        this.setCurrentPresetGroup(this.inboxState.presetGroups$.value);
    }
    /**
     * Method to set the new/overwrite preset groups for the preset.
     * @param command The command to execute.
     * @param attributesUsed Boolean to indicate if attributes are used.
     */
    setAllNewSettingsForPreset(command, attributesUsed) {
        // use emitter to send what is happend to the preset
        // determine the operation to execute
        if (command === 'overwrite') {
            if (JSON.stringify(this.inboxState.activePresetName$.value) === JSON.stringify(this.newPresetName$.value)) {
                if (!attributesUsed) {
                    if (this.newPresetName$.value[0] === this.newPresetName$.value[1]) {
                        this.setCurrentPresetAction({
                            operation: 'update',
                            groupName: this.newPresetName$.value[0],
                        });
                    }
                    else {
                        this.setCurrentPresetAction({
                            operation: 'update',
                            groupName: this.newPresetName$.value[0],
                            presetName: this.newPresetName$.value[1],
                        });
                    }
                }
                else {
                    if (this.newPresetName$.value[0] === this.newPresetName$.value[1]) {
                        this.setCurrentPresetAction({
                            operation: 'attribute-update',
                            groupName: this.newPresetName$.value[0],
                        });
                    }
                    else {
                        this.setCurrentPresetAction({
                            operation: 'attribute-update',
                            groupName: this.newPresetName$.value[0],
                            presetName: this.newPresetName$.value[1],
                        });
                    }
                }
            }
            else {
                this.setCurrentPresetAction({
                    operation: 'update & rename',
                    groupName: this.newPresetName$.value[0],
                    newPresetName: this.newPresetName$.value[1],
                });
                this.inboxState.presetGroups$.value.forEach((element) => {
                    if (element.groupName === this.inboxState.activePresetName$.value[0]) {
                        element.presets.forEach((preset) => {
                            if (preset.name === this.inboxState.activePresetName$.value[1]) {
                                preset.name = this.newPresetName$.value[1];
                            }
                        });
                    }
                });
            }
        }
        else if (command === 'create') {
            this.setCurrentPresetAction({
                operation: 'create',
                groupName: this.newPresetName$.value[0],
                presetName: this.newPresetName$.value[1],
            });
        }
        this.setPresetNames(this.inboxState.presetGroups$.value.flatMap((element) => {
            return element.presets.map((preset) => [element.groupName, preset.name]);
        }));
        // get the values from each state
        this.inboxState.selectedMainAttributesSubject$.subscribe((value) => {
            this.selectedAttributesSubject = value;
        });
        this.inboxState.selectedDetailAttributesSubject$.subscribe((value) => {
            this.selectedAttributesDetailsSubject = value;
        });
        this.mainFacadeSetterService.numberMainAttributesChosenByUser$.subscribe((value) => {
            this.numberMainAttributesChosenByUserSubject = value;
        });
        this.allSelectedAttributesSubject = this.inboxState.selectedAllAttributesSubject$.value;
        this.sortSubject = this.filterState.sortSubject$.value;
        this.iconFilterSubject = this.filterState.iconFilterSubject$.value;
        this.filterSubject = this.filterState.simpleFilterSubject$.value;
        // extract the labels of the selected attributes in an array
        // TODO: refactor to use all selected attributes
        let extractedLabelsOfSelectedAttributes = this.selectedAttributesSubject.map((element) => element.identifier);
        extractedLabelsOfSelectedAttributes = extractedLabelsOfSelectedAttributes.concat(this.selectedAttributesDetailsSubject.map((element) => element.identifier));
        this.setMainAttributesToNewPreset(this.selectedAttributesSubject);
        this.setDetailsAttributesToNewPreset(this.selectedAttributesDetailsSubject);
        // BUFFER HANDLING FOR FILTER AND SORT STARTS HERE
        // get the filter and sort attributes from the active preset
        let filterFromActivePreset = this.inboxState.activePreset$.value.filterAttributes;
        let sortFromActivePreset = this.inboxState.activePreset$.value.sortAttributes;
        const iconFilterFromActivePreset = this.inboxState.activePreset$.value.iconAttributes;
        // Filter handling
        // emit the preset filter but check if attributes have been removed in the meantime
        if (filterFromActivePreset &&
            filterFromActivePreset.length > 0 &&
            filterFromActivePreset.some((item) => !extractedLabelsOfSelectedAttributes.includes(item.identifier))) {
            // update filterFromActivePreset to include only selected attributes
            filterFromActivePreset = filterFromActivePreset.filter((item) => extractedLabelsOfSelectedAttributes.includes(item.identifier));
            // transform the filter attributes to the inbox interface
            const transformedFilterFromActivePreset = this.filterToolbarService.transformFilterAttributeIntoInboxInterface(filterFromActivePreset, this.allSelectedAttributesSubject);
            // Update the bufferFilterSort with the filtered attributes
            this.inboxState.bufferFilterSort.value.filterAttributes = transformedFilterFromActivePreset;
            // Set the filter to the new preset
            this.setFilterToNewPreset(filterFromActivePreset);
        }
        // Sort handling
        if (sortFromActivePreset &&
            sortFromActivePreset.length > 0 &&
            sortFromActivePreset.some((item) => !extractedLabelsOfSelectedAttributes.includes(item.identifier))) {
            // Update sortFromActivePreset to include only selected labels
            sortFromActivePreset = sortFromActivePreset.filter((item) => extractedLabelsOfSelectedAttributes.includes(item.identifier));
            // Update sortAttributes in bufferFilterSort
            this.inboxState.bufferFilterSort.value.sortAttributes = sortFromActivePreset;
            // Set the sort filter to the new preset
            this.setSortFilterToNewPreset(sortFromActivePreset);
        }
        // buffer icon filter handling
        if (this.changeValuePresetService.iconFilterChangedSubject$.value.changed) {
            // clear and update iconFilterAttributes buffer
            this.inboxState.bufferFilterSort.value.iconFilterAttributes = [];
            const iconFilterFromActiveState = [];
            this.filterState.iconFilterSubject$.value.forEach((iconFilter) => {
                if (iconFilter.active) {
                    iconFilterFromActiveState.push({
                        identifier: this.filterToolbarService.getIconFilterCombinedKey(iconFilter),
                        icon: iconFilter.icon,
                    });
                }
            });
            this.inboxState.bufferFilterSort.value.iconFilterAttributes = iconFilterFromActiveState;
            // set the icon filter to the new preset
            this.setIconFilterToNewPreset(iconFilterFromActivePreset || []);
        }
        // if the presets are changed through select and unselect of attributes, the filter and sort attributes should not be changed in the new preset
        if (!attributesUsed) {
            // If attributes are deselected, which are necessary for the filter or sort section, then the following sort or filter attributes should be deleted from the preset groups
            this.sortSubject = this.sortSubject.filter((item) => extractedLabelsOfSelectedAttributes.includes(item.identifier));
            // Filter out keys not in labelsArray
            this.filterSubject = this.filterSubject.filter((item) => extractedLabelsOfSelectedAttributes.includes(item.identifier));
            // transforms the active icon filter values to icon filter type in preset
            const iconFilterFromActivePreset = [];
            this.iconFilterSubject.forEach((iconFilter) => {
                if (iconFilter.active) {
                    iconFilterFromActivePreset.push({
                        identifier: this.filterToolbarService.getIconFilterCombinedKey(iconFilter),
                        icon: iconFilter.icon,
                    });
                }
            });
            this.setSortFilterToNewPreset(this.sortSubject);
            this.setFilterToNewPreset(this.filterToolbarService.transformFilterAttributeIntoPresetInterface(this.filterSubject, this.allSelectedAttributesSubject));
            this.setIconFilterToNewPreset(iconFilterFromActivePreset);
        }
        // BUFFER HANDLING FOR FILTER AND SORT ENDS HERE
        this.setVisibilityToNewPreset(true);
        this.setNumberMainAttributesChosenByUserToPreset(this.numberMainAttributesChosenByUserSubject);
        this.setCurrentPresetGroup(this.inboxState.presetGroups$.value);
        this.inboxState.setActivePresetName(this.newPresetName$.value);
    }
    /**
     * Set the main attributes to the new preset.
     * @param event Selected attributes.
     */
    setMainAttributesToNewPreset(event) {
        //presetName which is created in the preset input
        this.selectedAttributes = [];
        if (this.newPresetName$.value[1].length !== 0 && event.length !== 0) {
            //transfer the selected attributes to the new preset with main as default attribute
            event.forEach((element) => {
                this.selectedAttributes.push({
                    identifier: element.identifier,
                    defaultAttribute: 'main',
                });
            });
            // if the new preset is not already used, create a new preset and push to preset groups
            const isArrayInMultidimensionalArray = this.isArrayInMultidimensionalArray(this.presetNames$.value, this.newPresetName$.value);
            if (!isArrayInMultidimensionalArray) {
                const newPreset = {
                    name: this.newPresetName$.value[1],
                    visible: true,
                    changeable: true,
                    numberMainAttributesChosenByUser: 12,
                    selectedAttributes: this.selectedAttributes,
                    sortAttributes: [],
                    filterAttributes: [],
                    iconAttributes: [],
                };
                this.inboxState.presetGroups$.value.forEach((group) => {
                    if (group.groupName === this.newPresetName$.value[0]) {
                        group.presets.push(newPreset);
                    }
                });
                this.presetNames$.value.push(this.newPresetName$.value);
            }
            else {
                this.inboxState.presetGroups$.value.forEach((group) => {
                    if (group.groupName === this.newPresetName$.value[0]) {
                        group.presets.forEach((preset) => {
                            if (preset.name === this.newPresetName$.value[1]) {
                                preset.selectedAttributes = this.selectedAttributes;
                            }
                        });
                    }
                });
                // Set the updated value of the presetGroups$
                this.inboxState.setPresetGroups(this.inboxState.presetGroups$.value);
            }
        }
    }
    /**
     * Set the details attributes to the new preset.
     * @param event Selected attributes.
     */
    setDetailsAttributesToNewPreset(event) {
        this.selectedAttributes = [];
        if (this.newPresetName$.value[1].length !== 0 && event.length !== 0) {
            event.forEach((element) => {
                this.selectedAttributes.push({
                    identifier: element.identifier,
                    defaultAttribute: 'detail',
                });
            });
            const isArrayInMultidimensionalArray = this.isArrayInMultidimensionalArray(this.presetNames$.value, this.newPresetName$.value);
            const presetGroups = this.inboxState.presetGroups$.value;
            if (!isArrayInMultidimensionalArray) {
                const newPreset = {
                    name: this.newPresetName$.value[1],
                    visible: true,
                    changeable: true,
                    numberMainAttributesChosenByUser: 12,
                    selectedAttributes: this.selectedAttributes,
                    sortAttributes: [],
                    filterAttributes: [],
                    iconAttributes: [],
                };
                presetGroups.forEach((group) => {
                    if (group.groupName === this.newPresetName$.value[0]) {
                        group.presets.push(newPreset);
                    }
                });
                this.inboxState.setPresetGroups(presetGroups);
                this.presetNames$.value.push(this.newPresetName$.value);
            }
            else {
                presetGroups.forEach((group) => {
                    if (group.groupName === this.newPresetName$.value[0]) {
                        group.presets.forEach((preset) => {
                            if (preset.name === this.newPresetName$.value[1]) {
                                preset.selectedAttributes = preset.selectedAttributes
                                    ?.concat(this.selectedAttributes)
                                    .filter(this.onlyUnique);
                            }
                        });
                    }
                });
                this.inboxState.setPresetGroups(presetGroups);
            }
            presetGroups.forEach((group) => {
                if (group.groupName === this.newPresetName$.value[0]) {
                    group.presets.forEach((preset) => {
                        if (preset.name === this.newPresetName$.value[1]) {
                            this.presetNames$.value.push([group.groupName, preset.name]);
                        }
                    });
                }
            });
        }
    }
    /**
     * Set the sort filter to the new preset.
     * @param event Selected sort filters.
     */
    setSortFilterToNewPreset(event) {
        const presetGroups = this.inboxState.presetGroups$.value;
        const targetPreset = presetGroups
            .find((group) => group.groupName === this.newPresetName$.value[0])
            ?.presets.find((preset) => preset.name === this.newPresetName$.value[1]);
        if (targetPreset) {
            targetPreset.sortAttributes = event.map((value) => ({
                identifier: value.identifier,
                sort: value.sort,
            }));
            this.inboxState.setPresetGroups(presetGroups);
        }
    }
    /**
     * Set the sort filter to the new preset.
     * @param event Selected sort filters.
     */
    setIconFilterToNewPreset(event) {
        const presetGroups = this.inboxState.presetGroups$.value;
        const targetPreset = presetGroups
            .find((group) => group.groupName === this.newPresetName$.value[0])
            ?.presets.find((preset) => preset.name === this.newPresetName$.value[1]);
        if (targetPreset) {
            targetPreset.iconAttributes = event.map((value) => ({
                identifier: value.identifier,
                icon: value.icon,
            }));
            this.inboxState.setPresetGroups(presetGroups);
        }
    }
    /**
     * Set the visibility to the new preset.
     * @param event Selected visibility.
     */
    setVisibilityToNewPreset(event) {
        const presetGroups = this.inboxState.presetGroups$.value;
        presetGroups.forEach((group) => {
            if (group.groupName === this.newPresetName$.value[0]) {
                const targetPreset = group.presets.find((preset) => preset.name === this.newPresetName$.value[1]);
                if (targetPreset) {
                    targetPreset.visible = event;
                }
            }
        });
        this.inboxState.setPresetGroups(presetGroups);
    }
    /**
     * Set the number of main attributes to the new preset.
     * @param event
     */
    setNumberMainAttributesChosenByUserToPreset(event) {
        if (this.newPresetName$.value[1].length !== 0) {
            const presetGroups = this.inboxState.presetGroups$.value;
            presetGroups.forEach((group) => {
                if (group.groupName === this.newPresetName$.value[0]) {
                    const targetPreset = group.presets.find((preset) => preset.name === this.newPresetName$.value[1]);
                    if (targetPreset) {
                        targetPreset.numberMainAttributesChosenByUser = event;
                    }
                }
            });
            this.inboxState.setPresetGroups(presetGroups);
        }
    }
    /**
     * Set the filter to the new preset.
     * @param event Selected filters.
     */
    setFilterToNewPreset(event) {
        const presetGroups = this.inboxState.presetGroups$.value;
        presetGroups.forEach((group) => {
            if (group.groupName === this.newPresetName$.value[0]) {
                const targetPreset = group.presets.find((preset) => preset.name === this.newPresetName$.value[1]);
                if (targetPreset) {
                    targetPreset.filterAttributes = event;
                }
            }
        });
        this.inboxState.setPresetGroups(presetGroups);
    }
    /**
     * Auxiliary method to check if item is unique.
     * @param value Item to check.
     * @param index Index of item.
     * @param self Item to check.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    onlyUnique(value, index, self) {
        return self.indexOf(value) === index;
    }
    /**
     * Method to check if an array is in a multidimensional array.
     * @param arr The array.
     * @param target The target array.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    isArrayInMultidimensionalArray(arr, target) {
        return arr.some((innerArray) => innerArray.length === target.length && innerArray.every((value, index) => value === target[index]));
    }
    /**
     * Method to update the attributes in the preset groups.
     * @param presetName The preset to update. [groupName, presetName]
     * @param selectedAttributes The selected attributes.
     */
    updateAttributeInPresets(presetName, selectedAttributes) {
        const operation = 'update';
        this.setCurrentPresetAction({ operation, groupName: presetName[0], presetName: presetName[1] });
        this.setNewPresetName(presetName);
        this.updatePresetInPresets(presetName, (presets) => ({
            ...presets,
            selectedAttributes: selectedAttributes.map((attribute) => ({
                identifier: attribute,
                defaultAttribute: 'main',
            })),
        }));
    }
    /**
     * Updates current presetGroups in state. Also emits the new presetGroups via setting the current presetGroups.
     * @param presetGroups The new presetGroups.
     */
    updatePresetGroupAndNotify(presetGroups) {
        this.inboxState.setPresetGroups(presetGroups);
        this.setCurrentPresetGroup(presetGroups);
    }
    /**
     * Helper method to update a preset in preset groups.
     * @param presetName The preset to update.
     * @param updateFunc The function to update the preset.
     */
    updatePresetInPresets(presetName, updateFunc) {
        const newPresetGroups = this.inboxState.presetGroups$.value.map((presetGroups) => {
            if (presetGroups.groupName === presetName[0]) {
                const updatedPresets = presetGroups.presets.map((preset) => {
                    if (preset.name === presetName[1]) {
                        return updateFunc(preset);
                    }
                    return preset;
                });
                return { ...presetGroups, presets: updatedPresets };
            }
            return presetGroups;
        });
        this.inboxState.setPresetGroups(newPresetGroups);
        this.setCurrentPresetGroup(newPresetGroups);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: UpdatePresetsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: UpdatePresetsService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: UpdatePresetsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Service for downloading data items as a csv file.
 */
class CsvService {
    constructor() {
        /**
         * The state of the inbox.
         */
        this.inboxState = inject(InboxState);
    }
    /**
     * Download the data items as a csv file.
     */
    downloadCSV() {
        // convert data to a csv string
        const csv = this.convertToCSV(this.inboxState.filteredDataItemsSubject$.value);
        // create a blob from the csv string
        const blob = new Blob([csv], { type: 'text/csv' });
        // trigger a download of the blob
        const link = document.createElement('a');
        link.href = URL.createObjectURL(blob);
        link.download = 'dataItems.csv';
        link.click();
        link.remove();
    }
    /**
     * Convert an array of objects to a csv string.
     * @param {any[]} objArray The array of objects to convert.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    convertToCSV(objArray) {
        // get the keys (headers) of the first object in the array
        const keys = Object.keys(objArray[0]);
        // create an array of header strings
        const headers = keys.join(',');
        // create an array of rows and replace any commas with a space
        const rows = objArray.map((item) => keys.map((key) => String(item[key]).replace(/,/g, '')).join(','));
        //join the headers and rows together
        return headers + '\n' + rows.join('\n');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: CsvService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: CsvService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: CsvService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Service containing helper methods for the inbox main facade usage.
 */
class InboxHelperService {
    constructor() {
        /**
         * First Index of data-items-list.
         */
        this.startIndexDataItemsListSubject$ = new BehaviorSubject(0);
        /**
         * Service to handle the data items.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * Service to handle the keyboard.
         */
        this.keyboardService = inject(KeyboardService);
        /**
         * Service to handle the inbox configuration.
         */
        this.setInboxConfigurationService = inject(MainFacadeSetterService);
        /**
         * Boolean to check if the current header is in an edge case loop (e.g. when the user scrolls down header is hidden and the available space is enough to show the header again (no scrolling needed)).
         */
        this.headerEdgeCase = false;
        /**
         * Boolean to check the virtual scroll has no scroll bar.
         */
        this.noScroll = false;
    }
    /**
     * Setter for the first index of the data items list.
     * @param {number} value The value to set.
     * @internal
     */
    setStartIndexDataItemsListSubject(value) {
        this.startIndexDataItemsListSubject$.next(value);
    }
    /**
     * Getter for the list of data items which are chosen in the data items list.
     * @param {any[]} dataItems The list of dataItems.
     * @param {string[]} dataItemsListId The list of data items ids.
     * @internal
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getBulkDataItemsList(dataItems, dataItemsListId) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        return dataItems.filter((elem) => {
            let included = false;
            dataItemsListId.forEach((value) => {
                if (elem['inboxId'] === value) {
                    included = true;
                }
            });
            return included;
        });
    }
    /**
     * Handler to get the notes from the selected data item.
     * @param noteInput The note input.
     */
    getSelectedDataItemNotes(noteInput) {
        if (noteInput !== undefined) {
            return noteInput;
        }
        else if (this.dataItemsService.activeDataItem$.value) {
            return this.dataItemsService.activeDataItem$.value.notes;
        }
        return [];
    }
    /**
     * Method to handle scroll change.
     * @param {number} scrollPosition Clicked data item.
     */
    onScrollChange(scrollPosition) {
        // check if the header is in a loop, if so emit -2, reset is not possible
        if (!this.headerEdgeCase) {
            this.headerEdgeCase = this.startIndexDataItemsListSubject$.value > 0 && this.noScroll && scrollPosition === 0;
        }
        if (this.headerEdgeCase) {
            this.setInboxConfigurationService.setVirtualScrollerPosition(-2);
        }
        // check if the scroller has no scroll
        if (this.dataItemsService.virtualScrollerHeight$.value >
            this.dataItemsService.virtualScrollerScrollableContentHeight$.value) {
            this.noScroll = true;
            this.setInboxConfigurationService.setVirtualScrollerPosition(-1);
        }
        else {
            this.noScroll = false;
            this.setStartIndexDataItemsListSubject(scrollPosition);
            this.setInboxConfigurationService.setVirtualScrollerPosition(scrollPosition);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxHelperService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxHelperService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxHelperService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Responsible to deal with further information of a data item.
 *
 * ```html
 * <talenra-detail-view-information
 *   [key]="detailViewItem.key"
 *   [label]="detailViewItem.label"
 *   [icon]="detailViewItem.icon"
 *   [useScroll]="true"
 * ></talenra-detail-view-information>
 * ```
 */
class DetailViewInformationComponent {
    constructor() {
        /**
         * The data item information tab bar item.
         */
        this.detailViewTab = input.required();
        /**
         * The public service of the inbox detail view.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
        /**
         * The binding for the class attribute of the host element.
         * @internal
         */
        this.className = '';
        /**
         * The subscriptions of this component.
         * @internal
         **/
        this.subscriptions = new Subscription();
    }
    /**
     * Initializes the component.
     * @internal
     */
    ngOnInit() {
        this.subscriptions.add(this.inboxDetailViewService.selectedDetailViewTab$.subscribe((key) => {
            this.className = key === this.detailViewTab().key ? 'selected' : '';
        }));
    }
    /**
     * Unsubscribes from all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: DetailViewInformationComponent, isStandalone: true, selector: "talenra-detail-view-information", inputs: { detailViewTab: { classPropertyName: "detailViewTab", publicName: "detailViewTab", isSignal: true, isRequired: true, transformFunction: null } }, host: { properties: { "class": "this.className" } }, ngImport: i0, template: "@if (detailViewTab().useScroll) {\n  <talenra-scroll-container class=\"scroll-container\">\n    <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n  </talenra-scroll-container>\n} @else {\n  <div class=\"no-scroll-container\">\n    <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n  </div>\n}\n\n<ng-template #content>\n  <ng-content></ng-content>\n</ng-template>\n", styles: [":host{display:block;position:absolute;inset:0;padding:0 1rem;pointer-events:none;opacity:0;transform:translate(10%);transition:opacity .5s,transform .5s}:host.selected{z-index:1;pointer-events:all;opacity:1;transform:translate(0);transition-delay:.25s}.scroll-container{height:calc(100% - .5rem);width:100%}.no-scroll-container{position:relative;height:100%}\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-detail-view-information', standalone: true, imports: [NgTemplateOutlet, ScrollContainerComponent], template: "@if (detailViewTab().useScroll) {\n  <talenra-scroll-container class=\"scroll-container\">\n    <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n  </talenra-scroll-container>\n} @else {\n  <div class=\"no-scroll-container\">\n    <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n  </div>\n}\n\n<ng-template #content>\n  <ng-content></ng-content>\n</ng-template>\n", styles: [":host{display:block;position:absolute;inset:0;padding:0 1rem;pointer-events:none;opacity:0;transform:translate(10%);transition:opacity .5s,transform .5s}:host.selected{z-index:1;pointer-events:all;opacity:1;transform:translate(0);transition-delay:.25s}.scroll-container{height:calc(100% - .5rem);width:100%}.no-scroll-container{position:relative;height:100%}\n"] }]
        }], propDecorators: { className: [{
                type: HostBinding,
                args: ['class']
            }] } });

/**
 * Displays a note box which contains info icons correlating note.
 *
 * ```html
 * <talenra-inbox-note-box [noteBoxItems]="noteBoxItems"></talenra-inbox-note-box>
 * ```
 */
class InboxNoteBoxComponent {
    constructor() {
        /**
         * Input data to create a dynamic component.
         */
        this.noteBoxItems = [];
        /**
         * The inbox detail view service.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
    }
    /**
     * Method to emit the expanding and condensing of the note box.
     */
    onExpandClick() {
        this.inboxDetailViewService.setNoteBoxExpanded(!this.inboxDetailViewService.noteBoxExpanded$.value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxNoteBoxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: InboxNoteBoxComponent, isStandalone: true, selector: "talenra-inbox-note-box", inputs: { noteBoxItems: "noteBoxItems" }, ngImport: i0, template: "<div class=\"note-box\">\n  <div class=\"shutter-box\">\n    @if ((inboxDetailViewService.detailViewExpanded$ | async) && noteBoxItems.length > 0) {\n      <button\n        (click)=\"onExpandClick()\"\n        [icon]=\"inboxDetailViewService.noteBoxExpanded$.value ? 'expand-less' : 'expand-more'\"\n        class=\"shutter-box-button\"\n        data-testid=\"inbox-note-box-collapse\"\n        kind=\"ghost\"\n        talenra-button\n        size=\"m\"></button>\n    }\n  </div>\n  <div\n    [class.detail-view-not-expanded]=\"(inboxDetailViewService.detailViewExpanded$ | async) === false\"\n    [class.expanded]=\"!inboxDetailViewService.noteBoxExpanded$.value\"\n    [class.no-items]=\"noteBoxItems.length === 0\"\n    class=\"note-box-content\">\n    <div class=\"note-box-info\">\n      @for (note of noteBoxItems; let index = $index; track note.identifier) {\n        <div class=\"item\">\n          <talenra-icon class=\"icon-font\" [class]=\"'color--' + note.activeIconColor\" name=\"{{ note.icon }}\"></talenra-icon>\n          <span\n            #noteText\n            [talenraTooltip]=\"note.note\"\n            [talenraTooltipDisabled]=\"noteText.clientWidth === noteText.scrollWidth\"\n            class=\"item-text\"\n            >{{ note.note }}</span\n          >\n        </div>\n      }\n    </div>\n  </div>\n</div>\n", styles: [":host{--color-background: #ffffff;--color-text: #000000;--color-primary: #0099a8}.note-box{width:100%;border-radius:.1875rem;background:var(--color-background)}.shutter-box{height:1.75rem;display:flex;flex-wrap:nowrap;flex-direction:row-reverse}.shutter-box-button{margin-right:1rem}.note-box-content{padding:0 1rem .5rem;height:max-content;width:100%;max-height:15.625rem;margin-bottom:.25rem;opacity:1;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;transition:max-height .3s,opacity .3s,padding-bottom .3s,width .3s}.note-box-content.expanded{overflow:hidden;max-height:0;padding-bottom:0;opacity:0;width:0}.note-box-content.no-items{padding:0 .5rem 0rem 1rem}.note-box-content.detail-not-view-expanded{width:0}.note-box-info{vertical-align:middle}.item{height:22px;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.item-icon{padding-top:1px}.item-text{margin-left:.75rem;color:var(--color-text);overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.material-icons{vertical-align:middle}.icon-font{font-size:18px}.color--status-red{color:#e20057}.color--status-green{color:#00d000}.color--status-orange{color:#e26000}.color--status-violet{color:#b103c7}.color--petrol{color:#0099a8}.color--petrol-dark{color:#005f71}.color--denim{color:#0069a3}.color--denim-dark{color:#04466a}.color--black{color:#000}.color--primary{color:var(--color-primary)}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-text: #cccccc}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxNoteBoxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-note-box', standalone: true, imports: [AsyncPipe, ButtonComponent, IconComponent, TooltipDirective], template: "<div class=\"note-box\">\n  <div class=\"shutter-box\">\n    @if ((inboxDetailViewService.detailViewExpanded$ | async) && noteBoxItems.length > 0) {\n      <button\n        (click)=\"onExpandClick()\"\n        [icon]=\"inboxDetailViewService.noteBoxExpanded$.value ? 'expand-less' : 'expand-more'\"\n        class=\"shutter-box-button\"\n        data-testid=\"inbox-note-box-collapse\"\n        kind=\"ghost\"\n        talenra-button\n        size=\"m\"></button>\n    }\n  </div>\n  <div\n    [class.detail-view-not-expanded]=\"(inboxDetailViewService.detailViewExpanded$ | async) === false\"\n    [class.expanded]=\"!inboxDetailViewService.noteBoxExpanded$.value\"\n    [class.no-items]=\"noteBoxItems.length === 0\"\n    class=\"note-box-content\">\n    <div class=\"note-box-info\">\n      @for (note of noteBoxItems; let index = $index; track note.identifier) {\n        <div class=\"item\">\n          <talenra-icon class=\"icon-font\" [class]=\"'color--' + note.activeIconColor\" name=\"{{ note.icon }}\"></talenra-icon>\n          <span\n            #noteText\n            [talenraTooltip]=\"note.note\"\n            [talenraTooltipDisabled]=\"noteText.clientWidth === noteText.scrollWidth\"\n            class=\"item-text\"\n            >{{ note.note }}</span\n          >\n        </div>\n      }\n    </div>\n  </div>\n</div>\n", styles: [":host{--color-background: #ffffff;--color-text: #000000;--color-primary: #0099a8}.note-box{width:100%;border-radius:.1875rem;background:var(--color-background)}.shutter-box{height:1.75rem;display:flex;flex-wrap:nowrap;flex-direction:row-reverse}.shutter-box-button{margin-right:1rem}.note-box-content{padding:0 1rem .5rem;height:max-content;width:100%;max-height:15.625rem;margin-bottom:.25rem;opacity:1;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;transition:max-height .3s,opacity .3s,padding-bottom .3s,width .3s}.note-box-content.expanded{overflow:hidden;max-height:0;padding-bottom:0;opacity:0;width:0}.note-box-content.no-items{padding:0 .5rem 0rem 1rem}.note-box-content.detail-not-view-expanded{width:0}.note-box-info{vertical-align:middle}.item{height:22px;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.item-icon{padding-top:1px}.item-text{margin-left:.75rem;color:var(--color-text);overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.material-icons{vertical-align:middle}.icon-font{font-size:18px}.color--status-red{color:#e20057}.color--status-green{color:#00d000}.color--status-orange{color:#e26000}.color--status-violet{color:#b103c7}.color--petrol{color:#0099a8}.color--petrol-dark{color:#005f71}.color--denim{color:#0069a3}.color--denim-dark{color:#04466a}.color--black{color:#000}.color--primary{color:var(--color-primary)}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-text: #cccccc}\n"] }]
        }], propDecorators: { noteBoxItems: [{
                type: Input
            }] } });

/**
 * The subcategory of the data item list. Here a single pair of data is considered.  When selecting an element, various
 * actions are possible, e.g. displaying further information.
 *
 * ```html
 * <talenra-data-item
 *   [dataItem]="item"
 *   [furtherActionsMenu]="furtherActionsMenu"
 *   (dataItemsInteractions)="onDataItemsInteractions($event)"
 *   (clickedDataItem)="onSelectClick(item)"
 *   (shiftDataItem)="onShiftDataItemClick(item)"
 * ></talenra-data-item>
 * ```
 */
class DataItemComponent {
    constructor() {
        /**
         * Input for the selected main attributes
         */
        this.selectedMainAttributes = [];
        /**
         * Input for pairing attributes
         */
        this.pairingAttributes = [];
        /**
         * Input attribute to disable the icon buttons.
         */
        this.disableButtons = false;
        /**
         * Input attribute for the checkbox value.
         */
        this.checkboxValueChange = false;
        /**
         * Input attribute to check if the data item is locked.
         */
        this.lockedDataItem = false;
        /**
         * Transfer the clicked data item from the data items list item to the data item sidebar information.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.clickedDataItem = new EventEmitter();
        /**
         * Transfer the clicked data item from the data items list item to the data item sidebar information.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.shiftDataItem = new EventEmitter();
        /**
         * EventEmitter to send data items interactions.
         */
        this.dataItemsInteractions = new EventEmitter();
        /**
         * EventEmitter to send checkbox interactions.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.checkBoxInteraction = new EventEmitter();
        /**
         * Formgroup for the checkbox.
         */
        this.checkedForm = new FormGroup({
            check: new FormControl({ value: false, disabled: false }),
        });
        /**
         * Class to interact with data-item
         */
        this.dataItemsClass = new DataItemsClass();
        /**
         * The number of displayed attributes.
         */
        this.numberShownAttributes = 0;
        /**
         * The changed main attributes. Changed to incorporate the pairing of attributes.
         */
        this.changedMainAttributes = [];
        /**
         * The changed main attributes. The first half of the changed main attributes.
         */
        this.firstChangedMainAttributes = [];
        /**
         * The changed main attributes. The second half of the changed main attributes.
         */
        this.secondChangedMainAttributes = [];
        /**
         * The inbox service.
         */
        this.inboxState = inject(InboxState);
        /**
         * The data items service.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * The inbox toolbar service.
         */
        this.inboxToolbarService = inject(InboxToolbarService);
        /**
         * The Math object to use for calculations.
         * @protected
         */
        this.Math = Math;
        /**
         * The subscriptions of the data item list component.
         * @internal
         */
        this.subscriptions = new Subscription();
        /**
         * The observable for the resize event.
         * @private
         */
        this.resizeObservable$ = new Observable();
        /**
         * The subscription for the resize event.
         * @private
         */
        this.resizeSubscription$ = new Subscription();
        /**
         * The changeDetectorRef reference.
         * @private
         */
        this.changeDetectorRef = inject(ChangeDetectorRef);
        /**
         * The keyboard service.
         * @private
         */
        this.keyboardService = inject(KeyboardService);
    }
    /**
     * Initializes the data item list component.
     * @internal
     */
    ngOnInit() {
        this.initializeComponent();
    }
    /**
     * Detects changes in the input values.
     * @param changes The changes.
     * @internal
     **/
    ngOnChanges(changes) {
        // Handle changes to 'dataItem'
        const dataItemChanges = changes['dataItem'];
        if (dataItemChanges && !dataItemChanges.firstChange) {
            this.resetOnChange();
        }
        const checkboxChanges = changes['checkboxValueChange'];
        if (checkboxChanges && !checkboxChanges.firstChange) {
            this.checkedForm.get('check')?.setValue(checkboxChanges.currentValue);
        }
        const lockedDataItemChanges = changes['lockedDataItem'];
        if (lockedDataItemChanges && !lockedDataItemChanges.firstChange) {
            // disable checkbox if data item is locked
            if (lockedDataItemChanges.currentValue) {
                this.checkedForm.get('check')?.disable();
            }
            else {
                this.checkedForm.get('check')?.enable();
            }
        }
        const selectedDataItemChanges = changes['selectedDataItem'];
        if (selectedDataItemChanges && !selectedDataItemChanges.firstChange) {
            this.resetOnChange();
        }
        const mainAttributesChanges = changes['selectedMainAttributes'];
        if (mainAttributesChanges && !mainAttributesChanges.firstChange) {
            this.resetOnChange();
        }
        const pairingAttributesChanges = changes['pairingAttributes'];
        if (pairingAttributesChanges && !pairingAttributesChanges.firstChange) {
            this.resetOnChange();
        }
    }
    /**
     * Unsubscribes from all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
    }
    /**
     * To transfer data item list to data item sidebar information.
     */
    onDataItemListItemTransferClick() {
        if (!this.lockedDataItem) {
            if (this.keyboardService.metaKeyPressed.value) {
                const value = this.checkedForm.get('check')?.value;
                if (value) {
                    this.checkedForm.get('check')?.setValue(false);
                    this.checkBoxInteraction.emit({ checkedValue: false, dataItem: this.dataItem });
                }
                else {
                    this.checkedForm.get('check')?.setValue(true);
                    this.checkBoxInteraction.emit({ checkedValue: true, dataItem: this.dataItem });
                }
            }
            else if (this.keyboardService.shiftKeyPressed.value) {
                this.shiftDataItem.emit(this.dataItem);
            }
            else {
                this.clickedDataItem.emit(this.dataItem);
            }
        }
    }
    /**
     * After the checkbox is clicked, mouseEvent is propagated to stop further propagation on the whole item click.
     * @param {MouseEvent} event MouseEvent on the checkbox click.
     */
    onCheckboxClick(event) {
        event.stopPropagation();
    }
    /**
     * After the icon is clicked, action possibilities will be shown.
     * IconBtnFunction in inbox component handles the process.
     * @param source The source of the click.
     */
    onGetActionsClick(source) {
        if (source === 'mouse') {
            // set action menu expanded to true
            this.inboxState.setActionsMenuClickFlag(true);
            this.inboxState.setActionMenuExpanded(true);
            this.dataItemsInteractions.emit({
                dataItems: [this.dataItem],
                message: InteractedDataItemsMessageTypes.More,
            });
            this.inboxState.setActionsMenuClickFlag(false);
        }
        else {
            this.dataItemsInteractions.emit({
                dataItems: [this.dataItem],
                message: InteractedDataItemsMessageTypes.More,
            });
        }
        // subscribe to window resizing event to close when window is resized
        this.resizeObservable$ = fromEvent(window, 'resize');
        this.resizeSubscription$ = this.resizeObservable$.subscribe(() => {
            // close menu when window is resized and unsubscribe from window resizing event, for performance reasons
            this.inboxState.setActionMenuExpanded(false);
            this.talenraInboxDataItemsListItemMenuTrigger.closeMenu();
            this.resizeSubscription$.unsubscribe();
        });
    }
    /**
     * After the icon is clicked, the new process step (open new page, etc.) will start.
     * IconBtnFunction in inbox component handles the process.
     * @param {MouseEvent} event MouseEvent on the icon click.
     */
    onStartProcessClick(event) {
        event.stopPropagation();
        if (!this.lockedDataItem) {
            if (!this.inboxState.inboxConfiguration$.value.disableInteractionsDataItemsList &&
                !this.inboxState.inboxConfiguration$.value.disableContinueButtonDataItemsList) {
                this.dataItemsInteractions.emit({
                    dataItems: [this.dataItem],
                    message: InteractedDataItemsMessageTypes.Process,
                });
            }
        }
    }
    /**
     * Handles the changes of the checkbox.
     * @param event
     */
    onCheckedChange(event) {
        this.checkBoxInteraction.emit({ checkedValue: event.checked, dataItem: this.dataItem });
    }
    /**
     * The subscription, which handles the action menu interaction (open/close).
     * @param value The value given by the subscription.
     */
    interactionActionMenuSubscription(value) {
        if (value &&
            !this.disableButtons &&
            this.inboxToolbarService.selectedItemsCount$.value <= 1 &&
            this.selectedDataItem === this.dataItem &&
            this.talenraInboxDataItemsListItemMenuTrigger &&
            this.talenraInboxDataItemsListItemMenuTrigger.menuClosed) {
            // set action menu expanded to true
            this.inboxState.setActionsMenuClickFlag(true);
            this.inboxState.setActionMenuExpanded(true);
            this.inboxState.setActionsMenuClickFlag(false);
            this.talenraInboxDataItemsListItemMenuTrigger.openMenu();
            this.talenraInboxDataItemsListItemMenuTrigger.focus();
        }
        else if (this.selectedDataItem &&
            this.selectedDataItem !== this.dataItem &&
            this.talenraInboxDataItemsListItemMenuTrigger) {
            // unsubscribe from window resizing event, for performance reasons
            if (this.resizeSubscription$) {
                this.resizeSubscription$.unsubscribe();
            }
            this.talenraInboxDataItemsListItemMenuTrigger.closeMenu();
        }
        else if (!value) {
            this.talenraInboxDataItemsListItemMenuTrigger &&
                this.talenraInboxDataItemsListItemMenuTrigger.menuOpen &&
                this.talenraInboxDataItemsListItemMenuTrigger.closeMenu();
        }
    }
    /**
     * Handles the closing of the action menu.
     * Sets the value for the public api.
     */
    onActionsMenuClosed() {
        this.inboxState.setActionMenuExpanded(false);
    }
    /**
     * Initializes the component.
     * @internal
     */
    initializeComponent() {
        // subscription for the changes in the item UI by the attributes-settings-service
        const copiedArray = [];
        this.selectedMainAttributes.forEach((val) => copiedArray.push(Object.assign({}, val)));
        this.changedMainAttributes = copiedArray;
        // sets up the pairing of specific attributes
        if (this.pairingAttributes) {
            this.pairingAttributes.forEach((pair) => {
                this.attributePairingHandler(pair);
            });
        }
        // change number of shown attributes
        if (this.changedMainAttributes) {
            // split the changedMainAttributes into two arrays
            this.firstChangedMainAttributes = [];
            this.secondChangedMainAttributes = [];
            const halfNumber = Math.ceil(this.changedMainAttributes.length / 2);
            this.firstChangedMainAttributes = this.changedMainAttributes.slice(0, halfNumber);
            this.secondChangedMainAttributes = this.changedMainAttributes.slice(halfNumber);
            this.numberShownAttributes = this.changedMainAttributes.length;
        }
        this.subscriptions.add(this.keyboardService.escapeKeyPressed.subscribe((value) => {
            // unsubscribe from window resizing event, for performance reasons
            if (value && this.resizeSubscription$) {
                this.resizeSubscription$.unsubscribe();
            }
            value && this.talenraInboxDataItemsListItemMenuTrigger && this.talenraInboxDataItemsListItemMenuTrigger.closeMenu();
        }));
        // subscription if the public api is used to open/close the actions menu
        this.subscriptions.add(this.inboxState.actionMenuExpanded$.subscribe((value) => {
            if (!this.inboxState.actionsMenuClickFlag.value) {
                this.interactionActionMenuSubscription(value);
            }
        }));
        // subscription to change in the inbox configuration
        this.subscriptions.add(this.inboxState.inboxConfiguration$.subscribe(() => {
            this.changeDetectorRef.detectChanges();
        }));
        // set checkbox value
        if (this.checkboxValueChange) {
            this.checkedForm.get('check')?.setValue(this.checkboxValueChange);
        }
        // disable locked data items
        if (this.lockedDataItem) {
            this.checkedForm.get('check')?.disable();
        }
        else {
            this.checkedForm.get('check')?.enable();
        }
    }
    /**
     * Resets the component on changes
     * @private
     */
    resetOnChange() {
        this.subscriptions.unsubscribe();
        this.subscriptions.closed = false;
        this.initializeComponent();
    }
    /**
     * Handles the pairing of specific attributes.
     * @private
     */
    attributePairingHandler(pair) {
        // checks if the attributes are not empty
        if (this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.firstAttribute) !== '–' &&
            this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.secondAttribute) !== '–') {
            if (!pair.commaSeparation) {
                this.dataItemsClass.setElemFromDataItemValue(this.dataItem, pair.identifier, this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.firstAttribute) +
                    ' ' +
                    this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.secondAttribute));
            }
            else if (pair.commaSeparation) {
                this.dataItemsClass.setElemFromDataItemValue(this.dataItem, pair.identifier, this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.firstAttribute) +
                    ', ' +
                    this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.secondAttribute));
            }
        }
        else if (
        // checks if the first attribute is empty and the second attribute is not empty
        this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.firstAttribute) === '–' &&
            this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.secondAttribute) !== '–') {
            this.dataItemsClass.setElemFromDataItemValue(this.dataItem, pair.identifier, this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.secondAttribute));
        }
        else if (
        // checks if the first attribute is not empty and the second attribute is empty
        this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.firstAttribute) !== '–' &&
            this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.secondAttribute) === '–') {
            this.dataItemsClass.setElemFromDataItemValue(this.dataItem, pair.identifier, this.dataItemsClass.getElemFromDataItemDisplayed(this.dataItem, pair.firstAttribute));
        }
        else {
            // checks if the first attribute is empty and the second attribute is empty
            this.dataItemsClass.setElemFromDataItemValue(this.dataItem, pair.identifier, '–');
        }
        if (pair.firstAttribute && pair.secondAttribute) {
            // get the index of the attributes in the this.selectedAttributes$
            const indexFirstAttribute = this.changedMainAttributes.findIndex((e) => e.identifier === pair.firstAttribute);
            const indexSecondAttribute = this.changedMainAttributes.findIndex((e) => e.identifier === pair.secondAttribute);
            if (indexFirstAttribute === -1 || indexSecondAttribute === -1) {
                return;
            }
            if (indexSecondAttribute > indexFirstAttribute) {
                // deletes the firstAttribute of the list of items and set the this.selectedAttributes$
                this.changedMainAttributes[indexFirstAttribute].identifier = pair.identifier;
                this.changedMainAttributes[indexFirstAttribute].label = pair.label;
                this.changedMainAttributes.splice(indexSecondAttribute, 1);
            }
            else {
                // deletes the secondAttribute of the list of items and set the this.selectedAttributes$
                this.changedMainAttributes[indexSecondAttribute].identifier = pair.identifier;
                this.changedMainAttributes[indexSecondAttribute].label = pair.label;
                this.changedMainAttributes.splice(indexFirstAttribute, 1);
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DataItemComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: DataItemComponent, isStandalone: true, selector: "talenra-data-item", inputs: { dataItem: "dataItem", selectedDataItem: "selectedDataItem", selectedMainAttributes: "selectedMainAttributes", pairingAttributes: "pairingAttributes", disableButtons: "disableButtons", checkboxValueChange: "checkboxValueChange", lockedDataItem: "lockedDataItem" }, outputs: { clickedDataItem: "clickedDataItem", shiftDataItem: "shiftDataItem", dataItemsInteractions: "dataItemsInteractions", checkBoxInteraction: "checkBoxInteraction" }, viewQueries: [{ propertyName: "talenraInboxDataItemsListItemMenuTrigger", first: true, predicate: MatMenuTrigger, descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div\n  (click)=\"onDataItemListItemTransferClick()\"\n  (dblclick)=\"onStartProcessClick($event)\"\n  [class.bulk-selected]=\"checkedForm.get('check')?.value\"\n  [class.locked]=\"lockedDataItem\"\n  [class.scroll-bar-margin]=\"\n    dataItemsService.virtualScrollerScrollableContentHeight$.value === dataItemsService.virtualScrollerHeight$.value\n  \"\n  [class.selected]=\"dataItem === selectedDataItem\"\n  class=\"data-item\"\n  data-testid=\"inbox-data-item-box\">\n  <div class=\"data-item-info\">\n    @if (!inboxState.inboxConfiguration$.value.disableNotesDataItemsList) {\n      <div [class.hide-icons]=\"dataItemsService.compressedDataItem$.value\" class=\"data-item-icons\">\n        @for (note of dataItem['notes']; track note.identifier) {\n          <talenra-icon\n            [class.locked]=\"lockedDataItem\"\n            [name]=\"note.icon\"\n            [class]=\"'color--' + note.activeIconColor\"\n            class=\"icon-font\"></talenra-icon>\n        }\n      </div>\n    }\n    <div #inboxDataItemContainer class=\"data-item-attributes\">\n      <div class=\"data-item-attributes-container\">\n        @for (item of firstChangedMainAttributes; track item.identifier; let index = $index) {\n          <div class=\"data-item-attributes-condensed-first\">\n            <div class=\"item-container\">\n              <div\n                #inboxDataItemContainerContent\n                [talenraTooltipDisabled]=\"\n                  inboxDataItemContainerContent.offsetWidth + 1 <= inboxDataItemContainer.scrollWidth\n                \"\n                [talenraTooltip]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                [textToCopy]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                class=\"attribute-pairing\">\n                @if (inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <span class=\"label-value-pairing\">\n                    <span [class.locked]=\"lockedDataItem\" class=\"label\">\n                      {{ item.label + ': ' }}\n                    </span>\n                    <span [class.locked]=\"lockedDataItem\" class=\"attribute-text\"\n                      >&nbsp;{{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}</span\n                    >\n                  </span>\n                }\n                @if (!inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <div [class.locked]=\"lockedDataItem\" class=\"attribute-text\">\n                    {{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}\n                  </div>\n                }\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n      <div class=\"data-item-attributes-container\">\n        @for (item of secondChangedMainAttributes; track item.identifier; let index = $index) {\n          <div class=\"data-item-attributes-condensed-second\">\n            <div class=\"item-container\">\n              <div\n                #inboxDataItemContainerContent\n                [talenraTooltipDisabled]=\"\n                  inboxDataItemContainerContent.offsetWidth + 1 <= inboxDataItemContainer.scrollWidth\n                \"\n                [talenraTooltip]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                [textToCopy]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                class=\"attribute-pairing\">\n                @if (inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <span class=\"label-value-pairing\">\n                    <span [class.locked]=\"lockedDataItem\" class=\"label\">\n                      {{ item.label + ': ' }}\n                    </span>\n                    <span [class.locked]=\"lockedDataItem\" class=\"attribute-text\"\n                      >&nbsp;{{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}</span\n                    >\n                  </span>\n                }\n                @if (!inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <div [class.locked]=\"lockedDataItem\" class=\"attribute-text\">\n                    {{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}\n                  </div>\n                }\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n    </div>\n  </div>\n\n  @if (!inboxState.inboxConfiguration$.value.disableInteractionsDataItemsList) {\n    <div [formGroup]=\"checkedForm\" class=\"data-item-interactions\">\n      @if (!inboxState.inboxConfiguration$.value.disableCheckboxDataItemsList && !lockedDataItem) {\n        <talenra-checkbox\n          (checkedChange)=\"onCheckedChange($event)\"\n          (click)=\"onCheckboxClick($event)\"\n          class=\"checkbox\"\n          data-testid=\"inbox-data-item-checkbox\"\n          formControlName=\"check\"\n          talenraTooltip=\"Markieren\"></talenra-checkbox>\n      }\n      @if (!inboxState.inboxConfiguration$.value.disableFurtherInteractionsDataItemsList && !lockedDataItem) {\n        <button\n          (click)=\"onGetActionsClick('mouse')\"\n          (menuClosed)=\"onActionsMenuClosed()\"\n          [disabled]=\"disableButtons || lockedDataItem\"\n          [matMenuTriggerFor]=\"furtherActions\"\n          data-testid=\"inbox-data-item-more-actions\"\n          icon=\"more-vert\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"Aktionen\"\n          tabindex=\"-1\"></button>\n      }\n      @if (!inboxState.inboxConfiguration$.value.disableContinueButtonDataItemsList && !lockedDataItem) {\n        <button\n          (click)=\"onStartProcessClick($event)\"\n          [disabled]=\"disableButtons || lockedDataItem\"\n          data-testid=\"inbox-data-item-process\"\n          icon=\"arrow-forward\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"Fall ausf\u00FChren\"></button>\n      }\n      @if (lockedDataItem) {\n        <talenra-icon [class.locked]=\"lockedDataItem\" class=\"locked-icon\" name=\"lock\"></talenra-icon>\n      }\n    </div>\n  }\n</div>\n\n<mat-menu #furtherActions hasBackdrop=\"true\" xPosition=\"before\">\n  <ng-content select=\"[further-actions-menu]\"></ng-content>\n</mat-menu>\n", styles: [":host{--color-background: #ffffff;--color-text: #000000;--color-locked-text: #b3b3b3;--color-label: #666666;--color-locked-label: #b3b3b3;--color-primary: #0099a8}.data-item{container:dataItem/inline-size;position:relative;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between;max-height:max-content;background-color:var(--color-background);padding:.5rem .0625rem .5rem 1.5rem;margin-bottom:.125rem;margin-right:.125rem;border-radius:.1875rem;border:.0625rem solid var(--color-background);-webkit-user-select:none;user-select:none}.data-item:before{content:\"\";position:absolute;top:50%;left:0;width:.25rem;height:0;background-color:transparent;transform:translateY(-50%);transition-property:height,background-color;transition-duration:.3s}.data-item.selected:before{height:100%;background-color:var(--color-primary)}.data-item.bulk-selected{border-color:var(--color-primary)}.data-item:hover{cursor:pointer}.data-item.locked{color:var(--color-locked-text)}.data-item.scroll-bar-margin{margin-right:0}.data-item-info{font-size:1rem;line-height:1.125rem;font-weight:300;font-style:normal;letter-spacing:.02em;flex:1 1 100%}.data-item-info .data-item-icons>*{padding-right:.375rem}.data-item-icons{opacity:1;margin-top:.3125rem;height:1.4375rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:flex-start;transition:opacity .3s,height .3s}.data-item-icons.hide-icons{opacity:0;height:0}.data-item-attributes{display:flex;flex-direction:row;flex-wrap:wrap;height:100%;width:100%}.data-item-attributes .data-item-attributes-condensed-first:first-child{font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em}.data-item-attributes-container{width:50%}.item-container{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;width:100%;min-width:.0625rem;padding-right:1.625rem}.attribute-pairing{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:block;min-width:.0625rem}.label-value-pairing{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.label{font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-label)}.label.locked{color:var(--color-locked-label)}.attribute-text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:block;min-width:.0625rem;color:var(--color-text)}.attribute-text.locked{color:var(--color-locked-text)}.data-item-interactions{margin-bottom:auto;margin-right:0;min-width:4.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:end;align-items:center}.checkbox{margin-right:.25rem}.icon-font{font-size:1.125rem}.icon-font.locked{opacity:.3}.locked-icon{margin-right:.25rem}.locked-icon.locked{color:var(--color-locked-text)}.color--status-red{color:#e20057}.color--status-green{color:#00d000}.color--status-orange{color:#e26000}.color--status-violet{color:#b103c7}.color--petrol{color:#0099a8}.color--petrol-dark{color:#005f71}.color--denim{color:#0069a3}.color--denim-dark{color:#04466a}.color--black{color:#000}.color--primary{color:var(--color-primary)}@container dataItem (max-width: 550px){.data-item-info{overflow:hidden}.data-item-attributes{flex-direction:column}.item-container{padding-right:0}.data-item-attributes-container{width:100%;max-width:fit-content}}@container dataItem (max-width: 270px){.data-item-interactions{flex-direction:column;min-width:1.75rem}}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-text: #cccccc;--color-locked-text: #4d4d4d;--color-label: #cccccc;--color-locked-label: #4d4d4d}\n"], dependencies: [{ kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "directive", type: CopyContentDirective, selector: "[textToCopy]", inputs: ["textToCopy", "copyContentPosition", "copyContentNegativeColor", "copyContentTooltip"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: CheckboxComponent, selector: "talenra-checkbox", inputs: ["size", "labelPosition", "indeterminate", "pointerDisabled"], outputs: ["indeterminateChange", "checkedChange"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "component", type: MatMenu, selector: "mat-menu", inputs: ["backdropClass", "aria-label", "aria-labelledby", "aria-describedby", "xPosition", "yPosition", "overlapTrigger", "hasBackdrop", "class", "classList"], outputs: ["closed", "close"], exportAs: ["matMenu"] }, { kind: "directive", type: MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", inputs: ["mat-menu-trigger-for", "matMenuTriggerFor", "matMenuTriggerData", "matMenuTriggerRestoreFocus"], outputs: ["menuOpened", "onMenuOpen", "menuClosed", "onMenuClose"], exportAs: ["matMenuTrigger"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DataItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-data-item', standalone: true, imports: [
                        IconComponent,
                        TooltipDirective,
                        CopyContentDirective,
                        ReactiveFormsModule,
                        CheckboxComponent,
                        ButtonComponent,
                        MatMenu,
                        MatMenuTrigger,
                    ], template: "<div\n  (click)=\"onDataItemListItemTransferClick()\"\n  (dblclick)=\"onStartProcessClick($event)\"\n  [class.bulk-selected]=\"checkedForm.get('check')?.value\"\n  [class.locked]=\"lockedDataItem\"\n  [class.scroll-bar-margin]=\"\n    dataItemsService.virtualScrollerScrollableContentHeight$.value === dataItemsService.virtualScrollerHeight$.value\n  \"\n  [class.selected]=\"dataItem === selectedDataItem\"\n  class=\"data-item\"\n  data-testid=\"inbox-data-item-box\">\n  <div class=\"data-item-info\">\n    @if (!inboxState.inboxConfiguration$.value.disableNotesDataItemsList) {\n      <div [class.hide-icons]=\"dataItemsService.compressedDataItem$.value\" class=\"data-item-icons\">\n        @for (note of dataItem['notes']; track note.identifier) {\n          <talenra-icon\n            [class.locked]=\"lockedDataItem\"\n            [name]=\"note.icon\"\n            [class]=\"'color--' + note.activeIconColor\"\n            class=\"icon-font\"></talenra-icon>\n        }\n      </div>\n    }\n    <div #inboxDataItemContainer class=\"data-item-attributes\">\n      <div class=\"data-item-attributes-container\">\n        @for (item of firstChangedMainAttributes; track item.identifier; let index = $index) {\n          <div class=\"data-item-attributes-condensed-first\">\n            <div class=\"item-container\">\n              <div\n                #inboxDataItemContainerContent\n                [talenraTooltipDisabled]=\"\n                  inboxDataItemContainerContent.offsetWidth + 1 <= inboxDataItemContainer.scrollWidth\n                \"\n                [talenraTooltip]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                [textToCopy]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                class=\"attribute-pairing\">\n                @if (inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <span class=\"label-value-pairing\">\n                    <span [class.locked]=\"lockedDataItem\" class=\"label\">\n                      {{ item.label + ': ' }}\n                    </span>\n                    <span [class.locked]=\"lockedDataItem\" class=\"attribute-text\"\n                      >&nbsp;{{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}</span\n                    >\n                  </span>\n                }\n                @if (!inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <div [class.locked]=\"lockedDataItem\" class=\"attribute-text\">\n                    {{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}\n                  </div>\n                }\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n      <div class=\"data-item-attributes-container\">\n        @for (item of secondChangedMainAttributes; track item.identifier; let index = $index) {\n          <div class=\"data-item-attributes-condensed-second\">\n            <div class=\"item-container\">\n              <div\n                #inboxDataItemContainerContent\n                [talenraTooltipDisabled]=\"\n                  inboxDataItemContainerContent.offsetWidth + 1 <= inboxDataItemContainer.scrollWidth\n                \"\n                [talenraTooltip]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                [textToCopy]=\"dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier)\"\n                class=\"attribute-pairing\">\n                @if (inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <span class=\"label-value-pairing\">\n                    <span [class.locked]=\"lockedDataItem\" class=\"label\">\n                      {{ item.label + ': ' }}\n                    </span>\n                    <span [class.locked]=\"lockedDataItem\" class=\"attribute-text\"\n                      >&nbsp;{{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}</span\n                    >\n                  </span>\n                }\n                @if (!inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList) {\n                  <div [class.locked]=\"lockedDataItem\" class=\"attribute-text\">\n                    {{ dataItemsClass.getElemFromDataItemDisplayed(dataItem, item.identifier) }}\n                  </div>\n                }\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n    </div>\n  </div>\n\n  @if (!inboxState.inboxConfiguration$.value.disableInteractionsDataItemsList) {\n    <div [formGroup]=\"checkedForm\" class=\"data-item-interactions\">\n      @if (!inboxState.inboxConfiguration$.value.disableCheckboxDataItemsList && !lockedDataItem) {\n        <talenra-checkbox\n          (checkedChange)=\"onCheckedChange($event)\"\n          (click)=\"onCheckboxClick($event)\"\n          class=\"checkbox\"\n          data-testid=\"inbox-data-item-checkbox\"\n          formControlName=\"check\"\n          talenraTooltip=\"Markieren\"></talenra-checkbox>\n      }\n      @if (!inboxState.inboxConfiguration$.value.disableFurtherInteractionsDataItemsList && !lockedDataItem) {\n        <button\n          (click)=\"onGetActionsClick('mouse')\"\n          (menuClosed)=\"onActionsMenuClosed()\"\n          [disabled]=\"disableButtons || lockedDataItem\"\n          [matMenuTriggerFor]=\"furtherActions\"\n          data-testid=\"inbox-data-item-more-actions\"\n          icon=\"more-vert\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"Aktionen\"\n          tabindex=\"-1\"></button>\n      }\n      @if (!inboxState.inboxConfiguration$.value.disableContinueButtonDataItemsList && !lockedDataItem) {\n        <button\n          (click)=\"onStartProcessClick($event)\"\n          [disabled]=\"disableButtons || lockedDataItem\"\n          data-testid=\"inbox-data-item-process\"\n          icon=\"arrow-forward\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"Fall ausf\u00FChren\"></button>\n      }\n      @if (lockedDataItem) {\n        <talenra-icon [class.locked]=\"lockedDataItem\" class=\"locked-icon\" name=\"lock\"></talenra-icon>\n      }\n    </div>\n  }\n</div>\n\n<mat-menu #furtherActions hasBackdrop=\"true\" xPosition=\"before\">\n  <ng-content select=\"[further-actions-menu]\"></ng-content>\n</mat-menu>\n", styles: [":host{--color-background: #ffffff;--color-text: #000000;--color-locked-text: #b3b3b3;--color-label: #666666;--color-locked-label: #b3b3b3;--color-primary: #0099a8}.data-item{container:dataItem/inline-size;position:relative;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between;max-height:max-content;background-color:var(--color-background);padding:.5rem .0625rem .5rem 1.5rem;margin-bottom:.125rem;margin-right:.125rem;border-radius:.1875rem;border:.0625rem solid var(--color-background);-webkit-user-select:none;user-select:none}.data-item:before{content:\"\";position:absolute;top:50%;left:0;width:.25rem;height:0;background-color:transparent;transform:translateY(-50%);transition-property:height,background-color;transition-duration:.3s}.data-item.selected:before{height:100%;background-color:var(--color-primary)}.data-item.bulk-selected{border-color:var(--color-primary)}.data-item:hover{cursor:pointer}.data-item.locked{color:var(--color-locked-text)}.data-item.scroll-bar-margin{margin-right:0}.data-item-info{font-size:1rem;line-height:1.125rem;font-weight:300;font-style:normal;letter-spacing:.02em;flex:1 1 100%}.data-item-info .data-item-icons>*{padding-right:.375rem}.data-item-icons{opacity:1;margin-top:.3125rem;height:1.4375rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:flex-start;transition:opacity .3s,height .3s}.data-item-icons.hide-icons{opacity:0;height:0}.data-item-attributes{display:flex;flex-direction:row;flex-wrap:wrap;height:100%;width:100%}.data-item-attributes .data-item-attributes-condensed-first:first-child{font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em}.data-item-attributes-container{width:50%}.item-container{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;width:100%;min-width:.0625rem;padding-right:1.625rem}.attribute-pairing{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:block;min-width:.0625rem}.label-value-pairing{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.label{font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-label)}.label.locked{color:var(--color-locked-label)}.attribute-text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:block;min-width:.0625rem;color:var(--color-text)}.attribute-text.locked{color:var(--color-locked-text)}.data-item-interactions{margin-bottom:auto;margin-right:0;min-width:4.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:end;align-items:center}.checkbox{margin-right:.25rem}.icon-font{font-size:1.125rem}.icon-font.locked{opacity:.3}.locked-icon{margin-right:.25rem}.locked-icon.locked{color:var(--color-locked-text)}.color--status-red{color:#e20057}.color--status-green{color:#00d000}.color--status-orange{color:#e26000}.color--status-violet{color:#b103c7}.color--petrol{color:#0099a8}.color--petrol-dark{color:#005f71}.color--denim{color:#0069a3}.color--denim-dark{color:#04466a}.color--black{color:#000}.color--primary{color:var(--color-primary)}@container dataItem (max-width: 550px){.data-item-info{overflow:hidden}.data-item-attributes{flex-direction:column}.item-container{padding-right:0}.data-item-attributes-container{width:100%;max-width:fit-content}}@container dataItem (max-width: 270px){.data-item-interactions{flex-direction:column;min-width:1.75rem}}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-text: #cccccc;--color-locked-text: #4d4d4d;--color-label: #cccccc;--color-locked-label: #4d4d4d}\n"] }]
        }], propDecorators: { dataItem: [{
                type: Input
            }], selectedDataItem: [{
                type: Input
            }], selectedMainAttributes: [{
                type: Input
            }], pairingAttributes: [{
                type: Input
            }], disableButtons: [{
                type: Input
            }], checkboxValueChange: [{
                type: Input
            }], lockedDataItem: [{
                type: Input
            }], clickedDataItem: [{
                type: Output
            }], shiftDataItem: [{
                type: Output
            }], dataItemsInteractions: [{
                type: Output
            }], checkBoxInteraction: [{
                type: Output
            }], talenraInboxDataItemsListItemMenuTrigger: [{
                type: ViewChild,
                args: [MatMenuTrigger]
            }] } });

/**
 * One of the main components of the application. Responsible for ensuring that the transmitted data is properly structured to the user.
 *
 * ```html
 * <talenra-data-items-list
 *   [dataItemsChange]="filteredDataItems"
 *   [scrollToIndex]="keyboardService.scrollToIndex"
 *   [furtherActionsMenu]="furtherActionsMenu"
 *   (dataItemsInteractions)="onDataItemsInteractions($event)"
 *   (clickedDataItems)="selectedDataItem($event)"
 *   (scrollChange)="onScrollChange($event)"
 * ></talenra-data-items-list>
 * ```
 */
class DataItemsListComponent {
    constructor() {
        /**
         * Input attribute for the data items list to be displayed in the UI.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.dataItems = [];
        /**
         * Input attribute for the selected main attributes to be displayed in attributes settings and data items list.
         */
        this.selectedMainAttributes = [];
        /**
         * Input attribute to scroll to specific index
         */
        this.scrollToIndex = 0;
        /**
         * Checkbox state of the toolbar checkbox.
         * The state changes all the checkboxes in the data items list.
         * Outline: No checkbox is checked.
         * Indeterminate: Does not change the state of the checkboxes.
         * Checked: All checkboxes are checked.
         */
        this.mainCheckboxState = CheckboxState.Outline;
        /**
         * Transfer the clicked data item from the data item list to the data item sidebar information.
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.clickedDataItem = new EventEmitter();
        /**
         * EventEmitter to send data items interactions.
         */
        this.dataItemsInteractions = new EventEmitter();
        /**
         * EventEmitter to send change in Scroll Position.
         */
        this.virtualScrollChange = new EventEmitter();
        /**
         * EventEmitter to send change number of marked data items.
         */
        this.numberMarkedDataItemsChange = new EventEmitter();
        /**
         * Emitter for the change in the checkbox state of the toolbar checkbox.
         */
        this.mainCheckboxStateChange = new EventEmitter();
        /**
         * Class to interact with data-items-list-data.
         */
        this.dataItemsClass = new DataItemsClass();
        /**
         * List of all marked data items names
         */
        this.markedDataItems = [];
        /**
         * List of all locked data items inbox id's.
         */
        this.lockedDataItemsInboxId = [];
        /**
         * List of all data items names which have been marked through click on the checkbox
         */
        this.markedDataItemsFormGroupCheckboxes = [];
        /**
         * The data items service.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * Semaphore to stop accessing checkbox value a second time.
         * @internal
         */
        this.checkboxSemaphore = new BehaviorSubject(false);
        /**
         * Checks if content is initialized
         * @internal
         */
        this.initialized = false;
        /**
         * Subscriptions
         * @internal
         */
        this.subscriptions = new Subscription();
        /**
         * The element reference.
         * @private
         */
        this.elementRef = inject(ElementRef);
        /**
         * The zone to run the resize observer.
         * @private
         */
        this.zone = inject(NgZone);
        /**
         * Observers the size of the data items list to handle the scrollbar and set the width of the data items list.
         * @internal
         */
        this.observer = new ResizeObserver(() => {
            this.zone.run(() => {
                if (this.elementRef.nativeElement.children[0] !== undefined) {
                    this.dataItemsService.setVirtualScrollerHeight(this.elementRef.nativeElement.children[0].offsetHeight);
                }
                if (this.elementRef.nativeElement.children[0].children[0] !== undefined) {
                    this.dataItemsService.setVirtualScrollerScrollableContentHeight(this.elementRef.nativeElement.children[0].children[0].offsetHeight);
                }
                else {
                    this.dataItemsService.setVirtualScrollerScrollableContentHeight(this.elementRef.nativeElement.children[0].offsetHeight);
                }
            });
        });
    }
    /**
     * Initializes the data items list component.
     * @internal
     */
    ngOnInit() {
        // initialize checked list
        this.dataItems.forEach((value) => {
            const formGroup = {
                id: value['inboxId'],
                checked: new FormGroup({
                    check: new FormControl({ value: false, disabled: false }),
                }),
            };
            this.markedDataItemsFormGroupCheckboxes.push(formGroup);
            this.subscriptions.add(formGroup.checked.valueChanges.subscribe(() => {
                if (!this.checkboxSemaphore.value) {
                    this.handleMarkedDataItems(value);
                }
            }));
        });
    }
    /**
     * Detects changes of the input values.
     * @internal
     * @param {SimpleChanges} changes The changed input values.
     */
    ngOnChanges(changes) {
        const dataItemsChange = changes['dataItems'];
        if (dataItemsChange) {
            // reset internal list to the filtered items
            this.markedDataItems = [];
            // adjust the marked data items form group checkboxes to add/remove the new items
            if (!dataItemsChange.firstChange) {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                dataItemsChange.currentValue.forEach((value) => {
                    if (this.markedDataItemsFormGroupCheckboxes.find((x) => x.id === value['inboxId']) === undefined) {
                        const formGroup = {
                            id: value['inboxId'],
                            checked: new FormGroup({
                                check: new FormControl({ value: false, disabled: false }),
                            }),
                        };
                        this.markedDataItemsFormGroupCheckboxes.push(formGroup);
                    }
                });
            }
            // check if the data items are marked
            this.markedDataItemsFormGroupCheckboxes.forEach((elem) => {
                if (this.containsDataItem(elem.id) && elem.checked.get('check')?.value) {
                    this.markDataItem(elem.id);
                }
                else if (!this.containsDataItem(elem.id) && elem.checked.get('check')?.value) {
                    elem.checked.get('check')?.setValue(false);
                    this.unmarkDataItem(elem.id);
                }
            });
            this.setToolbarCheckboxState();
            // re observe to resize-observer after no data items message is shown
            if (this.dataItems.length !== 0 && this.initialized) {
                setTimeout(() => {
                    this.observer.observe(this.elementRef.nativeElement.firstElementChild);
                }, 0);
            }
        }
        const scrollToIndexChange = changes['scrollToIndex'];
        if (scrollToIndexChange && this.virtualScroller !== undefined) {
            this.virtualScroller.scrollToIndex(scrollToIndexChange.currentValue);
        }
        const lockedDataItemsChange = changes['lockedDataItems'];
        if (lockedDataItemsChange && this.virtualScroller !== undefined) {
            // set the locked data items inbox id list
            this.setLockedDataItem(lockedDataItemsChange.currentValue);
        }
        const mainCheckboxStateChange = changes['mainCheckboxState'];
        if (mainCheckboxStateChange && this.virtualScroller !== undefined) {
            // reset marked data items
            switch (mainCheckboxStateChange.currentValue) {
                case CheckboxState.Outline:
                    this.markedDataItems = [];
                    this.checkboxSemaphore.next(true);
                    this.markedDataItemsFormGroupCheckboxes.forEach((elem) => {
                        if (this.containsDataItem(elem.id)) {
                            elem.checked.get('check')?.setValue(false);
                        }
                    });
                    this.numberMarkedDataItemsChange.emit(this.numberMarkedDataItems());
                    this.dataItemsService.setSelectedIdDataItemsList(this.markedDataItems);
                    this.checkboxSemaphore.next(false);
                    break;
                case CheckboxState.Checked:
                    this.checkboxSemaphore.next(true);
                    this.markedDataItemsFormGroupCheckboxes.forEach((elem) => {
                        if (this.containsDataItem(elem.id) && !this.getLockedDataItem(elem.id)) {
                            elem.checked.get('check')?.setValue(true);
                        }
                    });
                    this.checkboxSemaphore.next(false);
                    this.markedDataItems = [];
                    this.dataItems.forEach((elem) => {
                        if (!this.getLockedDataItem(elem['inboxId'])) {
                            this.markDataItem(elem['inboxId']);
                        }
                    });
                    this.numberMarkedDataItemsChange.emit(this.numberMarkedDataItems());
                    this.dataItemsService.setSelectedIdDataItemsList(this.markedDataItems);
                    break;
                default:
                    break;
            }
        }
    }
    /**
     * Sets the visual state of the data items list.
     * Specifically for the compressed view and scrollbar design of the data items list.
     * @internal
     */
    ngAfterViewInit() {
        this.subscriptions.add(this.dataItemsService.compressedDataItem$.subscribe(() => {
            if (this.virtualScroller !== undefined) {
                const startIndex = this.virtualScroller.viewPortInfo.startIndex;
                // refresh the view
                if (startIndex === 0) {
                    this.virtualScroller.scrollToIndex(this.virtualScroller.viewPortInfo.startIndex - 1);
                }
            }
        }));
        // Listen to scroll events
        // - throttled for performance
        // - debounced to ensure we still catch the final scroll position
        const virtualScroller = document.getElementById('virtualScroller');
        virtualScroller &&
            this.subscriptions.add(fromEvent(virtualScroller, 'scroll')
                .pipe(throttleTime(150), tap(() => this.onScroll()))
                .subscribe());
        this.observer.observe(this.elementRef.nativeElement.firstElementChild);
        this.initialized = true;
    }
    /**
     * Unsubscribes from all subscriptions and unobserved from the resize observer.
     * @internal
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
        this.observer.unobserve(this.elementRef.nativeElement.firstElementChild);
    }
    /**
     * Depending on the clicked data items button the corresponding event actions will be shown.
     * @param {IInteractedDataItems} event The InterDataItemsModel with the clicked data item and information about the clicked button.
     */
    onDataItemsInteractions(event) {
        this.dataItemsInteractions.emit(event);
    }
    /**
     * Handler to mark data items, used by the emitter of a single data item.
     * @param {any} item Clicked data item.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    handleMarkedDataItems(item) {
        if (this.getMarkedDataItem(item['inboxId']) === item['inboxId']) {
            this.unmarkDataItem(item['inboxId']);
        }
        else {
            this.markDataItem(item['inboxId']);
        }
        this.setToolbarCheckboxState();
    }
    /**
     * Method to set the state of the toolbar checkbox.
     */
    setToolbarCheckboxState() {
        // get length of locked data items
        const lockedDataItemsLength = this.getLockedDataItemInboxIdList(this.lockedDataItems).length;
        // check if length of list to disable control of single items
        if (this.markedDataItems.length === 0) {
            this.mainCheckboxStateChange.emit(CheckboxState.Outline);
        }
        if (this.markedDataItems.length > 0) {
            this.mainCheckboxStateChange.emit(CheckboxState.Indeterminate);
        }
        if (this.markedDataItems.length >= this.dataItems.length - lockedDataItemsLength && this.dataItems.length != 0) {
            this.mainCheckboxStateChange.emit(CheckboxState.Checked);
        }
        // set number of checked data items
        this.numberMarkedDataItemsChange.emit(this.numberMarkedDataItems());
        this.dataItemsService.setSelectedIdDataItemsList(this.markedDataItems);
    }
    /**
     * Method to handle selected / clicked data items.
     * @param {any} item Clicked data items.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    onSelectClick(item) {
        this.selectedDataItem = item;
        this.clickedDataItem.emit(item);
        const index = this.dataItems.findIndex((x) => x['inboxId'] === this.selectedDataItem['inboxId']);
        index > this.dataItems.length && this.virtualScroller.scrollToIndex(index);
    }
    /**
     * Method to handle selected / clicked data items.
     * @param {any} item Clicked data item.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    onShiftDataItemClick(item) {
        const selectedItemIndex = this.dataItems.findIndex((dataItemList) => dataItemList['inboxId'] === this.selectedDataItem['inboxId']);
        const shiftItemIndex = this.dataItems.findIndex((dataItemList) => dataItemList['inboxId'] === item['inboxId']);
        const greater = selectedItemIndex <= shiftItemIndex;
        this.dataItems.forEach((value, index) => {
            if ((selectedItemIndex <= index && shiftItemIndex >= index && greater) ||
                (selectedItemIndex >= index && shiftItemIndex <= index && !greater)) {
                const formGroupItem = this.getFormGroupDataItemByID(value['inboxId'])?.get('check');
                // check if data item is locked
                // the form have to be got by inboxId because the caseItems are filtered and the markedCasesFormGroupCheckboxes are not
                if (!formGroupItem?.value && !this.getLockedDataItem(value['inboxId'])) {
                    formGroupItem?.setValue(true);
                }
            }
        });
    }
    /**
     * Method to handle scroll change.
     */
    onScroll() {
        setTimeout(() => {
            this.virtualScrollChange.emit(this.virtualScroller.viewPortInfo.scrollStartPosition);
        }, 50);
    }
    /**
     * Method to get data item by name.
     * @param {string} item Item name from the data item.
     */
    getFormGroupDataItemByID(item) {
        const value = this.markedDataItemsFormGroupCheckboxes.find((x) => x.id === item);
        if (value) {
            return value.checked;
        }
        return null;
    }
    /**
     * Auxiliary method to check if the data item is marked.
     * @param inboxId Data item id of the chosen data item.
     */
    checkIfDataItemMarked(inboxId) {
        return this.markedDataItems.includes(inboxId);
    }
    /**
     * Handles the interaction of one checkbox in the data items list.
     * @param event
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    onCheckboxInteraction(event) {
        this.getFormGroupDataItemByID(event.dataItem['inboxId'])?.get('check')?.setValue(event.checkedValue);
    }
    /**
     * Sets the locked data items for the data item list.
     * @param lockedDataItems The locked data items.
     */
    setLockedDataItem(lockedDataItems) {
        this.lockedDataItemsInboxId = this.getLockedDataItemInboxIdList(lockedDataItems);
    }
    /**
     * Gets the locked data items for the data item list.
     * @param lockedDataItems The locked data items.
     */
    getLockedDataItemInboxIdList(lockedDataItems) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const lockedDataItemsInboxId = [];
        if (lockedDataItems !== undefined) {
            lockedDataItems.forEach((dataItem) => {
                const index = this.dataItems.findIndex((value) => this.dataItemsClass.getElemFromDataItemDisplayed(value, dataItem.identifier) === dataItem.value);
                if (index !== -1) {
                    lockedDataItemsInboxId.push(this.dataItems[index]['inboxId']);
                }
            });
        }
        return lockedDataItemsInboxId;
    }
    /**
     * Gets the locked data item for the given item element.
     * @param itemInboxId The inbox id of the item.
     */
    getLockedDataItem(itemInboxId) {
        return this.lockedDataItemsInboxId.includes(itemInboxId);
    }
    /**
     * Auxiliary method to mark chosen data item.
     * @param {string} id Data item name of the marked data item.
     * @private
     * @internal
     */
    markDataItem(id) {
        this.markedDataItems.push(id);
    }
    /**
     * Auxiliary method to unmark chosen data item.
     * @param {string} id Data item name of the unmarked data item.
     * @private
     * @internal
     */
    unmarkDataItem(id) {
        this.markedDataItems.forEach((value, index) => {
            if (value == id)
                this.markedDataItems.splice(index, 1);
        });
    }
    /**
     * Auxiliary method to get the chosen data item.
     * @param {string} id Data item name of the chosen data item.
     * @private
     * @internal
     */
    getMarkedDataItem(id) {
        let value = '';
        this.markedDataItems.filter((elem) => {
            if (elem === id) {
                value = elem;
            }
        });
        return value;
    }
    /**
     * Auxiliary method to check if data item is contained in data items.
     * @param {string} id Data item name of the chosen data item.
     * @private
     * @internal
     */
    containsDataItem(id) {
        let bool = false;
        this.dataItems.forEach((elem) => {
            if (elem['inboxId'] === id) {
                bool = true;
                return;
            }
        });
        return bool;
    }
    /**
     * Auxiliary method to get the number of marked data items.
     * @private
     * @internal
     */
    numberMarkedDataItems() {
        let num = 0;
        this.markedDataItemsFormGroupCheckboxes.forEach((elem) => {
            if (elem.checked.get('check')?.value) {
                num++;
            }
        });
        return num;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DataItemsListComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: DataItemsListComponent, isStandalone: true, selector: "talenra-data-items-list", inputs: { dataItems: "dataItems", selectedDataItem: "selectedDataItem", selectedMainAttributes: "selectedMainAttributes", pairingAttributes: "pairingAttributes", scrollToIndex: "scrollToIndex", lockedDataItems: "lockedDataItems", mainCheckboxState: "mainCheckboxState" }, outputs: { clickedDataItem: "clickedDataItem", dataItemsInteractions: "dataItemsInteractions", virtualScrollChange: "virtualScrollChange", numberMarkedDataItemsChange: "numberMarkedDataItemsChange", mainCheckboxStateChange: "mainCheckboxStateChange" }, viewQueries: [{ propertyName: "virtualScroller", first: true, predicate: ["virtualScroller"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "@if (this.dataItems.length !== 0) {\n  <virtual-scroller #virtualScroller [items]=\"dataItems\" class=\"virtual-scroller\" id=\"virtualScroller\">\n    @for (item of virtualScroller.viewPortItems; track item) {\n      <talenra-data-item\n        (checkBoxInteraction)=\"onCheckboxInteraction($event)\"\n        (clickedDataItem)=\"onSelectClick(item)\"\n        (dataItemsInteractions)=\"onDataItemsInteractions($event)\"\n        (shiftDataItem)=\"onShiftDataItemClick(item)\"\n        [checkboxValueChange]=\"checkIfDataItemMarked(item['inboxId'])\"\n        [class.locked-data-item]=\"getLockedDataItem(item['inboxId'])\"\n        [dataItem]=\"item\"\n        [disableButtons]=\"markedDataItems.length > 1\"\n        [lockedDataItem]=\"getLockedDataItem(item['inboxId'])\"\n        [pairingAttributes]=\"pairingAttributes\"\n        [selectedDataItem]=\"selectedDataItem\"\n        [selectedMainAttributes]=\"selectedMainAttributes\"\n        id=\"talenraInboxDataItemsListItem\">\n        <ng-content ngProjectAs=\"[further-actions-menu]\" select=\"[further-actions-menu]\"></ng-content>\n      </talenra-data-item>\n    }\n    @if (dataItems.length > 0) {\n      <div class=\"last-data-item-buffer\"></div>\n    }\n  </virtual-scroller>\n} @else {\n  <div class=\"no-data-item-found-message-container\">\n    <talenra-message immutable kind=\"ghost\" text=\"Keine Ergebnisse gefunden.\"></talenra-message>\n  </div>\n}\n", styles: [":host{--color-no-data-item-background: #ffffff;--color-text: #000000}.virtual-scroller{width:100%;height:100%;position:absolute;scrollbar-color:rgba(0,0,0,.5) transparent}.last-data-item-buffer{height:1.5rem}.no-data-item-found-message-container{background:var(--color-no-data-item-background);color:var(--color-text);padding:.125rem 1.5rem}.appearance--dark :host{--color-no-data-item-background: #333333;--color-text: #cccccc}.appearance--dark :host .virtual-scroller{scrollbar-color:rgba(255,255,255,.5) transparent}\n"], dependencies: [{ kind: "ngmodule", type: VirtualScrollerModule }, { kind: "component", type: i1$1.VirtualScrollerComponent, selector: "virtual-scroller,[virtualScroller]", inputs: ["executeRefreshOutsideAngularZone", "enableUnequalChildrenSizes", "RTL", "useMarginInsteadOfTranslate", "modifyOverflowStyleOfParentScroll", "stripedTable", "scrollbarWidth", "scrollbarHeight", "childWidth", "childHeight", "ssrChildWidth", "ssrChildHeight", "ssrViewportWidth", "ssrViewportHeight", "bufferAmount", "scrollAnimationTime", "resizeBypassRefreshThreshold", "scrollThrottlingTime", "scrollDebounceTime", "checkResizeInterval", "items", "compareItems", "horizontal", "parentScroll"], outputs: ["vsUpdate", "vsChange", "vsStart", "vsEnd"], exportAs: ["virtualScroller"] }, { kind: "component", type: DataItemComponent, selector: "talenra-data-item", inputs: ["dataItem", "selectedDataItem", "selectedMainAttributes", "pairingAttributes", "disableButtons", "checkboxValueChange", "lockedDataItem"], outputs: ["clickedDataItem", "shiftDataItem", "dataItemsInteractions", "checkBoxInteraction"] }, { kind: "component", type: MessageComponent, selector: "talenra-message", inputs: ["identifier", "type", "level", "size", "kind", "text", "description", "immutable", "dismissible"], outputs: ["removeMessage"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DataItemsListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-data-items-list', standalone: true, imports: [VirtualScrollerModule, DataItemComponent, MessageComponent], template: "@if (this.dataItems.length !== 0) {\n  <virtual-scroller #virtualScroller [items]=\"dataItems\" class=\"virtual-scroller\" id=\"virtualScroller\">\n    @for (item of virtualScroller.viewPortItems; track item) {\n      <talenra-data-item\n        (checkBoxInteraction)=\"onCheckboxInteraction($event)\"\n        (clickedDataItem)=\"onSelectClick(item)\"\n        (dataItemsInteractions)=\"onDataItemsInteractions($event)\"\n        (shiftDataItem)=\"onShiftDataItemClick(item)\"\n        [checkboxValueChange]=\"checkIfDataItemMarked(item['inboxId'])\"\n        [class.locked-data-item]=\"getLockedDataItem(item['inboxId'])\"\n        [dataItem]=\"item\"\n        [disableButtons]=\"markedDataItems.length > 1\"\n        [lockedDataItem]=\"getLockedDataItem(item['inboxId'])\"\n        [pairingAttributes]=\"pairingAttributes\"\n        [selectedDataItem]=\"selectedDataItem\"\n        [selectedMainAttributes]=\"selectedMainAttributes\"\n        id=\"talenraInboxDataItemsListItem\">\n        <ng-content ngProjectAs=\"[further-actions-menu]\" select=\"[further-actions-menu]\"></ng-content>\n      </talenra-data-item>\n    }\n    @if (dataItems.length > 0) {\n      <div class=\"last-data-item-buffer\"></div>\n    }\n  </virtual-scroller>\n} @else {\n  <div class=\"no-data-item-found-message-container\">\n    <talenra-message immutable kind=\"ghost\" text=\"Keine Ergebnisse gefunden.\"></talenra-message>\n  </div>\n}\n", styles: [":host{--color-no-data-item-background: #ffffff;--color-text: #000000}.virtual-scroller{width:100%;height:100%;position:absolute;scrollbar-color:rgba(0,0,0,.5) transparent}.last-data-item-buffer{height:1.5rem}.no-data-item-found-message-container{background:var(--color-no-data-item-background);color:var(--color-text);padding:.125rem 1.5rem}.appearance--dark :host{--color-no-data-item-background: #333333;--color-text: #cccccc}.appearance--dark :host .virtual-scroller{scrollbar-color:rgba(255,255,255,.5) transparent}\n"] }]
        }], propDecorators: { dataItems: [{
                type: Input
            }], selectedDataItem: [{
                type: Input
            }], selectedMainAttributes: [{
                type: Input
            }], pairingAttributes: [{
                type: Input
            }], scrollToIndex: [{
                type: Input
            }], lockedDataItems: [{
                type: Input
            }], mainCheckboxState: [{
                type: Input
            }], clickedDataItem: [{
                type: Output
            }], dataItemsInteractions: [{
                type: Output
            }], virtualScrollChange: [{
                type: Output
            }], numberMarkedDataItemsChange: [{
                type: Output
            }], mainCheckboxStateChange: [{
                type: Output
            }], virtualScroller: [{
                type: ViewChild,
                args: ['virtualScroller']
            }] } });

/**
 * The further information of a data item is divided into different tabs to get a better overview of the presented data.
 * This component represents one general tab.
 *
 * ```html
 * <talenra-detail-view-information-tab
 *   [iconType]="assignment"
 *   [counter]="10"
 * ></talenra-detail-view-information-tab>
 * ```
 */
class DetailViewInformationTabComponent {
    constructor() {
        /**
         * Input attributes to set icon and badge count of tab component.
         */
        this.iconType = input.required();
        /**
         * The counter is used to display the number of items in the tab.
         */
        this.counter = input(0, { transform: numberAttribute });
        /**
         * The maximum value to display. If the actual value is greater than the max value, the max value will be displayed
         * followed by a plus sign.
         */
        this.maxBadgeCounter = input(99, {
            transform: (value) => (value === undefined ? 99 : value),
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationTabComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "19.1.6", type: DetailViewInformationTabComponent, isStandalone: true, selector: "talenra-detail-view-information-tab", inputs: { iconType: { classPropertyName: "iconType", publicName: "iconType", isSignal: true, isRequired: true, transformFunction: null }, counter: { classPropertyName: "counter", publicName: "counter", isSignal: true, isRequired: false, transformFunction: null }, maxBadgeCounter: { classPropertyName: "maxBadgeCounter", publicName: "maxBadgeCounter", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0, template: "<button [class]=\"'talenra-icon--' + iconType()\" class=\"button talenra-icon\"></button>\n<talenra-badge [counter]=\"counter()\" [maxVal]=\"maxBadgeCounter()\" class=\"badge\"></talenra-badge>\n", styles: [":host{position:relative;display:block;min-width:46px;flex-grow:.0001;border-top:4px solid #999999;transition:flex-grow .3s,border-top-color 1.2s}:host:hover,:host.selected{border-top-color:#0099a8}:host.stretched{flex-grow:1}.button{border:0;outline:none;appearance:none;background-color:transparent;width:100%;height:45px;margin-top:-4px;font-size:18px;color:#999;cursor:pointer;transition:color .3s}:host:hover .button,:host.selected .button{color:#0099a8}.badge{position:absolute;top:50%;left:50%;transform:translateY(-3px)}.appearance--dark :host{border-top-color:#666}.appearance--dark :host.selected{border-top-color:#0099a8}.theme--denim :host:hover,.theme--denim :host.selected{border-top-color:#0069a3}.theme--denim :host:hover .button,.theme--denim :host.selected .button{color:#0069a3}\n"], dependencies: [{ kind: "component", type: BadgeComponent, selector: "talenra-badge", inputs: ["counter", "maxVal"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationTabComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-detail-view-information-tab', standalone: true, imports: [BadgeComponent], template: "<button [class]=\"'talenra-icon--' + iconType()\" class=\"button talenra-icon\"></button>\n<talenra-badge [counter]=\"counter()\" [maxVal]=\"maxBadgeCounter()\" class=\"badge\"></talenra-badge>\n", styles: [":host{position:relative;display:block;min-width:46px;flex-grow:.0001;border-top:4px solid #999999;transition:flex-grow .3s,border-top-color 1.2s}:host:hover,:host.selected{border-top-color:#0099a8}:host.stretched{flex-grow:1}.button{border:0;outline:none;appearance:none;background-color:transparent;width:100%;height:45px;margin-top:-4px;font-size:18px;color:#999;cursor:pointer;transition:color .3s}:host:hover .button,:host.selected .button{color:#0099a8}.badge{position:absolute;top:50%;left:50%;transform:translateY(-3px)}.appearance--dark :host{border-top-color:#666}.appearance--dark :host.selected{border-top-color:#0099a8}.theme--denim :host:hover,.theme--denim :host.selected{border-top-color:#0069a3}.theme--denim :host:hover .button,.theme--denim :host.selected .button{color:#0069a3}\n"] }]
        }] });

/**
 * The accumulation of several tabs. This is where the basic arrangement of the tabs is set.
 *
 * ```html
 * <talenra-detail-view-information-tab-bar
 *   [dataItemInformationTabBarItems]="dataItemInformationTabBarItems"
 * ></talenra-detail-view-information-tab-bar>
 * ```
 */
class DetailViewInformationTabBarComponent {
    /** @internal */
    constructor() {
        /**
         * Information about key, label and icons that are initialized in data item information tab bar items
         */
        this.detailViewInformationTabBarItems = input.required();
        /**
         * The selected tab.
         */
        this.selectedTab = model.required();
        /**
         * Determines if the arrow navigation is active.
         */
        this.arrowNavigationActive = input(false);
        /**
         * The injected services.
         */
        this.keyboardService = inject(KeyboardService);
        this.destroyRef = inject(DestroyRef);
        // subscribe if the arrow right key is pressed to navigate to the next tab
        this.keyboardService.arrowRightKeyPressed.pipe(takeUntilDestroyed(this.destroyRef)).subscribe((pressed) => {
            if (pressed && this.arrowNavigationActive()) {
                this.arrowNavigateToNextTab();
            }
        });
        // subscribe if the arrow left key is pressed to navigate to the next tab
        this.keyboardService.arrowLeftKeyPressed.pipe(takeUntilDestroyed(this.destroyRef)).subscribe((pressed) => {
            if (pressed && this.arrowNavigationActive()) {
                this.arrowNavigateToPreviousTab();
            }
        });
    }
    /**
     * Selects the specific tab and expands the layout with layout service.
     * @param {string} key The name of the selected tab.
     */
    selectDataItemInformationTab(key) {
        this.selectedTab.set(key);
    }
    /**
     * Navigates to the next tab.
     */
    arrowNavigateToNextTab() {
        // find position of the selected tab
        const currentIndex = this.detailViewInformationTabBarItems().findIndex((item) => item.key === this.selectedTab());
        // get first tab
        const firstTab = this.detailViewInformationTabBarItems()[0];
        // get the next tab
        const nextTab = this.detailViewInformationTabBarItems()[currentIndex + 1];
        // if the selected tab is not found, set the first tab as selected
        if (currentIndex === -1 && firstTab) {
            firstTab.key && this.selectedTab.set(firstTab.key);
        }
        // if the last tab is selected, set the first tab as selected
        else if (currentIndex === this.detailViewInformationTabBarItems().length - 1 && firstTab) {
            firstTab.key && this.selectedTab.set(firstTab.key);
        }
        // if next tab is available set the next tab as selected
        else if (nextTab) {
            nextTab.key && this.selectedTab.set(nextTab.key);
        }
    }
    /**
     * Navigates to the previous tab.
     */
    arrowNavigateToPreviousTab() {
        // find position of the selected tab
        const currentIndex = this.detailViewInformationTabBarItems().findIndex((item) => item.key === this.selectedTab());
        // get first tab key
        const firstTab = this.detailViewInformationTabBarItems()[0];
        // get the previous tab key
        const previousTab = this.detailViewInformationTabBarItems()[currentIndex - 1];
        // get the last tab
        const lastTab = this.detailViewInformationTabBarItems()[this.detailViewInformationTabBarItems().length - 1];
        // if the selected tab is not found, set the first tab as selected
        if (currentIndex === -1 && firstTab) {
            firstTab.key && this.selectedTab.set(firstTab.key);
        }
        // if the first tab is selected, set the last tab as selected
        else if (currentIndex === 0 && lastTab) {
            lastTab.key && this.selectedTab.set(lastTab.key);
        }
        // if next tab is available set the next tab as selected
        else if (previousTab) {
            previousTab.key && this.selectedTab.set(previousTab.key);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationTabBarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: DetailViewInformationTabBarComponent, isStandalone: true, selector: "talenra-detail-view-information-tab-bar", inputs: { detailViewInformationTabBarItems: { classPropertyName: "detailViewInformationTabBarItems", publicName: "detailViewInformationTabBarItems", isSignal: true, isRequired: true, transformFunction: null }, selectedTab: { classPropertyName: "selectedTab", publicName: "selectedTab", isSignal: true, isRequired: true, transformFunction: null }, arrowNavigationActive: { classPropertyName: "arrowNavigationActive", publicName: "arrowNavigationActive", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { selectedTab: "selectedTabChange" }, ngImport: i0, template: "@for (dataItemInformationTabBarItem of detailViewInformationTabBarItems(); track dataItemInformationTabBarItem.key) {\n  <talenra-detail-view-information-tab\n    (click)=\"selectDataItemInformationTab(dataItemInformationTabBarItem.key ? dataItemInformationTabBarItem.key : '1')\"\n    [class.selected]=\"dataItemInformationTabBarItem.key === selectedTab()\"\n    [class.stretched]=\"dataItemInformationTabBarItem.key === selectedTab()\"\n    [counter]=\"dataItemInformationTabBarItem.counter?.value\"\n    [maxBadgeCounter]=\"dataItemInformationTabBarItem.maxCounter\"\n    [iconType]=\"dataItemInformationTabBarItem.icon\"\n    data-testid=\"inbox-detail-view-tab\"></talenra-detail-view-information-tab>\n}\n", styles: [":host{display:flex;justify-content:space-between;height:46px;background-color:#fff}:host>*+*{margin-left:8px}.collapse{border:0;outline:none;appearance:none;background-color:transparent;display:flex;justify-content:center;align-items:center;width:20px;height:45px;font-size:18px;color:#999;cursor:pointer;transition:color .3s,background-color .3s}.collapse:hover{color:#0099a8}.appearance--dark :host{background-color:#333}.theme--denim :host .collapse:hover{color:#0069a3}\n"], dependencies: [{ kind: "component", type: DetailViewInformationTabComponent, selector: "talenra-detail-view-information-tab", inputs: ["iconType", "counter", "maxBadgeCounter"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationTabBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-detail-view-information-tab-bar', standalone: true, imports: [DetailViewInformationTabComponent], template: "@for (dataItemInformationTabBarItem of detailViewInformationTabBarItems(); track dataItemInformationTabBarItem.key) {\n  <talenra-detail-view-information-tab\n    (click)=\"selectDataItemInformationTab(dataItemInformationTabBarItem.key ? dataItemInformationTabBarItem.key : '1')\"\n    [class.selected]=\"dataItemInformationTabBarItem.key === selectedTab()\"\n    [class.stretched]=\"dataItemInformationTabBarItem.key === selectedTab()\"\n    [counter]=\"dataItemInformationTabBarItem.counter?.value\"\n    [maxBadgeCounter]=\"dataItemInformationTabBarItem.maxCounter\"\n    [iconType]=\"dataItemInformationTabBarItem.icon\"\n    data-testid=\"inbox-detail-view-tab\"></talenra-detail-view-information-tab>\n}\n", styles: [":host{display:flex;justify-content:space-between;height:46px;background-color:#fff}:host>*+*{margin-left:8px}.collapse{border:0;outline:none;appearance:none;background-color:transparent;display:flex;justify-content:center;align-items:center;width:20px;height:45px;font-size:18px;color:#999;cursor:pointer;transition:color .3s,background-color .3s}.collapse:hover{color:#0099a8}.appearance--dark :host{background-color:#333}.theme--denim :host .collapse:hover{color:#0069a3}\n"] }]
        }], ctorParameters: () => [] });

/**
 * The data item information tab bar and data item information components are merged into the data item information box
 * for better handling.
 *
 * ```html
 * <talenra-detail-view-information-box
 *   [dataItemInformationTabBarItems]="dataItemInformationTabBarItems"
 * ></talenra-detail-view-information-box>
 * ```
 */
class DetailViewInformationBoxComponent {
    constructor() {
        /**
         * List of all data item information tab bar items
         */
        this.detailViewInformationTabBarItems = input.required();
        /**
         * The public service of the inbox detail view.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
        this.inboxToolbarService = inject(InboxToolbarService);
        /**
         * Subscriptions of the data item information box.
         *  @internal
         */
        this.subscriptions = new Subscription();
    }
    /**
     * Unsubscribe from all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
    }
    /**
     * Selects the specific tab and expands the layout with layout service.
     * @param key The key of the selected tab.
     */
    onTabChange(key) {
        this.inboxDetailViewService.setSelectedDetailViewTab(key);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationBoxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: DetailViewInformationBoxComponent, isStandalone: true, selector: "talenra-detail-view-information-box", inputs: { detailViewInformationTabBarItems: { classPropertyName: "detailViewInformationTabBarItems", publicName: "detailViewInformationTabBarItems", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0, template: "@if (inboxDetailViewService.detailViewExpanded$ | async) {\n  <talenra-detail-view-information-tab-bar\n    (selectedTabChange)=\"onTabChange($event)\"\n    [arrowNavigationActive]=\"\n      (inboxDetailViewService.detailViewExpanded$ | async) === true &&\n      (inboxToolbarService.configurationPanelExpanded$ | async) === false\n    \"\n    [detailViewInformationTabBarItems]=\"detailViewInformationTabBarItems()\"\n    [selectedTab]=\"inboxDetailViewService.selectedDetailViewTab$.value\"></talenra-detail-view-information-tab-bar>\n}\n\n<div class=\"panels\">\n  <div class=\"panels-inner\">\n    <ng-content select=\"[data-item-information-outlet]\"></ng-content>\n  </div>\n</div>\n", styles: [":host{--color-background: #ffffff;--color-text: #000000}.panels{display:block;overflow:hidden;height:calc(100% - 46px);width:100%;background-color:var(--color-background);color:var(--color-text)}.panels-inner{position:relative;width:100%;height:100%}.appearance--dark :host{--color-background: #333333;--color-text: #cccccc}\n"], dependencies: [{ kind: "component", type: DetailViewInformationTabBarComponent, selector: "talenra-detail-view-information-tab-bar", inputs: ["detailViewInformationTabBarItems", "selectedTab", "arrowNavigationActive"], outputs: ["selectedTabChange"] }, { kind: "pipe", type: AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: DetailViewInformationBoxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-detail-view-information-box', standalone: true, imports: [DetailViewInformationTabBarComponent, AsyncPipe], template: "@if (inboxDetailViewService.detailViewExpanded$ | async) {\n  <talenra-detail-view-information-tab-bar\n    (selectedTabChange)=\"onTabChange($event)\"\n    [arrowNavigationActive]=\"\n      (inboxDetailViewService.detailViewExpanded$ | async) === true &&\n      (inboxToolbarService.configurationPanelExpanded$ | async) === false\n    \"\n    [detailViewInformationTabBarItems]=\"detailViewInformationTabBarItems()\"\n    [selectedTab]=\"inboxDetailViewService.selectedDetailViewTab$.value\"></talenra-detail-view-information-tab-bar>\n}\n\n<div class=\"panels\">\n  <div class=\"panels-inner\">\n    <ng-content select=\"[data-item-information-outlet]\"></ng-content>\n  </div>\n</div>\n", styles: [":host{--color-background: #ffffff;--color-text: #000000}.panels{display:block;overflow:hidden;height:calc(100% - 46px);width:100%;background-color:var(--color-background);color:var(--color-text)}.panels-inner{position:relative;width:100%;height:100%}.appearance--dark :host{--color-background: #333333;--color-text: #cccccc}\n"] }]
        }] });

/**
 * The data item information box and inbox note-box are merged into the inbox detail view for better handling.
 *
 * ```html
 * <talenra-inbox-detail-view [dataItemInformationTabBarItems]="dataItemInformationTabBarItems">
 *   <ng-content inbox-note-box> ... </ng-content>
 *   <ng-content detail-view-information-outlet"> ... </ng-content>
 * </talenra-inbox-detail-view>
 * ```
 */
class InboxDetailViewComponent {
    constructor() {
        /**
         * Items used to initialize the tab bar with content.
         */
        this.dataItemInformationTabBarItems = input.required();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxDetailViewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "19.1.6", type: InboxDetailViewComponent, isStandalone: true, selector: "talenra-inbox-detail-view", inputs: { dataItemInformationTabBarItems: { classPropertyName: "dataItemInformationTabBarItems", publicName: "dataItemInformationTabBarItems", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0, template: "<ng-content select=\"[inbox-note-box]\"></ng-content>\n<talenra-detail-view-information-box\n  [detailViewInformationTabBarItems]=\"dataItemInformationTabBarItems()\"\n  class=\"ui-data-item-information-box\">\n  <ng-content ngProjectAs=\"[data-item-information-outlet]\" select=\"[data-item-information-outlet]\"></ng-content>\n</talenra-detail-view-information-box>\n", styles: [":host{display:flex;flex-direction:column;flex-wrap:nowrap}.ui-data-item-information-box{flex-grow:1}\n"], dependencies: [{ kind: "component", type: DetailViewInformationBoxComponent, selector: "talenra-detail-view-information-box", inputs: ["detailViewInformationTabBarItems"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxDetailViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-detail-view', standalone: true, imports: [DetailViewInformationBoxComponent], template: "<ng-content select=\"[inbox-note-box]\"></ng-content>\n<talenra-detail-view-information-box\n  [detailViewInformationTabBarItems]=\"dataItemInformationTabBarItems()\"\n  class=\"ui-data-item-information-box\">\n  <ng-content ngProjectAs=\"[data-item-information-outlet]\" select=\"[data-item-information-outlet]\"></ng-content>\n</talenra-detail-view-information-box>\n", styles: [":host{display:flex;flex-direction:column;flex-wrap:nowrap}.ui-data-item-information-box{flex-grow:1}\n"] }]
        }] });

/**
 * Parent component of data items list and inbox detail view for better structure and handling.
 *
 * ```html
 * <talenra-inbox-layout
 *   [detailViewInformationTabBarItems]="dataItemInformationTabBarItems"
 *   [usePagination]="usePagination">
 *   <talenra-data-items-list>
 *     <div further-actions-menu>...</div>
 *   </talenra-data-items-list>
 * </talenra-inbox-layout>
 * ```
 */
class InboxLayoutComponent {
    constructor() {
        /**
         * List of all data item information tab bar items
         */
        this.detailViewInformationTabBarItems = input.required();
        /**
         * If true, the pagination feature is enabled.
         *
         * ```html
         * <talenra-inbox [attributes]="attributes" usePagination>...</talenra-inbox>
         * ```
         */
        this.usePagination = false;
        /**
         * Vertical width of sidePanel, when opened.
         */
        this.detailViewWidth = 360;
        /**
         * Vertical width of sidePanel, when closed.
         */
        this.panelWidth = {
            width: `0px`,
        };
        /**
         Vertical default width of sidePanel.
         */
        this.defaultPanelWidth = {
            left: `0px`,
        };
        /**
         * Controls the time frame in which resizing is used.
         */
        this.isResizing$ = new BehaviorSubject(false);
        /**
         * The state of the inbox.
         */
        this.inboxState = inject(InboxState);
        /**
         * Injected inbox detail view service.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
        /**
         * The data items service.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * The keyboard service.
         */
        this.keyboardService = inject(KeyboardService);
        /**
         * Vertical width of sidePanel, when closed.
         */
        this.minPanelWidth = 260;
    }
    /**
     * Setter for the controls.
     * @param {boolean} isResizing True if resizing is used, false if not.
     */
    setResizing(isResizing) {
        this.isResizing$.next(isResizing);
    }
    /**
     * Closes the side panel after half of the minimum width has been reached
     * @param event Event of the resizing.
     * @internal
     */
    onResizing(event) {
        if (event.size.width < this.minPanelWidth / 2) {
            this.setResizing(false);
            this.inboxDetailViewService.setDetailViewExpanded(false);
        }
    }
    /**
     * Shuts down slow transition (lag), while resizing.
     * @internal
     */
    onResizeStart() {
        this.setResizing(true);
    }
    /**
     * Normalizes slow transition (lag), after Resizing for closing the smooth closing transition.
     * @internal
     */
    onResizeStop() {
        // set width after resizing to chosen real value
        const element = document.getElementById('talenraInboxDetailView');
        this.detailViewWidth = element ? element.offsetWidth : 360;
        // reset chosen big detail view screen (if it was chosen)x
        if (this.keyboardService.bigDetailViewScreen.value) {
            this.keyboardService.bigDetailViewScreen.next(false);
        }
        this.setResizing(false);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxLayoutComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: InboxLayoutComponent, isStandalone: true, selector: "talenra-inbox-layout", inputs: { detailViewInformationTabBarItems: { classPropertyName: "detailViewInformationTabBarItems", publicName: "detailViewInformationTabBarItems", isSignal: true, isRequired: true, transformFunction: null }, usePagination: { classPropertyName: "usePagination", publicName: "usePagination", isSignal: false, isRequired: false, transformFunction: booleanAttribute } }, ngImport: i0, template: "<div\n  [class.expanded]=\"\n    inboxDetailViewService.detailViewExpanded$.value && !inboxState.inboxConfiguration$.value.disableDetailView\n  \"\n  [class.no-scroll-bar-expanded]=\"\n    dataItemsService.virtualScrollerScrollableContentHeight$.value < dataItemsService.virtualScrollerHeight$.value &&\n    (inboxDetailViewService.detailViewExpanded$ | async) &&\n    !inboxState.inboxConfiguration$.value.disableDetailView\n  \"\n  [class.paginator]=\"usePagination\"\n  class=\"data-items-list-paginator-wrapper\">\n  <div [class.use-paginator]=\"usePagination\" class=\"data-items-list\">\n    <div class=\"content\">\n      <div class=\"data-items-list-wrapper\">\n        <ng-content></ng-content>\n      </div>\n    </div>\n  </div>\n  @if (usePagination) {\n    <div\n      [class.detail-view-collapsed]=\"\n        !(inboxDetailViewService.detailViewExpanded$.value && !inboxState.inboxConfiguration$.value.disableDetailView)\n      \"\n      [class.detail-view-collapsed-no-scroll-bar]=\"\n        dataItemsService.virtualScrollerScrollableContentHeight$.value <\n          dataItemsService.virtualScrollerHeight$.value &&\n        !(\n          (inboxDetailViewService.detailViewExpanded$ | async) &&\n          !inboxState.inboxConfiguration$.value.disableDetailView\n        )\n      \"\n      [class.detail-view-expanded-no-scroll-bar]=\"\n        dataItemsService.virtualScrollerScrollableContentHeight$.value <\n          dataItemsService.virtualScrollerHeight$.value &&\n        (inboxDetailViewService.detailViewExpanded$ | async) &&\n        !inboxState.inboxConfiguration$.value.disableDetailView\n      \"\n      [class.detail-view-expanded-has-scroll-bar]=\"\n        dataItemsService.virtualScrollerScrollableContentHeight$.value >=\n          dataItemsService.virtualScrollerHeight$.value &&\n        (inboxDetailViewService.detailViewExpanded$ | async) &&\n        !inboxState.inboxConfiguration$.value.disableDetailView\n      \"\n      class=\"paginator\">\n      <ng-content select=\"[inbox-paginator]\"></ng-content>\n    </div>\n  }\n</div>\n\n@if (!inboxState.inboxConfiguration$.value.disableDetailView) {\n  <talenra-inbox-detail-view\n    (rzResizing)=\"onResizing($event)\"\n    (rzStart)=\"onResizeStart()\"\n    (rzStop)=\"onResizeStop()\"\n    [dataItemInformationTabBarItems]=\"detailViewInformationTabBarItems()\"\n    [class.expanded]=\"inboxDetailViewService.detailViewExpanded$ | async\"\n    [class.stop-transition]=\"isResizing$ | async\"\n    [class.no-scroll-bar]=\"\n      (inboxDetailViewService.detailViewExpanded$ | async) === false &&\n      dataItemsService.virtualScrollerScrollableContentHeight$.value < dataItemsService.virtualScrollerHeight$.value &&\n      inboxState.inboxConfiguration$.value.disableDataItemsList !== true\n    \"\n    [ngResizable]=\"inboxDetailViewService.detailViewExpanded$ | async\"\n    [ngStyle]=\"(inboxDetailViewService.detailViewExpanded$ | async) ? defaultPanelWidth : panelWidth\"\n    [rzHandles]=\"'w'\"\n    [style.width]=\"(keyboardService.bigDetailViewScreen | async) ? '100%' : detailViewWidth + 'px'\"\n    class=\"inbox-detail-view\"\n    id=\"talenraInboxDetailView\">\n    <ng-content ngProjectAs=\"[data-item-information-outlet]\" select=\"[data-item-information-outlet]\"></ng-content>\n    <ng-content ngProjectAs=\"[inbox-note-box]\" select=\"[inbox-note-box]\"></ng-content>\n  </talenra-inbox-detail-view>\n}\n", styles: [":host{position:relative;display:flex;justify-content:space-between;flex-grow:1;height:100%;margin-top:.5rem;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased}.data-items-list-paginator-wrapper{display:flex;flex-direction:column;justify-content:center;flex-grow:1;min-width:270px;margin-right:0;transition:width .3s;height:100%}.data-items-list-paginator-wrapper.expanded{margin-right:.25rem}.data-items-list-paginator-wrapper.no-scroll-bar-expanded{margin-right:.5rem}.data-items-list{display:flex;justify-content:center;flex-grow:1;height:100%}.data-items-list.no-scroll-bar-expanded{margin-right:.5rem}.data-items-list.use-paginator{height:calc(100% - 3.5rem)}.data-items-list-wrapper{width:100%;height:100%;position:absolute}.content{overflow:hidden;position:relative;width:100%;max-width:87.5rem}.paginator.detail-view-collapsed{margin-right:1rem}.paginator.detail-view-collapsed-no-scroll-bar{margin-right:0}.paginator.detail-view-expanded-no-scroll-bar{margin-right:.125rem}.paginator.detail-view-expanded-has-scroll-bar{margin-right:1rem}.inbox-detail-view{position:sticky;height:100%;width:0;min-width:0;opacity:0;padding-right:0;transition:width .3s,opacity .3s .1s,min-width .3s,padding-right .1s,margin-right .1s}.inbox-detail-view.expanded{width:360px;min-width:260px;opacity:1;margin-right:1rem}.inbox-detail-view.stop-transition{transition:width 0s}.inbox-detail-view.no-scroll-bar{margin-right:1rem}@media (max-width: 43.375em){.inbox-detail-view{position:sticky;height:100%;right:0;z-index:59;opacity:0}.inbox-detail-view:after{content:\"\";position:absolute;top:0;left:0;bottom:0;width:.0625rem;opacity:0;transition:opacity .3s}.inbox-detail-view.expanded{display:none;transition:width .3s,opacity .3s .1s}.inbox-detail-view.expanded:after{opacity:1}}@media (max-width: 43.375em){.data-items-list{margin-right:0}.data-items-list.expanded{margin-right:0;transition:margin-right .3s}}@media (min-width: 99.25em) and (max-width: 114.615em){.panels-inner,.inbox-detail-view.expanded{width:360px-0.0625rem}.data-items-list.expanded{margin-right:.25rem}}@media (min-width: 114.625em){.panels-inner,.inbox-detail-view.expanded{width:418px-0.0625rem}.data-items-list.expanded{margin-right:.25rem}}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "component", type: InboxDetailViewComponent, selector: "talenra-inbox-detail-view", inputs: ["dataItemInformationTabBarItems"] }, { kind: "ngmodule", type: AngularDraggableModule }, { kind: "directive", type: i1$2.AngularResizableDirective, selector: "[ngResizable]", inputs: ["ngResizable", "rzHandles", "rzHandleDoms", "rzAspectRatio", "rzContainment", "rzGrid", "rzMinWidth", "rzMinHeight", "rzMaxWidth", "rzMaxHeight", "rzScale", "preventDefaultEvent"], outputs: ["rzStart", "rzResizing", "rzStop"], exportAs: ["ngResizable"] }, { kind: "directive", type: NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxLayoutComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-layout', standalone: true, imports: [AsyncPipe, InboxDetailViewComponent, AngularDraggableModule, NgStyle], template: "<div\n  [class.expanded]=\"\n    inboxDetailViewService.detailViewExpanded$.value && !inboxState.inboxConfiguration$.value.disableDetailView\n  \"\n  [class.no-scroll-bar-expanded]=\"\n    dataItemsService.virtualScrollerScrollableContentHeight$.value < dataItemsService.virtualScrollerHeight$.value &&\n    (inboxDetailViewService.detailViewExpanded$ | async) &&\n    !inboxState.inboxConfiguration$.value.disableDetailView\n  \"\n  [class.paginator]=\"usePagination\"\n  class=\"data-items-list-paginator-wrapper\">\n  <div [class.use-paginator]=\"usePagination\" class=\"data-items-list\">\n    <div class=\"content\">\n      <div class=\"data-items-list-wrapper\">\n        <ng-content></ng-content>\n      </div>\n    </div>\n  </div>\n  @if (usePagination) {\n    <div\n      [class.detail-view-collapsed]=\"\n        !(inboxDetailViewService.detailViewExpanded$.value && !inboxState.inboxConfiguration$.value.disableDetailView)\n      \"\n      [class.detail-view-collapsed-no-scroll-bar]=\"\n        dataItemsService.virtualScrollerScrollableContentHeight$.value <\n          dataItemsService.virtualScrollerHeight$.value &&\n        !(\n          (inboxDetailViewService.detailViewExpanded$ | async) &&\n          !inboxState.inboxConfiguration$.value.disableDetailView\n        )\n      \"\n      [class.detail-view-expanded-no-scroll-bar]=\"\n        dataItemsService.virtualScrollerScrollableContentHeight$.value <\n          dataItemsService.virtualScrollerHeight$.value &&\n        (inboxDetailViewService.detailViewExpanded$ | async) &&\n        !inboxState.inboxConfiguration$.value.disableDetailView\n      \"\n      [class.detail-view-expanded-has-scroll-bar]=\"\n        dataItemsService.virtualScrollerScrollableContentHeight$.value >=\n          dataItemsService.virtualScrollerHeight$.value &&\n        (inboxDetailViewService.detailViewExpanded$ | async) &&\n        !inboxState.inboxConfiguration$.value.disableDetailView\n      \"\n      class=\"paginator\">\n      <ng-content select=\"[inbox-paginator]\"></ng-content>\n    </div>\n  }\n</div>\n\n@if (!inboxState.inboxConfiguration$.value.disableDetailView) {\n  <talenra-inbox-detail-view\n    (rzResizing)=\"onResizing($event)\"\n    (rzStart)=\"onResizeStart()\"\n    (rzStop)=\"onResizeStop()\"\n    [dataItemInformationTabBarItems]=\"detailViewInformationTabBarItems()\"\n    [class.expanded]=\"inboxDetailViewService.detailViewExpanded$ | async\"\n    [class.stop-transition]=\"isResizing$ | async\"\n    [class.no-scroll-bar]=\"\n      (inboxDetailViewService.detailViewExpanded$ | async) === false &&\n      dataItemsService.virtualScrollerScrollableContentHeight$.value < dataItemsService.virtualScrollerHeight$.value &&\n      inboxState.inboxConfiguration$.value.disableDataItemsList !== true\n    \"\n    [ngResizable]=\"inboxDetailViewService.detailViewExpanded$ | async\"\n    [ngStyle]=\"(inboxDetailViewService.detailViewExpanded$ | async) ? defaultPanelWidth : panelWidth\"\n    [rzHandles]=\"'w'\"\n    [style.width]=\"(keyboardService.bigDetailViewScreen | async) ? '100%' : detailViewWidth + 'px'\"\n    class=\"inbox-detail-view\"\n    id=\"talenraInboxDetailView\">\n    <ng-content ngProjectAs=\"[data-item-information-outlet]\" select=\"[data-item-information-outlet]\"></ng-content>\n    <ng-content ngProjectAs=\"[inbox-note-box]\" select=\"[inbox-note-box]\"></ng-content>\n  </talenra-inbox-detail-view>\n}\n", styles: [":host{position:relative;display:flex;justify-content:space-between;flex-grow:1;height:100%;margin-top:.5rem;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased}.data-items-list-paginator-wrapper{display:flex;flex-direction:column;justify-content:center;flex-grow:1;min-width:270px;margin-right:0;transition:width .3s;height:100%}.data-items-list-paginator-wrapper.expanded{margin-right:.25rem}.data-items-list-paginator-wrapper.no-scroll-bar-expanded{margin-right:.5rem}.data-items-list{display:flex;justify-content:center;flex-grow:1;height:100%}.data-items-list.no-scroll-bar-expanded{margin-right:.5rem}.data-items-list.use-paginator{height:calc(100% - 3.5rem)}.data-items-list-wrapper{width:100%;height:100%;position:absolute}.content{overflow:hidden;position:relative;width:100%;max-width:87.5rem}.paginator.detail-view-collapsed{margin-right:1rem}.paginator.detail-view-collapsed-no-scroll-bar{margin-right:0}.paginator.detail-view-expanded-no-scroll-bar{margin-right:.125rem}.paginator.detail-view-expanded-has-scroll-bar{margin-right:1rem}.inbox-detail-view{position:sticky;height:100%;width:0;min-width:0;opacity:0;padding-right:0;transition:width .3s,opacity .3s .1s,min-width .3s,padding-right .1s,margin-right .1s}.inbox-detail-view.expanded{width:360px;min-width:260px;opacity:1;margin-right:1rem}.inbox-detail-view.stop-transition{transition:width 0s}.inbox-detail-view.no-scroll-bar{margin-right:1rem}@media (max-width: 43.375em){.inbox-detail-view{position:sticky;height:100%;right:0;z-index:59;opacity:0}.inbox-detail-view:after{content:\"\";position:absolute;top:0;left:0;bottom:0;width:.0625rem;opacity:0;transition:opacity .3s}.inbox-detail-view.expanded{display:none;transition:width .3s,opacity .3s .1s}.inbox-detail-view.expanded:after{opacity:1}}@media (max-width: 43.375em){.data-items-list{margin-right:0}.data-items-list.expanded{margin-right:0;transition:margin-right .3s}}@media (min-width: 99.25em) and (max-width: 114.615em){.panels-inner,.inbox-detail-view.expanded{width:360px-0.0625rem}.data-items-list.expanded{margin-right:.25rem}}@media (min-width: 114.625em){.panels-inner,.inbox-detail-view.expanded{width:418px-0.0625rem}.data-items-list.expanded{margin-right:.25rem}}\n"] }]
        }], propDecorators: { usePagination: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

class SkeletonLoadingDataItemsListComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SkeletonLoadingDataItemsListComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: SkeletonLoadingDataItemsListComponent, isStandalone: true, selector: "talenra-skeleton-loading-data-items-list", ngImport: i0, template: "<div class=\"skeleton-data-items-list\">\n  @for (number of [0, 1, 2, 3, 4]; track number) {\n    <div class=\"skeleton-data-items-list-item\">\n      <div class=\"skeleton-data-items-list-item-left\">\n        <div class=\"skeleton-data-items-list-item-icon\">\n          @for (number of [0, 1, 2]; track number) {\n            <div class=\"skeleton skeleton-data-items-list-item-icon-item\"></div>\n          }\n        </div>\n        <div class=\"skeleton-data-items-list-item-information\">\n          @for (number of [0, 1, 2]; track number) {\n            <div class=\"skeleton skeleton-data-items-list-item-information-item\"></div>\n          }\n        </div>\n      </div>\n      <div class=\"skeleton-data-items-list-item-right\">\n        <div class=\"skeleton-data-items-list-item-actions\">\n          @for (number of [0, 1, 2]; track number) {\n            <div class=\"skeleton skeleton-data-items-list-item-actions-item\"></div>\n          }\n        </div>\n      </div>\n    </div>\n  }\n</div>\n", styles: [":host{--color-background: #ffffff;--color-animation-background: #f2f2f2}.skeleton{animation:skeleton-loading 1s linear infinite alternate}@keyframes skeleton-loading{0%{background-color:var(--color-animation-background) 50%}to{background-color:var(--color-animation-background)}}:host{position:relative;display:flex;justify-content:center}.skeleton-data-items-list{width:100%}.skeleton-data-items-list>:nth-child(3){opacity:.8}.skeleton-data-items-list>:nth-child(4){opacity:.6}.skeleton-data-items-list>:nth-child(5){opacity:.4}.skeleton-data-items-list-item{width:100%;height:5.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;max-height:max-content;background:var(--color-background);padding-top:.5rem;padding-bottom:.375rem;margin-bottom:.125rem;margin-right:.125rem;border-radius:.125rem}.skeleton-data-items-list-item-left{width:50%;margin-left:1.5rem}.skeleton-data-items-list-item-left .skeleton-data-items-list-item-icons>*{padding-right:.375rem}.skeleton-data-items-list-item-right{width:15%;margin-left:auto;margin-bottom:auto;margin-right:0;display:flex;flex-direction:column;flex-wrap:nowrap;align-items:center}.skeleton-data-items-list-item-icon{width:100%;height:1.375rem;margin-bottom:.0625rem;display:flex;flex-direction:row;flex-wrap:nowrap}.skeleton-data-items-list-item-icon-item{margin-right:.5rem;height:1.125rem;width:1.125rem;border-radius:1.125rem}.skeleton-data-items-list-item-information{height:3.375rem;margin-bottom:.0625rem;display:flex;flex-direction:column;flex-wrap:nowrap}.skeleton-data-items-list-item-information-item{width:80%;height:.5rem;margin-top:.625rem;margin-bottom:.0625rem;border-radius:.1875rem}.skeleton-data-items-list-item-information-item:first-child{width:40%;margin-top:.375rem}.skeleton-data-items-list-item-information-item:last-child{width:60%}.skeleton-data-items-list-item-actions{width:100%;height:1.375rem;display:flex;flex-direction:row-reverse;flex-wrap:nowrap}.skeleton-data-items-list-item-actions-item{margin-left:.5rem;height:1.125rem;width:1.125rem;border-radius:1.125rem}.skeleton-data-items-list-item-actions-item:first-child{margin-right:1rem}.appearance--dark :host{--color-background: #333333;--color-animation-background: #666666}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SkeletonLoadingDataItemsListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-skeleton-loading-data-items-list', standalone: true, imports: [], template: "<div class=\"skeleton-data-items-list\">\n  @for (number of [0, 1, 2, 3, 4]; track number) {\n    <div class=\"skeleton-data-items-list-item\">\n      <div class=\"skeleton-data-items-list-item-left\">\n        <div class=\"skeleton-data-items-list-item-icon\">\n          @for (number of [0, 1, 2]; track number) {\n            <div class=\"skeleton skeleton-data-items-list-item-icon-item\"></div>\n          }\n        </div>\n        <div class=\"skeleton-data-items-list-item-information\">\n          @for (number of [0, 1, 2]; track number) {\n            <div class=\"skeleton skeleton-data-items-list-item-information-item\"></div>\n          }\n        </div>\n      </div>\n      <div class=\"skeleton-data-items-list-item-right\">\n        <div class=\"skeleton-data-items-list-item-actions\">\n          @for (number of [0, 1, 2]; track number) {\n            <div class=\"skeleton skeleton-data-items-list-item-actions-item\"></div>\n          }\n        </div>\n      </div>\n    </div>\n  }\n</div>\n", styles: [":host{--color-background: #ffffff;--color-animation-background: #f2f2f2}.skeleton{animation:skeleton-loading 1s linear infinite alternate}@keyframes skeleton-loading{0%{background-color:var(--color-animation-background) 50%}to{background-color:var(--color-animation-background)}}:host{position:relative;display:flex;justify-content:center}.skeleton-data-items-list{width:100%}.skeleton-data-items-list>:nth-child(3){opacity:.8}.skeleton-data-items-list>:nth-child(4){opacity:.6}.skeleton-data-items-list>:nth-child(5){opacity:.4}.skeleton-data-items-list-item{width:100%;height:5.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;max-height:max-content;background:var(--color-background);padding-top:.5rem;padding-bottom:.375rem;margin-bottom:.125rem;margin-right:.125rem;border-radius:.125rem}.skeleton-data-items-list-item-left{width:50%;margin-left:1.5rem}.skeleton-data-items-list-item-left .skeleton-data-items-list-item-icons>*{padding-right:.375rem}.skeleton-data-items-list-item-right{width:15%;margin-left:auto;margin-bottom:auto;margin-right:0;display:flex;flex-direction:column;flex-wrap:nowrap;align-items:center}.skeleton-data-items-list-item-icon{width:100%;height:1.375rem;margin-bottom:.0625rem;display:flex;flex-direction:row;flex-wrap:nowrap}.skeleton-data-items-list-item-icon-item{margin-right:.5rem;height:1.125rem;width:1.125rem;border-radius:1.125rem}.skeleton-data-items-list-item-information{height:3.375rem;margin-bottom:.0625rem;display:flex;flex-direction:column;flex-wrap:nowrap}.skeleton-data-items-list-item-information-item{width:80%;height:.5rem;margin-top:.625rem;margin-bottom:.0625rem;border-radius:.1875rem}.skeleton-data-items-list-item-information-item:first-child{width:40%;margin-top:.375rem}.skeleton-data-items-list-item-information-item:last-child{width:60%}.skeleton-data-items-list-item-actions{width:100%;height:1.375rem;display:flex;flex-direction:row-reverse;flex-wrap:nowrap}.skeleton-data-items-list-item-actions-item{margin-left:.5rem;height:1.125rem;width:1.125rem;border-radius:1.125rem}.skeleton-data-items-list-item-actions-item:first-child{margin-right:1rem}.appearance--dark :host{--color-background: #333333;--color-animation-background: #666666}\n"] }]
        }] });

/**
 * InboxSkeletonLoadingComponent is used to display the skeleton loading in the inbox, if the loading input is set to true.
 */
class InboxSkeletonLoadingComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxSkeletonLoadingComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: InboxSkeletonLoadingComponent, isStandalone: true, selector: "talenra-inbox-skeleton-loading", ngImport: i0, template: "<div class=\"skeleton-inbox\">\n  <div class=\"skeleton-toolbar\">\n    <div class=\"skeleton-toolbar-left\">\n      <div class=\"skeleton skeleton-toolbar-left-item\"></div>\n    </div>\n    <div class=\"skeleton-toolbar-right\">\n      @for (number of [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]; track number) {\n        <div class=\"skeleton skeleton-toolbar-right-item\"></div>\n      }\n    </div>\n  </div>\n  <div class=\"skeleton-filter-toolbar\">\n    <div class=\"skeleton-filter-toolbar-left\">\n      @for (number of [0, 1]; track number) {\n        <div class=\"skeleton skeleton-filter-toolbar-left-item\"></div>\n      }\n    </div>\n    <div class=\"skeleton-filter-toolbar-middle\">\n      @for (number of [0, 1, 2, 3]; track number) {\n        <div class=\"skeleton skeleton-filter-toolbar-middle-item\"></div>\n      }\n    </div>\n    <div class=\"skeleton-filter-toolbar-right\"></div>\n  </div>\n\n  <talenra-skeleton-loading-data-items-list></talenra-skeleton-loading-data-items-list>\n</div>\n", styles: [":host{--color-background: #ffffff;--color-animation-background: #f2f2f2}.skeleton{animation:skeleton-loading 1s linear infinite alternate}@keyframes skeleton-loading{0%{background-color:var(--color-animation-background) 50%}to{background-color:var(--color-animation-background)}}:host{position:relative;display:flex;justify-content:center}.skeleton-inbox{width:1400px}.skeleton-toolbar{width:100%;height:50px;margin-bottom:1px;margin-top:1px;border-radius:1px;background:var(--color-background);display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between}.skeleton-toolbar-left{width:33%;position:relative;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;margin-left:24px}.skeleton-toolbar-right{position:relative;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;margin-right:4px}.skeleton-toolbar-left-item{height:24px;width:24px;border-radius:24px}.skeleton-toolbar-right-item{height:24px;width:24px;border-radius:24px;margin-left:12px}.skeleton-toolbar-right-item:last-child{margin-right:8px}.skeleton-filter-toolbar{width:100%;height:34px;margin-bottom:8px;border-radius:1px;position:relative;margin-top:1px;background:var(--color-background);display:flex;flex-direction:row;flex-wrap:nowrap}.skeleton-filter-toolbar-left{display:flex;flex-wrap:nowrap;flex-direction:row;flex:1;margin-right:auto;margin-left:24px}.skeleton-filter-toolbar-left-item{margin-top:13px;margin-right:12px;width:50px;height:8px;border-radius:3px}.skeleton-filter-toolbar-middle{display:flex;flex-direction:row;flex-wrap:nowrap;vertical-align:middle;text-align:center;justify-content:center;flex:1}.skeleton-filter-toolbar-middle-item{margin-top:8px;margin-right:8px;width:18px;height:18px;border-radius:18px}.skeleton-filter-toolbar-right{display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto}.skeleton-filter-toolbar-right-item{margin-top:6px;margin-right:6px;width:22px;height:22px;border-radius:8px}.appearance--dark :host{--color-background: #333333;--color-animation-background: #666666}\n"], dependencies: [{ kind: "component", type: SkeletonLoadingDataItemsListComponent, selector: "talenra-skeleton-loading-data-items-list" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxSkeletonLoadingComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-skeleton-loading', standalone: true, imports: [SkeletonLoadingDataItemsListComponent], template: "<div class=\"skeleton-inbox\">\n  <div class=\"skeleton-toolbar\">\n    <div class=\"skeleton-toolbar-left\">\n      <div class=\"skeleton skeleton-toolbar-left-item\"></div>\n    </div>\n    <div class=\"skeleton-toolbar-right\">\n      @for (number of [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]; track number) {\n        <div class=\"skeleton skeleton-toolbar-right-item\"></div>\n      }\n    </div>\n  </div>\n  <div class=\"skeleton-filter-toolbar\">\n    <div class=\"skeleton-filter-toolbar-left\">\n      @for (number of [0, 1]; track number) {\n        <div class=\"skeleton skeleton-filter-toolbar-left-item\"></div>\n      }\n    </div>\n    <div class=\"skeleton-filter-toolbar-middle\">\n      @for (number of [0, 1, 2, 3]; track number) {\n        <div class=\"skeleton skeleton-filter-toolbar-middle-item\"></div>\n      }\n    </div>\n    <div class=\"skeleton-filter-toolbar-right\"></div>\n  </div>\n\n  <talenra-skeleton-loading-data-items-list></talenra-skeleton-loading-data-items-list>\n</div>\n", styles: [":host{--color-background: #ffffff;--color-animation-background: #f2f2f2}.skeleton{animation:skeleton-loading 1s linear infinite alternate}@keyframes skeleton-loading{0%{background-color:var(--color-animation-background) 50%}to{background-color:var(--color-animation-background)}}:host{position:relative;display:flex;justify-content:center}.skeleton-inbox{width:1400px}.skeleton-toolbar{width:100%;height:50px;margin-bottom:1px;margin-top:1px;border-radius:1px;background:var(--color-background);display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between}.skeleton-toolbar-left{width:33%;position:relative;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;margin-left:24px}.skeleton-toolbar-right{position:relative;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;margin-right:4px}.skeleton-toolbar-left-item{height:24px;width:24px;border-radius:24px}.skeleton-toolbar-right-item{height:24px;width:24px;border-radius:24px;margin-left:12px}.skeleton-toolbar-right-item:last-child{margin-right:8px}.skeleton-filter-toolbar{width:100%;height:34px;margin-bottom:8px;border-radius:1px;position:relative;margin-top:1px;background:var(--color-background);display:flex;flex-direction:row;flex-wrap:nowrap}.skeleton-filter-toolbar-left{display:flex;flex-wrap:nowrap;flex-direction:row;flex:1;margin-right:auto;margin-left:24px}.skeleton-filter-toolbar-left-item{margin-top:13px;margin-right:12px;width:50px;height:8px;border-radius:3px}.skeleton-filter-toolbar-middle{display:flex;flex-direction:row;flex-wrap:nowrap;vertical-align:middle;text-align:center;justify-content:center;flex:1}.skeleton-filter-toolbar-middle-item{margin-top:8px;margin-right:8px;width:18px;height:18px;border-radius:18px}.skeleton-filter-toolbar-right{display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto}.skeleton-filter-toolbar-right-item{margin-top:6px;margin-right:6px;width:22px;height:22px;border-radius:8px}.appearance--dark :host{--color-background: #333333;--color-animation-background: #666666}\n"] }]
        }] });

/**
 * Component to display the four icon filters and handle the click of them.
 *
 * ```html
 * <talenra-icon-filters
 *   [(availableIcons)]="availableIcons"
 * ></talenra-icon-filters>
 * ```
 */
class IconFiltersComponent {
    constructor() {
        /**
         * List of given IconFilters.
         */
        this.availableIcons = model([]);
    }
    /**
     * Method to save and emit changes.
     * @param iconInput The icon that changed and is to be emitted.
     */
    onValuesSelected(iconInput) {
        iconInput.active = !iconInput.active;
        // trigger change detection for parent component
        this.availableIcons.set([...this.availableIcons()]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: IconFiltersComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: IconFiltersComponent, isStandalone: true, selector: "talenra-icon-filter", inputs: { availableIcons: { classPropertyName: "availableIcons", publicName: "availableIcons", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { availableIcons: "availableIconsChange" }, ngImport: i0, template: "@for (iconFilter of availableIcons(); track iconFilter.identifier) {\n  <button\n    [class]=\"iconFilter.active ? 'icons-active-border' : 'icons-border'\"\n    class=\"icon-btn\"\n    (click)=\"onValuesSelected(iconFilter)\"\n    talenraTooltip=\"{{ iconFilter.iconTooltip }}\">\n    @if (iconFilter.active) {\n      <talenra-icon\n        [class]=\"'color--' + iconFilter.activeIconColor\"\n        aria-label=\"Icon Filter Button Activated\"\n        class=\"icon-font\"\n        name=\"{{ iconFilter.icon }}\"></talenra-icon>\n    } @else {\n      <talenra-icon\n        aria-label=\"Icon Filter Button Deactivated\"\n        class=\"icon-font icon-deactivated\"\n        name=\"{{ iconFilter.icon }}\"></talenra-icon>\n    }\n  </button>\n}\n", styles: [":host{--color-primary: #0099a8;--color-deactivated-icon: #666666;height:100%}.icon-btn{padding:.1875rem .25rem 0;margin:0 .125rem;height:100%;border:none;background:none;vertical-align:middle}.icons-border{border-bottom:.1875rem solid transparent}.icons-border:hover:not([disabled]){cursor:pointer}.icons-active-border{border-bottom:.1875rem solid var(--color-primary)}.icon-font{font-size:1.125rem}.icon-deactivated{color:var(--color-deactivated-icon)}.color--status-red{color:#e20057}.color--status-green{color:#00d000}.color--status-orange{color:#e26000}.color--status-violet{color:#b103c7}.color--black{color:#000}.color--primary{color:var(--color-primary)}.theme--denim :host{--color-primary: #0069a3}\n"], dependencies: [{ kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: IconFiltersComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-icon-filter', standalone: true, imports: [TooltipDirective, IconComponent], template: "@for (iconFilter of availableIcons(); track iconFilter.identifier) {\n  <button\n    [class]=\"iconFilter.active ? 'icons-active-border' : 'icons-border'\"\n    class=\"icon-btn\"\n    (click)=\"onValuesSelected(iconFilter)\"\n    talenraTooltip=\"{{ iconFilter.iconTooltip }}\">\n    @if (iconFilter.active) {\n      <talenra-icon\n        [class]=\"'color--' + iconFilter.activeIconColor\"\n        aria-label=\"Icon Filter Button Activated\"\n        class=\"icon-font\"\n        name=\"{{ iconFilter.icon }}\"></talenra-icon>\n    } @else {\n      <talenra-icon\n        aria-label=\"Icon Filter Button Deactivated\"\n        class=\"icon-font icon-deactivated\"\n        name=\"{{ iconFilter.icon }}\"></talenra-icon>\n    }\n  </button>\n}\n", styles: [":host{--color-primary: #0099a8;--color-deactivated-icon: #666666;height:100%}.icon-btn{padding:.1875rem .25rem 0;margin:0 .125rem;height:100%;border:none;background:none;vertical-align:middle}.icons-border{border-bottom:.1875rem solid transparent}.icons-border:hover:not([disabled]){cursor:pointer}.icons-active-border{border-bottom:.1875rem solid var(--color-primary)}.icon-font{font-size:1.125rem}.icon-deactivated{color:var(--color-deactivated-icon)}.color--status-red{color:#e20057}.color--status-green{color:#00d000}.color--status-orange{color:#e26000}.color--status-violet{color:#b103c7}.color--black{color:#000}.color--primary{color:var(--color-primary)}.theme--denim :host{--color-primary: #0069a3}\n"] }]
        }] });

/**
 * FilterToolbar is used to display the filter toolbar in the inbox toolbar.
 *
 * ```html
 * <talenra-filter-toolbar
 *   [scrollBarShadow]="headerHidden()"
 *   [searchedAndFilteredDataItems]="filteredDataItems"
 * ></talenra-filter-toolbar>
 * ```
 */
class FilterToolbarComponent {
    constructor() {
        /**
         * List of given IconFilters.
         */
        this.iconFilters = model([]);
        /**
         * The used service.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        this.inboxState = inject(InboxState);
        this.filterState = inject(FilterStateService);
        this.setInboxConfigurationService = inject(MainFacadeSetterService);
        this.updatePresetsService = inject(UpdatePresetsService);
        this.changedValuesService = inject(ChangedPresetValuesService);
        this.mainFacadeSetterService = inject(MainFacadeSetterService);
        /**
         * Destroy references to subscriptions.
         */
        this.destroyRef = inject(DestroyRef);
        /**
         * Subscriptions for the filter toolbar component.
         * @internal
         */
        this.initialSubscriptions = new Subscription();
    }
    /**
     * Initializes the filter toolbar component.
     * @internal
     */
    ngOnInit() {
        // delete all buffer filters and sort filters if the preset is changed and
        // handle the new selected attributes to corresponding filter type
        this.initialSubscriptions.add(this.inboxState.activePresetName$.subscribe((element) => {
            if (JSON.stringify(element) !== JSON.stringify(this.currentPresetName)) {
                // reset the buffer filter and sort (to preset standard)
                this.inboxState.resetBufferFilterSort();
            }
            // apply the presets icon filters
            this.handlePresetGroupsForFilterToolbar(element[0], element[1]);
        }));
        this.inboxState.presetGroups$.pipe(takeUntilDestroyed(this.destroyRef)).subscribe(() => {
            // update the filter toolbar with all changes which are saved in the buffer
            if (this.updatePresetsService.currentPresetAction$.value.operation === 'attribute-update') {
                // delete all icon filters from the filter toolbar
                this.iconFilters().forEach((iconFilter) => {
                    iconFilter.active = false;
                });
                // set the new filters
                this.setInboxConfigurationService.allAttributes$.value.forEach((allSelectedAttribute) => {
                    // check if the attribute is selected in the icon filter buffer
                    if (allSelectedAttribute.iconFilter) {
                        // set icon filter values like buffer
                        this.inboxState.bufferFilterSort.value.iconFilterAttributes.forEach((iconFilterBuffer) => {
                            const foundElem = this.iconFilters().find((iconFilterAvailable) => iconFilterBuffer.identifier ===
                                this.filterToolbarService.getIconFilterCombinedKey(iconFilterAvailable));
                            // set filter as active
                            if (foundElem) {
                                foundElem.active = true;
                            }
                        });
                        // check and set change in comparison to the preset values
                        this.changedValuesService.setPresetGroupsAndCompareIfChangedIconFilter();
                    }
                });
            }
        });
    }
    /**
     * Unsubscribe from all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.initialSubscriptions.unsubscribe();
    }
    /**
     * Function to handle the preset groups for the filter toolbar.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     */
    handlePresetGroupsForFilterToolbar(groupName, presetName) {
        // guard to check if the groupName and presetName are not empty
        if (groupName !== '' && presetName !== '') {
            // set the current preset name, to check if the preset is changed
            this.currentPresetName = [groupName, presetName];
            // find the matching group
            const matchingGroup = this.inboxState.presetGroups$.value.find((presetGroup) => presetGroup.groupName === this.inboxState.activePresetName$.value[0]);
            if (matchingGroup) {
                // find the matching preset
                const filteredPreset = matchingGroup.presets.find((preset) => preset.name === this.inboxState.activePresetName$.value[1]);
                // delete all icon filters
                this.iconFilters().forEach((iconFilter) => {
                    iconFilter.active = false;
                });
                // set the icon filter state from the preset
                if (filteredPreset && filteredPreset.iconAttributes) {
                    const iconAttributes = [];
                    filteredPreset.iconAttributes.forEach((iconFilterAttribute) => {
                        this.iconFilters().forEach((elem) => {
                            // check if the icon filter attribute is active in preset, has to check combined key, because identifier from preset is combined key
                            if ('icon' + '_' + elem.icon + '_' + elem.identifier === iconFilterAttribute.identifier) {
                                elem.active = true;
                                iconAttributes.push(elem);
                            }
                        });
                    });
                    // set the icon filter attributes in the filter state
                    this.filterState.setIconFilterSubject(iconAttributes);
                    // set the active icon filter in FilterSortSearch
                    const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
                    activeFilterSortSearch.iconAttributes = { ...this.iconFilters() };
                    this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
                }
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterToolbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: FilterToolbarComponent, isStandalone: true, selector: "talenra-filter-toolbar", inputs: { iconFilters: { classPropertyName: "iconFilters", publicName: "iconFilters", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { iconFilters: "iconFiltersChange" }, ngImport: i0, template: "@if (!inboxState.inboxConfiguration$.value.disableSearchToolbar) {\n  <form [formGroup]=\"mainFacadeSetterService.searchField\">\n    <talenra-search-field showButton (search)=\"mainFacadeSetterService.onSearchFieldChange($event.value)\">\n      <input talenra-search placeholder=\"Suche in Hauptliste\" formControlName=\"searchField\" kind=\"no-indent\" />\n    </talenra-search-field>\n  </form>\n}\n\n@if (!inboxState.inboxConfiguration$.value.disableQuickFilters) {\n  <talenra-icon-filter class=\"icon-selector\" [(availableIcons)]=\"iconFilters\"></talenra-icon-filter>\n}\n", styles: [":host{--color-background: #ffffff;position:relative;margin-top:.0625rem;padding-left:1.5rem;border-radius:.1875rem;background:var(--color-background);display:grid;grid-template-columns:repeat(3,1fr)}.icon-selector{align-self:center;justify-self:center}.appearance--dark :host{--color-background: #333333}\n"], dependencies: [{ kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: SearchFieldComponent, selector: "talenra-search-field", inputs: ["showIcon", "showButton", "size"], outputs: ["search", "clear"] }, { kind: "component", type: SearchInputComponent, selector: "input[talenra-search]", inputs: ["kind", "disabled"] }, { kind: "component", type: IconFiltersComponent, selector: "talenra-icon-filter", inputs: ["availableIcons"], outputs: ["availableIconsChange"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: FilterToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-filter-toolbar', standalone: true, imports: [ReactiveFormsModule, SearchFieldComponent, SearchInputComponent, IconFiltersComponent], template: "@if (!inboxState.inboxConfiguration$.value.disableSearchToolbar) {\n  <form [formGroup]=\"mainFacadeSetterService.searchField\">\n    <talenra-search-field showButton (search)=\"mainFacadeSetterService.onSearchFieldChange($event.value)\">\n      <input talenra-search placeholder=\"Suche in Hauptliste\" formControlName=\"searchField\" kind=\"no-indent\" />\n    </talenra-search-field>\n  </form>\n}\n\n@if (!inboxState.inboxConfiguration$.value.disableQuickFilters) {\n  <talenra-icon-filter class=\"icon-selector\" [(availableIcons)]=\"iconFilters\"></talenra-icon-filter>\n}\n", styles: [":host{--color-background: #ffffff;position:relative;margin-top:.0625rem;padding-left:1.5rem;border-radius:.1875rem;background:var(--color-background);display:grid;grid-template-columns:repeat(3,1fr)}.icon-selector{align-self:center;justify-self:center}.appearance--dark :host{--color-background: #333333}\n"] }]
        }] });

/**
 * Responsible for interaction with bottom bar.
 *
 * ```html
 * <talenra-inbox-configuration-panel-bottom-bar
 *   (buttonAction)="onButtonAction($event)"
 * ></talenra-inbox-configuration-panel-bottom-bar>
 * ```
 */
class InboxConfigurationPanelBottomBarComponent {
    constructor() {
        /**
         * Emits actions.
         */
        this.buttonAction = output();
        /**
         * Injects the filter state service.
         */
        this.filterState = inject(FilterStateService);
    }
    /**
     * Triggers the button action.
     * @param mouseEvent The mouse action that is to be stopped from propagation.
     * @param action The action that is to be emitted.
     */
    onActionClick(mouseEvent, action) {
        mouseEvent.stopPropagation();
        this.buttonAction.emit(action);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxConfigurationPanelBottomBarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.6", type: InboxConfigurationPanelBottomBarComponent, isStandalone: true, selector: "talenra-inbox-configuration-panel-bottom-bar", outputs: { buttonAction: "buttonAction" }, ngImport: i0, template: "<button\n  (click)=\"onActionClick($event, 'cancel')\"\n  data-testid=\"inbox-configuration-panel-bottom-bar-cancel\"\n  kind=\"secondary\"\n  label=\"Abbrechen\"\n  talenra-button></button>\n<!--<button-->\n<!--  (click)=\"onActionClick($event, 'reset')\"-->\n<!--  class=\"undo-button\"-->\n<!--  data-testid=\"inbox-configuration-panel-bottom-bar-reset\"-->\n<!--  kind=\"secondary\"-->\n<!--  label=\"Zur\u00FCcksetzen\"-->\n<!--  talenra-button></button>-->\n<button\n  (click)=\"onActionClick($event, 'confirm')\"\n  [disabled]=\"\n    filterState.filterAndSortChangedInComparisonToEmittedState() ||\n    ((filterState.falseOrderRangeFilter | async) && filterState.falseOrderRangeFilter.value.length > 0)\n  \"\n  class=\"undo-button\"\n  data-testid=\"inbox-configuration-panel-bottom-bar-confirm\"\n  kind=\"primary\"\n  label=\"Anwenden\"\n  talenra-button></button>\n", styles: [":host{height:3.5rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.undo-button{margin-left:auto;right:0}.apply-button{margin-left:1rem;right:0}\n"], dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxConfigurationPanelBottomBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-configuration-panel-bottom-bar', standalone: true, imports: [ButtonComponent, AsyncPipe], changeDetection: ChangeDetectionStrategy.OnPush, template: "<button\n  (click)=\"onActionClick($event, 'cancel')\"\n  data-testid=\"inbox-configuration-panel-bottom-bar-cancel\"\n  kind=\"secondary\"\n  label=\"Abbrechen\"\n  talenra-button></button>\n<!--<button-->\n<!--  (click)=\"onActionClick($event, 'reset')\"-->\n<!--  class=\"undo-button\"-->\n<!--  data-testid=\"inbox-configuration-panel-bottom-bar-reset\"-->\n<!--  kind=\"secondary\"-->\n<!--  label=\"Zur\u00FCcksetzen\"-->\n<!--  talenra-button></button>-->\n<button\n  (click)=\"onActionClick($event, 'confirm')\"\n  [disabled]=\"\n    filterState.filterAndSortChangedInComparisonToEmittedState() ||\n    ((filterState.falseOrderRangeFilter | async) && filterState.falseOrderRangeFilter.value.length > 0)\n  \"\n  class=\"undo-button\"\n  data-testid=\"inbox-configuration-panel-bottom-bar-confirm\"\n  kind=\"primary\"\n  label=\"Anwenden\"\n  talenra-button></button>\n", styles: [":host{height:3.5rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.undo-button{margin-left:auto;right:0}.apply-button{margin-left:1rem;right:0}\n"] }]
        }] });

/**
 * The service to check if the values of the filter and sort are changed in comparison to the default values of the preset.
 */
class ExpertFilterService {
    /**
     * Adds the simple filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param value The value to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     */
    addSimpleFilterToExpertFilter(queryToAddTo, value, attribute) {
        // check if the attribute is a filter attribute
        if (attribute.filterMode !== undefined) {
            // set the rules according to the filter mode
            // possible filter mode: single-select, multi-select, date-range, char-range, number-range
            if (value && value[1]) {
                switch (attribute.filterMode) {
                    case 'single-select':
                        this.addSingleSelectFilter(queryToAddTo, attribute, value[1]);
                        break;
                    case 'multi-select':
                        this.addMultiSelectFilter(queryToAddTo, attribute, value[1]);
                        break;
                    case 'date-range':
                        this.addDateRangeFilter(queryToAddTo, attribute, value[1]);
                        break;
                    case 'char-range':
                        this.addCharRangeFilter(queryToAddTo, attribute, value[1]);
                        break;
                    case 'number-range':
                        this.addNumberRangeFilter(queryToAddTo, attribute, value[1]);
                        break;
                    default:
                        break;
                }
            }
        }
    }
    /**
     * Generates a UUID.
     */
    generateUUID() {
        // Create a UUID using the template format xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx
        return '10000000-1000-4000-8000-100000000000'.replace(/[018]/g, (c) => (+c ^ (crypto.getRandomValues(new Uint8Array(1))[0] & (15 >> (+c / 4)))).toString(16));
    }
    /**
     * Adds a single select filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    addSingleSelectFilter(queryToAddTo, attribute, value) {
        // check if the value is a string
        if (typeof value === 'string') {
            // add the attribute to the expert filter
            queryToAddTo.rules.push({
                identifier: this.generateUUID(),
                operator: 'equal',
                key: attribute.identifier,
                label: attribute.label,
                type: QueryBuilderValueType.String,
                value: value,
            });
        }
    }
    /**
     * Adds a multi select filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    addMultiSelectFilter(queryToAddTo, attribute, value) {
        // check if the value is an array
        if (Array.isArray(value)) {
            // check if the value is a string array
            if (value.every((e) => typeof e === 'string')) {
                // create empty rules array for the subGroup
                const rules = [];
                // add each value to the subGroup
                value.forEach((val) => {
                    rules.push({
                        identifier: this.generateUUID(),
                        operator: QueryBuilderOptionOperator.Contains,
                        key: attribute.identifier,
                        label: attribute.label,
                        type: QueryBuilderValueType.Option,
                        value: val,
                    });
                });
                // create sub group for the multi select filter
                const subGroup = {
                    identifier: this.generateUUID(),
                    rules: rules,
                    condition: QueryBuilderCondition.Or,
                    hierarchyLevel: 2,
                };
                // add the subGroup to the expert filter
                queryToAddTo.rules.push(subGroup);
            }
        }
    }
    /**
     * Adds a date range filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    addDateRangeFilter(queryToAddTo, attribute, value) {
        // check if the value is an array
        if (Array.isArray(value)) {
            // check if the value is a Date array
            if (value.every((e) => e instanceof Date)) {
                // add from and to date to the expert filter
                this.addRangeSubGroup(queryToAddTo, attribute, QueryBuilderCondition.And, QueryBuilderValueType.Date, value, 'after', 'before');
            }
        }
    }
    /**
     * Adds a char range filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    addCharRangeFilter(queryToAddTo, attribute, value) {
        // check if the value is an array
        if (Array.isArray(value)) {
            // check if the value is a string array
            if (value.every((e) => typeof e === 'string')) {
                // add from and to string to the expert filter
                this.addRangeSubGroup(queryToAddTo, attribute, QueryBuilderCondition.And, QueryBuilderValueType.String, value, 'startsWith', 'endsWith');
            }
        }
    }
    /**
     * Adds a number range filter to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param value The value to add to the expert filter.
     */
    addNumberRangeFilter(queryToAddTo, attribute, value) {
        // check if the value is an array
        if (Array.isArray(value)) {
            // check if the value is a number array
            if (value.every((e) => !isNaN(Number(e)))) {
                // add from and to number to the expert filter
                this.addRangeSubGroup(queryToAddTo, attribute, QueryBuilderCondition.And, QueryBuilderValueType.Number, value, 'greater', 'lesser');
            }
        }
    }
    /**
     * Adds a range sub group to the expert filter.
     * @param queryToAddTo The query to add to the expert filter.
     * @param attribute The attribute to add to the expert filter.
     * @param condition The condition to add to the expert filter.
     * @param type The type to add to the expert filter.
     * @param values The values to add to the expert filter.
     * @param firstOperator The first operator to add to the expert filter.
     * @param secondOperator The second operator to add to the expert filter.
     */
    addRangeSubGroup(queryToAddTo, attribute, condition, type, values, firstOperator, secondOperator) {
        // create empty rules array for the subGroup
        const rules = [];
        // add the from number to the subGroup
        rules.push({
            identifier: this.generateUUID(),
            operator: firstOperator,
            key: attribute.identifier,
            label: attribute.label,
            type: type,
            value: values[0],
        });
        // add the to number to the subGroup
        rules.push({
            identifier: this.generateUUID(),
            operator: secondOperator,
            key: attribute.identifier,
            label: attribute.label,
            type: type,
            value: values[1],
        });
        // add the subGroup to the expert filter
        queryToAddTo.rules.push({
            identifier: this.generateUUID(),
            rules: rules,
            condition: condition,
            hierarchyLevel: 2,
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ExpertFilterService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ExpertFilterService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ExpertFilterService, decorators: [{
            type: Injectable
        }] });

/**
 * Values accepted by AttributeListComponent's mode input property. Determines the type of the list: Primary stands for
 * the upper attributes list that holds the attributes displayed in list-view, while Secondary stands for the lower
 * attributes list that holds the attributes displayed in detail-view.
 *
 * @internal
 */
const AttributeListRole = {
    Pirmary: 'primary',
    Secondary: 'secondary',
};
/**
 * Values accepted by AttributeListComponent's kind input property. Determines the visual style of the list.
 */
const AttributeListKind = {
    Default: 'default',
    Narrow: 'narrow',
};

const cfg = {
    /**
     * Threshold to switch list style from default to narrow (compact).
     *
     * If the instance has less attributes than this value, default style is used. Otherwise narrow style is requested.
     *
     * @internal
     */
    listStyleThreshold: 24,
};

/**
 * Drag preview for attribute item.
 *
 * Will be injected _outside_ of the origin's host context. To style it without style leaking moving the drag-preview
 * to its own component seems to be a clean solution.
 *
 * @internal
 */
class AttributeItemDragPreviewComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributeItemDragPreviewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.6", type: AttributeItemDragPreviewComponent, isStandalone: true, selector: "inbox-attribute-item-drag-preview", ngImport: i0, template: "<ng-content></ng-content>\n", styles: [":host{--color-background: #eaf4f6;--color-text: #333333}.theme--denim :host{--color-background: #e5f0f6}.appearance--dark :host{--color-background: #333333;--color-text: #e6e6e6}:host{display:block;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;box-sizing:border-box;color:var(--color-text);background-color:var(--color-background);box-shadow:0 2px 5px #0003;width:100%}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributeItemDragPreviewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'inbox-attribute-item-drag-preview', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>\n", styles: [":host{--color-background: #eaf4f6;--color-text: #333333}.theme--denim :host{--color-background: #e5f0f6}.appearance--dark :host{--color-background: #333333;--color-text: #e6e6e6}:host{display:block;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;box-sizing:border-box;color:var(--color-text);background-color:var(--color-background);box-shadow:0 2px 5px #0003;width:100%}\n"] }]
        }] });

/** @internal */
class AttributesListComponent {
    constructor() {
        /** Whether drag'n'drop of items in the list is disabled */
        this.dragDisabled = false;
        /** Defines the visual style of the list (default or compact) */
        this.kind = AttributeListKind.Default;
        // Un-/check
        /** Attribute un-/checked event */
        this.checkedChange = new EventEmitter();
        /** Drop event */
        this.cdkDropListDropped = new EventEmitter();
        /** While a given attribute is used in a filter or sort, it is locked in the settings. */
        this.lockedAttributes = [];
        // Drag'n'drop
        /** Event emitted when an item is moved to the other list. Contains the index of the moved item. */
        this.moveToOtherListTriggered = new EventEmitter();
    }
    /** @internal */
    get classKind() {
        return `kind--${this.kind}`;
    }
    // Locked attributes
    /** Handle checkedChange event */
    onCheckedChange(index) {
        this.checkedChange.emit(this.attributes[index]);
    }
    /** Workaround to make fake labels clickable. */
    checkAttribute(index) {
        const currentValue = !!this.attributes[index].checked.get('check')?.value;
        this.attributes[index].checked.get('check')?.setValue(!currentValue);
        this.checkedChange.emit(this.attributes[index]);
    }
    // Move between lists
    /** Pass-through the CDK's drop event */
    onDrop(event) {
        this.cdkDropListDropped.emit(event);
    }
    // Returns whether a given attribute is required by a filter or sort
    isLocked(label) {
        return this.lockedAttributes.some((locked) => locked.identifier === label);
    }
    // Helpers
    /** Emit the "move to other list" event */
    moveToOtherList(index, event) {
        event.stopPropagation();
        this.moveToOtherListTriggered.emit(index);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributesListComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: AttributesListComponent, isStandalone: true, selector: "inbox-attributes-list", inputs: { attributes: "attributes", role: "role", dragDisabled: "dragDisabled", kind: "kind", lockedAttributes: "lockedAttributes" }, outputs: { checkedChange: "checkedChange", cdkDropListDropped: "cdkDropListDropped", moveToOtherListTriggered: "moveToOtherListTriggered" }, host: { properties: { "class": "this.classKind" } }, ngImport: i0, template: "<div\n  (cdkDropListDropped)=\"onDrop($event)\"\n  [cdkDropListData]=\"attributes\"\n  [cdkDropListDisabled]=\"dragDisabled\"\n  cdkDropList>\n  @for (attribute of attributes; track attribute.identifier) {\n    <div cdkDrag>\n      <!-- Item displayed in list by default -->\n      <ng-container *ngTemplateOutlet=\"item\"></ng-container>\n\n      <!--\n      Drag preview shown while dragging\n      Note: We need an ng-template to make matchSize work.\n      (s. https://github.com/angular/components/issues/27750#issuecomment-1730784068)\n      -->\n      <ng-template cdkDragPreview matchSize>\n        <inbox-attribute-item-drag-preview>\n          <ng-container *ngTemplateOutlet=\"item\"></ng-container>\n        </inbox-attribute-item-drag-preview>\n      </ng-template>\n\n      <!-- Placeholder shows \"landing\" position while dragging -->\n      <div class=\"drag-placeholder\" *cdkDragPlaceholder></div>\n\n      <!-- Template for default item and drag-preview -->\n      <ng-template #item>\n        <div class=\"item\" [formGroup]=\"attribute.checked\">\n          <talenra-checkbox\n            class=\"checkbox\"\n            formControlName=\"check\"\n            (checkedChange)=\"onCheckedChange($index)\"></talenra-checkbox>\n          <span class=\"label\" (click)=\"checkAttribute($index)\">{{ attribute.label }}</span>\n          <div class=\"icons\">\n            @if (isLocked(attribute.identifier)) {\n              <talenra-icon name=\"filter-alt\" talenraTooltip=\"Filter/Sortierung aktiv\"></talenra-icon>\n            }\n            <talenra-icon\n              [name]=\"role === 'primary' ? 'arrow-downward' : 'arrow-upward'\"\n              class=\"switch-list\"\n              data-testid=\"inbox-main-attributes-move\"\n              (click)=\"moveToOtherList($index, $event)\"></talenra-icon>\n            <talenra-icon class=\"icon\" name=\"drag-indicator\" cdkDragHandle [class.inactive]=\"dragDisabled\"></talenra-icon>\n          </div>\n        </div>\n      </ng-template>\n    </div>\n  }\n</div>\n", styles: [":host{--color-placeholder-background: #f2f2f2;--color-placeholder-border: #e6e6e6;--color-icon: #999999;--color-icon-enabled: #666666;--color-background-hover: #f2f2f2}.appearance--dark :host{--color-placeholder-background: #262626;--color-placeholder-border: #4d4d4d;--color-icon: #666666;--color-background-hover: #262626}:host{display:block}.scroll{height:100%}.drag-placeholder{min-height:1.6875rem;border-radius:.1875rem;background:var(--color-placeholder-background);border:solid .0625rem var(--color-placeholder-border);transition:transform .25s cubic-bezier(0,0,.2,1)}.item{display:flex;justify-content:space-between;align-items:center;padding-left:.25rem;border-radius:.1875rem;transition:background-color .3s}.item:hover{background-color:var(--color-background-hover)}:host.kind--default .item{margin:.5rem 0}.checkbox,.icons{flex-grow:0}.icons{display:flex;gap:.25rem;padding-right:.25rem}.label{margin-left:.5rem;flex-grow:1;cursor:pointer}.icons talenra-icon{font-size:1rem;color:var(--color-icon)}.icons talenra-icon.switch-list{color:var(--color-icon-enabled)}.icons talenra-icon[cdkdraghandle]{cursor:move}.icons talenra-icon[cdkdraghandle].inactive{visibility:hidden}.switch-list{opacity:0;transition:opacity .3s;cursor:pointer;color:var(--color-icon-enabled)}.item:hover .switch-list{opacity:1}\n"], dependencies: [{ kind: "component", type: AttributeItemDragPreviewComponent, selector: "inbox-attribute-item-drag-preview" }, { kind: "component", type: CheckboxComponent, selector: "talenra-checkbox", inputs: ["size", "labelPosition", "indeterminate", "pointerDisabled"], outputs: ["indeterminateChange", "checkedChange"] }, { kind: "ngmodule", type: DragDropModule }, { kind: "directive", type: i1$3.CdkDropList, selector: "[cdkDropList], cdk-drop-list", inputs: ["cdkDropListConnectedTo", "cdkDropListData", "cdkDropListOrientation", "id", "cdkDropListLockAxis", "cdkDropListDisabled", "cdkDropListSortingDisabled", "cdkDropListEnterPredicate", "cdkDropListSortPredicate", "cdkDropListAutoScrollDisabled", "cdkDropListAutoScrollStep", "cdkDropListElementContainer"], outputs: ["cdkDropListDropped", "cdkDropListEntered", "cdkDropListExited", "cdkDropListSorted"], exportAs: ["cdkDropList"] }, { kind: "directive", type: i1$3.CdkDrag, selector: "[cdkDrag]", inputs: ["cdkDragData", "cdkDragLockAxis", "cdkDragRootElement", "cdkDragBoundary", "cdkDragStartDelay", "cdkDragFreeDragPosition", "cdkDragDisabled", "cdkDragConstrainPosition", "cdkDragPreviewClass", "cdkDragPreviewContainer", "cdkDragScale"], outputs: ["cdkDragStarted", "cdkDragReleased", "cdkDragEnded", "cdkDragEntered", "cdkDragExited", "cdkDragDropped", "cdkDragMoved"], exportAs: ["cdkDrag"] }, { kind: "directive", type: i1$3.CdkDragHandle, selector: "[cdkDragHandle]", inputs: ["cdkDragHandleDisabled"] }, { kind: "directive", type: i1$3.CdkDragPreview, selector: "ng-template[cdkDragPreview]", inputs: ["data", "matchSize"] }, { kind: "directive", type: i1$3.CdkDragPlaceholder, selector: "ng-template[cdkDragPlaceholder]", inputs: ["data"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributesListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'inbox-attributes-list', imports: [
                        AttributeItemDragPreviewComponent,
                        CheckboxComponent,
                        DragDropModule,
                        FormsModule,
                        IconComponent,
                        NgTemplateOutlet,
                        ReactiveFormsModule,
                        TooltipDirective,
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<div\n  (cdkDropListDropped)=\"onDrop($event)\"\n  [cdkDropListData]=\"attributes\"\n  [cdkDropListDisabled]=\"dragDisabled\"\n  cdkDropList>\n  @for (attribute of attributes; track attribute.identifier) {\n    <div cdkDrag>\n      <!-- Item displayed in list by default -->\n      <ng-container *ngTemplateOutlet=\"item\"></ng-container>\n\n      <!--\n      Drag preview shown while dragging\n      Note: We need an ng-template to make matchSize work.\n      (s. https://github.com/angular/components/issues/27750#issuecomment-1730784068)\n      -->\n      <ng-template cdkDragPreview matchSize>\n        <inbox-attribute-item-drag-preview>\n          <ng-container *ngTemplateOutlet=\"item\"></ng-container>\n        </inbox-attribute-item-drag-preview>\n      </ng-template>\n\n      <!-- Placeholder shows \"landing\" position while dragging -->\n      <div class=\"drag-placeholder\" *cdkDragPlaceholder></div>\n\n      <!-- Template for default item and drag-preview -->\n      <ng-template #item>\n        <div class=\"item\" [formGroup]=\"attribute.checked\">\n          <talenra-checkbox\n            class=\"checkbox\"\n            formControlName=\"check\"\n            (checkedChange)=\"onCheckedChange($index)\"></talenra-checkbox>\n          <span class=\"label\" (click)=\"checkAttribute($index)\">{{ attribute.label }}</span>\n          <div class=\"icons\">\n            @if (isLocked(attribute.identifier)) {\n              <talenra-icon name=\"filter-alt\" talenraTooltip=\"Filter/Sortierung aktiv\"></talenra-icon>\n            }\n            <talenra-icon\n              [name]=\"role === 'primary' ? 'arrow-downward' : 'arrow-upward'\"\n              class=\"switch-list\"\n              data-testid=\"inbox-main-attributes-move\"\n              (click)=\"moveToOtherList($index, $event)\"></talenra-icon>\n            <talenra-icon class=\"icon\" name=\"drag-indicator\" cdkDragHandle [class.inactive]=\"dragDisabled\"></talenra-icon>\n          </div>\n        </div>\n      </ng-template>\n    </div>\n  }\n</div>\n", styles: [":host{--color-placeholder-background: #f2f2f2;--color-placeholder-border: #e6e6e6;--color-icon: #999999;--color-icon-enabled: #666666;--color-background-hover: #f2f2f2}.appearance--dark :host{--color-placeholder-background: #262626;--color-placeholder-border: #4d4d4d;--color-icon: #666666;--color-background-hover: #262626}:host{display:block}.scroll{height:100%}.drag-placeholder{min-height:1.6875rem;border-radius:.1875rem;background:var(--color-placeholder-background);border:solid .0625rem var(--color-placeholder-border);transition:transform .25s cubic-bezier(0,0,.2,1)}.item{display:flex;justify-content:space-between;align-items:center;padding-left:.25rem;border-radius:.1875rem;transition:background-color .3s}.item:hover{background-color:var(--color-background-hover)}:host.kind--default .item{margin:.5rem 0}.checkbox,.icons{flex-grow:0}.icons{display:flex;gap:.25rem;padding-right:.25rem}.label{margin-left:.5rem;flex-grow:1;cursor:pointer}.icons talenra-icon{font-size:1rem;color:var(--color-icon)}.icons talenra-icon.switch-list{color:var(--color-icon-enabled)}.icons talenra-icon[cdkdraghandle]{cursor:move}.icons talenra-icon[cdkdraghandle].inactive{visibility:hidden}.switch-list{opacity:0;transition:opacity .3s;cursor:pointer;color:var(--color-icon-enabled)}.item:hover .switch-list{opacity:1}\n"] }]
        }], propDecorators: { attributes: [{
                type: Input,
                args: [{ required: true }]
            }], role: [{
                type: Input,
                args: [{ required: true }]
            }], dragDisabled: [{
                type: Input
            }], kind: [{
                type: Input
            }], checkedChange: [{
                type: Output
            }], cdkDropListDropped: [{
                type: Output
            }], lockedAttributes: [{
                type: Input
            }], moveToOtherListTriggered: [{
                type: Output
            }], classKind: [{
                type: HostBinding,
                args: ['class']
            }] } });

/**
 * Attributes settings are responsible for providing content to the selected attributes within the data items list and data item information.
 *
 * ```html
 * <talenra-attributes-settings
 *   [attributesSettingsList]="attributesSettingsList"
 *   [maxAttributesShown]="maxAttributesShown"
 *   [selectedMainAttributes]="selectedMainAttributes"
 *   [selectedDetailAttributes]="selectedDetailAttributes"
 *   [isExpanded]="isExpanded"
 *   (isExpandedChange)="expandedChangeHandler($event)"
 *   (selectedMainAttributesEmitter)="selectedMainAttributesEmitterHandler($event)"
 *   (selectedDetailAttributesEmitter)="selectedDetailAttributesEmitterHandler($event)"
 *   (selectedAllAttributesEmitter)="selectedAllAttributesEmitterHandler($event)"
 * ></talenra-attributes-settings>
 * ```
 */
class AttributesSettingsComponent {
    constructor() {
        /**
         * The maximum Attributes, which are to be shown in the data-item-list-items.
         * Further they are divided in the ui.
         * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings-service.
         * Default value is 12, like chosen in the requirements.
         */
        this.maxAttributesShown = 12;
        /**
         * The maximum Attributes, which are to be shown in the data-item-list-items mutated by the user.
         */
        this.numberMainAttributesChosenByUser = 12;
        /**
         * The boolean value is used to expand the attributes settings UI.
         */
        this.isExpanded = false;
        /**
         * Sets the selected main attributes.
         */
        this.selectedMainAttributes = [];
        /**
         * Sets the selected detail attributes.
         */
        this.selectedDetailAttributes = [];
        /**
         * List of attributes key which are used to lock the attributes in the attribute settings.
         * Gets updated by the used attributes in the filter toolbar.
         */
        this.lockedAttributes = [];
        /**
         * Emits the main selected attributes.
         */
        this.selectedMainAttributesEmitter = new EventEmitter();
        /**
         * Emits the detail selected attributes.
         */
        this.selectedDetailAttributesEmitter = new EventEmitter();
        /**
         * Emits the all selected attributes.
         */
        this.selectedAllAttributesEmitter = new EventEmitter();
        /**
         * The number value that is chosen by the user to show the main attributes.
         */
        this.numberMainAttributesChosenByUserEmitter = new EventEmitter();
        /**
         * The main attributes.
         */
        this.mainAttributes = [];
        /**
         * The detail attributes.
         */
        this.detailAttributes = [];
        /**
         * The detail attributes.
         */
        this.detailAttributesSearch = [];
        /**
         * Boolean to know if all checkboxes are checked.
         */
        this.allAttributesSettingsChecked = new FormGroup({
            check: new FormControl({ value: false, disabled: false }),
        });
        /**
         * List style for the checkbox behavior and UI.
         */
        this.indeterminateAllAttributes = false;
        /**
         * List of all marked attributes labels
         */
        this.markedAttributes = [];
        /**
         * The inbox service.
         */
        this.inboxState = inject(InboxState);
        /**
         * Boolean to set if label is shown.
         */
        this.showAttributeLabelsDataItemsList = this.inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList;
        /**
         * The form-group which defines the overall form consisting most of the time
         * of multiple inputs, gets passed into the component.
         * Get Value HTML:
         *     {{searchField.get(searchFieldFcn)!.value}}
         */
        this.searchForm = new FormGroup({
            query: new FormControl(''),
        });
        /**
         * Semaphore to stop accessing checkbox value a second time.
         * @internal
         */
        this.checkboxSemaphore = new BehaviorSubject(false);
        /**
         * Semaphore to stop multiple change save.
         * @internal
         */
        this.multipleChangeSemaphore = new BehaviorSubject(false);
        /**
         * The subscriptions of the component.
         *  @internal
         */
        this.subscriptions = new Subscription();
    }
    /**
     * Returns whether list-style "narrow" (a more compact layout) is preferred. The compact layout is used for extensive
     * numbers of attributes.
     *
     * @internal
     */
    get preferNarrowList() {
        return !!(this.attributesSettingsList && this.attributesSettingsList?.length > cfg.listStyleThreshold);
    }
    /** @internal */
    get classNames() {
        return this.preferNarrowList ? 'kind--narrow' : 'kind--default';
    }
    /**
     * The initialization of the component.
     * @internal
     */
    ngOnInit() {
        this.initializeComponent();
    }
    /**
     * Detects changes in the component.
     * @internal
     **/
    ngOnChanges(changes) {
        const preSetOptionsGroupChanges = changes['preSetOptionsGroup'];
        if (preSetOptionsGroupChanges && !preSetOptionsGroupChanges.firstChange) {
            this.subscriptions.unsubscribe();
            this.subscriptions.closed = false;
            this.initializeComponent();
        }
        const attributesSettingsListChanges = changes['attributesSettingsList'];
        if (attributesSettingsListChanges && !attributesSettingsListChanges.firstChange) {
            this.subscriptions.unsubscribe();
            this.subscriptions.closed = false;
            this.initializeComponent();
        }
        const selectedMainAttributesChanges = changes['selectedMainAttributes'];
        if (selectedMainAttributesChanges && !selectedMainAttributesChanges.firstChange) {
            this.subscriptions.unsubscribe();
            this.subscriptions.closed = false;
            this.initializeComponent();
        }
        const selectedDetailAttributesChanges = changes['selectedDetailAttributes'];
        if (selectedDetailAttributesChanges && !selectedDetailAttributesChanges.firstChange) {
            this.subscriptions.unsubscribe();
            this.subscriptions.closed = false;
            this.initializeComponent();
        }
        const numberMainAttributesChosenByUserChanges = changes['numberMainAttributesChosenByUser'];
        if (numberMainAttributesChosenByUserChanges && !numberMainAttributesChosenByUserChanges.firstChange) {
            this.subscriptions.unsubscribe();
            this.subscriptions.closed = false;
            this.initializeComponent();
        }
        const lockedAttributesChanges = changes['lockedAttributes'];
        if (lockedAttributesChanges && !lockedAttributesChanges.firstChange) {
            this.subscriptions.unsubscribe();
            this.subscriptions.closed = false;
            this.initializeComponent();
        }
        const isExpandedChanges = changes['isExpanded'];
        if (isExpandedChanges && !isExpandedChanges.firstChange) {
            if (isExpandedChanges.currentValue) {
                this.orderAttributes();
            }
        }
    }
    /**
     * Unsubscribes from all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
    }
    /**
     * Auxiliary method to create a list for the checked items.
     * @param list The list that contains the attributes.
     * @internal
     */
    createList(list) {
        const value = [];
        list.filter((elem) => {
            if (elem.checked.get('check')?.value)
                value.push({
                    identifier: elem.identifier,
                    checked: elem.checked,
                    label: elem.label,
                    filterMode: elem.filterMode,
                    dateFilterRestriction: elem.dateFilterRestriction,
                    sortable: elem.sortable,
                });
        });
        return value;
    }
    /**
     * Called if attributes are changed and have to be emitted.
     */
    onAttributesSettingsChanges() {
        if (!this.multipleChangeSemaphore.value) {
            const mainAttributesPrepared = this.createList(this.mainAttributes);
            this.selectedMainAttributesEmitter.emit(mainAttributesPrepared);
            this.selectedMainAttributes = mainAttributesPrepared;
            const detailAttributesPrepared = this.createList(this.detailAttributes);
            this.selectedDetailAttributesEmitter.emit(detailAttributesPrepared);
            this.selectedDetailAttributes = detailAttributesPrepared;
            const allAttributesPrepared = this.createList([...this.mainAttributes, ...this.detailAttributes]);
            this.selectedAllAttributesEmitter.emit(allAttributesPrepared);
        }
    }
    /**
     * Handler to mark attributes.
     * @param {IAttributeItem} item Clicked attribute.
     */
    handleMarkedAttribute(item) {
        if (this.getMarkedAttribute(item.identifier) === item.identifier && !item.checked.get('check')?.value) {
            this.unmarkAttribute(item.identifier);
        }
        else if (item.checked.get('check')?.value) {
            this.markAttribute(item.identifier);
        }
        // check if length of list to disable control of single items
        if (this.markedAttributes.length === this.attributesSettingsList?.length) {
            this.indeterminateAllAttributes = false;
            this.checkboxSemaphore.next(true);
            this.allAttributesSettingsChecked.get('check')?.setValue(true);
        }
        else if (this.markedAttributes.length <= 1) {
            this.indeterminateAllAttributes = false;
            this.checkboxSemaphore.next(true);
            this.allAttributesSettingsChecked.get('check')?.setValue(false);
        }
        else if (this.markedAttributes.length > 1) {
            this.indeterminateAllAttributes = true;
            this.checkboxSemaphore.next(true);
            this.allAttributesSettingsChecked.get('check')?.setValue(false);
        }
    }
    /**
     * Auxiliary method to mark chosen attributes.
     * @param {string} id Attributes name of the marked attributes.
     * @internal
     */
    markAttribute(id) {
        if (this.getMarkedAttribute(id) === '') {
            this.markedAttributes.push(id);
        }
    }
    /**
     * Auxiliary method to unmark chosen attributes.
     * @param {string} id Attributes name of the unmarked attributes.
     * @internal
     */
    unmarkAttribute(id) {
        this.markedAttributes.forEach((value, index) => {
            if (value == id && this.mainAttributes[0].identifier !== id)
                this.markedAttributes.splice(index, 1);
        });
    }
    /**
     * Auxiliary method to get the chosen attribute.
     * @param {string} id Attribute name of the chosen attribute.
     * @internal
     */
    getMarkedAttribute(id) {
        let value = '';
        this.markedAttributes.filter((elem) => {
            if (elem === id) {
                value = elem;
            }
        });
        return value;
    }
    /**
     * To change the array place of dragged item.
     * @param event The dragged item.
     * @param list The list to move the item to. True for main list, false for detail list.
     * @internal
     */
    onDrop(list, event) {
        // enable the first element of the main list
        const firstElement = this.mainAttributes[0];
        firstElement.checked.get('check')?.enable();
        // change the position in arrays
        // move in same list
        if (event.previousContainer === event.container) {
            moveItemInArray(event.container.data, event.previousIndex, event.currentIndex);
        }
        // move to other list
        else {
            if (list === AttributeListRole.Secondary) {
                transferArrayItem(this.mainAttributes, this.detailAttributes, event.previousIndex, event.currentIndex);
                if (event.currentIndex === 0) {
                    transferArrayItem(this.detailAttributes, this.mainAttributes, 1, this.mainAttributes.length);
                }
                else {
                    transferArrayItem(this.detailAttributes, this.mainAttributes, 0, this.mainAttributes.length);
                }
            }
            else {
                transferArrayItem(this.mainAttributes, this.detailAttributes, this.mainAttributes.length, 0);
                transferArrayItem(this.detailAttributes, this.mainAttributes, event.previousIndex + 1, event.currentIndex);
            }
        }
        this.checkLockedAttributesDisableFirstElement();
    }
    /**
     * Update Attributes of the view to the current state.
     */
    updateAttributes() {
        this.orderAttributes();
        // set selected elements
        this.attributesSettingsList?.forEach((item, index) => {
            // enable all checkboxes, specific ones will be disabled later
            item.checked.get('check')?.enable();
            // set selected elements
            const selectedAttributes = this.selectedMainAttributes?.find((e) => e.identifier === item.identifier);
            const selectedAttributesDetails = this.selectedDetailAttributes?.find((e) => e.identifier === item.identifier);
            const combinedAttribute = selectedAttributes || selectedAttributesDetails;
            combinedAttribute && item.checked.get('check')?.setValue(true);
            !combinedAttribute && item.checked.get('check')?.setValue(false);
            combinedAttribute && this.handleMarkedAttribute(item);
            // add to specific list
            if (index < this.numberMainAttributesChosenByUser) {
                this.mainAttributes.push(item);
            }
            else if (index >= this.numberMainAttributesChosenByUser) {
                this.detailAttributes.push(item);
            }
            // set list to unchanged
            this.detailAttributesSearch = this.detailAttributes;
            // reset search field
            this.searchForm.get('query')?.setValue('');
        });
        // lock all attributes which are used in the filters and sortFilter (not iconFilter)
        this.lockAttributes();
        // the first element is always selected and disabled
        const firstElement = this.mainAttributes[0];
        firstElement && firstElement.checked.get('check')?.setValue(true);
        firstElement && firstElement.checked.get('check')?.disable();
    }
    /**
     * Method to get if the search field is active.
     */
    isSearchActive() {
        return this.searchForm.get('query')?.value !== '';
    }
    /**
     * Method to reset the attributes.
     */
    resetAttributes() {
        this.markedAttributes = [];
        this.mainAttributes = [];
        this.detailAttributes = [];
        this.detailAttributesSearch = [];
    }
    /**
     * Method to set the checkbox value of all attributes checkbox.
     * @param value The value of the checkbox.
     */
    allAttributesSettingsCheckedChange(value) {
        if (!this.checkboxSemaphore.value) {
            // stop change save execution, for multiple change save
            this.multipleChangeSemaphore.next(true);
            if (value) {
                // set selected elements
                this.attributesSettingsList?.forEach((item) => {
                    item.checked.get('check')?.setValue(true);
                    if (!this.getMarkedAttribute(item.identifier)) {
                        if (item.checked.get('check')?.value) {
                            this.markAttribute(item.identifier);
                        }
                    }
                });
            }
            else {
                // set selected elements
                this.attributesSettingsList?.forEach((item) => {
                    item.checked.get('check')?.setValue(false);
                    if (item.checked.get('check')?.value) {
                        this.markAttribute(item.identifier);
                    }
                });
                // set marked attributes to empty
                this.markedAttributes = [];
                // lock all attributes which are used in the filters and sortFilter (not iconFilter)
                this.lockAttributes();
                // set first element as active
                const firstAttribute = this.attributesSettingsList?.[0];
                firstAttribute && firstAttribute.checked.get('check')?.setValue(true);
                firstAttribute && this.markAttribute(firstAttribute.identifier);
            }
            // enable change save execution
            this.multipleChangeSemaphore.next(false);
        }
        else {
            this.checkboxSemaphore.next(false);
        }
        // immediate change in display
        this.onAttributesSettingsChanges();
    }
    /**
     * Method to set the toggle to show or not show labels in data items.
     * @param $event The event that is triggered by the click.
     */
    changeShowAttributeLabelsDataItemsList($event) {
        const inboxConfiguration = this.inboxState.inboxConfiguration$.value;
        inboxConfiguration.showAttributeLabelsDataItemsList = $event;
        this.inboxState.setInboxConfiguration(inboxConfiguration);
    }
    /**
     * Checks if the filter is active.
     * @param attributeLabel The label of the filter.
     */
    isFilterActive(attributeLabel) {
        return this.lockedAttributes.some((attribute) => attribute.identifier === attributeLabel && attribute.origin === 'filter');
    }
    /**
     * Checks if the sort is active.
     * @param attributeLabel The label of the filter.
     */
    isSortActive(attributeLabel) {
        return this.lockedAttributes.some((attribute) => attribute.identifier === attributeLabel && attribute.origin === 'sort');
    }
    /**
     * Method to move the attribute to the other part of the list.
     * @param list The list to move the item to ('primary' or 'secondary')
     * @param index The index of the item.
     * @param event The event that is triggered by the click.
     */
    moveToOtherList(list, index, event = undefined) {
        // Prevent the panel from closing.
        event && event.stopPropagation();
        // enable the first element of the main list
        const firstElement = this.mainAttributes[0];
        firstElement.checked.get('check')?.enable();
        // change the position in arrays
        if (list === AttributeListRole.Pirmary) {
            // move selected item to top of secondary list
            transferArrayItem(this.mainAttributes, this.detailAttributes, index, 0);
            // move the first item of the secondary list to the end of the primary list
            transferArrayItem(this.detailAttributes, this.mainAttributes, 1, this.mainAttributes.length);
        }
        else {
            // move last item of primary list to top of secondary list
            transferArrayItem(this.mainAttributes, this.detailAttributes, this.mainAttributes.length - 1, 0);
            if (this.isSearchActive()) {
                const detailIndexSearch = this.detailAttributes.findIndex((x) => x.identifier === this.detailAttributesSearch[index].identifier);
                transferArrayItem(this.detailAttributes, this.mainAttributes, detailIndexSearch, this.mainAttributes.length);
            }
            else {
                transferArrayItem(this.detailAttributes, this.mainAttributes, index + 1, this.mainAttributes.length);
            }
        }
        this.checkLockedAttributesDisableFirstElement();
    }
    /**
     * Decrease/increase the maximum attributes shown
     */
    updateAttributesMax(deviation) {
        // Normalize argument
        deviation = parseInt(deviation.toString(), 10);
        // Abort if changing the value is not permitted in configuration
        if (this.inboxState.inboxConfiguration$.value.disableFlexibleMainAttributes || deviation === 0)
            return;
        this.numberMainAttributesChosenByUser += deviation;
        if (deviation > 0) {
            transferArrayItem(this.detailAttributes, this.mainAttributes, 0, this.mainAttributes.length);
        }
        else {
            transferArrayItem(this.mainAttributes, this.detailAttributes, this.mainAttributes.length, 0);
        }
        // emit changes in number
        this.numberMainAttributesChosenByUserEmitter.emit(this.numberMainAttributesChosenByUser);
        // set list to unchanged
        this.detailAttributesSearch = this.detailAttributes;
        // reset search field
        this.searchForm.get('query')?.setValue('');
        this.onAttributesSettingsChanges();
    }
    /**
     * The initialization of the component.
     * @private
     */
    initializeComponent() {
        this.resetAttributes();
        // move first item of attributes as selected
        this.updateAttributes();
        this.subscriptions.add(this.allAttributesSettingsChecked.get('check')?.valueChanges.subscribe((value) => {
            this.allAttributesSettingsCheckedChange(value);
        }));
        // search field interaction
        this.subscriptions.add(this.searchForm.get('query')?.valueChanges.subscribe((value) => {
            // set searched value to '' if null, to avoid logic failure
            if (value === null) {
                this.searchForm.get('query')?.setValue('');
            }
            else {
                this.detailAttributesSearch = this.detailAttributes.filter((item) => {
                    return item.label.toLowerCase().includes(value.toLowerCase());
                });
            }
        }));
        // initialize semaphores
        this.checkboxSemaphore.next(false);
        this.multipleChangeSemaphore.next(false);
    }
    /**
     * Method to order the selected attributes.
     */
    orderAttributes() {
        // move first item of attributes as selected
        this.selectedMainAttributes?.reverse().forEach((elem) => {
            const index = this.attributesSettingsList?.findIndex((x) => x.identifier === elem.identifier);
            if (this.attributesSettingsList && index) {
                moveItemInArray(this.attributesSettingsList, index, 0);
            }
        });
        this.selectedMainAttributes?.reverse();
        // move first item of details attributes to end to get the element between main and detail attributes
        this.selectedDetailAttributes?.reverse().forEach((elem) => {
            const index = this.attributesSettingsList?.findIndex((x) => x.identifier === elem.identifier);
            if (this.attributesSettingsList && index) {
                moveItemInArray(this.attributesSettingsList, index, this.attributesSettingsList.length);
            }
        });
        // move first item of details attributes as selected
        this.selectedDetailAttributes?.forEach((elem) => {
            const index = this.attributesSettingsList?.findIndex((x) => x.identifier === elem.identifier);
            if (this.attributesSettingsList && index) {
                moveItemInArray(this.attributesSettingsList, index, this.numberMainAttributesChosenByUser);
            }
        });
        this.selectedDetailAttributes?.reverse();
    }
    /**
     * Method to lock the attributes.
     */
    lockAttributes() {
        // lock all attributes which are used in the filters and sortFilter (not iconFilter)
        this.lockedAttributes.forEach((item) => {
            const index = this.attributesSettingsList?.findIndex((x) => x.identifier === item.identifier);
            if (this.attributesSettingsList &&
                index &&
                this.attributesSettingsList[index] &&
                this.attributesSettingsList[index].checked &&
                this.attributesSettingsList[index].checked.get('check')) {
                // add guards to avoid null pointer exceptions
                if (this.attributesSettingsList[index].checked && this.attributesSettingsList[index].checked.get('check')) {
                    this.attributesSettingsList[index].checked.get('check')?.setValue(true);
                    this.attributesSettingsList[index].checked.get('check')?.disable();
                }
            }
        });
    }
    /**
     * Auxiliary method to check for locked attributes and disable the first element.
     * Furthermore, reset search of attributes detail list and call onAttributesSettingsChanges.
     * @private
     */
    checkLockedAttributesDisableFirstElement() {
        // lock all attributes which are used in the filters and sortFilter (not iconFilter)
        this.lockAttributes();
        // the first element is always selected
        const firstElement = this.mainAttributes[0];
        firstElement && firstElement.checked.get('check')?.setValue(true);
        firstElement.checked.get('check')?.disable();
        // set list to unchanged
        this.detailAttributesSearch = this.detailAttributes;
        // reset search fieldx
        this.searchForm.get('query')?.setValue('');
        // immediate change in display
        this.onAttributesSettingsChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributesSettingsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: AttributesSettingsComponent, isStandalone: true, selector: "talenra-attributes-settings", inputs: { attributesSettingsList: "attributesSettingsList", maxAttributesShown: "maxAttributesShown", numberMainAttributesChosenByUser: "numberMainAttributesChosenByUser", isExpanded: "isExpanded", selectedMainAttributes: "selectedMainAttributes", selectedDetailAttributes: "selectedDetailAttributes", lockedAttributes: "lockedAttributes" }, outputs: { selectedMainAttributesEmitter: "selectedMainAttributesEmitter", selectedDetailAttributesEmitter: "selectedDetailAttributesEmitter", selectedAllAttributesEmitter: "selectedAllAttributesEmitter", numberMainAttributesChosenByUserEmitter: "numberMainAttributesChosenByUserEmitter" }, host: { properties: { "class": "this.classNames" } }, usesOnChanges: true, ngImport: i0, template: "<div class=\"all-attributes\">\n  <div [formGroup]=\"allAttributesSettingsChecked\" class=\"control-pair\">\n    <talenra-checkbox\n      [(indeterminate)]=\"indeterminateAllAttributes\"\n      [talenraTooltip]=\"allAttributesSettingsChecked.get('check')?.value === true ? 'Alle abw\u00E4hlen' : 'Alle ausw\u00E4hlen'\"\n      data-testid=\"check/uncheck all\"\n      formControlName=\"check\"></talenra-checkbox>\n    <span>Alle</span>\n  </div>\n  @if (inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList !== undefined) {\n    <div class=\"control-pair\">\n      <talenra-toggle\n        (ngModelChange)=\"changeShowAttributeLabelsDataItemsList($event)\"\n        [ngModel]=\"showAttributeLabelsDataItemsList\"></talenra-toggle>\n      <span>Label</span>\n    </div>\n  }\n</div>\n\n<div class=\"stepper\">\n  @if (!inboxState.inboxConfiguration$.value.disableFlexibleMainAttributes) {\n    <div class=\"stepper-inner\">\n      <button\n        (click)=\"updateAttributesMax(-1)\"\n        [disabled]=\"numberMainAttributesChosenByUser <= 1\"\n        data-testid=\"Maximale Anzahl an Hauptattributen verringern\"\n        icon=\"remove\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Anzahl Hauptattribute verringern\"\n        size=\"s\"></button>\n      <div class=\"stepper-value\">\n        {{ numberMainAttributesChosenByUser }}\n      </div>\n      <button\n        (click)=\"updateAttributesMax(1)\"\n        [disabled]=\"numberMainAttributesChosenByUser >= maxAttributesShown\"\n        data-testid=\"Maximale Anzahl an Hauptattributen erh\u00F6hen\"\n        icon=\"add\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Anzahl Hauptattribute erh\u00F6hen\"\n        size=\"s\"></button>\n    </div>\n  }\n</div>\n\n<div cdkDropListGroup class=\"flexible-height\">\n  <div class=\"lists\">\n    <div class=\"list-container primary\">\n      <talenra-scroll-container class=\"scroll\" useOverlay>\n        <inbox-attributes-list\n          (cdkDropListDropped)=\"onDrop('primary', $event)\"\n          (checkedChange)=\"handleMarkedAttribute($event)\"\n          (moveToOtherListTriggered)=\"moveToOtherList('primary', $event)\"\n          [attributes]=\"mainAttributes\"\n          [dragDisabled]=\"isSearchActive()\"\n          [kind]=\"preferNarrowList ? 'narrow' : 'default'\"\n          [lockedAttributes]=\"lockedAttributes\"\n          class=\"list\"\n          role=\"primary\"></inbox-attributes-list>\n      </talenra-scroll-container>\n    </div>\n\n    <hr class=\"separator\" />\n\n    <talenra-search-field [formGroup]=\"searchForm\" class=\"filter\" showIcon>\n      <input formControlName=\"query\" kind=\"no-indent\" talenra-search />\n    </talenra-search-field>\n    <div class=\"list-container secondary\">\n      <talenra-scroll-container class=\"scroll\" useOverlay>\n        <inbox-attributes-list\n          (cdkDropListDropped)=\"onDrop('secondary', $event)\"\n          (checkedChange)=\"handleMarkedAttribute($event)\"\n          (moveToOtherListTriggered)=\"moveToOtherList('secondary', $event)\"\n          [attributes]=\"detailAttributesSearch\"\n          [dragDisabled]=\"isSearchActive()\"\n          [kind]=\"preferNarrowList ? 'narrow' : 'default'\"\n          [lockedAttributes]=\"lockedAttributes\"\n          class=\"list\"\n          role=\"secondary\"></inbox-attributes-list>\n      </talenra-scroll-container>\n    </div>\n  </div>\n</div>\n", styles: [":host{--color-primary: #0099a8;--color-background: #ffffff;--color-border: #f2f2f2;--color-text: #000000;--color-icons: #999999;--color-lines: #cccccc;--color-attribute-item-background-hover: #f2f2f2;--color-attribute-item-background-drag: #eaf4f6}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-border: #262626;--color-text: #ffffff;--color-icons: #666666;--color-lines: #666666;--color-attribute-item-background-hover: #262626}:host{display:flex;flex-direction:column;height:calc(100% - 45px);font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-text);-webkit-user-select:none;user-select:none}.all-attributes{display:flex;justify-content:space-between;gap:1rem;padding-left:.25rem;padding-right:.375rem}.control-pair{display:flex;flex-wrap:nowrap;align-items:center}.control-pair span{margin-left:.5rem}.separator{width:100%;height:.0625rem;background-color:var(--color-lines);border:0;flex-shrink:0;margin:.4375rem -.25rem .4375rem 0}.flexible-height{flex-grow:1;flex-shrink:1;overflow-y:hidden;margin-right:-1.5rem;padding-right:1.5rem}.lists{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%}.list-container{margin-right:-1.5rem;overflow-y:hidden}.list-container.primary{flex-shrink:1;margin-bottom:.25rem}:host.kind--narrow .list-container.primary{margin-bottom:.5rem}.list-container.primary .scroll{height:100%;overflow-y:auto}.list-container .list{margin-right:1.5rem}.list-container.secondary{flex-shrink:4}.list-container.secondary .scroll{height:100%;overflow-y:auto}.filter{margin-bottom:.75rem}:host.kind--default .filter{margin-top:.625rem}:host.kind--narrow .filter{margin-bottom:1rem}.stepper{position:relative;display:flex;justify-content:center;align-items:center;margin-top:-.0625rem;margin-bottom:-.25rem}:host.kind--narrow .stepper{margin-top:-.5rem;margin-bottom:-.1875rem}.stepper:before{content:\"\";position:absolute;inset:50% 0 0;height:.0625rem;background-color:var(--color-lines)}.stepper-inner{display:flex;z-index:1;align-items:center;gap:.6875rem;background-color:var(--color-background);padding:.25rem .75rem}.stepper-value{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:300;font-style:normal;letter-spacing:.02em}\n"], dependencies: [{ kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: CheckboxComponent, selector: "talenra-checkbox", inputs: ["size", "labelPosition", "indeterminate", "pointerDisabled"], outputs: ["indeterminateChange", "checkedChange"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "component", type: ToggleComponent, selector: "talenra-toggle", outputs: ["checkedChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }, { kind: "component", type: AttributesListComponent, selector: "inbox-attributes-list", inputs: ["attributes", "role", "dragDisabled", "kind", "lockedAttributes"], outputs: ["checkedChange", "cdkDropListDropped", "moveToOtherListTriggered"] }, { kind: "component", type: SearchFieldComponent, selector: "talenra-search-field", inputs: ["showIcon", "showButton", "size"], outputs: ["search", "clear"] }, { kind: "directive", type: CdkDropListGroup, selector: "[cdkDropListGroup]", inputs: ["cdkDropListGroupDisabled"], exportAs: ["cdkDropListGroup"] }, { kind: "component", type: SearchInputComponent, selector: "input[talenra-search]", inputs: ["kind", "disabled"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributesSettingsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-attributes-settings', standalone: true, imports: [
                        ReactiveFormsModule,
                        CheckboxComponent,
                        TooltipDirective,
                        ToggleComponent,
                        FormsModule,
                        ButtonComponent,
                        ScrollContainerComponent,
                        AttributesListComponent,
                        SearchFieldComponent,
                        CdkDropListGroup,
                        SearchInputComponent,
                    ], template: "<div class=\"all-attributes\">\n  <div [formGroup]=\"allAttributesSettingsChecked\" class=\"control-pair\">\n    <talenra-checkbox\n      [(indeterminate)]=\"indeterminateAllAttributes\"\n      [talenraTooltip]=\"allAttributesSettingsChecked.get('check')?.value === true ? 'Alle abw\u00E4hlen' : 'Alle ausw\u00E4hlen'\"\n      data-testid=\"check/uncheck all\"\n      formControlName=\"check\"></talenra-checkbox>\n    <span>Alle</span>\n  </div>\n  @if (inboxState.inboxConfiguration$.value.showAttributeLabelsDataItemsList !== undefined) {\n    <div class=\"control-pair\">\n      <talenra-toggle\n        (ngModelChange)=\"changeShowAttributeLabelsDataItemsList($event)\"\n        [ngModel]=\"showAttributeLabelsDataItemsList\"></talenra-toggle>\n      <span>Label</span>\n    </div>\n  }\n</div>\n\n<div class=\"stepper\">\n  @if (!inboxState.inboxConfiguration$.value.disableFlexibleMainAttributes) {\n    <div class=\"stepper-inner\">\n      <button\n        (click)=\"updateAttributesMax(-1)\"\n        [disabled]=\"numberMainAttributesChosenByUser <= 1\"\n        data-testid=\"Maximale Anzahl an Hauptattributen verringern\"\n        icon=\"remove\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Anzahl Hauptattribute verringern\"\n        size=\"s\"></button>\n      <div class=\"stepper-value\">\n        {{ numberMainAttributesChosenByUser }}\n      </div>\n      <button\n        (click)=\"updateAttributesMax(1)\"\n        [disabled]=\"numberMainAttributesChosenByUser >= maxAttributesShown\"\n        data-testid=\"Maximale Anzahl an Hauptattributen erh\u00F6hen\"\n        icon=\"add\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Anzahl Hauptattribute erh\u00F6hen\"\n        size=\"s\"></button>\n    </div>\n  }\n</div>\n\n<div cdkDropListGroup class=\"flexible-height\">\n  <div class=\"lists\">\n    <div class=\"list-container primary\">\n      <talenra-scroll-container class=\"scroll\" useOverlay>\n        <inbox-attributes-list\n          (cdkDropListDropped)=\"onDrop('primary', $event)\"\n          (checkedChange)=\"handleMarkedAttribute($event)\"\n          (moveToOtherListTriggered)=\"moveToOtherList('primary', $event)\"\n          [attributes]=\"mainAttributes\"\n          [dragDisabled]=\"isSearchActive()\"\n          [kind]=\"preferNarrowList ? 'narrow' : 'default'\"\n          [lockedAttributes]=\"lockedAttributes\"\n          class=\"list\"\n          role=\"primary\"></inbox-attributes-list>\n      </talenra-scroll-container>\n    </div>\n\n    <hr class=\"separator\" />\n\n    <talenra-search-field [formGroup]=\"searchForm\" class=\"filter\" showIcon>\n      <input formControlName=\"query\" kind=\"no-indent\" talenra-search />\n    </talenra-search-field>\n    <div class=\"list-container secondary\">\n      <talenra-scroll-container class=\"scroll\" useOverlay>\n        <inbox-attributes-list\n          (cdkDropListDropped)=\"onDrop('secondary', $event)\"\n          (checkedChange)=\"handleMarkedAttribute($event)\"\n          (moveToOtherListTriggered)=\"moveToOtherList('secondary', $event)\"\n          [attributes]=\"detailAttributesSearch\"\n          [dragDisabled]=\"isSearchActive()\"\n          [kind]=\"preferNarrowList ? 'narrow' : 'default'\"\n          [lockedAttributes]=\"lockedAttributes\"\n          class=\"list\"\n          role=\"secondary\"></inbox-attributes-list>\n      </talenra-scroll-container>\n    </div>\n  </div>\n</div>\n", styles: [":host{--color-primary: #0099a8;--color-background: #ffffff;--color-border: #f2f2f2;--color-text: #000000;--color-icons: #999999;--color-lines: #cccccc;--color-attribute-item-background-hover: #f2f2f2;--color-attribute-item-background-drag: #eaf4f6}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-border: #262626;--color-text: #ffffff;--color-icons: #666666;--color-lines: #666666;--color-attribute-item-background-hover: #262626}:host{display:flex;flex-direction:column;height:calc(100% - 45px);font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-text);-webkit-user-select:none;user-select:none}.all-attributes{display:flex;justify-content:space-between;gap:1rem;padding-left:.25rem;padding-right:.375rem}.control-pair{display:flex;flex-wrap:nowrap;align-items:center}.control-pair span{margin-left:.5rem}.separator{width:100%;height:.0625rem;background-color:var(--color-lines);border:0;flex-shrink:0;margin:.4375rem -.25rem .4375rem 0}.flexible-height{flex-grow:1;flex-shrink:1;overflow-y:hidden;margin-right:-1.5rem;padding-right:1.5rem}.lists{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%}.list-container{margin-right:-1.5rem;overflow-y:hidden}.list-container.primary{flex-shrink:1;margin-bottom:.25rem}:host.kind--narrow .list-container.primary{margin-bottom:.5rem}.list-container.primary .scroll{height:100%;overflow-y:auto}.list-container .list{margin-right:1.5rem}.list-container.secondary{flex-shrink:4}.list-container.secondary .scroll{height:100%;overflow-y:auto}.filter{margin-bottom:.75rem}:host.kind--default .filter{margin-top:.625rem}:host.kind--narrow .filter{margin-bottom:1rem}.stepper{position:relative;display:flex;justify-content:center;align-items:center;margin-top:-.0625rem;margin-bottom:-.25rem}:host.kind--narrow .stepper{margin-top:-.5rem;margin-bottom:-.1875rem}.stepper:before{content:\"\";position:absolute;inset:50% 0 0;height:.0625rem;background-color:var(--color-lines)}.stepper-inner{display:flex;z-index:1;align-items:center;gap:.6875rem;background-color:var(--color-background);padding:.25rem .75rem}.stepper-value{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:300;font-style:normal;letter-spacing:.02em}\n"] }]
        }], propDecorators: { attributesSettingsList: [{
                type: Input
            }], maxAttributesShown: [{
                type: Input
            }], numberMainAttributesChosenByUser: [{
                type: Input
            }], isExpanded: [{
                type: Input
            }], selectedMainAttributes: [{
                type: Input
            }], selectedDetailAttributes: [{
                type: Input
            }], lockedAttributes: [{
                type: Input
            }], selectedMainAttributesEmitter: [{
                type: Output
            }], selectedDetailAttributesEmitter: [{
                type: Output
            }], selectedAllAttributesEmitter: [{
                type: Output
            }], numberMainAttributesChosenByUserEmitter: [{
                type: Output
            }], classNames: [{
                type: HostBinding,
                args: ['class']
            }] } });

class SortSelectionComponent {
    constructor() {
        /**
         * The availableAttributes input is an array of AttributeItem that contains the available sortable attributes.
         */
        this.availableAttributes = input([]);
        /**
         * The sortSelections input is an array of strings that contains the selected sorts.
         */
        this.sortSelections = input([]);
        /**
         * The sortSelections output is an array of strings that contains the selected sorts.
         */
        this.sortSelectionsChange = output();
        /**
         * The availableAttributes output is an array of AttributeItem that contains the available filters.
         */
        this.copyAvailableAttributes = computed(() => {
            const availableAttributes = [];
            this.availableAttributes().forEach((attribute) => {
                availableAttributes.push({
                    checked: new FormGroup({}),
                    identifier: attribute.identifier,
                    label: attribute.label,
                    filterMode: attribute.filterMode,
                    dateFilterRestriction: attribute.dateFilterRestriction,
                });
            });
            return availableAttributes;
        });
        /**
         * The availableSortAttributes computed property is an array of strings that contains the available sort attributes.
         */
        this.availableSortAttributes = [];
        /**
         * The selectedAttributes input is an array of AttributeItem that contains the selected sorts.
         */
        this.selectedAttributes = [];
        /**
         * The selected values.
         */
        this.selectionForm = new FormGroup({
            attributeSelection: new FormControl(''),
        });
    }
    /**
     * @internal
     */
    ngOnInit() {
        this.initializeSortAttributes();
    }
    /**
     * @internal
     */
    ngOnChanges(changes) {
        const sortSelectionsChanges = changes['sortSelections'];
        if (sortSelectionsChanges && !sortSelectionsChanges.firstChange) {
            // reset the selected sorts
            this.selectedAttributes = [];
            // add the selected sorts to the selected sorts
            sortSelectionsChanges.currentValue.forEach((sortSelection) => {
                // get the selected attribute from the available sorts
                const selectedAttribute = this.copyAvailableAttributes().find((attribute) => attribute.identifier === sortSelection.identifier);
                // add the selected sort to the selected sorts
                selectedAttribute &&
                    this.selectedAttributes.push({
                        attribute: selectedAttribute,
                        sortAttribute: { identifier: sortSelection.identifier, sort: sortSelection.sort },
                        attributeSelectOptions: this.createAttributeOptions(selectedAttribute.identifier),
                    });
            });
            // remove the selected sort from the available sorts
            this.initializeSortAttributes();
        }
    }
    /**
     * Removes the sort from the selection.
     * @param sortIndex The sort index.
     */
    deleteSortAttribute(sortIndex) {
        // remove the selected sort from the selected sorts via the sort index
        this.selectedAttributes.splice(sortIndex, 1);
        // add the selected sort from the available sorts
        this.initializeSortAttributes();
    }
    /**
     * Called when the user selects a sort.
     * @param selectChange The select change.
     */
    onSortSelectionAdd(selectChange) {
        // set the copy available attributes to proper values for the logic, after reset by the select
        this.resetCopyAvailableAttributes();
        // reset the selected sorts
        this.selectionForm.reset();
        // get the selected attribute from the available sorts
        const selectedAttribute = this.copyAvailableAttributes().find((attribute) => attribute.identifier === selectChange.value);
        // add the selected sort to the selected sorts
        selectedAttribute &&
            this.selectedAttributes.push({
                attribute: selectedAttribute,
                sortAttribute: { identifier: selectChange.value, sort: 'asc' },
                attributeSelectOptions: this.createAttributeOptions(selectChange.value),
            });
        // remove the selected sort from the available sorts
        this.initializeSortAttributes();
    }
    /**
     * Called when the user changes a filter attribute.
     * @param selectChange The select change.
     * @param index The index.
     */
    onSortSelectionChange(selectChange, index) {
        // set the copy available attributes to proper values for the logic, after reset by the select
        this.resetCopyAvailableAttributes();
        // get the selected attribute from the available sorts
        const selectedAttribute = this.copyAvailableAttributes().find((attribute) => attribute.identifier === selectChange.value);
        // remove the current selected sort from the selected sorts
        this.selectedAttributes.splice(index, 1);
        // add the selected sort to the selected sorts
        selectedAttribute &&
            this.selectedAttributes.splice(index, 0, {
                attribute: selectedAttribute,
                sortAttribute: { identifier: selectChange.value, sort: 'asc' },
                attributeSelectOptions: this.createAttributeOptions(selectChange.value),
            });
        // update the options of the available filters
        this.initializeSortAttributes();
    }
    /**
     * Called when the user clicks the x button in the sort attribute selection.
     * @param value The value of the attribute selector.
     * @param index The index.
     */
    onAttributeSelectionModelChange(value, index) {
        // set the copy available attributes to proper values for the logic, after reset by the select
        this.resetCopyAvailableAttributes();
        // if the value is null, the x button was clicked
        // remove the selected sort from the selected sort at the index
        if (value === null) {
            this.selectedAttributes.splice(index, 1);
        }
        // update the options of the available filters
        this.initializeSortAttributes();
    }
    /**
     * Changes the sort direction.
     * @param attributesIndex The sort index.
     */
    onSortChange(attributesIndex) {
        // get the selected attribute from the available sorts
        const selectedAttribute = this.selectedAttributes[attributesIndex].sortAttribute;
        // change the sort direction
        if (selectedAttribute) {
            selectedAttribute.sort = selectedAttribute.sort === 'asc' ? 'desc' : 'asc';
        }
        this.emitSortSelections();
    }
    /**
     * Called when the user drops an element.
     * @param dropElement The drop element.
     */
    onDrop(dropElement) {
        // move item in the selected sorts
        moveItemInArray(dropElement.container.data, dropElement.previousIndex, dropElement.currentIndex);
        this.emitSortSelections();
    }
    /**
     * Initializes the sort attributes.
     */
    initializeSortAttributes() {
        // initialize the available sort attributes to remove the selected sorts
        this.availableSortAttributes = [];
        this.copyAvailableAttributes().forEach((attribute) => {
            // check if the attribute is not in the selected sorts
            if (!this.selectedAttributes.find((selectedAttribute) => selectedAttribute.attribute.identifier === attribute.identifier)) {
                // add the available sort to the available sort attributes
                this.availableSortAttributes.push({
                    attribute: {
                        identifier: attribute.identifier,
                        checked: new FormGroup({}),
                        label: attribute.label,
                        filterMode: attribute.filterMode,
                    },
                    attributeSelectOptions: this.createAttributeOptions(attribute.identifier),
                });
            }
        });
        // adjust the options for the selected sorts
        this.selectedAttributes.forEach((selectedAttribute) => {
            selectedAttribute.attributeSelectOptions = this.createInitialAttributeOptions(selectedAttribute.attribute.identifier);
        });
        this.emitSortSelections();
    }
    /**
     * Emits the sort selections.
     */
    emitSortSelections() {
        const sortSelections = [];
        this.selectedAttributes.forEach((selectedAttribute) => {
            // add the selected sort to the selected sorts
            if (selectedAttribute.sortAttribute?.identifier && selectedAttribute.sortAttribute?.sort) {
                sortSelections.push(selectedAttribute.sortAttribute);
            }
        });
        this.sortSelectionsChange.emit(sortSelections);
    }
    /**
     * Auxiliary method to create the attribute options for the selected Attributes.
     * @param selectedAttributeIdentifier The selected attribute identifier.
     */
    createAttributeOptions(selectedAttributeIdentifier) {
        // reset the attribute options
        const attributeOptions = [];
        // create the attribute options for the selected Attributes
        this.copyAvailableAttributes().forEach((attribute) => {
            // push only the not selected attributes and the selected attribute
            if (attribute.identifier === selectedAttributeIdentifier ||
                !this.sortSelections().find((selectedAttribute) => selectedAttribute.identifier === attribute.identifier)) {
                attributeOptions.push(attribute);
            }
        });
        return attributeOptions;
    }
    /**
     * Auxiliary method to create the attribute options for the selected Attributes.
     * @param selectedAttributeIdentifier The selected attribute identifier.
     */
    createInitialAttributeOptions(selectedAttributeIdentifier) {
        // reset the attribute options
        const attributeOptions = [];
        // create the attribute options for the selected Attributes
        this.copyAvailableAttributes().forEach((attribute) => {
            // push only the not selected attributes and the selected attribute
            if (attribute.identifier === selectedAttributeIdentifier ||
                !this.selectedAttributes.find((selectedAttribute) => selectedAttribute.attribute.identifier === attribute.identifier)) {
                attributeOptions.push({
                    identifier: attribute.identifier,
                    checked: new FormGroup({}),
                    label: attribute.label,
                    filterMode: attribute.filterMode,
                    dateFilterRestriction: attribute.dateFilterRestriction,
                });
            }
        });
        return attributeOptions;
    }
    /**
     * Resets the copy available attributes.
     */
    resetCopyAvailableAttributes() {
        this.availableAttributes().forEach((attribute, index) => {
            this.copyAvailableAttributes()[index].identifier = attribute.identifier;
            this.copyAvailableAttributes()[index].checked = new FormGroup({});
            this.copyAvailableAttributes()[index].label = attribute.label;
            this.copyAvailableAttributes()[index].filterMode = attribute.filterMode;
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SortSelectionComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: SortSelectionComponent, isStandalone: true, selector: "talenra-sort-selection", inputs: { availableAttributes: { classPropertyName: "availableAttributes", publicName: "availableAttributes", isSignal: true, isRequired: false, transformFunction: null }, sortSelections: { classPropertyName: "sortSelections", publicName: "sortSelections", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { sortSelectionsChange: "sortSelectionsChange" }, usesOnChanges: true, ngImport: i0, template: "<talenra-scroll-container class=\"advanced-sort\">\n  <div class=\"layout-advanced-sort-drop-down\">\n    <div (cdkDropListDropped)=\"onDrop($event)\" [cdkDropListData]=\"selectedAttributes\" cdkDropList>\n      @for (selectedAttribute of selectedAttributes; track $index) {\n        <div class=\"grid-chosen-sort-elements\" cdkDrag>\n          <talenra-form-field label=\"Sortierung nach\">\n            <talenra-select\n              useFilter\n              data-testid=\"talenra-inbox-sort-selection-selected-attribute\"\n              (ngModelChange)=\"onAttributeSelectionModelChange($event, $index)\"\n              (selectionChange)=\"onSortSelectionChange($event, $index)\"\n              [(ngModel)]=\"selectedAttribute.attribute.identifier\">\n              @for (attribute of selectedAttribute.attributeSelectOptions; track attribute.identifier) {\n                <talenra-option data-testid=\"talenra-inbox-selection-sort-option\" [value]=\"attribute.identifier\"\n                  >{{ attribute.label }}\n                </talenra-option>\n              }\n            </talenra-select>\n          </talenra-form-field>\n          <button\n            data-testid=\"inbox-sort-ascending-descending-button\"\n            (click)=\"onSortChange($index)\"\n            [icon]=\"\n              selectedAttribute.sortAttribute?.sort === 'asc' ? 'sort-ascending-duplex' : 'sort-descending-duplex'\n            \"\n            [talenraTooltip]=\"selectedAttribute.sortAttribute?.sort === 'asc' ? 'Aufsteigend' : 'Absteigend'\"\n            kind=\"ghost\"\n            class=\"sort-icon\"\n            talenra-button></button>\n          <button\n            (click)=\"deleteSortAttribute($index)\"\n            data-testid=\"inbox-sort-deselection-button\"\n            icon=\"delete\"\n            kind=\"ghost\"\n            talenra-button\n            talenraTooltip=\"L\u00F6schen\"></button>\n          <button\n            data-testid=\"inbox-sort-drag-button\"\n            cdkDragHandle\n            class=\"drag-icon\"\n            icon=\"drag-indicator\"\n            kind=\"ghost\"\n            talenra-button></button>\n        </div>\n      }\n\n      <form [formGroup]=\"selectionForm\" class=\"grid-chosen-sort-elements\">\n        <talenra-form-field label=\"Sortierung nach\">\n          <talenra-select\n            (selectionChange)=\"onSortSelectionAdd($event)\"\n            data-testid=\"talenra-inbox-sort-selection-attribute-selector\"\n            formControlName=\"attributeSelection\"\n            useFilter>\n            @for (attribute of availableSortAttributes; track attribute.attribute.identifier) {\n              <talenra-option data-testid=\"talenra-inbox-selection-sort-option\" [value]=\"attribute.attribute.identifier\"\n                >{{ attribute.attribute.label }}\n              </talenra-option>\n            }\n          </talenra-select>\n        </talenra-form-field>\n      </form>\n    </div>\n  </div>\n</talenra-scroll-container>\n", styles: [":host{--color-primary: #0099a8}.advanced-sort{height:100%}.layout-advanced-sort-drop-down{position:relative;min-width:fit-content;display:flex;flex-direction:column;flex-wrap:nowrap}.grid-chosen-sort-elements{position:relative;min-width:fit-content;display:grid;grid-template-columns:1fr 1.75rem 1.75rem 1.75rem;column-gap:.5rem;grid-auto-flow:row;align-items:center}.sort-icon{--color-label: var(--color-primary)}.drag-icon{cursor:grab;color:#b3b3b3}.theme--denim :host{--color-primary: #0069a3}\n"], dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "component", type: FormFieldComponent, selector: "talenra-form-field", inputs: ["hint", "label", "size"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }, { kind: "component", type: SelectComponent, selector: "talenra-select", inputs: ["useFilter", "allowMultiple", "noOptionsMessage", "noMatchMessage", "disabled", "value", "readonly", "kind", "placeholder"], outputs: ["selectionChange"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "directive", type: CdkDrag, selector: "[cdkDrag]", inputs: ["cdkDragData", "cdkDragLockAxis", "cdkDragRootElement", "cdkDragBoundary", "cdkDragStartDelay", "cdkDragFreeDragPosition", "cdkDragDisabled", "cdkDragConstrainPosition", "cdkDragPreviewClass", "cdkDragPreviewContainer", "cdkDragScale"], outputs: ["cdkDragStarted", "cdkDragReleased", "cdkDragEnded", "cdkDragEntered", "cdkDragExited", "cdkDragDropped", "cdkDragMoved"], exportAs: ["cdkDrag"] }, { kind: "directive", type: CdkDropList, selector: "[cdkDropList], cdk-drop-list", inputs: ["cdkDropListConnectedTo", "cdkDropListData", "cdkDropListOrientation", "id", "cdkDropListLockAxis", "cdkDropListDisabled", "cdkDropListSortingDisabled", "cdkDropListEnterPredicate", "cdkDropListSortPredicate", "cdkDropListAutoScrollDisabled", "cdkDropListAutoScrollStep", "cdkDropListElementContainer"], outputs: ["cdkDropListDropped", "cdkDropListEntered", "cdkDropListExited", "cdkDropListSorted"], exportAs: ["cdkDropList"] }, { kind: "directive", type: CdkDragHandle, selector: "[cdkDragHandle]", inputs: ["cdkDragHandleDisabled"] }, { kind: "component", type: OptionComponent, selector: "talenra-option", inputs: ["value", "icon", "isHidden"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SortSelectionComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-sort-selection', imports: [
                        ButtonComponent,
                        FormFieldComponent,
                        FormsModule,
                        ReactiveFormsModule,
                        ScrollContainerComponent,
                        SelectComponent,
                        TooltipDirective,
                        CdkDrag,
                        CdkDropList,
                        CdkDragHandle,
                        OptionComponent,
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<talenra-scroll-container class=\"advanced-sort\">\n  <div class=\"layout-advanced-sort-drop-down\">\n    <div (cdkDropListDropped)=\"onDrop($event)\" [cdkDropListData]=\"selectedAttributes\" cdkDropList>\n      @for (selectedAttribute of selectedAttributes; track $index) {\n        <div class=\"grid-chosen-sort-elements\" cdkDrag>\n          <talenra-form-field label=\"Sortierung nach\">\n            <talenra-select\n              useFilter\n              data-testid=\"talenra-inbox-sort-selection-selected-attribute\"\n              (ngModelChange)=\"onAttributeSelectionModelChange($event, $index)\"\n              (selectionChange)=\"onSortSelectionChange($event, $index)\"\n              [(ngModel)]=\"selectedAttribute.attribute.identifier\">\n              @for (attribute of selectedAttribute.attributeSelectOptions; track attribute.identifier) {\n                <talenra-option data-testid=\"talenra-inbox-selection-sort-option\" [value]=\"attribute.identifier\"\n                  >{{ attribute.label }}\n                </talenra-option>\n              }\n            </talenra-select>\n          </talenra-form-field>\n          <button\n            data-testid=\"inbox-sort-ascending-descending-button\"\n            (click)=\"onSortChange($index)\"\n            [icon]=\"\n              selectedAttribute.sortAttribute?.sort === 'asc' ? 'sort-ascending-duplex' : 'sort-descending-duplex'\n            \"\n            [talenraTooltip]=\"selectedAttribute.sortAttribute?.sort === 'asc' ? 'Aufsteigend' : 'Absteigend'\"\n            kind=\"ghost\"\n            class=\"sort-icon\"\n            talenra-button></button>\n          <button\n            (click)=\"deleteSortAttribute($index)\"\n            data-testid=\"inbox-sort-deselection-button\"\n            icon=\"delete\"\n            kind=\"ghost\"\n            talenra-button\n            talenraTooltip=\"L\u00F6schen\"></button>\n          <button\n            data-testid=\"inbox-sort-drag-button\"\n            cdkDragHandle\n            class=\"drag-icon\"\n            icon=\"drag-indicator\"\n            kind=\"ghost\"\n            talenra-button></button>\n        </div>\n      }\n\n      <form [formGroup]=\"selectionForm\" class=\"grid-chosen-sort-elements\">\n        <talenra-form-field label=\"Sortierung nach\">\n          <talenra-select\n            (selectionChange)=\"onSortSelectionAdd($event)\"\n            data-testid=\"talenra-inbox-sort-selection-attribute-selector\"\n            formControlName=\"attributeSelection\"\n            useFilter>\n            @for (attribute of availableSortAttributes; track attribute.attribute.identifier) {\n              <talenra-option data-testid=\"talenra-inbox-selection-sort-option\" [value]=\"attribute.attribute.identifier\"\n                >{{ attribute.attribute.label }}\n              </talenra-option>\n            }\n          </talenra-select>\n        </talenra-form-field>\n      </form>\n    </div>\n  </div>\n</talenra-scroll-container>\n", styles: [":host{--color-primary: #0099a8}.advanced-sort{height:100%}.layout-advanced-sort-drop-down{position:relative;min-width:fit-content;display:flex;flex-direction:column;flex-wrap:nowrap}.grid-chosen-sort-elements{position:relative;min-width:fit-content;display:grid;grid-template-columns:1fr 1.75rem 1.75rem 1.75rem;column-gap:.5rem;grid-auto-flow:row;align-items:center}.sort-icon{--color-label: var(--color-primary)}.drag-icon{cursor:grab;color:#b3b3b3}.theme--denim :host{--color-primary: #0069a3}\n"] }]
        }] });

class TextFilterComponent {
    constructor() {
        /**
         * The attribute to identify which filter is selected.
         */
        this.attribute = input.required();
        /**
         * The filterSelection output is used to emit the filter values.
         */
        this.filterSelection = output();
        /**
         * The filterValues are the values that are used to filter the data items.
         */
        this.reactiveForm = new FormGroup({
            textField: new FormControl(''),
        });
    }
    /**
     * Function is called when the component is initialized.
     */
    ngOnInit() {
        // initialize the filter values if the filter attribute is set
        if (this.attribute().filterAttribute) {
            this.initializeFilterValues();
        }
        // react on value changes
        this.reactiveForm.get('textField')?.valueChanges.subscribe((value) => {
            // check for null values
            if (value === null) {
                this.onValuesSelected('');
            }
            else {
                this.onValuesSelected(value);
            }
        });
    }
    /**
     * @internal
     */
    ngOnChanges(changes) {
        const attributeChanges = changes['attribute'];
        // initialize the filter values if the filter attribute is set
        if (attributeChanges && !attributeChanges.firstChange && attributeChanges.currentValue.filterAttribute) {
            // check if the values are the same
            if (attributeChanges.currentValue.filterAttribute &&
                attributeChanges.previousValue.filterAttribute &&
                attributeChanges.currentValue.filterAttribute.value !== attributeChanges.previousValue.filterAttribute.value) {
                this.initializeFilterValues();
            }
        }
    }
    /**
     * Function is necessary to delete the filter from the filter toolbar.
     * Furthermore, the previous filtering with the deleted filter will be ignored.
     * @param mouseEvent The mouse event.
     */
    resetValue(mouseEvent) {
        mouseEvent.stopPropagation();
        this.reactiveForm.get('textField')?.setValue('');
    }
    /**
     * All selected filters will be saved in the map with there defintion and values
     * @param value The value of the filter.
     */
    onValuesSelected(value) {
        this.filterSelection.emit({
            attribute: this.attribute().attribute,
            operator: this.attribute().operator,
            filterAttribute: {
                identifier: this.attribute().attribute.identifier,
                operator: this.attribute().operator,
                value,
            },
        });
    }
    /**
     * Function is necessary to initialize the filter values.
     */
    initializeFilterValues() {
        // check for the specific filters
        const filterAttribute = this.attribute().filterAttribute;
        if (filterAttribute && filterAttribute.value) {
            const filterValue = filterAttribute.value;
            // check for null values
            if (typeof filterValue === 'string') {
                this.reactiveForm.get('textField')?.setValue(filterValue);
            }
            else {
                this.reactiveForm.get('textField')?.setValue('');
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: TextFilterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "19.1.6", type: TextFilterComponent, isStandalone: true, selector: "talenra-text-filter", inputs: { attribute: { classPropertyName: "attribute", publicName: "attribute", isSignal: true, isRequired: true, transformFunction: null } }, outputs: { filterSelection: "filterSelection" }, usesOnChanges: true, ngImport: i0, template: "<form [formGroup]=\"reactiveForm\" class=\"form-group\" novalidate>\n  <div class=\"field-wrap\">\n    <talenra-form-field [label]=\"attribute().attribute.label\" class=\"text-field\">\n      <input formControlName=\"textField\" talenra-input />\n    </talenra-form-field>\n  </div>\n  <button\n    (click)=\"resetValue($event)\"\n    [disabled]=\"!reactiveForm.value.textField\"\n    data-testid=\"inbox-filter-deselection-undo\"\n    icon=\"undo\"\n    kind=\"ghost\"\n    talenra-button\n    talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n</form>\n", styles: [".form-group{min-height:2.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;gap:.5rem}.field-wrap{width:100%;display:flex}.text-field{flex-grow:1}\n"], dependencies: [{ kind: "component", type: InputComponent, selector: "input[talenra-input], textarea[talenra-input]", inputs: ["type", "disabled", "readonly"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: FormFieldComponent, selector: "talenra-form-field", inputs: ["hint", "label", "size"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: TextFilterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-text-filter', standalone: true, imports: [InputComponent, ButtonComponent, TooltipDirective, ReactiveFormsModule, FormFieldComponent], changeDetection: ChangeDetectionStrategy.OnPush, template: "<form [formGroup]=\"reactiveForm\" class=\"form-group\" novalidate>\n  <div class=\"field-wrap\">\n    <talenra-form-field [label]=\"attribute().attribute.label\" class=\"text-field\">\n      <input formControlName=\"textField\" talenra-input />\n    </talenra-form-field>\n  </div>\n  <button\n    (click)=\"resetValue($event)\"\n    [disabled]=\"!reactiveForm.value.textField\"\n    data-testid=\"inbox-filter-deselection-undo\"\n    icon=\"undo\"\n    kind=\"ghost\"\n    talenra-button\n    talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n</form>\n", styles: [".form-group{min-height:2.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;gap:.5rem}.field-wrap{width:100%;display:flex}.text-field{flex-grow:1}\n"] }]
        }] });

/**
 * The selection filter component is a component to show a selected item from a pool of items.
 * There is a multiple selection possible.
 *
 * '''html
 *   <talenra-selection-filter
 *     (filterSelection)="onFilterSelection($event)" [attribute]="selectedAttribute" [possibleValues]="possibleSelection">
 *   </talenra-selection-filter>
 *  '''
 */
class SelectionFilterComponent {
    constructor() {
        /**
         * The attribute to identify which filter is selected.
         */
        this.attribute = input.required();
        /**
         * The filterSelection output is used to emit the filter values.
         */
        this.filterSelection = output();
        /**
         * The possible values of the filter.
         */
        this.possibleValues = input([]);
        /**
         * The select component.
         */
        this.select = null;
        /**
         * The selected values.
         */
        this.selectionForm = new FormGroup({
            singleSelect: new FormControl(undefined),
            multiSelect: new FormControl([]),
        });
        /**
         * The inboxState is used to get the active view name.
         * @private
         */
        this.inboxState = inject(InboxState);
        /**
         * The inboxToolbarService is used to get if the attribute settings are closed
         */
        this.inboxToolbarService = inject(InboxToolbarService);
        /**
         * The destroyRef is used to destroy the component.
         * @private
         */
        this.destroyRef = inject(DestroyRef);
        // the effect is necessary to get the selected side panel tab change to close the option list
        effect(() => {
            this.inboxState.selectedSidePanelTab() && this.select && this.select.hidePanel();
        });
        // close the option list if the configuration panel is closed
        this.inboxToolbarService.configurationPanelExpanded$
            .pipe(takeUntilDestroyed(this.destroyRef))
            .subscribe((expanded) => {
            if (!expanded && this.select) {
                this.select.hidePanel();
                // un focus the select component
                if (document.activeElement === this.select['elementRef'].nativeElement) {
                    // blur the select component
                    // TODO: check if the select component is still focused
                    this.select['elementRef'].nativeElement.blur();
                }
            }
        });
    }
    /**
     * @internal
     */
    ngOnInit() {
        // initialize the filter values if the filter attribute is set
        if (this.attribute().filterAttribute) {
            this.initializeFilterValues();
        }
        // react on value changes
        this.selectionForm
            .get('singleSelect')
            ?.valueChanges.pipe(takeUntilDestroyed(this.destroyRef))
            .subscribe((value) => {
            this.onValuesSelected(value);
        });
        // react on value changes
        this.selectionForm
            .get('multiSelect')
            ?.valueChanges.pipe(takeUntilDestroyed(this.destroyRef))
            .subscribe((value) => {
            this.onValuesSelected(value);
        });
    }
    /**
     * @internal
     */
    ngOnChanges(changes) {
        const attributeChanges = changes['attribute'];
        // initialize the filter values if the filter attribute is set
        if (attributeChanges && !attributeChanges.firstChange) {
            // check if the values are the same
            if (attributeChanges.currentValue.filterAttribute &&
                attributeChanges.previousValue.filterAttribute &&
                JSON.stringify(attributeChanges.currentValue.filterAttribute.value) !==
                    JSON.stringify(attributeChanges.previousValue.filterAttribute.value)) {
                // initialize the filter values if the filter attribute is set
                // needs to be handled in next change detection cycle, that options are set properly
                setTimeout(() => {
                    this.initializeFilterValues();
                }, 0);
            }
            // check if attribute value was defined and is now undefined
            else if (attributeChanges.previousValue.filterAttribute && !attributeChanges.currentValue.filterAttribute) {
                // reset the selected values
                this.resetValues();
            }
        }
    }
    /**
     * Function is necessary to delete the filter from the filter toolbar.
     * Furthermore, the previous filterings with the deleted filter will be ignored.
     * @param mouseEvent The mouse event.
     */
    resetValues(mouseEvent) {
        mouseEvent?.stopPropagation();
        // reset the selected values
        if (this.attribute().attribute.filterMode === 'single-select') {
            this.selectionForm.get('singleSelect')?.setValue(undefined);
        }
        else if (this.attribute().attribute.filterMode === 'multi-select') {
            this.selectionForm.get('multiSelect')?.setValue([]);
        }
    }
    /**
     * All selected filters will be saved in the map with there definition and values
     * @param value The value of the filter.
     */
    onValuesSelected(value) {
        this.filterSelection.emit({
            attribute: this.attribute().attribute,
            operator: this.attribute().operator,
            filterAttribute: {
                identifier: this.attribute().attribute.identifier,
                operator: this.attribute().operator,
                value: value,
            },
        });
    }
    /**
     * Function is necessary to initialize the filter values.
     */
    initializeFilterValues() {
        // check for the specific filters
        const filterAttribute = this.attribute().filterAttribute;
        if (filterAttribute) {
            // get value from possible values
            const filterAttributeValue = filterAttribute.value;
            if (this.attribute().attribute.filterMode === 'multi-select' &&
                filterAttribute.value &&
                Array.isArray(filterAttribute.value)) {
                const values = [];
                filterAttribute.value.forEach((value) => {
                    // get value from possible values
                    this.possibleValues().forEach((possibleValue) => {
                        if (possibleValue.key === value.key) {
                            values.push(possibleValue);
                        }
                    });
                });
                this.selectionForm.get('multiSelect')?.setValue(values);
            }
            else if (this.attribute().attribute.filterMode === 'single-select' &&
                typeof filterAttributeValue === 'object' &&
                'label' in filterAttributeValue &&
                'key' in filterAttributeValue) {
                // get value from possible values
                this.possibleValues().forEach((possibleValue) => {
                    if (possibleValue.key === filterAttributeValue.key) {
                        this.selectionForm.get('singleSelect')?.setValue(possibleValue);
                    }
                });
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SelectionFilterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: SelectionFilterComponent, isStandalone: true, selector: "talenra-selection-filter", inputs: { attribute: { classPropertyName: "attribute", publicName: "attribute", isSignal: true, isRequired: true, transformFunction: null }, possibleValues: { classPropertyName: "possibleValues", publicName: "possibleValues", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { filterSelection: "filterSelection" }, viewQueries: [{ propertyName: "select", first: true, predicate: ["talenraFilterSelect"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div class=\"drop-down-layout\">\n  <form [formGroup]=\"selectionForm\" class=\"drop-down-input\">\n    <talenra-form-field [label]=\"attribute().attribute.label\">\n      <talenra-select\n        #talenraFilterSelect\n        [allowMultiple]=\"attribute().attribute.filterMode === 'multi-select'\"\n        [formControlName]=\"attribute().attribute.filterMode === 'multi-select' ? 'multiSelect' : 'singleSelect'\"\n        data-testid=\"talenra-inbox-selection-filter\"\n        useFilter>\n        @for (attribute of possibleValues(); track attribute.key) {\n          <talenra-option data-testid=\"talenra-inbox-selection-filter-option\" [value]=\"attribute\"\n            >{{ attribute.label }}\n          </talenra-option>\n        }\n      </talenra-select>\n    </talenra-form-field>\n  </form>\n  <button\n    (click)=\"resetValues($event)\"\n    [disabled]=\"\n      (attribute().attribute.filterMode === 'single-select' && !selectionForm.get('singleSelect')?.value) ||\n      (attribute().attribute.filterMode === 'multi-select' && selectionForm.get('multiSelect')?.value.length === 0)\n    \"\n    data-testid=\"inbox-filter-deselection-undo\"\n    icon=\"undo\"\n    kind=\"ghost\"\n    talenra-button\n    talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n</div>\n", styles: [".drop-down-layout{min-height:2.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;gap:.5rem}.drop-down-input{width:100%}\n"], dependencies: [{ kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: FormFieldComponent, selector: "talenra-form-field", inputs: ["hint", "label", "size"] }, { kind: "component", type: SelectComponent, selector: "talenra-select", inputs: ["useFilter", "allowMultiple", "noOptionsMessage", "noMatchMessage", "disabled", "value", "readonly", "kind", "placeholder"], outputs: ["selectionChange"] }, { kind: "component", type: OptionComponent, selector: "talenra-option", inputs: ["value", "icon", "isHidden"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SelectionFilterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-selection-filter', standalone: true, imports: [
                        ReactiveFormsModule,
                        FormFieldComponent,
                        SelectComponent,
                        OptionComponent,
                        ButtonComponent,
                        TooltipDirective,
                    ], template: "<div class=\"drop-down-layout\">\n  <form [formGroup]=\"selectionForm\" class=\"drop-down-input\">\n    <talenra-form-field [label]=\"attribute().attribute.label\">\n      <talenra-select\n        #talenraFilterSelect\n        [allowMultiple]=\"attribute().attribute.filterMode === 'multi-select'\"\n        [formControlName]=\"attribute().attribute.filterMode === 'multi-select' ? 'multiSelect' : 'singleSelect'\"\n        data-testid=\"talenra-inbox-selection-filter\"\n        useFilter>\n        @for (attribute of possibleValues(); track attribute.key) {\n          <talenra-option data-testid=\"talenra-inbox-selection-filter-option\" [value]=\"attribute\"\n            >{{ attribute.label }}\n          </talenra-option>\n        }\n      </talenra-select>\n    </talenra-form-field>\n  </form>\n  <button\n    (click)=\"resetValues($event)\"\n    [disabled]=\"\n      (attribute().attribute.filterMode === 'single-select' && !selectionForm.get('singleSelect')?.value) ||\n      (attribute().attribute.filterMode === 'multi-select' && selectionForm.get('multiSelect')?.value.length === 0)\n    \"\n    data-testid=\"inbox-filter-deselection-undo\"\n    icon=\"undo\"\n    kind=\"ghost\"\n    talenra-button\n    talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n</div>\n", styles: [".drop-down-layout{min-height:2.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;gap:.5rem}.drop-down-input{width:100%}\n"] }]
        }], ctorParameters: () => [], propDecorators: { select: [{
                type: ViewChild,
                args: ['talenraFilterSelect']
            }] } });

/**
 * Range filter component, which enables three possible filter types:
 * 1. date-range
 * 2. char-range
 * 3. number-range
 * All three filter types are used to filter the data items by a range of values.
 * The filter displays two input fields, one for the start value and one for the end value.
 * An error message for the start and end input field is displayed if the input is syntactically false.
 *
 * ```html
 * <talenra-range-filter (filterSelection)="onFilterSelection($event)" [attribute]="selectedAttribute"></talenra-range-filter>
 * ```
 */
class RangeFilterComponent {
    constructor() {
        /**
         * The attribute to identify which filter is selected.
         */
        this.attribute = input.required();
        /**
         * The filterSelection output is used to emit the filter values.
         */
        this.filterSelection = output();
        /**
         * The char and number range values.
         */
        this.charNumberRange = new FormGroup({
            start: new FormControl(''),
            end: new FormControl(''),
        }, { validators: [DataItemsClass.startBeforeEnd('start', 'end', true)] });
        /**
         *  The date range values.
         */
        this.dateRange = new FormGroup({
            startDate: new FormControl(null, validateDate()),
            endDate: new FormControl(null, validateDate()),
        }, { validators: [CustomValidators.startDateBeforeEndDate('startDate', 'endDate', true)] });
        /**
         * The falseEndInput is used to check if the end input is syntactically false.
         */
        this.falseEndInput = false;
        /**
         * The charRangeAlphabet is the alphabet that is used for the char range filter.
         * @internal
         */
        this.charRangeAlphabet = 'AÀÁÂÃÄÅÆBCÇDÐEÈÉÊËFGHIÌÍÎÏJKLMNÑOÒÓÔÕÖPQRSTUÙÚÛÜVWXYÝÿZ0123456789!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~€‚ƒ„…†‡ˆ‰Š‹ŒŽ‘’“”•–—˜™š›œžŸ¡¢£¤¥¦§¨©ª«¬®¯°±²³´µ¶·¸¹º»¼½¾¿×ØÞßð÷þ';
        /**
         * Destroy references to subscriptions.
         */
        this.destroyRef = inject(DestroyRef);
        /**
         * The filter state service is used to set the filter and sort subject.
         */
        this.filterStateService = inject(FilterStateService);
        /**
         * The filter state service is used to set the filter and sort subject.
         */
        this.inboxToolbarService = inject(InboxToolbarService);
        /**
         * The unique id of the range filter. Needed for the false order range filter.
         */
        this.id = this.generateUUID();
        this.dateInTheFutureFilter = dateInTheFutureFilter;
        this.validateDate = validateDate;
        this.dateInThePastFilter = dateInThePastFilter;
    }
    /**
     * This method is called when the component is initialized.
     * @internal
     */
    ngOnInit() {
        // initialize the filter values if the filter attribute is set
        if (this.attribute().filterAttribute) {
            this.initializeFilterValues();
        }
        // check if panel opened again, and if so, to the last valid value
        this.inboxToolbarService.configurationPanelExpanded$
            .pipe(takeUntilDestroyed(this.destroyRef))
            .subscribe((value) => {
            if (value) {
                this.initializeFilterValues();
            }
        });
        // subscribe to the value changes of the input fields of date-range
        if (this.attribute().attribute.filterMode === 'date-range') {
            this.dateRange.valueChanges.pipe(takeUntilDestroyed(this.destroyRef)).subscribe((selectedValue) => {
                // check for any error in input values
                if (this.dateRange.valid) {
                    this.onValuesSelected(this.attribute().attribute.identifier, selectedValue.startDate, selectedValue.endDate);
                    if (this.filterStateService.containsFalseOrderRangeFilter(this.id)) {
                        this.filterStateService.removeFalseOrderRangeFilter(this.id);
                    }
                }
                else {
                    this.onValuesSelected(this.attribute().attribute.identifier, undefined, undefined);
                    if (!this.filterStateService.containsFalseOrderRangeFilter(this.id)) {
                        this.filterStateService.addFalseOrderRangeFilter(this.id);
                    }
                }
            });
        }
        // subscribe to the value changes of the input fields of char-range and number-range
        else if (this.attribute().attribute.filterMode === 'char-range' ||
            this.attribute().attribute.filterMode === 'number-range') {
            this.charNumberRange.valueChanges.pipe(takeUntilDestroyed(this.destroyRef)).subscribe((selectedValue) => {
                // check if the end input is syntactically false
                if (selectedValue.end !== null &&
                    selectedValue.start !== null &&
                    selectedValue.end !== undefined &&
                    selectedValue.start !== undefined &&
                    selectedValue.start !== '') {
                    this.checkEndInputFalse(selectedValue.start, selectedValue.end);
                }
                // check for false end input error in input values
                if (!this.falseEndInput) {
                    this.onValuesSelected(this.attribute().attribute.identifier, selectedValue.start, selectedValue.end);
                }
                else {
                    this.onValuesSelected(this.attribute().attribute.identifier, undefined, undefined);
                }
            });
        }
    }
    /**
     * @internal
     */
    ngOnChanges(changes) {
        const attributeChanges = changes['attribute'];
        // initialize the filter values if the filter attribute is set
        if (attributeChanges && !attributeChanges.firstChange && attributeChanges.currentValue.filterAttribute) {
            // check if one value is not defined and the other is
            if (attributeChanges.previousValue.filterAttribute === undefined &&
                (this.dateRange.get('startDate')?.value !== attributeChanges.currentValue.filterAttribute.value.start ||
                    this.dateRange.get('endDate')?.value !== attributeChanges.currentValue.filterAttribute.value.end)) {
                setTimeout(() => {
                    this.initializeFilterValues();
                }, 0);
            }
            // check if the values are the same, for infinite loop after emit of filter
            else if (attributeChanges.currentValue.filterAttribute &&
                attributeChanges.previousValue.filterAttribute &&
                (attributeChanges.previousValue.filterAttribute.value.start !==
                    attributeChanges.currentValue.filterAttribute.value.start ||
                    attributeChanges.previousValue.filterAttribute.value.end !==
                        attributeChanges.currentValue.filterAttribute.value.end)) {
                // check if the values are the same as in the form group, important for key control in the date-range filter
                if (attributeChanges.currentValue.attribute &&
                    attributeChanges.currentValue.attribute.filterMode === 'date-range' &&
                    (this.dateRange.get('startDate')?.value !== attributeChanges.currentValue.filterAttribute.value.start ||
                        this.dateRange.get('endDate')?.value !== attributeChanges.currentValue.filterAttribute.value.end)) {
                    setTimeout(() => {
                        this.initializeFilterValues();
                    }, 0);
                }
                // handling for char-range and number-range filter
                if (attributeChanges.currentValue.attribute &&
                    (attributeChanges.currentValue.attribute.filterMode === 'number-range' ||
                        attributeChanges.currentValue.attribute.filterMode === 'char-range') &&
                    (this.charNumberRange.get('start')?.value !== attributeChanges.currentValue.filterAttribute.value.start ||
                        this.charNumberRange.get('end')?.value !== attributeChanges.currentValue.filterAttribute.value.end)) {
                    setTimeout(() => {
                        this.initializeFilterValues();
                    }, 0);
                }
            }
        }
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.filterStateService.removeFalseOrderRangeFilter(this.id);
    }
    /**
     * Resets the chosen filter values.
     * @param mouseEvent The mouse event.
     */
    resetFilterAttribute(mouseEvent) {
        mouseEvent.stopPropagation();
        // reset the values of the filter
        this.resetValues();
        // if filterType is date-range trigger onValuesSelected with manually set undefined values
        if (this.attribute().attribute.filterMode === 'date-range') {
            this.onValuesSelected(this.attribute().attribute.identifier, undefined, undefined);
        }
    }
    /**
     * Auxiliary method to check if start string is before the end string of the given alphabet.
     * @param start The start string.
     * @param end The end string.
     */
    checkEndInputFalse(start, end) {
        if (start === '' || end === '') {
            this.falseEndInput = false;
        }
        else if (this.attribute().attribute.filterMode === 'number-range') {
            this.falseEndInput = Number(start) > Number(end);
        }
        else if (this.attribute().attribute.filterMode === 'char-range' &&
            typeof start === 'string' &&
            typeof end === 'string') {
            this.falseEndInput = this.sortString(start, end) !== 1;
        }
        if (this.falseEndInput && !this.filterStateService.containsFalseOrderRangeFilter(this.id)) {
            this.filterStateService.addFalseOrderRangeFilter(this.id);
        }
        else if (!this.falseEndInput && this.filterStateService.containsFalseOrderRangeFilter(this.id)) {
            this.filterStateService.removeFalseOrderRangeFilter(this.id);
        }
    }
    /**
     * Function is necessary to prevent the enter key from being pressed.
     * @param event The event if the enter key is pressed.
     */
    onEnterKey(event) {
        event.preventDefault();
    }
    /**
     * Sorts the string values.
     * Returns -1 if a is smaller than b.
     * @param a String to compare.
     * @param b String to compare.
     * @internal
     */
    sortString(a, b) {
        if (a === '' || b === '') {
            return 1;
        }
        if (a === b) {
            return 1;
        }
        // cast the values to upper case
        a = a.toUpperCase();
        b = b.toUpperCase();
        //if the first characters matching the data item attribute and check if start value length is bigger or same as end (e.g. 'ik11' - 'ik115'), return -1
        if (a.length > b.length && a.startsWith(b)) {
            return -1;
        }
        // check if value is after the start range
        // checking via condition (e.g. 'BAU' -> 'BA9' -> 'B9' -> 'b.firstLetter - 1' is not in start of the string)
        // start with last char in string and work to the front
        for (let i = a.length - 1; i > -1; i--) {
            // get position of the char in the alphabet
            const charPositionAlphabet = this.charRangeAlphabet.indexOf(a.charAt(i));
            // create a working string to be able to manipulate it for startWith() function
            let workingString = a;
            if (workingString.substring(0, i + 1) === b) {
                return 1;
            }
            // break loop if first letter of b is reached or if a partial value of b is reached and the second loop has to check
            if (workingString.substring(0, i + 1) === b.substring(0, 1) || b.startsWith(workingString.substring(0, i + 1))) {
                break;
            }
            // iterate through the alphabet from the char position to the front
            for (let j = charPositionAlphabet + 1; j < this.charRangeAlphabet.length; j++) {
                // construct the working string of the previous values to check if the value starts with it
                // removing the last char if all possible values are checked of alphabet are checked
                workingString = this.replaceCharAt(workingString, i, this.charRangeAlphabet[j]);
                // break loop if first letter of b is reached or if a partial value of b is reached and the second loop has to check
                if (workingString.substring(0, i + 1) === b.substring(0, 1) ||
                    b.startsWith(workingString.substring(0, i + 1))) {
                    return 1;
                }
            }
        }
        // check if value is before the end range
        // checking via condition (e.g. 'THEO' -> 'THEA' -> 'THA' -> 'TA')
        // start with last char in string and work to the front
        for (let i = b.length - 1; i > 0; i--) {
            // get position of the char in the alphabet
            const charPositionAlphabet = this.charRangeAlphabet.indexOf(b.charAt(i));
            // create a working string to be able to manipulate it for startWith() function
            let workingString = b;
            if (workingString.substring(0, i + 1) === a) {
                return 1;
            }
            // break loop if first letter of a is reached or if a partial value of a is reached and the first loop checked it
            if (workingString.substring(0, i + 1) === a.substring(0, 1) || a.startsWith(workingString.substring(0, i + 1))) {
                break;
            }
            // iterate through the alphabet from the char position to the back
            for (let j = charPositionAlphabet - 1; j > -1; j--) {
                // construct the working string of the previous values to check if the value starts with it
                // removing the last char if all possible values are checked of alphabet are checked
                workingString = this.replaceCharAt(workingString, i, this.charRangeAlphabet[j]);
                // break loop if first letter of a is reached or if a partial value of a is reached and the first loop checked it
                if (workingString.substring(0, i + 1) === a.substring(0, 1) ||
                    a.startsWith(workingString.substring(0, i + 1))) {
                    return 1;
                }
            }
        }
        return -1;
    }
    /**
     * All selected filters will be saved in the map with there defintion and values
     * @param filterIdentifier The filterIdentifier is the name that is used to identify the filter.
     * @param start The start value of the filter.
     * @param end The end value of the filter.
     */
    onValuesSelected(filterIdentifier, start, end) {
        const emittedValue = {
            attribute: this.attribute().attribute,
            operator: this.attribute().operator,
        };
        // if the filter is a number-range filter, transform the values to numbers
        if (this.attribute().attribute.filterMode === 'number-range') {
            start = start === null ? undefined : start;
            end = end === null ? undefined : end;
            start = start === '' ? undefined : start;
            end = end === '' ? undefined : end;
            start = start ? Number(start) : start;
            end = end ? Number(end) : end;
        }
        // check for type of filter
        if ((typeof start === 'string' && typeof end === 'string') ||
            (typeof start === 'string' && (end === '' || end === null || end === undefined)) ||
            ((start === '' || start === null || start === undefined) && typeof end === 'string')) {
            start = start === null ? undefined : start;
            end = end === null ? undefined : end;
            // emit char-range filter
            emittedValue.filterAttribute = {
                identifier: filterIdentifier,
                operator: this.attribute().operator,
                value: { start, end },
            };
            this.filterSelection.emit(emittedValue);
        }
        else if ((typeof start === 'number' && typeof end === 'number') ||
            (typeof start === 'number' && end === undefined) ||
            (start === undefined && typeof end === 'number')) {
            // emit number-range filter
            emittedValue.filterAttribute = {
                identifier: filterIdentifier,
                operator: this.attribute().operator,
                value: { start, end },
            };
            this.filterSelection.emit(emittedValue);
        }
        else if ((start instanceof Date && end instanceof Date) ||
            (start instanceof Date && (end === null || end === undefined)) ||
            ((start === null || start === undefined) && end instanceof Date)) {
            // emit date-range filter
            emittedValue.filterAttribute = {
                identifier: filterIdentifier,
                operator: this.attribute().operator,
                value: { start, end },
            };
            this.filterSelection.emit(emittedValue);
        }
        else if (start === undefined && end === undefined) {
            // delete filter
            this.filterSelection.emit(emittedValue);
        }
    }
    /**
     * Function is necessary to reset the values of the filter.
     */
    resetValues() {
        this.charNumberRange.reset();
        this.dateRange.reset();
        this.falseEndInput = false;
        if (!this.falseEndInput && this.filterStateService.containsFalseOrderRangeFilter(this.id)) {
            this.filterStateService.removeFalseOrderRangeFilter(this.id);
        }
    }
    /**
     * Function is necessary to initialize the filter values.
     */
    initializeFilterValues() {
        // check for the specific filters
        const filterAttribute = this.attribute().filterAttribute;
        if (filterAttribute) {
            if (this.attribute().attribute.filterMode === 'date-range' &&
                filterAttribute.value &&
                typeof filterAttribute.value === 'object' &&
                'end' in filterAttribute.value &&
                'start' in filterAttribute.value) {
                this.dateRange.get('startDate')?.setValue(filterAttribute.value.start);
                this.dateRange.get('endDate')?.setValue(filterAttribute.value.end);
            }
            else if ((this.attribute().attribute.filterMode === 'char-range' ||
                this.attribute().attribute.filterMode === 'number-range') &&
                filterAttribute.value &&
                typeof filterAttribute.value === 'object' &&
                'end' in filterAttribute.value &&
                'start' in filterAttribute.value &&
                !(filterAttribute.value.start instanceof Date) &&
                !(filterAttribute.value.end instanceof Date)) {
                this.charNumberRange.get('start')?.setValue(filterAttribute.value.start);
                this.charNumberRange.get('end')?.setValue(filterAttribute.value.end);
            }
        }
    }
    /**
     * Replaces specific char in a string at a specific index.
     * @param str String to replace char in.
     * @param index Index where to replace in str.
     * @param replacement Replacement char.
     * @internal
     */
    replaceCharAt(str, index, replacement) {
        return str.substring(0, index) + replacement + str.substring(index + replacement.length);
    }
    /**
     * Generates a UUID.
     */
    generateUUID() {
        // Create a UUID using the template format xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx
        return '10000000-1000-4000-8000-100000000000'.replace(/[018]/g, (c) => (+c ^ (crypto.getRandomValues(new Uint8Array(1))[0] & (15 >> (+c / 4)))).toString(16));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: RangeFilterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: RangeFilterComponent, isStandalone: true, selector: "talenra-range-filter", inputs: { attribute: { classPropertyName: "attribute", publicName: "attribute", isSignal: true, isRequired: true, transformFunction: null } }, outputs: { filterSelection: "filterSelection" }, usesOnChanges: true, ngImport: i0, template: "@if (attribute().attribute.filterMode === 'char-range' || attribute().attribute.filterMode === 'number-range') {\n  <form [formGroup]=\"charNumberRange\" class=\"form-group\">\n    <div class=\"field-wrap\">\n      <talenra-form-field [label]=\"attribute().attribute.label + ' von'\" class=\"char-range-start\">\n        <input formControlName=\"start\" talenra-input />\n      </talenra-form-field>\n      <div class=\"input-divider\">\u2013</div>\n      <talenra-form-field class=\"char-range-end\" label=\"bis\">\n        <input (keydown.enter)=\"onEnterKey($event)\" formControlName=\"end\" talenra-input />\n      </talenra-form-field>\n    </div>\n    <button\n      (click)=\"resetFilterAttribute($event)\"\n      [disabled]=\"!charNumberRange.value.start && !charNumberRange.value.end\"\n      data-testid=\"inbox-filter-deselection-undo\"\n      icon=\"undo\"\n      kind=\"ghost\"\n      talenra-button\n      talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n  </form>\n}\n\n@if (attribute().attribute.filterMode === 'date-range') {\n  <div class=\"form-group\">\n    <form [formGroup]=\"dateRange\" class=\"date-range-input\">\n      <talenra-form-field class=\"date-input\" label=\"{{ attribute().attribute.label }} von\">\n        <talenra-date\n          [dateFilterFn]=\"\n            attribute().attribute.dateFilterRestriction === 'only-future'\n              ? dateInTheFutureFilter(true)\n              : attribute().attribute.dateFilterRestriction === 'only-past'\n                ? dateInThePastFilter(true)\n                : undefined\n          \"\n          [isBirthDate]=\"attribute().attribute.dateFilterRestriction === 'birthday'\"\n          formControlName=\"startDate\"></talenra-date>\n      </talenra-form-field>\n      <div class=\"input-divider\">\u2013</div>\n      <talenra-form-field class=\"date-input\" label=\"bis\">\n        <talenra-date\n          [dateFilterFn]=\"\n            attribute().attribute.dateFilterRestriction === 'only-future'\n              ? dateInTheFutureFilter(true)\n              : attribute().attribute.dateFilterRestriction === 'only-past'\n                ? dateInThePastFilter(true)\n                : undefined\n          \"\n          [isBirthDate]=\"attribute().attribute.dateFilterRestriction === 'birthday'\"\n          formControlName=\"endDate\"></talenra-date>\n      </talenra-form-field>\n    </form>\n    <button\n      (click)=\"resetFilterAttribute($event)\"\n      [disabled]=\"!dateRange.controls['startDate'].value && !dateRange.controls['endDate'].value\"\n      data-testid=\"inbox-filter-deselection-undo\"\n      icon=\"undo\"\n      kind=\"ghost\"\n      talenra-button\n      talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n  </div>\n}\n", styles: [".form-group{min-height:2.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;gap:.5rem}.field-wrap{width:100%;display:flex}.char-range-start,.char-range-end{flex-grow:1}.field-wrap input{width:100%;flex-grow:1}.input-divider{margin:.25rem .5rem;padding-top:1rem;color:#999}.date-range-input{flex-grow:1;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between}.date-range-input .date-input{flex-grow:1}\n"], dependencies: [{ kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: FormFieldComponent, selector: "talenra-form-field", inputs: ["hint", "label", "size"] }, { kind: "component", type: InputComponent, selector: "input[talenra-input], textarea[talenra-input]", inputs: ["type", "disabled", "readonly"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "component", type: DateComponent, selector: "talenra-date", inputs: ["dateFilterFn", "showTime", "timeLabel", "dynamicLocale", "isBirthDate", "disabled", "readonly"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: RangeFilterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-range-filter', standalone: true, imports: [ReactiveFormsModule, FormFieldComponent, InputComponent, ButtonComponent, TooltipDirective, DateComponent], template: "@if (attribute().attribute.filterMode === 'char-range' || attribute().attribute.filterMode === 'number-range') {\n  <form [formGroup]=\"charNumberRange\" class=\"form-group\">\n    <div class=\"field-wrap\">\n      <talenra-form-field [label]=\"attribute().attribute.label + ' von'\" class=\"char-range-start\">\n        <input formControlName=\"start\" talenra-input />\n      </talenra-form-field>\n      <div class=\"input-divider\">\u2013</div>\n      <talenra-form-field class=\"char-range-end\" label=\"bis\">\n        <input (keydown.enter)=\"onEnterKey($event)\" formControlName=\"end\" talenra-input />\n      </talenra-form-field>\n    </div>\n    <button\n      (click)=\"resetFilterAttribute($event)\"\n      [disabled]=\"!charNumberRange.value.start && !charNumberRange.value.end\"\n      data-testid=\"inbox-filter-deselection-undo\"\n      icon=\"undo\"\n      kind=\"ghost\"\n      talenra-button\n      talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n  </form>\n}\n\n@if (attribute().attribute.filterMode === 'date-range') {\n  <div class=\"form-group\">\n    <form [formGroup]=\"dateRange\" class=\"date-range-input\">\n      <talenra-form-field class=\"date-input\" label=\"{{ attribute().attribute.label }} von\">\n        <talenra-date\n          [dateFilterFn]=\"\n            attribute().attribute.dateFilterRestriction === 'only-future'\n              ? dateInTheFutureFilter(true)\n              : attribute().attribute.dateFilterRestriction === 'only-past'\n                ? dateInThePastFilter(true)\n                : undefined\n          \"\n          [isBirthDate]=\"attribute().attribute.dateFilterRestriction === 'birthday'\"\n          formControlName=\"startDate\"></talenra-date>\n      </talenra-form-field>\n      <div class=\"input-divider\">\u2013</div>\n      <talenra-form-field class=\"date-input\" label=\"bis\">\n        <talenra-date\n          [dateFilterFn]=\"\n            attribute().attribute.dateFilterRestriction === 'only-future'\n              ? dateInTheFutureFilter(true)\n              : attribute().attribute.dateFilterRestriction === 'only-past'\n                ? dateInThePastFilter(true)\n                : undefined\n          \"\n          [isBirthDate]=\"attribute().attribute.dateFilterRestriction === 'birthday'\"\n          formControlName=\"endDate\"></talenra-date>\n      </talenra-form-field>\n    </form>\n    <button\n      (click)=\"resetFilterAttribute($event)\"\n      [disabled]=\"!dateRange.controls['startDate'].value && !dateRange.controls['endDate'].value\"\n      data-testid=\"inbox-filter-deselection-undo\"\n      icon=\"undo\"\n      kind=\"ghost\"\n      talenra-button\n      talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n  </div>\n}\n", styles: [".form-group{min-height:2.75rem;display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;gap:.5rem}.field-wrap{width:100%;display:flex}.char-range-start,.char-range-end{flex-grow:1}.field-wrap input{width:100%;flex-grow:1}.input-divider{margin:.25rem .5rem;padding-top:1rem;color:#999}.date-range-input{flex-grow:1;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between}.date-range-input .date-input{flex-grow:1}\n"] }]
        }] });

/**
 * Possible selection is used to define the values of the dropdowns in the selection filter (multi & single select).
 */
class PossibleSelection {
    /**
     * Constructor for the possible selection.
     * @param filterToolbarService Service to get the data items.
     * @param setInboxConfigurationService Service to get the attributes.
     * @internal
     */
    constructor(filterToolbarService, setInboxConfigurationService) {
        this.filterToolbarService = filterToolbarService;
        this.setInboxConfigurationService = setInboxConfigurationService;
        /**
         * Map to save the label of the attribute and the possible selections.
         */
        this.identifierWithPossibleSelection = new Map();
        /**
         * Map to save the label of the attribute and the flag for the possible selections.
         */
        this.flagForPossibleSelection = new Map();
        /**
         * Auxiliary class to get the values of the data items.
         */
        this.dataItemsClass = new DataItemsClass();
        if (this.filterToolbarService) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            this.filterToolbarService.originalDataItems$.subscribe((result) => {
                // get only the attributes that are filterable (multi-select or single-select)
                const availableAttributesUndefinedOptions = this.setInboxConfigurationService.allAttributes$.value.filter((value) => (value.filterMode === 'multi-select' || value.filterMode === 'single-select') &&
                    value.filterSelectionOptions === undefined);
                const availableAttributesDefinedOptions = this.setInboxConfigurationService.allAttributes$.value.filter((value) => (value.filterMode === 'multi-select' || value.filterMode === 'single-select') &&
                    value.filterSelectionOptions !== undefined);
                // set for undefined options the possible selections
                availableAttributesUndefinedOptions.forEach((attribute, index) => {
                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                    result.forEach((e) => {
                        if (!this.identifierWithPossibleSelection.has(attribute.identifier)) {
                            // check if the attribute should not contain the '–' option
                            if (!(attribute.allowEmptyDataItemFilter === false &&
                                this.dataItemsClass.getElemFromDataItemDisplayed(e, attribute.identifier) === '–')) {
                                this.flagForPossibleSelection.set(attribute.identifier, 0);
                                this.identifierWithPossibleSelection.set(attribute.identifier, [
                                    {
                                        key: String(this.flagForPossibleSelection.get(attribute.identifier) + '_' + index + '_' + attribute.identifier),
                                        label: this.dataItemsClass.getElemFromDataItemDisplayed(e, attribute.identifier),
                                    },
                                ]);
                            }
                        }
                        // already has the attribute, adds further values
                        else {
                            const displayedNames = [];
                            Object.values(this.identifierWithPossibleSelection.get(attribute.identifier)).forEach((e) => displayedNames.push(e.label));
                            // check if the attribute should not contain the '–' option
                            if (!(attribute.allowEmptyDataItemFilter === false &&
                                this.dataItemsClass.getElemFromDataItemDisplayed(e, attribute.identifier) === '–')) {
                                if (!displayedNames.includes(this.dataItemsClass.getElemFromDataItemDisplayed(e, attribute.identifier))) {
                                    this.flagForPossibleSelection.set(attribute.identifier, this.flagForPossibleSelection.get(attribute.identifier) + 1);
                                    this.identifierWithPossibleSelection.get(attribute.identifier)?.push({
                                        key: String(this.flagForPossibleSelection.get(attribute.identifier) + '_' + index + '_' + attribute.identifier),
                                        label: this.dataItemsClass.getElemFromDataItemDisplayed(e, attribute.identifier),
                                    });
                                }
                            }
                        }
                    });
                });
                // set for defined options the possible selections
                availableAttributesDefinedOptions.forEach((attribute) => {
                    const optionsArray = [];
                    attribute.filterSelectionOptions?.forEach((option) => {
                        optionsArray.push({
                            key: option.key,
                            label: option.label,
                        });
                    });
                    this.identifierWithPossibleSelection.set(attribute.identifier, optionsArray);
                });
            });
        }
    }
}

class SimpleFilterSelectionComponent {
    constructor() {
        /**
         * The availableAttributes input is an array of AttributeItem that contains the available filters.
         */
        this.availableAttributes = input([]);
        /**
         * The filterSelection input is an array of strings that contains the selected filters.
         */
        this.filterSelections = input([]);
        /**
         * The selectedFilters output is an array of strings that contains the selected filters.
         */
        this.filterSelectionsChange = output();
        /**
         * The availableAttributes output is an array of AttributeItem that contains the available filters.
         */
        this.copyAvailableAttributes = computed(() => {
            const availableAttributes = [];
            this.availableAttributes().forEach((attribute) => {
                availableAttributes.push({
                    checked: new FormGroup({}),
                    identifier: attribute.identifier,
                    label: attribute.label,
                    filterMode: attribute.filterMode,
                    dateFilterRestriction: attribute.dateFilterRestriction,
                });
            });
            return availableAttributes;
        });
        /**
         * The selectedAttributes input is an array of AttributeItem that contains the selected filters.
         */
        this.selectedAttributes = [];
        /**
         * The filters array contains the selected filters.
         */
        this.filters = [];
        /**
         * The inbox service and references.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        this.setInboxConfigurationService = inject(MainFacadeSetterService);
        this.destroyRef = inject(DestroyRef);
        /**
         * The selected values.
         */
        this.selectionForm = new FormGroup({
            attributeSelection: new FormControl(''),
        });
    }
    /**
     * @internal
     */
    ngOnInit() {
        // when changes in the data items occurred reset the possible selection
        this.filterToolbarService.originalDataItems$.pipe(takeUntilDestroyed(this.destroyRef)).subscribe(() => {
            this.possibleSelection = new PossibleSelection(this.filterToolbarService, this.setInboxConfigurationService);
            this.filterToolbarService.identifierWithPossibleSelection =
                this.possibleSelection.identifierWithPossibleSelection;
        });
    }
    /**
     * @internal
     */
    ngOnChanges(changes) {
        const filterSelectionsChanges = changes['filterSelections'];
        if (filterSelectionsChanges && !filterSelectionsChanges.firstChange) {
            // reset the selected filters
            this.selectedAttributes = [];
            // add the selected filters to the selected filters
            filterSelectionsChanges.currentValue.forEach((filterSelection) => {
                // get the selected attribute from the available filters
                const selectedAttribute = this.copyAvailableAttributes().find((attribute) => attribute.identifier === filterSelection.identifier);
                // add the selected filter to the selected filters
                selectedAttribute &&
                    this.selectedAttributes.push({
                        attribute: selectedAttribute,
                        operator: filterSelection.operator ? filterSelection.operator : 'equal',
                        filterAttribute: {
                            identifier: filterSelection.identifier,
                            operator: filterSelection.operator,
                            value: filterSelection.value,
                        },
                    });
            });
        }
    }
    /**
     * Called when the user selects a filter.
     * @param selectChange The select change.
     */
    onAttributeSelectionAdd(selectChange) {
        // reset the selected filters
        this.selectionForm.reset();
        // get the selected attribute from the available filters
        const selectedAttribute = this.copyAvailableAttributes().find((attribute) => attribute.identifier === selectChange.value);
        // add the selected filter to the selected filters
        selectedAttribute && this.selectedAttributes.push({ attribute: selectedAttribute, operator: 'equal' });
    }
    /**
     * Removes the filter from the selection.
     * @param mouseEvent The mouse event.
     * @param selectedAttribute The selected attribute.
     * @param filterIndex The filter index.
     */
    deleteFilterAttribute(mouseEvent, selectedAttribute, filterIndex) {
        mouseEvent.stopPropagation();
        // remove the selected filter from the selected filters via the filter index
        this.selectedAttributes.splice(filterIndex, 1);
        // update the selected filters
        this.filters = [];
        this.selectedAttributes.forEach((attribute) => {
            // add the selected filter to the selected filters
            // check if the filter attribute is not null
            if (attribute.filterAttribute?.value) {
                // check if filterAttribute value is array and not null
                if (Array.isArray(attribute.filterAttribute.value) && attribute.filterAttribute.value.length > 0) {
                    this.filters.push({
                        identifier: attribute.attribute.identifier,
                        operator: attribute.operator,
                        value: attribute.filterAttribute.value,
                    });
                }
                else if (!Array.isArray(attribute.filterAttribute.value)) {
                    this.filters.push({
                        identifier: attribute.attribute.identifier,
                        operator: attribute.operator,
                        value: attribute.filterAttribute.value,
                    });
                }
            }
        });
        // emit the selected filters
        this.filterSelectionsChange.emit(this.filters);
    }
    /**
     * Called when the user selects a filter.
     * @param filterIndex The filter index.
     * @param filterAttribute The filter attribute.
     **/
    onFilterSelection(filterIndex, filterAttribute) {
        // add or replace the selected filter to the selected filters
        // replace the selected attributes at the filter index
        this.selectedAttributes[filterIndex] = filterAttribute;
        this.setFilters();
        // emit the selected filters
        this.filterSelectionsChange.emit(this.filters);
    }
    /**
     * Changes the value of the operator.
     * @param selectedAttributes The selected attributes.
     */
    changeOperator(selectedAttributes) {
        // set the proper operator
        selectedAttributes.operator = selectedAttributes.operator === 'equal' ? 'notEqual' : 'equal';
        // update the filter in the emitted filters
        this.setFilters();
        // emit the selected filters
        this.filterSelectionsChange.emit(this.filters);
    }
    /**
     * Called when the user changes a filter attribute.
     * @param selectChange The select change.
     * @param index The index.
     */
    onAttributeSelectionChange(selectChange, index) {
        // set the copy available attributes to proper values for the logic, after reset by the select
        this.resetCopyAvailableAttributes();
        // replace the selected filter to the selected filters at the index
        const selectedAttribute = this.selectedAttributes[index];
        // get the selected attribute from the available filters
        let newAttribute = undefined;
        this.copyAvailableAttributes().forEach((attribute) => {
            if (attribute.identifier === selectChange.value) {
                newAttribute = attribute;
                return;
            }
        });
        // check if attribute found
        if (selectedAttribute && newAttribute) {
            // delete the selected filter from the selected filters
            this.selectedAttributes.splice(index, 1);
            // change selected filter attribute value
            const newSelectedAttribute = {
                attribute: newAttribute,
                operator: selectedAttribute.operator,
            };
            // add the selected filter to the selected filters at the index
            this.selectedAttributes.splice(index, 0, newSelectedAttribute);
        }
        // reset the filters
        this.setFilters();
        // emit the selected filters
        this.filterSelectionsChange.emit(this.filters);
    }
    /**
     * Called when the user clicks the x button in the filter attribute selection.
     * @param value The value of the attribute selector.
     * @param index The index.
     */
    onAttributeSelectionModelChange(value, index) {
        // set the copy available attributes to proper values for the logic, after reset by the select
        this.resetCopyAvailableAttributes();
        // if the value is null, the x button was clicked
        // remove the selected filter from the selected filters at the index
        if (value === null) {
            this.selectedAttributes.splice(index, 1);
            // reset the filters
            this.setFilters();
            // emit the selected filters
            this.filterSelectionsChange.emit(this.filters);
        }
    }
    /**
     * Resets the copy available attributes.
     */
    resetCopyAvailableAttributes() {
        this.availableAttributes().forEach((attribute, index) => {
            this.copyAvailableAttributes()[index].identifier = attribute.identifier;
            this.copyAvailableAttributes()[index].checked = new FormGroup({});
            this.copyAvailableAttributes()[index].label = attribute.label;
            this.copyAvailableAttributes()[index].filterMode = attribute.filterMode;
        });
    }
    /**
     * Auxiliar function to set the filters.
     */
    setFilters() {
        // update the selected filters
        this.filters = [];
        // set the new filters
        this.selectedAttributes.forEach((selectedAttribute) => {
            // check if the filter attribute is not null
            if (selectedAttribute.filterAttribute?.identifier) {
                // check if filterAttribute value is array and not null
                if (Array.isArray(selectedAttribute.filterAttribute.value) &&
                    selectedAttribute.filterAttribute.value.length > 0) {
                    this.filters.push({
                        identifier: selectedAttribute.attribute.identifier,
                        operator: selectedAttribute.operator,
                        value: selectedAttribute.filterAttribute.value,
                    });
                }
                else if (!Array.isArray(selectedAttribute.filterAttribute.value)) {
                    const value = selectedAttribute.filterAttribute.value;
                    // check for text-field
                    if (typeof value === 'string' && value !== '') {
                        this.filters.push({
                            identifier: selectedAttribute.attribute.identifier,
                            operator: selectedAttribute.operator,
                            value: selectedAttribute.filterAttribute.value,
                        });
                    }
                    // check for single/multi select
                    if (typeof value === 'object' && 'key' in value && 'label' in value && value.key !== '') {
                        this.filters.push({
                            identifier: selectedAttribute.attribute.identifier,
                            operator: selectedAttribute.operator,
                            value: selectedAttribute.filterAttribute.value,
                        });
                    }
                    // check for char range
                    if (typeof value === 'object' &&
                        'start' in value &&
                        'end' in value &&
                        ((value.start !== '' && value.end !== '') ||
                            (value.start === '' && value.end !== '') ||
                            (value.start !== '' && value.end === ''))) {
                        this.filters.push({
                            identifier: selectedAttribute.attribute.identifier,
                            operator: selectedAttribute.operator,
                            value: selectedAttribute.filterAttribute.value,
                        });
                    }
                }
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SimpleFilterSelectionComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: SimpleFilterSelectionComponent, isStandalone: true, selector: "talenra-simple-filter-selection", inputs: { availableAttributes: { classPropertyName: "availableAttributes", publicName: "availableAttributes", isSignal: true, isRequired: false, transformFunction: null }, filterSelections: { classPropertyName: "filterSelections", publicName: "filterSelections", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { filterSelectionsChange: "filterSelectionsChange" }, usesOnChanges: true, ngImport: i0, template: "<talenra-scroll-container class=\"advanced-filter\">\n  <div class=\"layout-advanced-filter-drop-down\">\n    <div class=\"grid-chosen-filter-elements\">\n      @for (selectedAttribute of selectedAttributes; track index; let index = $index) {\n        <talenra-form-field label=\"Filter\">\n          <talenra-select\n            useFilter\n            (selectionChange)=\"onAttributeSelectionChange($event, index)\"\n            [(ngModel)]=\"selectedAttribute.attribute.identifier\"\n            (ngModelChange)=\"onAttributeSelectionModelChange($event, index)\"\n            data-testid=\"talenra-inbox-simple-filter-selection-selected-attribute\">\n            @for (attribute of copyAvailableAttributes(); track attribute.identifier; let index = $index) {\n              <talenra-option [value]=\"attribute.identifier\">{{ attribute.label }}</talenra-option>\n            }\n          </talenra-select>\n        </talenra-form-field>\n        <button\n          (click)=\"changeOperator(selectedAttribute)\"\n          [icon]=\"selectedAttribute.operator === 'equal' ? 'equal' : 'not-equal'\"\n          kind=\"ghost\"\n          talenra-button></button>\n        @switch (selectedAttribute.attribute.filterMode) {\n          @case ('multi-select') {\n            <talenra-selection-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"\n              [possibleValues]=\"\n                filterToolbarService.identifierWithPossibleSelection?.get(selectedAttribute.attribute.identifier) || []\n              \"></talenra-selection-filter>\n          }\n          @case ('single-select') {\n            <talenra-selection-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"\n              [possibleValues]=\"\n                filterToolbarService.identifierWithPossibleSelection?.get(selectedAttribute.attribute.identifier) || []\n              \"></talenra-selection-filter>\n          }\n          @case ('date-range') {\n            <talenra-range-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-range-filter>\n          }\n          @case ('char-range') {\n            <talenra-range-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-range-filter>\n          }\n          @case ('number-range') {\n            <talenra-range-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-range-filter>\n          }\n          @case ('text-field') {\n            <talenra-text-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-text-filter>\n          }\n        }\n        <button\n          (click)=\"deleteFilterAttribute($event, selectedAttribute, index)\"\n          class=\"interaction-button-close\"\n          data-testid=\"inbox-filter-deselection-button\"\n          icon=\"delete\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"L\u00F6schen\"></button>\n      }\n\n      <form [formGroup]=\"selectionForm\">\n        <talenra-form-field label=\"Filter\">\n          <talenra-select\n            (selectionChange)=\"onAttributeSelectionAdd($event)\"\n            data-testid=\"talenra-inbox-filter-selection-attribute-selector\"\n            formControlName=\"attributeSelection\"\n            useFilter>\n            @for (attribute of copyAvailableAttributes(); track attribute.identifier) {\n              <talenra-option data-testid=\"talenra-inbox-selection-filter-option\" [value]=\"attribute.identifier\"\n                >{{ attribute.label }}\n              </talenra-option>\n            }\n          </talenra-select>\n        </talenra-form-field>\n      </form>\n      <button icon=\"equal\" kind=\"ghost\" talenra-button></button>\n    </div>\n  </div>\n</talenra-scroll-container>\n", styles: [".advanced-filter{height:100%}.layout-advanced-filter-drop-down{position:relative;min-width:fit-content;display:flex;flex-direction:column;flex-wrap:nowrap}.grid-chosen-filter-elements{position:relative;min-width:fit-content;display:grid;grid-template-columns:13.75rem 1.75rem 1fr 1.75rem;grid-auto-flow:row;column-gap:.5rem;align-items:center}@media (max-width: 43.375em){.hits-text{display:flex;align-items:center;margin-right:5px}}\n"], dependencies: [{ kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }, { kind: "component", type: FormFieldComponent, selector: "talenra-form-field", inputs: ["hint", "label", "size"] }, { kind: "component", type: SelectComponent, selector: "talenra-select", inputs: ["useFilter", "allowMultiple", "noOptionsMessage", "noMatchMessage", "disabled", "value", "readonly", "kind", "placeholder"], outputs: ["selectionChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: OptionComponent, selector: "talenra-option", inputs: ["value", "icon", "isHidden"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "component", type: TextFilterComponent, selector: "talenra-text-filter", inputs: ["attribute"], outputs: ["filterSelection"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "component", type: SelectionFilterComponent, selector: "talenra-selection-filter", inputs: ["attribute", "possibleValues"], outputs: ["filterSelection"] }, { kind: "component", type: RangeFilterComponent, selector: "talenra-range-filter", inputs: ["attribute"], outputs: ["filterSelection"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: SimpleFilterSelectionComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-simple-filter-selection', standalone: true, imports: [
                        ScrollContainerComponent,
                        FormFieldComponent,
                        SelectComponent,
                        FormsModule,
                        OptionComponent,
                        ButtonComponent,
                        TextFilterComponent,
                        ReactiveFormsModule,
                        TooltipDirective,
                        SelectionFilterComponent,
                        RangeFilterComponent,
                    ], template: "<talenra-scroll-container class=\"advanced-filter\">\n  <div class=\"layout-advanced-filter-drop-down\">\n    <div class=\"grid-chosen-filter-elements\">\n      @for (selectedAttribute of selectedAttributes; track index; let index = $index) {\n        <talenra-form-field label=\"Filter\">\n          <talenra-select\n            useFilter\n            (selectionChange)=\"onAttributeSelectionChange($event, index)\"\n            [(ngModel)]=\"selectedAttribute.attribute.identifier\"\n            (ngModelChange)=\"onAttributeSelectionModelChange($event, index)\"\n            data-testid=\"talenra-inbox-simple-filter-selection-selected-attribute\">\n            @for (attribute of copyAvailableAttributes(); track attribute.identifier; let index = $index) {\n              <talenra-option [value]=\"attribute.identifier\">{{ attribute.label }}</talenra-option>\n            }\n          </talenra-select>\n        </talenra-form-field>\n        <button\n          (click)=\"changeOperator(selectedAttribute)\"\n          [icon]=\"selectedAttribute.operator === 'equal' ? 'equal' : 'not-equal'\"\n          kind=\"ghost\"\n          talenra-button></button>\n        @switch (selectedAttribute.attribute.filterMode) {\n          @case ('multi-select') {\n            <talenra-selection-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"\n              [possibleValues]=\"\n                filterToolbarService.identifierWithPossibleSelection?.get(selectedAttribute.attribute.identifier) || []\n              \"></talenra-selection-filter>\n          }\n          @case ('single-select') {\n            <talenra-selection-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"\n              [possibleValues]=\"\n                filterToolbarService.identifierWithPossibleSelection?.get(selectedAttribute.attribute.identifier) || []\n              \"></talenra-selection-filter>\n          }\n          @case ('date-range') {\n            <talenra-range-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-range-filter>\n          }\n          @case ('char-range') {\n            <talenra-range-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-range-filter>\n          }\n          @case ('number-range') {\n            <talenra-range-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-range-filter>\n          }\n          @case ('text-field') {\n            <talenra-text-filter\n              (filterSelection)=\"onFilterSelection(index, $event)\"\n              [attribute]=\"selectedAttribute\"></talenra-text-filter>\n          }\n        }\n        <button\n          (click)=\"deleteFilterAttribute($event, selectedAttribute, index)\"\n          class=\"interaction-button-close\"\n          data-testid=\"inbox-filter-deselection-button\"\n          icon=\"delete\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"L\u00F6schen\"></button>\n      }\n\n      <form [formGroup]=\"selectionForm\">\n        <talenra-form-field label=\"Filter\">\n          <talenra-select\n            (selectionChange)=\"onAttributeSelectionAdd($event)\"\n            data-testid=\"talenra-inbox-filter-selection-attribute-selector\"\n            formControlName=\"attributeSelection\"\n            useFilter>\n            @for (attribute of copyAvailableAttributes(); track attribute.identifier) {\n              <talenra-option data-testid=\"talenra-inbox-selection-filter-option\" [value]=\"attribute.identifier\"\n                >{{ attribute.label }}\n              </talenra-option>\n            }\n          </talenra-select>\n        </talenra-form-field>\n      </form>\n      <button icon=\"equal\" kind=\"ghost\" talenra-button></button>\n    </div>\n  </div>\n</talenra-scroll-container>\n", styles: [".advanced-filter{height:100%}.layout-advanced-filter-drop-down{position:relative;min-width:fit-content;display:flex;flex-direction:column;flex-wrap:nowrap}.grid-chosen-filter-elements{position:relative;min-width:fit-content;display:grid;grid-template-columns:13.75rem 1.75rem 1fr 1.75rem;grid-auto-flow:row;column-gap:.5rem;align-items:center}@media (max-width: 43.375em){.hits-text{display:flex;align-items:center;margin-right:5px}}\n"] }]
        }] });

/**
 * Responsible for customizing the layout of the data item settings component.
 *
 * ```html
 * <talenra-inbox-configuration-panel
 *   *ngIf="!loading; else skeletonLoading"
 *   [attributesSettingsList]="attributeList"
 *   [maxAttributesShown]="maxAttributesShown"
 *   [selectedMainAttributes]="selectedMainAttributes"
 *   [selectedDetailAttributes]="selectedDetailAttributes"
 *   [(isExpanded)]="keyboardService.attributesSettingsExpanded"
 *   (selectedMainAttributesEmitter)="selectedMainAttributesEmitterHandler($event)"
 *   (selectedDetailAttributesEmitter)="selectedDetailAttributesEmitterHandler($event)"
 *   (selectedAllAttributesEmitter)="selectedAllAttributesEmitterHandler($event)"
 *   (buttonAction)="onButtonAction($event)"
 * ></talenra-inbox-configuration-panel>
 * ```
 */
class InboxConfigurationPanelComponent {
    constructor() {
        /**
         * The maximum Attributes which are to be shown in the data-items-list-items.
         * Further they are divided in the ui.
         * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings-service.
         * Default value is 12, like chosen in the requirements.
         */
        this.maxAttributesShown = 12;
        /**
         * The maximum Attributes, which are to be shown in the data-items-list-items mutated by the user.
         */
        this.numberMainAttributesChosenByUser = 12;
        /**
         * The boolean value is used to expand the attributes settings UI.
         */
        this.isExpanded = false;
        /**
         * Sets the selected main attributes.
         */
        this.selectedMainAttributes = [];
        /**
         * Sets the selected detail attributes.
         */
        this.selectedDetailAttributes = [];
        /**
         * The selected tab. Should contain the key of the tab.
         */
        this.selectedTab = model('attribute-settings');
        /**
         * The query that is currently selected.
         */
        this.query = model({
            identifier: 'head',
            rules: [],
            condition: QueryBuilderCondition.And,
            hierarchyLevel: 1,
        });
        /**
         * The possible rules that can be selected.
         */
        this.possibleRules = input([]);
        /**
         * The values that can be selected in connection to each rule identifier.
         */
        this.possibleOptions = input([]);
        /**
         * The extra tabs for the panel.
         */
        this.customTabs = input([]);
        /**
         * The filterSelection input is an array of strings that contains the selected filters.
         */
        this.filterSelections = model([]);
        /**
         * The sortSelections input is an array of strings that contains the selected sorts.
         */
        this.sortSelections = model([]);
        /**
         * Emits the main selected attributes.
         */
        this.selectedMainAttributesEmitter = new EventEmitter();
        /**
         * Emits the detail selected attributes.
         */
        this.selectedDetailAttributesEmitter = new EventEmitter();
        /**
         * Emits the all selected attributes.
         */
        this.selectedAllAttributesEmitter = new EventEmitter();
        /**
         * The boolean value is used to expand the attributes settings UI.
         */
        this.isExpandedChange = new EventEmitter();
        /**
         * The number value that is chosen by the user to show the main attributes.
         */
        this.numberMainAttributesChosenByUserEmitter = new EventEmitter();
        /**
         * Emits actions.
         */
        this.buttonAction = output();
        /**
         * The selectedFilters output is an array of strings that contains the selected filters.
         */
        this.selectedFilters = output();
        /**
         * The selectedSorts output is an array that contains the selected sorts.
         */
        this.selectedSorts = output();
        /**
         * List of attributes key which are used to lock the attributes in the attribute settings.
         * Gets updated by the used attributes in the filter toolbar.
         */
        this.lockedAttributes = [];
        /**
         * The tab bar items.
         */
        this.tabBarItems = [];
        /**
         * List of available attributes for the simple filter selection.
         */
        this.availableFilterSelectionAttributes = [];
        /**
         * List of available attributes for the simple filter selection.
         */
        this.availableSortSelectionAttributes = [];
        /**
         * The filter kind.
         * false = simple filter
         * true = expert filter
         */
        this.filterKind = false;
        /**
         * The used services and references.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        this.inboxState = inject(InboxState);
        this.filterState = inject(FilterStateService);
        this.keyboardService = inject(KeyboardService);
        this.updatePresetsService = inject(UpdatePresetsService);
        this.changedValuesService = inject(ChangedPresetValuesService);
        /**
         * Injected set inbox configuration service.
         */
        this.mainFacadeSetterService = inject(MainFacadeSetterService);
        /**
         * Destroy references to subscriptions.
         */
        this.destroyRef = inject(DestroyRef);
    }
    /**
     * Emits the selected main attributes.
     * @param selectedMainAttributes The selected main attributes.
     */
    selectedMainAttributesEmitterHandler(selectedMainAttributes) {
        this.selectedMainAttributesEmitter.emit(selectedMainAttributes);
    }
    /**
     * Emits the selected detail attributes.
     * @param selectedDetailAttributes The selected detail attributes.
     */
    selectedDetailAttributesEmitterHandler(selectedDetailAttributes) {
        this.selectedDetailAttributesEmitter.emit(selectedDetailAttributes);
    }
    /**
     * Emits the selected all attributes.
     * @param selectedAllAttributes All selected attributes.
     */
    selectedAllAttributesEmitterHandler(selectedAllAttributes) {
        // set the all available attributes for the filter selection
        // after attribute change
        this.setAllFilterSelectionAttributes(selectedAllAttributes);
        // emit the selected all attributes
        this.selectedAllAttributesEmitter.emit(selectedAllAttributes);
    }
    /**
     * Emits the expanded change.
     * @param $event The boolean value is used to expand the attributes settings UI.
     */
    expandedChangeHandler($event) {
        this.isExpandedChange.emit($event);
    }
    /**
     * Emits the number main attributes chosen by user change.
     * @param $event The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserHandler($event) {
        this.numberMainAttributesChosenByUserEmitter.emit($event);
    }
    /**
     * @internal
     */
    ngOnInit() {
        this.initializeComponent();
    }
    /**
     * Detects changes in the component.
     * @internal
     **/
    ngOnChanges(changes) {
        const selectedMainAttributesChanges = changes['selectedMainAttributes'];
        const selectedDetailAttributesChanges = changes['selectedDetailAttributes'];
        const customTabsChanges = changes['customTabs'];
        const isExpandedChanges = changes['isExpanded'];
        if ((selectedMainAttributesChanges && !selectedMainAttributesChanges.firstChange) ||
            (selectedDetailAttributesChanges && !selectedDetailAttributesChanges.firstChange)) {
            // after changes in the selected attributes from outside the component
            this.setAllFilterSelectionAttributes([
                ...selectedMainAttributesChanges.currentValue,
                ...selectedDetailAttributesChanges.currentValue,
            ]);
        }
        if (customTabsChanges && !customTabsChanges.firstChange) {
            this.setTabItems();
        }
        if (isExpandedChanges && !isExpandedChanges.firstChange) {
            // if current value is false, reset the state to the last confirmed filter/sort/attribute
            if (!isExpandedChanges.currentValue) {
                // reset the filter values to the state of the last confirmed filter (emitted)
                // get values from buffer
                const bufferFilterState = [...this.mainFacadeSetterService.filterSortSearchEmitterBuffer.filterAttributes];
                const bufferSortState = [...this.mainFacadeSetterService.filterSortSearchEmitterBuffer.sortAttributes];
                // set the proper values to the filter and sort selection
                this.filterSelections.set(bufferFilterState);
                this.sortSelections.set(bufferSortState);
                // emit the values to the parent component
                this.selectedFilters.emit(bufferFilterState);
                this.selectedSorts.emit(bufferSortState);
                // set the locked attributes
                this.setLockedAttributesFilter(bufferFilterState);
                this.setLockedAttributesSort(bufferSortState);
            }
        }
    }
    /**
     * Change the selected tab.
     * @param tabKey The selected tab.
     */
    selectedTabChange(tabKey) {
        this.selectedTab.set(tabKey);
    }
    /**
     * Change the filter kind.
     * @param kind The filter kind.
     */
    filterKindChange(kind) {
        if (kind) {
            this.switchToExpertFilter(false);
        }
        else {
            this.switchToSimpleFilter();
        }
    }
    /**
     * Method to emit the close button and close the inbox detail view
     */
    onCloseClick() {
        this.isExpanded = false;
        this.isExpandedChange.emit(this.isExpanded);
    }
    /**
     * The action that is to be performed in for the items.
     * @param action The action clicked in the bottom bar.
     */
    onBottomBarAction(action) {
        switch (action) {
            case 'cancel':
                this.onCloseClick();
                break;
            case 'reset':
                // TODO: reset to last confirmed filter/sort/attribute
                break;
            case 'confirm':
                this.buttonAction.emit(action);
                break;
        }
    }
    /**
     * The action that is to be performed in for the items.
     * @param filterAttributes The selected filter attributes.
     */
    onSelectedFilters(filterAttributes) {
        this.selectedFilters.emit(filterAttributes);
        // set the locked attributes
        this.setLockedAttributesFilter(filterAttributes);
    }
    /**
     * Handles the sort change.
     * @param sort
     */
    onSortChange(sort) {
        this.selectedSorts.emit(sort);
        // set the locked attributes
        this.setLockedAttributesSort(sort);
    }
    /**
     * Switches to the expert filter and adds chosen simple filter elements to the expert filter query.
     * @protected
     */
    switchToExpertFilter(transferSimpleFilter = true) {
        // set filterKind and selectedTab to the expert filter
        this.filterKind = true;
        // reset the advanced filter
        this.resetExpertFilter();
        //TODO: reset the simple filter to the view values
        // set the possible rules from the simple filter to the expert filter
        if (transferSimpleFilter) {
            this.transferSimpleFilterToExpertFilter();
        }
    }
    /**
     * Switches from the expert filter to the simple filter.
     * Resets the simple filter to the view values.
     * @protected
     */
    switchToSimpleFilter() {
        // set filterKind and selectedTab to the simple filter
        this.filterKind = false;
        // reset the advanced filter
        this.resetExpertFilter();
        //TODO: reset the simple filter to the view values
    }
    /**
     * Method to reset the advanced filter.
     * @protected
     */
    resetExpertFilter() {
        this.query.set({
            identifier: this.query().identifier,
            rules: [],
            condition: QueryBuilderCondition.And,
            hierarchyLevel: 1,
        });
    }
    onClickOutside(event) {
        /**
         * Workaround for Firefox:
         * Firefox we receive a click event when the drag'n'drop is finished which closes the panel.
         * This faulty click event has target 'body'. For now we just ignore outside-clicks with target 'body'.
         * Better solutions very welcome!
         */
        if (event.target === document.getElementsByTagName('body').item(0))
            return;
        /**
         * Workaround for if the click is on the backdrop of the cdk-overlay.
         */
        if (event.target === document.getElementsByClassName('cdk-overlay-backdrop').item(0))
            return;
        this.isExpandedChange.emit(false);
    }
    /**
     * Initializes the component.
     * @protected
     */
    initializeComponent() {
        this.keyboardService.escapeKeyPressed.pipe(takeUntilDestroyed(this.destroyRef)).subscribe((value) => {
            if (value) {
                this.isExpanded = false;
                this.isExpandedChange.emit(false);
            }
        });
        // reset filter selection for the simple filter selection
        this.inboxState.presetGroups$.pipe(takeUntilDestroyed(this.destroyRef)).subscribe(() => {
            // update the filter toolbar with all changes which are saved in the buffer
            if (this.updatePresetsService.currentPresetAction$.value.operation === 'attribute-update') {
                // delete the simple filter selection
                this.filterState.resetSimpleFilterSelection();
                // check if buffer has changes in regard to the preset
                this.changedValuesService.checkFilterValuesChangedComparedToValuesInPreset();
                // delete the sort selection
                this.filterState.resetSortSelection();
                // check if buffer has changes in regard to the preset
                this.changedValuesService.checkSortValuesChangedComparedToValuesInPreset();
            }
        });
        // generate and set the possible tab items
        this.setTabItems();
        // set the all available attributes for the filter selection
        // after initialization of component
        this.setAllFilterSelectionAttributes([...this.selectedMainAttributes, ...this.selectedDetailAttributes]);
    }
    /**
     * Confirms the advanced filter.
     * @protected
     */
    confirmAdvancedFilter() {
        // TODO: implement confirmAdvancedFilter
        // set the filterToolbarService that the expert filter is active
        this.filterToolbarService.activeExpertFilter.set(!this.filterToolbarService.activeExpertFilter());
    }
    /**
     * Copies the query to clipboard.
     * @protected
     */
    onQueryDownload() {
        // copy the query to the clipboard
        navigator.clipboard.writeText(JSON.stringify(this.query()));
    }
    /**
     * Pastes the query.
     * @protected
     */
    onQueryUpload() {
        this.query.set(JSON.parse(prompt('Paste your query here') || ''));
    }
    /**
     * Sets the all available attributes for the filter selection.
     * @param selectedAllAttributes The selected all attributes.
     * @private
     */
    setAllFilterSelectionAttributes(selectedAllAttributes) {
        // reset the all available attributes for the filter selection
        this.availableFilterSelectionAttributes = [];
        // set the available filters for the filter selection
        selectedAllAttributes.forEach((elem) => {
            if (elem.filterMode !== undefined) {
                this.availableFilterSelectionAttributes.push(elem);
            }
        });
        // reset the all available attributes for the sort selection
        this.availableSortSelectionAttributes = [];
        // set the available filters for the filter selection
        selectedAllAttributes.forEach((elem) => {
            if (elem.sortable !== undefined) {
                this.availableSortSelectionAttributes.push(elem);
            }
        });
    }
    /**
     * Generates the possible tab items and sets the to the tab bar items.
     * @private
     */
    setTabItems() {
        // reset the tab bar items
        this.tabBarItems = [];
        // check all possible tab items
        if (!this.inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {
            this.tabBarItems.push({
                key: 'attribute-settings',
                label: 'Attribute',
                icon: 'edit-square',
                useScroll: false,
            });
        }
        if (!this.inboxState.inboxConfiguration$.value.disableFilterSelection) {
            this.tabBarItems.push({
                key: 'filter',
                label: 'Filter',
                icon: 'filter-alt',
                useScroll: false,
            });
        }
        if (!this.inboxState.inboxConfiguration$.value.disableSortSelection) {
            this.tabBarItems.push({ key: 'sort', label: 'Sort', icon: 'sort', useScroll: false });
        }
        // add the custom tabs to the tab bar items
        this.customTabs().forEach((tab, index) => {
            this.tabBarItems.push({
                key: tab.key ?? String(index),
                label: tab.label,
                icon: tab.icon,
                useScroll: tab.useScroll,
                counter: tab.counter,
                maxCounter: tab.maxCounter,
            });
            // if custom tab has no key, set the key to the index
            if (!tab.key) {
                tab.key = String(index);
            }
        });
    }
    /**
     * Transfers the simple filter to the expert filter.
     * @private
     */
    transferSimpleFilterToExpertFilter() {
        // for each selected filter selection attribute
        // TODO: implement transferSimpleFilterToExpertFilter
    }
    /**
     * Set locked attributes from the filter selection.
     */
    setLockedAttributesFilter(value) {
        const lockedFilterAttributes = value.map((attribute) => {
            return { origin: 'filter', identifier: attribute.identifier };
        });
        const removedLockedAttributes = this.lockedAttributes.filter((value) => value.origin !== 'filter');
        this.lockedAttributes = [...removedLockedAttributes, ...lockedFilterAttributes];
    }
    /**
     * Set locked attributes from the sort selection.
     */
    setLockedAttributesSort(value) {
        const lockedSortAttributes = value.map((attribute) => {
            return { origin: 'sort', identifier: attribute.identifier };
        });
        const removedLockedAttributes = this.lockedAttributes.filter((value) => value.origin !== 'sort');
        this.lockedAttributes = [...removedLockedAttributes, ...lockedSortAttributes];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxConfigurationPanelComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: InboxConfigurationPanelComponent, isStandalone: true, selector: "talenra-inbox-configuration-panel", inputs: { attributesSettingsList: { classPropertyName: "attributesSettingsList", publicName: "attributesSettingsList", isSignal: false, isRequired: false, transformFunction: null }, maxAttributesShown: { classPropertyName: "maxAttributesShown", publicName: "maxAttributesShown", isSignal: false, isRequired: false, transformFunction: null }, numberMainAttributesChosenByUser: { classPropertyName: "numberMainAttributesChosenByUser", publicName: "numberMainAttributesChosenByUser", isSignal: false, isRequired: false, transformFunction: null }, isExpanded: { classPropertyName: "isExpanded", publicName: "isExpanded", isSignal: false, isRequired: false, transformFunction: null }, selectedMainAttributes: { classPropertyName: "selectedMainAttributes", publicName: "selectedMainAttributes", isSignal: false, isRequired: false, transformFunction: null }, selectedDetailAttributes: { classPropertyName: "selectedDetailAttributes", publicName: "selectedDetailAttributes", isSignal: false, isRequired: false, transformFunction: null }, selectedTab: { classPropertyName: "selectedTab", publicName: "selectedTab", isSignal: true, isRequired: false, transformFunction: null }, query: { classPropertyName: "query", publicName: "query", isSignal: true, isRequired: false, transformFunction: null }, possibleRules: { classPropertyName: "possibleRules", publicName: "possibleRules", isSignal: true, isRequired: false, transformFunction: null }, possibleOptions: { classPropertyName: "possibleOptions", publicName: "possibleOptions", isSignal: true, isRequired: false, transformFunction: null }, customTabs: { classPropertyName: "customTabs", publicName: "customTabs", isSignal: true, isRequired: false, transformFunction: null }, filterSelections: { classPropertyName: "filterSelections", publicName: "filterSelections", isSignal: true, isRequired: false, transformFunction: null }, sortSelections: { classPropertyName: "sortSelections", publicName: "sortSelections", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { selectedTab: "selectedTabChange", query: "queryChange", filterSelections: "filterSelectionsChange", sortSelections: "sortSelectionsChange", selectedMainAttributesEmitter: "selectedMainAttributesEmitter", selectedDetailAttributesEmitter: "selectedDetailAttributesEmitter", selectedAllAttributesEmitter: "selectedAllAttributesEmitter", isExpandedChange: "isExpandedChange", numberMainAttributesChosenByUserEmitter: "numberMainAttributesChosenByUserEmitter", buttonAction: "buttonAction", selectedFilters: "selectedFilters", selectedSorts: "selectedSorts" }, providers: [ExpertFilterService], usesOnChanges: true, ngImport: i0, template: "<div [class.panel-expanded]=\"isExpanded\" class=\"attributes-settings-main\">\n  <ng-content></ng-content>\n</div>\n\n<div\n  [class.expanded]=\"isExpanded\"\n  [class.expanded-large]=\"isExpanded && selectedTab().endsWith('filter')\"\n  class=\"attributes-settings-panel\"\n  data-testid=\"inbox-attributes-settings-panel\">\n  <talenra-detail-view-information-tab-bar\n    (selectedTabChange)=\"selectedTabChange($event)\"\n    [arrowNavigationActive]=\"isExpanded\"\n    [detailViewInformationTabBarItems]=\"tabBarItems\"\n    [selectedTab]=\"selectedTab()\"\n    class=\"header-content\"></talenra-detail-view-information-tab-bar>\n  <button\n    (click)=\"onCloseClick()\"\n    class=\"close-button\"\n    data-testid=\"inbox-configuration-panel-close-button\"\n    icon=\"close\"\n    kind=\"ghost\"\n    talenra-button\n    size=\"m\"></button>\n  @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n    <div [class.not-displayed]=\"selectedTab() !== 'attribute-settings'\" class=\"sort-container tab-content\">\n      <div class=\"filter-selection-input-title medium-font\">\n        <div class=\"filter-selection-input-title-text\">\n          <span>{{\n            inboxState.inboxConfiguration$.value.attributeSettingsTitle\n              ? inboxState.inboxConfiguration$.value.attributeSettingsTitle\n              : 'Anzeige Fall-Informationen'\n          }}</span>\n        </div>\n      </div>\n      <talenra-attributes-settings\n        (numberMainAttributesChosenByUserEmitter)=\"numberMainAttributesChosenByUserHandler($event)\"\n        (selectedAllAttributesEmitter)=\"selectedAllAttributesEmitterHandler($event)\"\n        (selectedDetailAttributesEmitter)=\"selectedDetailAttributesEmitterHandler($event)\"\n        (selectedMainAttributesEmitter)=\"selectedMainAttributesEmitterHandler($event)\"\n        [attributesSettingsList]=\"attributesSettingsList\"\n        [isExpanded]=\"isExpanded\"\n        [lockedAttributes]=\"lockedAttributes\"\n        [maxAttributesShown]=\"maxAttributesShown\"\n        [numberMainAttributesChosenByUser]=\"numberMainAttributesChosenByUser\"\n        [selectedDetailAttributes]=\"selectedDetailAttributes\"\n        [selectedMainAttributes]=\"selectedMainAttributes\"></talenra-attributes-settings>\n    </div>\n  }\n  @if (!inboxState.inboxConfiguration$.value.disableFilterSelection) {\n    <div [class.not-displayed]=\"!selectedTab().endsWith('filter')\" class=\"filter-container tab-content\">\n      <div class=\"filter-selection-input-title medium-font\">\n        <div class=\"filter-selection-input-title-text\">\n          <span data-testid=\"inbox-filtering-title\">Filterung</span>\n          <!--          TODO: enable as soon as the expert filter is implemented-->\n          <!--          <button-->\n          <!--            (click)=\"onQueryDownload()\"-->\n          <!--            [disabled]=\"query().rules.length === 0\"-->\n          <!--            icon=\"file-download\"-->\n          <!--            kind=\"ghost\"-->\n          <!--            talenra-button-->\n          <!--            size=\"s\"></button>-->\n          <!--          <button (click)=\"onQueryUpload()\" icon=\"upload-file\" kind=\"ghost\" talenra-button size=\"s\"></button>-->\n        </div>\n        @if (!inboxState.inboxConfiguration$.value.disableFilterSelection) {\n          <!--          TODO: enable as soon as the expert filter is implemented-->\n          <!--          <talenra-toggle-->\n          <!--            (ngModelChange)=\"filterKindChange($event)\"-->\n          <!--            [(ngModel)]=\"filterKind\"-->\n          <!--            label=\"Erweitert\"></talenra-toggle>-->\n        }\n      </div>\n      <!--  FILTER SELECTION -->\n      <div\n        [class.not-displayed]=\"!inboxState.inboxConfiguration$.value.disableFilterSelection && filterKind\"\n        class=\"simple-filter-container\">\n        <talenra-simple-filter-selection\n          [availableAttributes]=\"availableFilterSelectionAttributes\"\n          [filterSelections]=\"filterSelections()\"\n          (filterSelectionsChange)=\"onSelectedFilters($event)\"\n          class=\"filter-selection-input-fields\"></talenra-simple-filter-selection>\n      </div>\n      <!--  EXPERT FILTER SELECTION -->\n      <!--          TODO: enable as soon as the expert filter is implemented-->\n      <!--      <div [class.not-displayed]=\"!filterKind\" class=\"expert-filter-container\">-->\n      <!--        <div class=\"expert-filter-header medium-font\">-->\n      <!--          <div class=\"placeholder-title\"></div>-->\n      <!--          <div class=\"expert-filter-title\">-->\n      <!--            <span>Advanced Filtering</span>-->\n      <!--            <talenra-icon [name]=\"'filter-list'\" class=\"expert-filter-header-icon\"></talenra-icon>-->\n      <!--          </div>-->\n      <!--                <button (click)=\"onCloseClick()\" icon=\"close\" kind=\"ghost\" talenra-button size=\"s\"></button>-->\n      <!--        </div>-->\n      <!--        <talenra-scroll-container class=\"expert-filter-scroll-container\">-->\n      <!--          <talenra-query-builder-->\n      <!--            [(query)]=\"query\"-->\n      <!--            [possibleRules]=\"possibleRules()!\"-->\n      <!--            [values]=\"possibleOptions()!\"-->\n      <!--            class=\"expert-filter-query-selector\"></talenra-query-builder>-->\n      <!--        </talenra-scroll-container>-->\n      <!--        <div class=\"expert-filter-button-interaction\">-->\n      <!--          <div class=\"expert-filter-button-interaction-confirm\">-->\n      <!--            <button-->\n      <!--              (click)=\"resetExpertFilter()\"-->\n      <!--              [disabled]=\"query().rules.length === 0\"-->\n      <!--              kind=\"secondary\"-->\n      <!--              label=\"Zur\u00FCcksetzen\"-->\n      <!--              talenra-button-->\n      <!--              size=\"s\"></button>-->\n      <!--            <button-->\n      <!--              (click)=\"confirmAdvancedFilter()\"-->\n      <!--              [label]=\"filterToolbarService.activeExpertFilter() ? 'Filter entfernen' : 'Filter anwenden'\"-->\n      <!--              kind=\"primary\"-->\n      <!--              talenra-button-->\n      <!--              size=\"s\"></button>-->\n      <!--          </div>-->\n      <!--        </div>-->\n      <!--      </div>-->\n    </div>\n  }\n\n  @if (!inboxState.inboxConfiguration$.value.disableSortSelection) {\n    <div [class.not-displayed]=\"selectedTab() !== 'sort'\" class=\"tab-content\">\n      <div class=\"filter-selection-input-title medium-font\">\n        <div class=\"filter-selection-input-title-text\">\n          <span>Sortierung</span>\n        </div>\n      </div>\n      <talenra-sort-selection\n        (sortSelectionsChange)=\"onSortChange($event)\"\n        [sortSelections]=\"sortSelections()\"\n        [availableAttributes]=\"availableSortSelectionAttributes\"></talenra-sort-selection>\n    </div>\n  }\n  @for (tab of customTabs(); track tab.key) {\n    <div class=\"tab-content custom-tab-content\" [class.not-displayed]=\"selectedTab() !== tab.key\">\n      @if (tab.useScroll) {\n        <talenra-scroll-container class=\"scroll-container\">\n          <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n        </talenra-scroll-container>\n      } @else {\n        <div class=\"no-scroll-container\">\n          <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n        </div>\n      }\n      <ng-template #content>\n        <ng-container\n          *ngTemplateOutlet=\"\n            tab.detailViewTabContentTemplate ? tab.detailViewTabContentTemplate : customTabContent\n          \"></ng-container>\n      </ng-template>\n    </div>\n  }\n  <talenra-inbox-configuration-panel-bottom-bar\n    (buttonAction)=\"onBottomBarAction($event)\"\n    class=\"bottom-bar\"></talenra-inbox-configuration-panel-bottom-bar>\n</div>\n\n<ng-template #customTabContent></ng-template>\n", styles: [":host{position:relative;display:flex;height:100%;width:100%;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;--color-background: #ffffff;--color-primary: #0099a8;--color-text: #000000;--color-separator: #f2f2f2;--color-icon: #999999;--color-inactive: #cccccc;--color-border: #f2f2f2}.header-content{border-left:.0625rem solid var(--color-border)}.close-button{position:absolute;left:-1.5rem;top:4.5625rem;padding:.625rem;border-radius:1.5rem;background-color:var(--color-background);--blend-mode: none !important;box-shadow:0 2px 5px #0003}.attributes-settings-main{display:flex;flex-direction:column;flex-wrap:nowrap;flex-grow:1;height:calc(100% - 2px);width:calc(100% - 48px);max-width:1400px}.attributes-settings-main.panel-expanded{pointer-events:none}.attributes-settings-panel{overflow:visible;position:fixed;height:calc(100% - 5.3125rem);display:flex;flex-direction:column;flex-wrap:nowrap;top:64px;width:0;right:0;opacity:0;transition:width .3s,opacity .3s}.attributes-settings-panel.expanded{width:600px;opacity:1;z-index:3}.attributes-settings-panel.expanded-large{width:880px;opacity:1;z-index:3}.tab-content{background-color:var(--color-background);height:100%;overflow:hidden;border-left:.0625rem solid var(--color-border);padding:1.9375rem 1.5rem .25rem}.filter-container{display:flex;flex-direction:column;flex-wrap:nowrap}.simple-filter-container{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%}.filter-selection-input-title{display:flex;flex-direction:row;justify-content:space-between;align-items:center;text-align:center}.filter-selection-input-title-text{font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;text-overflow:ellipsis;white-space:nowrap;overflow:hidden;height:1.5rem;width:100%;display:flex;align-items:center;justify-content:space-between;margin-bottom:1.3125rem;color:var(--color-text)}.filter-selection-input-fields{height:calc(100% - 3.5rem)}.expert-filter-container{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%;background-color:var(--color-background)}.expert-filter-header{display:flex;flex-direction:row;justify-content:space-between;align-items:center;margin-bottom:.125rem}.expert-filter-header-icon{color:var(--color-icon);font-size:1rem}.placeholder-title{width:1.5rem;height:1.5rem}.expert-filter-title-text{color:var(--color-text)}.expert-filter-query-selector{display:flex;flex-direction:column;flex-wrap:nowrap;margin-top:1.5rem;color:var(--color-text)}.expert-filter-scroll-container{max-height:calc(100% - 5.75rem)}.expert-filter-button-interaction{margin:1.5rem 0 .75rem;display:flex;flex-direction:row;align-items:center;justify-content:space-between;flex-wrap:nowrap}.expert-filter-button-interaction-confirm{display:flex;flex-direction:row;align-items:center;gap:1rem;flex-wrap:nowrap}.bottom-bar{height:3.5rem;padding:0 1.5rem;border-top:.0625rem solid var(--color-border);border-left:.0625rem solid var(--color-border);background-color:var(--color-background)}.custom-tab-content{background-color:var(--color-background)}.scroll-container{width:100%}.no-scroll-container{position:relative;height:100%}.not-displayed{display:none}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;color:var(--color-text)}@media (max-width: 1246px){.attributes-settings-panel.expanded-large{width:calc(100% - 2.875rem)}}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-inactive: #cccccc;--color-text: #cccccc;--color-separator: #4d4d4d;--color-border: #4d4d4d}\n"], dependencies: [{ kind: "component", type: DetailViewInformationTabBarComponent, selector: "talenra-detail-view-information-tab-bar", inputs: ["detailViewInformationTabBarItems", "selectedTab", "arrowNavigationActive"], outputs: ["selectedTabChange"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "component", type: AttributesSettingsComponent, selector: "talenra-attributes-settings", inputs: ["attributesSettingsList", "maxAttributesShown", "numberMainAttributesChosenByUser", "isExpanded", "selectedMainAttributes", "selectedDetailAttributes", "lockedAttributes"], outputs: ["selectedMainAttributesEmitter", "selectedDetailAttributesEmitter", "selectedAllAttributesEmitter", "numberMainAttributesChosenByUserEmitter"] }, { kind: "component", type: SortSelectionComponent, selector: "talenra-sort-selection", inputs: ["availableAttributes", "sortSelections"], outputs: ["sortSelectionsChange"] }, { kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: InboxConfigurationPanelBottomBarComponent, selector: "talenra-inbox-configuration-panel-bottom-bar", outputs: ["buttonAction"] }, { kind: "component", type: SimpleFilterSelectionComponent, selector: "talenra-simple-filter-selection", inputs: ["availableAttributes", "filterSelections"], outputs: ["filterSelectionsChange"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxConfigurationPanelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-configuration-panel', providers: [ExpertFilterService], standalone: true, imports: [
                        DetailViewInformationTabBarComponent,
                        ButtonComponent,
                        AttributesSettingsComponent,
                        SortSelectionComponent,
                        ScrollContainerComponent,
                        NgTemplateOutlet,
                        InboxConfigurationPanelBottomBarComponent,
                        SimpleFilterSelectionComponent,
                    ], template: "<div [class.panel-expanded]=\"isExpanded\" class=\"attributes-settings-main\">\n  <ng-content></ng-content>\n</div>\n\n<div\n  [class.expanded]=\"isExpanded\"\n  [class.expanded-large]=\"isExpanded && selectedTab().endsWith('filter')\"\n  class=\"attributes-settings-panel\"\n  data-testid=\"inbox-attributes-settings-panel\">\n  <talenra-detail-view-information-tab-bar\n    (selectedTabChange)=\"selectedTabChange($event)\"\n    [arrowNavigationActive]=\"isExpanded\"\n    [detailViewInformationTabBarItems]=\"tabBarItems\"\n    [selectedTab]=\"selectedTab()\"\n    class=\"header-content\"></talenra-detail-view-information-tab-bar>\n  <button\n    (click)=\"onCloseClick()\"\n    class=\"close-button\"\n    data-testid=\"inbox-configuration-panel-close-button\"\n    icon=\"close\"\n    kind=\"ghost\"\n    talenra-button\n    size=\"m\"></button>\n  @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n    <div [class.not-displayed]=\"selectedTab() !== 'attribute-settings'\" class=\"sort-container tab-content\">\n      <div class=\"filter-selection-input-title medium-font\">\n        <div class=\"filter-selection-input-title-text\">\n          <span>{{\n            inboxState.inboxConfiguration$.value.attributeSettingsTitle\n              ? inboxState.inboxConfiguration$.value.attributeSettingsTitle\n              : 'Anzeige Fall-Informationen'\n          }}</span>\n        </div>\n      </div>\n      <talenra-attributes-settings\n        (numberMainAttributesChosenByUserEmitter)=\"numberMainAttributesChosenByUserHandler($event)\"\n        (selectedAllAttributesEmitter)=\"selectedAllAttributesEmitterHandler($event)\"\n        (selectedDetailAttributesEmitter)=\"selectedDetailAttributesEmitterHandler($event)\"\n        (selectedMainAttributesEmitter)=\"selectedMainAttributesEmitterHandler($event)\"\n        [attributesSettingsList]=\"attributesSettingsList\"\n        [isExpanded]=\"isExpanded\"\n        [lockedAttributes]=\"lockedAttributes\"\n        [maxAttributesShown]=\"maxAttributesShown\"\n        [numberMainAttributesChosenByUser]=\"numberMainAttributesChosenByUser\"\n        [selectedDetailAttributes]=\"selectedDetailAttributes\"\n        [selectedMainAttributes]=\"selectedMainAttributes\"></talenra-attributes-settings>\n    </div>\n  }\n  @if (!inboxState.inboxConfiguration$.value.disableFilterSelection) {\n    <div [class.not-displayed]=\"!selectedTab().endsWith('filter')\" class=\"filter-container tab-content\">\n      <div class=\"filter-selection-input-title medium-font\">\n        <div class=\"filter-selection-input-title-text\">\n          <span data-testid=\"inbox-filtering-title\">Filterung</span>\n          <!--          TODO: enable as soon as the expert filter is implemented-->\n          <!--          <button-->\n          <!--            (click)=\"onQueryDownload()\"-->\n          <!--            [disabled]=\"query().rules.length === 0\"-->\n          <!--            icon=\"file-download\"-->\n          <!--            kind=\"ghost\"-->\n          <!--            talenra-button-->\n          <!--            size=\"s\"></button>-->\n          <!--          <button (click)=\"onQueryUpload()\" icon=\"upload-file\" kind=\"ghost\" talenra-button size=\"s\"></button>-->\n        </div>\n        @if (!inboxState.inboxConfiguration$.value.disableFilterSelection) {\n          <!--          TODO: enable as soon as the expert filter is implemented-->\n          <!--          <talenra-toggle-->\n          <!--            (ngModelChange)=\"filterKindChange($event)\"-->\n          <!--            [(ngModel)]=\"filterKind\"-->\n          <!--            label=\"Erweitert\"></talenra-toggle>-->\n        }\n      </div>\n      <!--  FILTER SELECTION -->\n      <div\n        [class.not-displayed]=\"!inboxState.inboxConfiguration$.value.disableFilterSelection && filterKind\"\n        class=\"simple-filter-container\">\n        <talenra-simple-filter-selection\n          [availableAttributes]=\"availableFilterSelectionAttributes\"\n          [filterSelections]=\"filterSelections()\"\n          (filterSelectionsChange)=\"onSelectedFilters($event)\"\n          class=\"filter-selection-input-fields\"></talenra-simple-filter-selection>\n      </div>\n      <!--  EXPERT FILTER SELECTION -->\n      <!--          TODO: enable as soon as the expert filter is implemented-->\n      <!--      <div [class.not-displayed]=\"!filterKind\" class=\"expert-filter-container\">-->\n      <!--        <div class=\"expert-filter-header medium-font\">-->\n      <!--          <div class=\"placeholder-title\"></div>-->\n      <!--          <div class=\"expert-filter-title\">-->\n      <!--            <span>Advanced Filtering</span>-->\n      <!--            <talenra-icon [name]=\"'filter-list'\" class=\"expert-filter-header-icon\"></talenra-icon>-->\n      <!--          </div>-->\n      <!--                <button (click)=\"onCloseClick()\" icon=\"close\" kind=\"ghost\" talenra-button size=\"s\"></button>-->\n      <!--        </div>-->\n      <!--        <talenra-scroll-container class=\"expert-filter-scroll-container\">-->\n      <!--          <talenra-query-builder-->\n      <!--            [(query)]=\"query\"-->\n      <!--            [possibleRules]=\"possibleRules()!\"-->\n      <!--            [values]=\"possibleOptions()!\"-->\n      <!--            class=\"expert-filter-query-selector\"></talenra-query-builder>-->\n      <!--        </talenra-scroll-container>-->\n      <!--        <div class=\"expert-filter-button-interaction\">-->\n      <!--          <div class=\"expert-filter-button-interaction-confirm\">-->\n      <!--            <button-->\n      <!--              (click)=\"resetExpertFilter()\"-->\n      <!--              [disabled]=\"query().rules.length === 0\"-->\n      <!--              kind=\"secondary\"-->\n      <!--              label=\"Zur\u00FCcksetzen\"-->\n      <!--              talenra-button-->\n      <!--              size=\"s\"></button>-->\n      <!--            <button-->\n      <!--              (click)=\"confirmAdvancedFilter()\"-->\n      <!--              [label]=\"filterToolbarService.activeExpertFilter() ? 'Filter entfernen' : 'Filter anwenden'\"-->\n      <!--              kind=\"primary\"-->\n      <!--              talenra-button-->\n      <!--              size=\"s\"></button>-->\n      <!--          </div>-->\n      <!--        </div>-->\n      <!--      </div>-->\n    </div>\n  }\n\n  @if (!inboxState.inboxConfiguration$.value.disableSortSelection) {\n    <div [class.not-displayed]=\"selectedTab() !== 'sort'\" class=\"tab-content\">\n      <div class=\"filter-selection-input-title medium-font\">\n        <div class=\"filter-selection-input-title-text\">\n          <span>Sortierung</span>\n        </div>\n      </div>\n      <talenra-sort-selection\n        (sortSelectionsChange)=\"onSortChange($event)\"\n        [sortSelections]=\"sortSelections()\"\n        [availableAttributes]=\"availableSortSelectionAttributes\"></talenra-sort-selection>\n    </div>\n  }\n  @for (tab of customTabs(); track tab.key) {\n    <div class=\"tab-content custom-tab-content\" [class.not-displayed]=\"selectedTab() !== tab.key\">\n      @if (tab.useScroll) {\n        <talenra-scroll-container class=\"scroll-container\">\n          <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n        </talenra-scroll-container>\n      } @else {\n        <div class=\"no-scroll-container\">\n          <ng-container *ngTemplateOutlet=\"content\"></ng-container>\n        </div>\n      }\n      <ng-template #content>\n        <ng-container\n          *ngTemplateOutlet=\"\n            tab.detailViewTabContentTemplate ? tab.detailViewTabContentTemplate : customTabContent\n          \"></ng-container>\n      </ng-template>\n    </div>\n  }\n  <talenra-inbox-configuration-panel-bottom-bar\n    (buttonAction)=\"onBottomBarAction($event)\"\n    class=\"bottom-bar\"></talenra-inbox-configuration-panel-bottom-bar>\n</div>\n\n<ng-template #customTabContent></ng-template>\n", styles: [":host{position:relative;display:flex;height:100%;width:100%;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;--color-background: #ffffff;--color-primary: #0099a8;--color-text: #000000;--color-separator: #f2f2f2;--color-icon: #999999;--color-inactive: #cccccc;--color-border: #f2f2f2}.header-content{border-left:.0625rem solid var(--color-border)}.close-button{position:absolute;left:-1.5rem;top:4.5625rem;padding:.625rem;border-radius:1.5rem;background-color:var(--color-background);--blend-mode: none !important;box-shadow:0 2px 5px #0003}.attributes-settings-main{display:flex;flex-direction:column;flex-wrap:nowrap;flex-grow:1;height:calc(100% - 2px);width:calc(100% - 48px);max-width:1400px}.attributes-settings-main.panel-expanded{pointer-events:none}.attributes-settings-panel{overflow:visible;position:fixed;height:calc(100% - 5.3125rem);display:flex;flex-direction:column;flex-wrap:nowrap;top:64px;width:0;right:0;opacity:0;transition:width .3s,opacity .3s}.attributes-settings-panel.expanded{width:600px;opacity:1;z-index:3}.attributes-settings-panel.expanded-large{width:880px;opacity:1;z-index:3}.tab-content{background-color:var(--color-background);height:100%;overflow:hidden;border-left:.0625rem solid var(--color-border);padding:1.9375rem 1.5rem .25rem}.filter-container{display:flex;flex-direction:column;flex-wrap:nowrap}.simple-filter-container{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%}.filter-selection-input-title{display:flex;flex-direction:row;justify-content:space-between;align-items:center;text-align:center}.filter-selection-input-title-text{font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;text-overflow:ellipsis;white-space:nowrap;overflow:hidden;height:1.5rem;width:100%;display:flex;align-items:center;justify-content:space-between;margin-bottom:1.3125rem;color:var(--color-text)}.filter-selection-input-fields{height:calc(100% - 3.5rem)}.expert-filter-container{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%;background-color:var(--color-background)}.expert-filter-header{display:flex;flex-direction:row;justify-content:space-between;align-items:center;margin-bottom:.125rem}.expert-filter-header-icon{color:var(--color-icon);font-size:1rem}.placeholder-title{width:1.5rem;height:1.5rem}.expert-filter-title-text{color:var(--color-text)}.expert-filter-query-selector{display:flex;flex-direction:column;flex-wrap:nowrap;margin-top:1.5rem;color:var(--color-text)}.expert-filter-scroll-container{max-height:calc(100% - 5.75rem)}.expert-filter-button-interaction{margin:1.5rem 0 .75rem;display:flex;flex-direction:row;align-items:center;justify-content:space-between;flex-wrap:nowrap}.expert-filter-button-interaction-confirm{display:flex;flex-direction:row;align-items:center;gap:1rem;flex-wrap:nowrap}.bottom-bar{height:3.5rem;padding:0 1.5rem;border-top:.0625rem solid var(--color-border);border-left:.0625rem solid var(--color-border);background-color:var(--color-background)}.custom-tab-content{background-color:var(--color-background)}.scroll-container{width:100%}.no-scroll-container{position:relative;height:100%}.not-displayed{display:none}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;color:var(--color-text)}@media (max-width: 1246px){.attributes-settings-panel.expanded-large{width:calc(100% - 2.875rem)}}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-inactive: #cccccc;--color-text: #cccccc;--color-separator: #4d4d4d;--color-border: #4d4d4d}\n"] }]
        }], propDecorators: { attributesSettingsList: [{
                type: Input
            }], maxAttributesShown: [{
                type: Input
            }], numberMainAttributesChosenByUser: [{
                type: Input
            }], isExpanded: [{
                type: Input
            }], selectedMainAttributes: [{
                type: Input
            }], selectedDetailAttributes: [{
                type: Input
            }], selectedMainAttributesEmitter: [{
                type: Output
            }], selectedDetailAttributesEmitter: [{
                type: Output
            }], selectedAllAttributesEmitter: [{
                type: Output
            }], isExpandedChange: [{
                type: Output
            }], numberMainAttributesChosenByUserEmitter: [{
                type: Output
            }] } });

class PresetsComponent {
    constructor() {
        /**
         * EventEmitter for the interactions with the preset.
         */
        this.presetInteractions = new EventEmitter();
        /**
         * The index of the preset that is currently edited corresponding with the order in the presetGroups.
         */
        this.indexOfPresetInEditing = 0;
        /**
         * The index of the group that is currently edited corresponding with the order in the presetGroups.
         */
        this.indexOfPresetGroupInEditing = 0;
        /**
         * Value if the check value is clicked, to change the style of the clicked button.
         */
        this.onCheckClick = false;
        /**
         * Name of the active preset.
         */
        this.activePresetName = ['', ''];
        /**
         * Save the input of presets.
         */
        this.presetMenuForm = new FormGroup({
            fcn: new FormControl(''),
        });
        /**
         * Save the input of new presets.
         */
        this.saveNewPresetMenuForm = new FormGroup({
            fcn: new FormControl(''),
        });
        /**
         * In many scenarios, the delete button int the preset menu should be hidden.
         * This map stores the information if the delete button should be shown or not.
         */
        this.showDeleteButton = new Map();
        /**
         * Map to store the expanded state of the accordion groups.
         */
        this.expandedGroup = new Map();
        /**
         * Value if the drag and drop is disabled, if the preset is edited through name change and deletion process.
         */
        this.dragAndDropDisabled = false;
        /**
         * Value if an item is dragged.
         * Used to disable the hover effect on non dragged items from other lists.
         */
        this.draggingState = false;
        /**
         * BehaviorSubject for edit state if a preset is currently edited and the other should not be interactable.
         */
        this.editState = new BehaviorSubject(false);
        /**
         * This array will store the extracted values from the presetGroups.
         */
        this.originalPresetGroupNames = [];
        /**
         * The filter toolbar service.
         * @internal
         */
        this.filterToolbarService = inject(FilterToolbarService);
        /**
         * The preset service.
         * @internal
         */
        this.presetsService = inject(PresetsService);
        /**
         * The keyboard service.
         * @internal
         */
        this.keyboardService = inject(KeyboardService);
        /**
         * The update preset service.
         * @internal
         */
        this.updatePresetsService = inject(UpdatePresetsService);
        /**
         * The state service.
         * @internal
         */
        this.inboxState = inject(InboxState);
        /**
         * The changed values service.
         * @internal
         */
        this.changedPresetValuesService = inject(ChangedPresetValuesService);
        /**
         * The snackbar service.
         * @internal
         * @TODO: replace with talenra injectors as soon as they are available
         */
        this._snackBar = inject(MatSnackBar);
        /**
         * Information if it is possible to save a new preset.
         * @private
         */
        this.saveNewPresetButtonIsDisabled = false;
        /**
         * Information if it is possible to save an existing preset.
         * @private
         */
        this.overwritePresetButtonIsDisabled = false;
        /**
         * Information about the visibility of the presets.
         * The first value is the name of the group, the second value is the name of the preset and the third value is the visibility of the preset.
         * @private
         */
        this.visibilityOfPresets = [];
        /**
         * The subscriptions of the inbox toolbar component.
         * @internal
         * @private
         */
        this.subscriptions = new Subscription();
    }
    /**
     * Initializes the inbox toolbar component.
     * @internal
     */
    ngOnInit() {
        this.initializeComponent();
    }
    /**
     * Handles the changes of the presetGroups.
     * @param changes The changes of the presetGroups.
     * @internal
     */
    ngOnChanges(changes) {
        const presetGroupsChanges = changes['presetGroups'];
        if (presetGroupsChanges && !presetGroupsChanges.firstChange) {
            this.presetGroups?.forEach((group) => {
                group.presets.forEach((preset) => {
                    this.visibilityOfPresets.push([group.groupName, preset.name, preset.visible ?? true]);
                });
                group.presets.forEach((preset) => {
                    const key = group.groupName + preset.name;
                    this.showDeleteButton.set(key, false);
                });
            });
            this.subscriptions.unsubscribe();
            this.subscriptions.closed = false;
            this.initializeComponent();
        }
    }
    /**
     * Handles the value of presetMenuForm to the presets.
     */
    onPresetFormSubmit() {
        if (this.presetMenuForm.valid &&
            this.presetMenuForm.value['fcn'] !== undefined &&
            this.presetMenuForm.value['fcn'] !== null &&
            this.savePresetName()) {
            // show snackbar message
            this.openSnackBarPreset('Die Änderungen wurden gespeichert.');
            const activePresetName = this.inboxState.activePresetName$.value[0];
            const fcnValue = this.presetMenuForm.value['fcn'];
            // set the new preset name in the presets
            this.updatePresetsService.setNewPresetName([activePresetName, fcnValue]);
            this.emitPresetInteractions('overwrite-preset');
            this.closePresetMenusAfterDelay();
            this.inboxState.resetBufferFilterSort();
        }
    }
    /**
     * Handles new values of presetMenuForm to the presets.
     */
    saveNewPresetFormSubmit() {
        if (this.presetMenuForm.valid &&
            this.saveNewPresetMenuForm.value['fcn'] !== undefined &&
            this.saveNewPresetMenuForm.value['fcn'] !== null &&
            this.saveNewPresetName()) {
            // show snackbar message
            this.openSnackBarPreset('Die View wurde gespeichert.');
            const activePresetName = this.inboxState.activePresetName$.value[0];
            const fcnValue = this.saveNewPresetMenuForm.value.fcn;
            // set the new preset name in the presets
            this.updatePresetsService.setNewPresetName([activePresetName, fcnValue]);
            this.emitPresetInteractions('create-new-preset');
            this.saveNewPresetMenuForm.controls['fcn'].setValue('');
            this.closePresetMenusAfterDelay();
            this.inboxState.resetBufferFilterSort();
        }
    }
    /**
     * To change the array place of dragged item.
     * @param event The dragged item.
     * @internal
     */
    drop(event) {
        // reset dragging state
        this.draggingState = false;
        if (event.isPointerOverContainer) {
            const previousIndex = event.previousIndex;
            const newIndex = event.currentIndex;
            // Assuming 'group.items' is an array for the current group
            const currentPreset = this.presetGroups.find((group) => group.presets.includes(event.item.data));
            // Reorder items within the same group
            if (currentPreset && previousIndex !== newIndex) {
                const [movedItem] = currentPreset.presets.splice(previousIndex, 1);
                currentPreset.presets.splice(newIndex, 0, movedItem);
            }
            this.presetsService.setDragDropPresetAndGroup([currentPreset, event.item.data.name]);
            this.emitPresetInteractions('drag-drop');
        }
    }
    /**
     * Presets are readonly by default. Only if the preset is edited, the preset is editable.
     * @param groupIndex The index of the group.
     * @param presetIndex The index of the preset.
     * @param event The mouse event.
     */
    setTextAreaReadOnly(groupIndex, presetIndex, event) {
        event.stopPropagation();
        this.editState.next(true);
        this.indexOfPresetInEditing = presetIndex;
        this.indexOfPresetGroupInEditing = groupIndex;
        this.showDeleteButton.clear();
        this.dragAndDropDisabled = true;
    }
    /**
     * To change the name of a preset and make only one preset editable.
     * @param groupName The name of the group.
     * @param oldPresetName The old name of the preset.
     * @param newPresetName The new name of the preset.
     */
    renamingPreset(groupName, oldPresetName, newPresetName) {
        if (!this.presetsService.presetNamesThatAreAlreadyUsed(groupName, oldPresetName).includes(newPresetName)) {
            this.indexOfPresetInEditing = -1;
            this.indexOfPresetGroupInEditing = -1;
            this.updatePresetsService.setCurrentRenamedPreset([groupName, oldPresetName, newPresetName]);
            this.emitPresetInteractions('rename-preset');
            this.dragAndDropDisabled = false;
        }
    }
    /**
     * To change the array place of presets.
     * @param groupName The name of the group.
     * @param preset The preset that will be moved.
     * @param direction The direction of the movement.
     */
    updatePresetPosition(groupName, preset, direction) {
        const currentPosition = this.presetsService.findPositionOfPreset(groupName, preset.name);
        const changeableStartIndex = this.presetsService.findIndexOfFirstChangeablePreset(groupName);
        const changeableEndIndex = this.presetsService.findIndexOfLastChangeablePreset(groupName);
        if ((direction === 'up' && currentPosition !== changeableStartIndex) ||
            (direction === 'down' && currentPosition !== changeableEndIndex)) {
            // set the new preset name in the presets
            this.updatePresetsService.setNewPresetName([groupName, preset.name]);
            this.emitPresetInteractions(`position-${direction}`);
        }
    }
    /**
     * Delete presets and emit it to the presets.
     * @param groupName The name of the group that contains the preset.
     * @param presetName The name of the preset that will be deleted.
     * @param event The mouse event.
     */
    deletePreset(groupName, presetName, event) {
        // set the new preset name in the presets
        this.updatePresetsService.setNewPresetName([groupName, presetName]);
        this.emitPresetInteractions('delete-preset');
        this.openSnackBarPreset('Die View wurde gelöscht.');
        this.confirmDeletePreset(false, groupName, presetName, event);
    }
    /**
     * Check and save the visibility of the preset.
     * @param bool The visibility of the preset.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     */
    checkIfPresetIsVisible(bool, groupName, presetName) {
        //to save the visibility of the preset in presets
        this.visibilityOfPresets.forEach((presetNameElem) => {
            if (presetNameElem[0] === groupName && presetNameElem[1] === presetName) {
                presetNameElem[2] = bool;
            }
        });
        // set the new preset name in the presets
        this.updatePresetsService.setNewPresetName([groupName, presetName]);
        if (bool) {
            this.emitPresetInteractions('visbility-on');
        }
        else {
            this.emitPresetInteractions('visbility-off');
        }
    }
    /**
     * A button to confirm to delete of a preset is shown.
     * @param bool Determines if the button is shown or not.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     * @param event The mouse event.
     */
    confirmDeletePreset(bool, groupName, presetName, event) {
        this.editState.next(false);
        // stop propagation to disable reset of showDeleteButton
        event.stopPropagation();
        if (bool) {
            const key = groupName + presetName;
            this.showDeleteButton.set(key, true);
            this.dragAndDropDisabled = true;
        }
        else {
            const key = groupName + presetName;
            this.showDeleteButton.set(key, false);
            this.dragAndDropDisabled = false;
        }
    }
    /**
     * What happens when the menu is opened.
     */
    onMenuOpened() {
        this.presetsService.setPresetMenuState(true);
        this.presetGroups.forEach((group) => {
            this.expandedGroup.set(group.groupName, true);
        });
        // check if input fields are available
        if (this.savePresetInput || this.saveNewPresetInput) {
            // check if preset is changeable
            if (!this.presetsService.checkIfChangeablePreset(this.activePresetName[0], this.activePresetName[1])) {
                // focus on input field to save new preset
                // set timeout to focus on input field after the menu is opened and not add 'v' value to the input field if the menu is opened
                setTimeout(() => {
                    if (this.saveNewPresetInput && this.saveNewPresetInput['elementRef']) {
                        this.saveNewPresetInput['elementRef'].nativeElement.focus();
                    }
                }, 0);
            }
            else {
                // focus on input field to overwrite preset
                // set timeout to focus on input field after the menu is opened and not add 'v' value to the input field if the menu is opened
                setTimeout(() => {
                    if (this.saveNewPresetInput && this.savePresetInput['elementRef']) {
                        this.savePresetInput['elementRef'].nativeElement.focus();
                    }
                }, 0);
            }
        }
    }
    /**
     * What happens when the menu is closed.
     */
    onMenuClosed() {
        this.presetsService.setPresetMenuState(false);
        setTimeout(() => {
            this.updateTextareaValue(this.indexOfPresetGroupInEditing);
            this.expandedGroup.clear();
            this.dragAndDropDisabled = false;
            this.indexOfPresetInEditing = -1;
            this.indexOfPresetGroupInEditing = -1;
            this.showDeleteButton.clear();
        }, 100);
    }
    /**
     * check if it is possible to save a new presetName in an existing preset
     */
    savePresetName() {
        return !!this.presetMenuForm.controls['fcn'].value?.trim() && !this.overwritePresetButtonIsDisabled;
    }
    /**
     * check if it is possible to save a new presetName in a new preset
     */
    saveNewPresetName() {
        return this.saveNewPresetMenuForm.controls['fcn'].value?.trim() && !this.saveNewPresetButtonIsDisabled;
    }
    /**
     * Handling of an accordion header click.
     * @param groupName The name of the group.
     */
    onAccordionClick(groupName) {
        this.expandedGroup.set(groupName, !this.expandedGroup.get(groupName));
    }
    /**
     * Handling the change in the edit state if clicked on all elements except the text area.
     * @param event The mouse event.
     * @param nextState The next state of the edit state.
     */
    changeEditState(event, nextState) {
        event.stopPropagation();
        this.dragAndDropDisabled = false;
        this.editState.next(nextState);
    }
    /**
     * Handling of a click on the text area of a preset name.
     * Stops propagation if the preset is currently edited.
     * @param event The mouse event.
     * @param presetIndex The index of the preset.
     * @param groupIndex The index of the group.
     */
    clickTextAreaName(event, presetIndex, groupIndex) {
        // stop propagation on active edited preset name
        if (presetIndex === this.indexOfPresetInEditing && groupIndex === this.indexOfPresetGroupInEditing) {
            event.stopPropagation();
        }
    }
    /**
     * Handling the enter press during the renaming of a preset.
     *
     * @param event The keyboard event.
     * @param group The group of the presets.
     * @param optionName The name of the preset.
     * @param inputText The text of the input.
     */
    checkAndRenamePreset(event, group, optionName, inputText) {
        event.preventDefault(); // Prevent the Enter key from causing a line break
        // Check if the input text is empty or contains only spaces
        if (inputText.trim() !== '') {
            // The textarea has content, perform the renaming logic
            this.renamingPreset(group, optionName, inputText);
        }
    }
    /**
     * Disable drag and drop if there is only one preset in the group
     * @param group The group of the presets
     * @internal
     */
    disableDragAndDropFunction(group) {
        // Check if dragAndDropDisabled is true OR if there's only one preset in the group
        // length 2 used because, the group counts also as a preset
        return this.dragAndDropDisabled || group.presets.length === 2;
    }
    /**
     * Stop the tab press from closing the material menu.
     * @param keyEvent The event that will be stopped.
     */
    stopTabClosingMenu(keyEvent) {
        keyEvent.stopPropagation();
    }
    /**
     * Handles the drag start event.
     * Used to set the dragging state to true.
     */
    dragStarted() {
        this.draggingState = true;
    }
    /**
     * Handle the snackbar message.
     * @param message The message that will be displayed in the snackbar.
     * @private
     */
    openSnackBarPreset(message) {
        this.onCheckClick = true;
        this._snackBar.open(message, '', {
            duration: 3000,
        });
        setTimeout(() => {
            this.onCheckClick = false;
            this.saveNewPresetMenuForm.value['fcn'] = '';
        }, 2000);
    }
    /**
     * Open or close the preset menu.
     * @param open Determines if the preset menu is open or not.
     * @private
     */
    openClosePresetWindow(open) {
        if (open) {
            // define a function to check if the menu is open
            const isMenuOpen = (menu) => (menu?.menuOpen !== undefined ? menu.menuOpen : false);
            // open or close the preset menu
            if (!isMenuOpen(this.talenraInboxPresetMenuTrigger)) {
                this.talenraInboxPresetMenuTrigger?.openMenu();
            }
            else if (isMenuOpen(this.talenraInboxPresetMenuTrigger)) {
                this.talenraInboxPresetMenuTrigger?.closeMenu();
            }
        }
    }
    /**
     * Update the textarea value if the preset is currently edited.
     * @param groupIndex The index of the group.
     * @private
     */
    updateTextareaValue(groupIndex) {
        if (this.originalPresetGroupNames[groupIndex]) {
            this.presetGroups.forEach((group, groupIndex) => {
                if (groupIndex === groupIndex) {
                    group.presets.forEach((preset, presetIndex) => {
                        if (presetIndex === presetIndex) {
                            this.originalPresetGroupNames[groupIndex].presetNames[presetIndex] = preset.name;
                        }
                    });
                }
            });
        }
    }
    /**
     * Determines the preset is saved by pressing of the enter key.
     * @internal
     * @private
     */
    savePresetOnEnter() {
        // if the preset menu is open and the preset is changed, the preset is saved
        if (this.talenraInboxPresetMenuTrigger?.menuOpen && this.changedPresetValuesService.filterSortChangedSubject$.value) {
            // check if a new preset can be created or the preset can be overwritten
            if (this.saveNewPresetMenuForm.valid && this.saveNewPresetMenuForm.value['fcn'] !== '') {
                this.saveNewPresetFormSubmit();
            }
            // check if the existing preset is mutable and the input field is not empty
            else if (this.presetMenuForm.valid &&
                this.presetMenuForm.value['fcn'] !== '' &&
                this.presetsService.checkIfChangeablePreset(this.activePresetName[0], this.activePresetName[1])) {
                this.onPresetFormSubmit();
            }
        }
    }
    /**
     * Closes preset menus after a delay of 1000ms.
     * @internal
     * @private
     */
    closePresetMenusAfterDelay() {
        setTimeout(() => {
            this.talenraInboxPresetMenuTrigger?.closeMenu();
        }, 1000);
    }
    /**
     * Emits an icon button event.
     * @param presetInteraction The name of the icon button to emit.
     * @emits
     * @private
     */
    emitPresetInteractions(presetInteraction) {
        this.presetInteractions.emit(presetInteraction);
    }
    /**
     * Initializes the component.
     * @private
     */
    initializeComponent() {
        // Check if presetGroups is defined and not empty
        if (this.presetGroups && this.presetGroups.length > 0) {
            this.originalPresetGroupNames = [];
            // Iterate through the presetGroups
            this.presetGroups.forEach((group) => {
                // Extract preset names from presets array
                const presetNames = group.presets.map((option) => option.name);
                // Save values in the extractedValues array as an object
                this.originalPresetGroupNames.push({ groupName: group.groupName, presetNames: presetNames });
            });
        }
        // subscription to check if a new preset name is already used in the current group, sets a boolean value
        // @internal
        this.subscriptions.add(
        // decides if a new typed preset name is already used in presets the current group
        this.saveNewPresetMenuForm.valueChanges.subscribe((value) => {
            if (value['fcn'] !== null && value['fcn'] !== undefined) {
                this.saveNewPresetButtonIsDisabled =
                    this.activePresetName[1] === value.fcn ||
                        this.presetsService
                            .presetNamesThatAreAlreadyUsed(this.activePresetName[0], this.activePresetName[1])
                            .includes(value['fcn']);
            }
        }));
        // subscription to check if a changed preset name is already used in the current group, sets a boolean value
        // @internal
        this.subscriptions.add(
        // decides if a new typed preset name is already used as the name of groups (= unchangeable presets)
        this.presetMenuForm.valueChanges.subscribe((value) => {
            if (value['fcn'] !== null && value['fcn'] !== undefined) {
                this.overwritePresetButtonIsDisabled = this.presetsService
                    .presetNamesThatAreAlreadyUsed(this.activePresetName[0], this.activePresetName[1])
                    .includes(value['fcn']);
            }
        }));
        // subscription to set the activePresetName in the presetMenuForm, if the activePresetName changes
        // @internal
        this.subscriptions.add(
        // If new preset is created, as default the activePresetName is set in the presetMenuForm
        this.inboxState.activePresetName$.subscribe((value) => {
            this.activePresetName = value;
            this.presetMenuForm.get('fcn')?.setValue(this.activePresetName[1]);
        }));
        // subscription to overwrite or create a new preset on the enter key
        this.subscriptions.add(this.keyboardService.enterKeyPressed.subscribe((value) => {
            if (value) {
                this.savePresetOnEnter();
            }
        }));
        // subscription to close preset menu
        this.subscriptions.add(this.keyboardService.escapeKeyPressed.subscribe((value) => {
            // define a function to check if the menu is open
            const isMenuOpen = (menu) => (menu?.menuOpen !== undefined ? menu.menuOpen : false);
            if (value) {
                if (isMenuOpen(this.talenraInboxPresetMenuTrigger)) {
                    this.talenraInboxPresetMenuTrigger?.closeMenu();
                }
            }
        }));
        // subscription to open or close the preset menu
        this.subscriptions.add(this.keyboardService.vKeyPressed.subscribe((value) => {
            if (value) {
                this.openClosePresetWindow(true);
            }
            else {
                this.openClosePresetWindow(false);
            }
        }));
        // subscription if shortcuts is opened/closed
        this.subscriptions.add(this.presetsService.presetMenuOpen.subscribe((value) => {
            if (!value) {
                this.talenraInboxPresetMenuTrigger?.closeMenu();
            }
        }));
        // subscription to set the edit state of the preset menu, disables the interactability of the other presets and the drag and drop
        // @internal
        this.subscriptions.add(this.editState.subscribe((value) => {
            if (!value) {
                this.updateTextareaValue(this.indexOfPresetGroupInEditing);
                // reset edited text area
                this.indexOfPresetInEditing = -1;
                this.indexOfPresetGroupInEditing = -1;
                // reset delete button
                this.showDeleteButton.clear();
            }
            else {
                this.updateTextareaValue(this.indexOfPresetGroupInEditing);
                this.dragAndDropDisabled = true;
            }
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: PresetsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: PresetsComponent, isStandalone: true, selector: "talenra-presets", inputs: { presetGroups: "presetGroups" }, outputs: { presetInteractions: "presetInteractions" }, viewQueries: [{ propertyName: "talenraInboxPresetMenuTrigger", first: true, predicate: ["talenraInboxPresetMenuTrigger"], descendants: true }, { propertyName: "savePresetInput", first: true, predicate: ["savePresetInput"], descendants: true }, { propertyName: "saveNewPresetInput", first: true, predicate: ["saveNewPresetInput"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "@if (!inboxState.inboxConfiguration$.value.disablePresetMenuToolbar) {\n  <div>\n    <ng-container>\n      <button\n        #talenraInboxPresetMenuTrigger=\"matMenuTrigger\"\n        (keydown.enter)=\"$event.preventDefault()\"\n        (menuClosed)=\"onMenuClosed()\"\n        (menuOpened)=\"onMenuOpened()\"\n        [matMenuTriggerFor]=\"presetMenu\"\n        class=\"btn\"\n        icon=\"inbox-eye\"\n        id=\"talenraInboxPresetMenuTrigger\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"View erstellen/\u00E4ndern\"></button>\n    </ng-container>\n  </div>\n}\n\n<mat-menu #presetMenu class=\"talenra-inbox-toolbar-preset-menu\">\n  <!-- All presets are displayed and can be renamed, visibility or the position changed -->\n  @if (!changedPresetValuesService.filterSortChangedSubject$.value) {\n    <div (click)=\"changeEditState($event, false)\">\n      <div class=\"preset-title medium-font\">\n        Meine Views\n        <talenra-icon class=\"preset-icon\" name=\"inbox-eye\"></talenra-icon>\n      </div>\n      <talenra-scroll-container class=\"preset-groups-scroll-container\">\n        @for (group of presetGroups; track group.groupName; let groupIndex = $index) {\n          <div>\n            <mat-accordion>\n              <mat-expansion-panel\n                [disabled]=\"!presetsService.hasChangeablePreset(group.groupName)\"\n                [expanded]=\"expandedGroup.get(group.groupName)\"\n                class=\"remove-mat-expansion-panel-padding\">\n                <mat-expansion-panel-header\n                  (click)=\"onAccordionClick(group.groupName)\"\n                  class=\"inbox-mat-expansion-panel-header\">\n                  <mat-panel-title class=\"inbox-mat-expansion-panel-title\"> {{ group.groupName }}</mat-panel-title>\n                </mat-expansion-panel-header>\n                <div\n                  (cdkDropListDropped)=\"drop($event)\"\n                  [cdkDropListDisabled]=\"dragAndDropDisabled\"\n                  [class.default-cursor]=\"!draggingState\"\n                  cdkDropList\n                  class=\"grabbing-cursor\"\n                  data-testid=\"inbox-preset-list\">\n                  @for (preSetOption of group.presets; track preSetOption.name; let presetIndex = $index) {\n                    <div\n                      (cdkDragStarted)=\"dragStarted()\"\n                      [cdkDragData]=\"preSetOption\"\n                      [cdkDragDisabled]=\"disableDragAndDropFunction(group)\"\n                      cdkDrag>\n                      <div *cdkDragPlaceholder class=\"custom-drag-preset-item-placeholder\"></div>\n                      @if (presetsService.checkIfChangeablePreset(group.groupName, preSetOption.name)) {\n                        <!-- preset items -->\n                        <div\n                          [class.disable-hover]=\"draggingState\"\n                          [class.grabbing-cursor]=\"draggingState\"\n                          class=\"preset-items move-cursor\">\n                          <div [class.disable-hover]=\"draggingState\" class=\"preset-items-tag\">\n                            <form>\n                              <textarea\n                                #presetNameInput\n                                (click)=\"clickTextAreaName($event, presetIndex, groupIndex)\"\n                                (keydown.enter)=\"\n                                  checkAndRenamePreset(\n                                    $event,\n                                    group.groupName,\n                                    preSetOption.name,\n                                    presetNameInput.value\n                                  )\n                                \"\n                                [(ngModel)]=\"originalPresetGroupNames[groupIndex].presetNames[presetIndex]\"\n                                [class.disable-hover]=\"draggingState\"\n                                [class.text-cursor]=\"editState | async\"\n                                [readonly]=\"\n                                  !(\n                                    presetIndex === indexOfPresetInEditing && groupIndex === indexOfPresetGroupInEditing\n                                  )\n                                \"\n                                class=\"preset-name-input preset-name-input-wide\"\n                                maxlength=\"30\"\n                                name=\"presetName\"\n                                >{{ preSetOption.name }}</textarea\n                              >\n                            </form>\n                            <div class=\"preset-items-buttons\">\n                              @if (showDeleteButton.get(group.groupName + preSetOption.name)) {\n                                <button\n                                  (click)=\"deletePreset(group.groupName, preSetOption.name, $event)\"\n                                  label=\"L\u00F6schen\"\n                                  talenra-button\n                                  size=\"s\"></button>\n                              }\n                              @if (\n                                presetIndex === indexOfPresetInEditing && groupIndex === indexOfPresetGroupInEditing\n                              ) {\n                                @if (\n                                  !presetsService\n                                    .presetNamesThatAreAlreadyUsed(group.groupName, preSetOption.name)\n                                    .includes(presetNameInput.value) && presetNameInput.value.trim() !== ''\n                                ) {\n                                  <button\n                                    (click)=\"renamingPreset(group.groupName, preSetOption.name, presetNameInput.value)\"\n                                    class=\"check-button\"\n                                    data-testid=\"inbox-preset-save-name\"\n                                    icon=\"check\"\n                                    kind=\"ghost\"\n                                    talenra-button\n                                    talenraTooltip=\"Best\u00E4tigen\"\n                                    size=\"s\"></button>\n                                }\n                              } @else {\n                                @if (!showDeleteButton.get(group.groupName + preSetOption.name)) {\n                                  <div class=\"interaction-buttons\">\n                                    <button\n                                      (click)=\"setTextAreaReadOnly(groupIndex, presetIndex, $event)\"\n                                      class=\"no-padding\"\n                                      data-testid=\"inbox-preset-name-edit\"\n                                      icon=\"edit\"\n                                      kind=\"ghost\"\n                                      talenra-button\n                                      talenraTooltip=\"Name bearbeiten\"\n                                      size=\"s\"></button>\n                                    <!-- Visibility-on button -->\n                                    @if (preSetOption.visible) {\n                                      <button\n                                        (click)=\"checkIfPresetIsVisible(false, group.groupName, preSetOption.name)\"\n                                        class=\"no-padding\"\n                                        data-testid=\"inbox-preset-name-visible\"\n                                        icon=\"visibility\"\n                                        kind=\"ghost\"\n                                        talenra-button\n                                        talenraTooltip=\"View ausblenden\"\n                                        size=\"s\"></button>\n                                    } @else {\n                                      <button\n                                        (click)=\"checkIfPresetIsVisible(true, group.groupName, preSetOption.name)\"\n                                        class=\"no-padding\"\n                                        data-testid=\"inbox-preset-name-not-visible\"\n                                        icon=\"visibility-off\"\n                                        kind=\"ghost\"\n                                        talenra-button\n                                        talenraTooltip=\"View anzeigen\"\n                                        size=\"s\"></button>\n                                    }\n                                    <!--Visibility-off button -->\n                                    <button\n                                      (click)=\"confirmDeletePreset(true, group.groupName, preSetOption.name, $event)\"\n                                      [disabled]=\"false\"\n                                      class=\"no-padding\"\n                                      data-testid=\"inbox-preset-delete\"\n                                      icon=\"delete\"\n                                      kind=\"ghost\"\n                                      talenra-button\n                                      talenraTooltip=\"L\u00F6schen\"\n                                      size=\"s\"></button>\n                                  </div>\n                                }\n                              }\n                              @if (\n                                presetsService.findPositionOfPreset(group.groupName, preSetOption.name) !==\n                                presetsService.findIndexOfFirstChangeablePreset(group.groupName)\n                              ) {\n                                <button\n                                  (click)=\"updatePresetPosition(group.groupName, preSetOption, 'up')\"\n                                  class=\"no-padding\"\n                                  data-testid=\"inbox-preset-move-up\"\n                                  icon=\"arrow-upward\"\n                                  kind=\"ghost\"\n                                  talenra-button\n                                  talenraTooltip=\"Nach oben\"\n                                  size=\"s\"></button>\n                              } @else {\n                                <div class=\"empty-preset-icon-placeholder\"></div>\n                              }\n                              @if (\n                                presetsService.findPositionOfPreset(group.groupName, preSetOption.name) !==\n                                presetsService.findIndexOfLastChangeablePreset(group.groupName)\n                              ) {\n                                <button\n                                  (click)=\"updatePresetPosition(group.groupName, preSetOption, 'down')\"\n                                  class=\"no-padding\"\n                                  data-testid=\"inbox-preset-move-down\"\n                                  icon=\"arrow-downward\"\n                                  kind=\"ghost\"\n                                  talenra-button\n                                  talenraTooltip=\"Nach unten\"\n                                  size=\"s\"></button>\n                              } @else {\n                                <div class=\"empty-preset-icon-placeholder\"></div>\n                              }\n                            </div>\n                          </div>\n                          @if (group.presets.length !== 2) {\n                            <div class=\"preset-items-grab\">\n                              <button\n                                class=\"move-cursor\"\n                                data-testid=\"inbox-preset-drag\"\n                                icon=\"drag-indicator\"\n                                kind=\"ghost\"\n                                talenra-button\n                                size=\"s\"></button>\n                            </div>\n                          }\n                        </div>\n                      }\n                    </div>\n                  }\n                </div>\n              </mat-expansion-panel>\n            </mat-accordion>\n          </div>\n        }\n      </talenra-scroll-container>\n    </div>\n  }\n\n  <!-- preset menu for the data items that the preset has been changed -->\n  @if (changedPresetValuesService.filterSortChangedSubject$.value) {\n    <div (click)=\"$event.stopPropagation()\">\n      <!-- Disable overwriting of the preset name if not changeable-->\n      @if (presetsService.checkIfChangeablePreset(activePresetName[0], activePresetName[1])) {\n        <div class=\"preset-start-container\">\u00C4nderungen speichern</div>\n        <form (ngSubmit)=\"onPresetFormSubmit()\" [formGroup]=\"presetMenuForm\" class=\"save-preset-form\">\n          <talenra-form-field label=\"View Name\">\n            <input\n              #savePresetInput\n              (keydown.tab)=\"stopTabClosingMenu($event)\"\n              class=\"save-preset-input\"\n              data-testid=\"inbox-overwrite-preset-input\"\n              formControlName=\"fcn\"\n              maxlength=\"30\"\n              talenra-input />\n          </talenra-form-field>\n          <button\n            (keydown.tab)=\"stopTabClosingMenu($event)\"\n            [disabled]=\"!savePresetName()\"\n            data-testid=\"inbox-save-overwrite-preset\"\n            icon=\"check\"\n            kind=\"ghost\"\n            talenra-button\n            talenraTooltip=\"View speichern\"\n            size=\"s\"\n            type=\"submit\"></button>\n        </form>\n      }\n      <div class=\"preset-start-container\">Als neue View speichern</div>\n      <form (ngSubmit)=\"saveNewPresetFormSubmit()\" [formGroup]=\"saveNewPresetMenuForm\" class=\"save-preset-form\">\n        <talenra-form-field label=\"View Name\">\n          <input\n            #saveNewPresetInput\n            (keydown.tab)=\"stopTabClosingMenu($event)\"\n            class=\"save-preset-input\"\n            data-testid=\"inbox-new-preset-input\"\n            formControlName=\"fcn\"\n            maxlength=\"30\"\n            talenra-input />\n        </talenra-form-field>\n        <button\n          (keydown.tab)=\"stopTabClosingMenu($event)\"\n          [disabled]=\"!saveNewPresetName()\"\n          data-testid=\"inbox-save-new-preset\"\n          icon=\"check\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"Neue View speichern\"\n          size=\"s\"\n          type=\"submit\"></button>\n      </form>\n    </div>\n  }\n</mat-menu>\n", styles: [":host{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;--color-background: #ffffff;--color-light-background: #f2f2f2;--color-title-icon: #666666}.preset-title{text-align:center;margin-bottom:.125rem}.preset-groups-scroll-container{width:23.75rem;min-height:fit-content;max-height:24.375rem}.inbox-mat-expansion-panel-header{padding:0 .3125rem;height:2rem!important}.preset-start-container{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;padding:1rem 1rem 0;font-weight:500}.presets-drop-lists{cursor:grabbing}.preset-items{position:relative;background:var(--color-background);height:2.25rem;margin-left:.875rem;border-radius:.1875rem;display:grid;grid-template-columns:93% 7%;grid-template-rows:1fr;grid-auto-flow:row}.preset-items:hover:not(.disable-hover){background:var(--color-light-background)}.preset-items:hover:not(.disable-hover) .preset-name-input{background:var(--color-light-background)}.preset-items-grab{display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto;align-self:center;justify-self:center}.preset-items-tag{display:flex;align-items:center;justify-content:space-between;height:1.5rem;width:100%;align-self:center;justify-self:center}.preset-items-tag:hover:not(.disable-hover){background:var(--color-light-background)}.preset-items-buttons{height:1.5rem;display:flex;align-items:center;flex-wrap:nowrap;flex-direction:row}.interaction-buttons{height:1.5rem}.no-padding{padding:0}.save-preset-form{display:flex;flex-direction:row;align-items:center;padding:0 1rem}.save-preset-input{width:20.3125rem}.preset-name-input{height:1.125rem;padding:0;border:none;outline:none;resize:none;border-radius:.25rem;margin-bottom:-.25rem;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;cursor:move;background:var(--color-background)}.preset-name-input:hover:not(.disable-hover){background:var(--color-light-background)}.preset-name-input-wide{flex-grow:1;max-width:100%}.custom-drag-preset-item-placeholder{margin-left:.875rem;background:var(--color-light-background);min-height:2.25rem;transition:transform .25s cubic-bezier(0,0,.2,1)}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em}.btn{padding:0;margin:0 .5rem}.check-button{margin-right:2.625rem}.preset-icon{color:var(--color-title-icon);font-size:1rem}.move-cursor{cursor:move}.move-cursor :active{cursor:grabbing}.text-cursor{cursor:text}.grabbing-cursor{cursor:grabbing}.default-cursor{cursor:default}.empty-preset-icon-placeholder{width:1.5rem;height:1.5rem}::ng-deep .mat-mdc-menu-panel.mat-mdc-menu-panel.talenra-inbox-toolbar-preset-menu{min-width:25rem;max-width:28.125rem;overflow:hidden}::ng-deep .remove-mat-expansion-panel-padding .mat-expansion-panel-content .mat-expansion-panel-body{padding:0;background-color:var(--color-background)}.remove-mat-expansion-panel-padding .mat-expansion-panel-header-title{padding-left:.625rem}.mat-accordion .mat-expansion-panel:last-of-type{border-bottom-right-radius:0;border-bottom-left-radius:0}.mat-expansion-panel:not([class*=mat-elevation-z]){box-shadow:none!important}.appearance--dark :host{--color-background: #333333;--color-light-background: #f2f2f2}\n"], dependencies: [{ kind: "directive", type: MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", inputs: ["mat-menu-trigger-for", "matMenuTriggerFor", "matMenuTriggerData", "matMenuTriggerRestoreFocus"], outputs: ["menuOpened", "onMenuOpen", "menuClosed", "onMenuClose"], exportAs: ["matMenuTrigger"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "component", type: MatMenu, selector: "mat-menu", inputs: ["backdropClass", "aria-label", "aria-labelledby", "aria-describedby", "xPosition", "yPosition", "overlapTrigger", "hasBackdrop", "class", "classList"], outputs: ["closed", "close"], exportAs: ["matMenu"] }, { kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }, { kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }, { kind: "directive", type: MatAccordion, selector: "mat-accordion", inputs: ["hideToggle", "displayMode", "togglePosition"], exportAs: ["matAccordion"] }, { kind: "component", type: MatExpansionPanel, selector: "mat-expansion-panel", inputs: ["hideToggle", "togglePosition"], outputs: ["afterExpand", "afterCollapse"], exportAs: ["matExpansionPanel"] }, { kind: "component", type: MatExpansionPanelHeader, selector: "mat-expansion-panel-header", inputs: ["expandedHeight", "collapsedHeight", "tabIndex"] }, { kind: "directive", type: MatExpansionPanelTitle, selector: "mat-panel-title" }, { kind: "directive", type: CdkDropList, selector: "[cdkDropList], cdk-drop-list", inputs: ["cdkDropListConnectedTo", "cdkDropListData", "cdkDropListOrientation", "id", "cdkDropListLockAxis", "cdkDropListDisabled", "cdkDropListSortingDisabled", "cdkDropListEnterPredicate", "cdkDropListSortPredicate", "cdkDropListAutoScrollDisabled", "cdkDropListAutoScrollStep", "cdkDropListElementContainer"], outputs: ["cdkDropListDropped", "cdkDropListEntered", "cdkDropListExited", "cdkDropListSorted"], exportAs: ["cdkDropList"] }, { kind: "directive", type: CdkDrag, selector: "[cdkDrag]", inputs: ["cdkDragData", "cdkDragLockAxis", "cdkDragRootElement", "cdkDragBoundary", "cdkDragStartDelay", "cdkDragFreeDragPosition", "cdkDragDisabled", "cdkDragConstrainPosition", "cdkDragPreviewClass", "cdkDragPreviewContainer", "cdkDragScale"], outputs: ["cdkDragStarted", "cdkDragReleased", "cdkDragEnded", "cdkDragEntered", "cdkDragExited", "cdkDragDropped", "cdkDragMoved"], exportAs: ["cdkDrag"] }, { kind: "directive", type: CdkDragPlaceholder, selector: "ng-template[cdkDragPlaceholder]", inputs: ["data"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: FormFieldComponent, selector: "talenra-form-field", inputs: ["hint", "label", "size"] }, { kind: "component", type: InputComponent, selector: "input[talenra-input], textarea[talenra-input]", inputs: ["type", "disabled", "readonly"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: PresetsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-presets', standalone: true, imports: [
                        MatMenuTrigger,
                        ButtonComponent,
                        MatMenu,
                        IconComponent,
                        ScrollContainerComponent,
                        MatAccordion,
                        MatExpansionPanel,
                        MatExpansionPanelHeader,
                        MatExpansionPanelTitle,
                        CdkDropList,
                        CdkDrag,
                        CdkDragPlaceholder,
                        TooltipDirective,
                        FormsModule,
                        AsyncPipe,
                        ReactiveFormsModule,
                        FormFieldComponent,
                        InputComponent,
                    ], template: "@if (!inboxState.inboxConfiguration$.value.disablePresetMenuToolbar) {\n  <div>\n    <ng-container>\n      <button\n        #talenraInboxPresetMenuTrigger=\"matMenuTrigger\"\n        (keydown.enter)=\"$event.preventDefault()\"\n        (menuClosed)=\"onMenuClosed()\"\n        (menuOpened)=\"onMenuOpened()\"\n        [matMenuTriggerFor]=\"presetMenu\"\n        class=\"btn\"\n        icon=\"inbox-eye\"\n        id=\"talenraInboxPresetMenuTrigger\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"View erstellen/\u00E4ndern\"></button>\n    </ng-container>\n  </div>\n}\n\n<mat-menu #presetMenu class=\"talenra-inbox-toolbar-preset-menu\">\n  <!-- All presets are displayed and can be renamed, visibility or the position changed -->\n  @if (!changedPresetValuesService.filterSortChangedSubject$.value) {\n    <div (click)=\"changeEditState($event, false)\">\n      <div class=\"preset-title medium-font\">\n        Meine Views\n        <talenra-icon class=\"preset-icon\" name=\"inbox-eye\"></talenra-icon>\n      </div>\n      <talenra-scroll-container class=\"preset-groups-scroll-container\">\n        @for (group of presetGroups; track group.groupName; let groupIndex = $index) {\n          <div>\n            <mat-accordion>\n              <mat-expansion-panel\n                [disabled]=\"!presetsService.hasChangeablePreset(group.groupName)\"\n                [expanded]=\"expandedGroup.get(group.groupName)\"\n                class=\"remove-mat-expansion-panel-padding\">\n                <mat-expansion-panel-header\n                  (click)=\"onAccordionClick(group.groupName)\"\n                  class=\"inbox-mat-expansion-panel-header\">\n                  <mat-panel-title class=\"inbox-mat-expansion-panel-title\"> {{ group.groupName }}</mat-panel-title>\n                </mat-expansion-panel-header>\n                <div\n                  (cdkDropListDropped)=\"drop($event)\"\n                  [cdkDropListDisabled]=\"dragAndDropDisabled\"\n                  [class.default-cursor]=\"!draggingState\"\n                  cdkDropList\n                  class=\"grabbing-cursor\"\n                  data-testid=\"inbox-preset-list\">\n                  @for (preSetOption of group.presets; track preSetOption.name; let presetIndex = $index) {\n                    <div\n                      (cdkDragStarted)=\"dragStarted()\"\n                      [cdkDragData]=\"preSetOption\"\n                      [cdkDragDisabled]=\"disableDragAndDropFunction(group)\"\n                      cdkDrag>\n                      <div *cdkDragPlaceholder class=\"custom-drag-preset-item-placeholder\"></div>\n                      @if (presetsService.checkIfChangeablePreset(group.groupName, preSetOption.name)) {\n                        <!-- preset items -->\n                        <div\n                          [class.disable-hover]=\"draggingState\"\n                          [class.grabbing-cursor]=\"draggingState\"\n                          class=\"preset-items move-cursor\">\n                          <div [class.disable-hover]=\"draggingState\" class=\"preset-items-tag\">\n                            <form>\n                              <textarea\n                                #presetNameInput\n                                (click)=\"clickTextAreaName($event, presetIndex, groupIndex)\"\n                                (keydown.enter)=\"\n                                  checkAndRenamePreset(\n                                    $event,\n                                    group.groupName,\n                                    preSetOption.name,\n                                    presetNameInput.value\n                                  )\n                                \"\n                                [(ngModel)]=\"originalPresetGroupNames[groupIndex].presetNames[presetIndex]\"\n                                [class.disable-hover]=\"draggingState\"\n                                [class.text-cursor]=\"editState | async\"\n                                [readonly]=\"\n                                  !(\n                                    presetIndex === indexOfPresetInEditing && groupIndex === indexOfPresetGroupInEditing\n                                  )\n                                \"\n                                class=\"preset-name-input preset-name-input-wide\"\n                                maxlength=\"30\"\n                                name=\"presetName\"\n                                >{{ preSetOption.name }}</textarea\n                              >\n                            </form>\n                            <div class=\"preset-items-buttons\">\n                              @if (showDeleteButton.get(group.groupName + preSetOption.name)) {\n                                <button\n                                  (click)=\"deletePreset(group.groupName, preSetOption.name, $event)\"\n                                  label=\"L\u00F6schen\"\n                                  talenra-button\n                                  size=\"s\"></button>\n                              }\n                              @if (\n                                presetIndex === indexOfPresetInEditing && groupIndex === indexOfPresetGroupInEditing\n                              ) {\n                                @if (\n                                  !presetsService\n                                    .presetNamesThatAreAlreadyUsed(group.groupName, preSetOption.name)\n                                    .includes(presetNameInput.value) && presetNameInput.value.trim() !== ''\n                                ) {\n                                  <button\n                                    (click)=\"renamingPreset(group.groupName, preSetOption.name, presetNameInput.value)\"\n                                    class=\"check-button\"\n                                    data-testid=\"inbox-preset-save-name\"\n                                    icon=\"check\"\n                                    kind=\"ghost\"\n                                    talenra-button\n                                    talenraTooltip=\"Best\u00E4tigen\"\n                                    size=\"s\"></button>\n                                }\n                              } @else {\n                                @if (!showDeleteButton.get(group.groupName + preSetOption.name)) {\n                                  <div class=\"interaction-buttons\">\n                                    <button\n                                      (click)=\"setTextAreaReadOnly(groupIndex, presetIndex, $event)\"\n                                      class=\"no-padding\"\n                                      data-testid=\"inbox-preset-name-edit\"\n                                      icon=\"edit\"\n                                      kind=\"ghost\"\n                                      talenra-button\n                                      talenraTooltip=\"Name bearbeiten\"\n                                      size=\"s\"></button>\n                                    <!-- Visibility-on button -->\n                                    @if (preSetOption.visible) {\n                                      <button\n                                        (click)=\"checkIfPresetIsVisible(false, group.groupName, preSetOption.name)\"\n                                        class=\"no-padding\"\n                                        data-testid=\"inbox-preset-name-visible\"\n                                        icon=\"visibility\"\n                                        kind=\"ghost\"\n                                        talenra-button\n                                        talenraTooltip=\"View ausblenden\"\n                                        size=\"s\"></button>\n                                    } @else {\n                                      <button\n                                        (click)=\"checkIfPresetIsVisible(true, group.groupName, preSetOption.name)\"\n                                        class=\"no-padding\"\n                                        data-testid=\"inbox-preset-name-not-visible\"\n                                        icon=\"visibility-off\"\n                                        kind=\"ghost\"\n                                        talenra-button\n                                        talenraTooltip=\"View anzeigen\"\n                                        size=\"s\"></button>\n                                    }\n                                    <!--Visibility-off button -->\n                                    <button\n                                      (click)=\"confirmDeletePreset(true, group.groupName, preSetOption.name, $event)\"\n                                      [disabled]=\"false\"\n                                      class=\"no-padding\"\n                                      data-testid=\"inbox-preset-delete\"\n                                      icon=\"delete\"\n                                      kind=\"ghost\"\n                                      talenra-button\n                                      talenraTooltip=\"L\u00F6schen\"\n                                      size=\"s\"></button>\n                                  </div>\n                                }\n                              }\n                              @if (\n                                presetsService.findPositionOfPreset(group.groupName, preSetOption.name) !==\n                                presetsService.findIndexOfFirstChangeablePreset(group.groupName)\n                              ) {\n                                <button\n                                  (click)=\"updatePresetPosition(group.groupName, preSetOption, 'up')\"\n                                  class=\"no-padding\"\n                                  data-testid=\"inbox-preset-move-up\"\n                                  icon=\"arrow-upward\"\n                                  kind=\"ghost\"\n                                  talenra-button\n                                  talenraTooltip=\"Nach oben\"\n                                  size=\"s\"></button>\n                              } @else {\n                                <div class=\"empty-preset-icon-placeholder\"></div>\n                              }\n                              @if (\n                                presetsService.findPositionOfPreset(group.groupName, preSetOption.name) !==\n                                presetsService.findIndexOfLastChangeablePreset(group.groupName)\n                              ) {\n                                <button\n                                  (click)=\"updatePresetPosition(group.groupName, preSetOption, 'down')\"\n                                  class=\"no-padding\"\n                                  data-testid=\"inbox-preset-move-down\"\n                                  icon=\"arrow-downward\"\n                                  kind=\"ghost\"\n                                  talenra-button\n                                  talenraTooltip=\"Nach unten\"\n                                  size=\"s\"></button>\n                              } @else {\n                                <div class=\"empty-preset-icon-placeholder\"></div>\n                              }\n                            </div>\n                          </div>\n                          @if (group.presets.length !== 2) {\n                            <div class=\"preset-items-grab\">\n                              <button\n                                class=\"move-cursor\"\n                                data-testid=\"inbox-preset-drag\"\n                                icon=\"drag-indicator\"\n                                kind=\"ghost\"\n                                talenra-button\n                                size=\"s\"></button>\n                            </div>\n                          }\n                        </div>\n                      }\n                    </div>\n                  }\n                </div>\n              </mat-expansion-panel>\n            </mat-accordion>\n          </div>\n        }\n      </talenra-scroll-container>\n    </div>\n  }\n\n  <!-- preset menu for the data items that the preset has been changed -->\n  @if (changedPresetValuesService.filterSortChangedSubject$.value) {\n    <div (click)=\"$event.stopPropagation()\">\n      <!-- Disable overwriting of the preset name if not changeable-->\n      @if (presetsService.checkIfChangeablePreset(activePresetName[0], activePresetName[1])) {\n        <div class=\"preset-start-container\">\u00C4nderungen speichern</div>\n        <form (ngSubmit)=\"onPresetFormSubmit()\" [formGroup]=\"presetMenuForm\" class=\"save-preset-form\">\n          <talenra-form-field label=\"View Name\">\n            <input\n              #savePresetInput\n              (keydown.tab)=\"stopTabClosingMenu($event)\"\n              class=\"save-preset-input\"\n              data-testid=\"inbox-overwrite-preset-input\"\n              formControlName=\"fcn\"\n              maxlength=\"30\"\n              talenra-input />\n          </talenra-form-field>\n          <button\n            (keydown.tab)=\"stopTabClosingMenu($event)\"\n            [disabled]=\"!savePresetName()\"\n            data-testid=\"inbox-save-overwrite-preset\"\n            icon=\"check\"\n            kind=\"ghost\"\n            talenra-button\n            talenraTooltip=\"View speichern\"\n            size=\"s\"\n            type=\"submit\"></button>\n        </form>\n      }\n      <div class=\"preset-start-container\">Als neue View speichern</div>\n      <form (ngSubmit)=\"saveNewPresetFormSubmit()\" [formGroup]=\"saveNewPresetMenuForm\" class=\"save-preset-form\">\n        <talenra-form-field label=\"View Name\">\n          <input\n            #saveNewPresetInput\n            (keydown.tab)=\"stopTabClosingMenu($event)\"\n            class=\"save-preset-input\"\n            data-testid=\"inbox-new-preset-input\"\n            formControlName=\"fcn\"\n            maxlength=\"30\"\n            talenra-input />\n        </talenra-form-field>\n        <button\n          (keydown.tab)=\"stopTabClosingMenu($event)\"\n          [disabled]=\"!saveNewPresetName()\"\n          data-testid=\"inbox-save-new-preset\"\n          icon=\"check\"\n          kind=\"ghost\"\n          talenra-button\n          talenraTooltip=\"Neue View speichern\"\n          size=\"s\"\n          type=\"submit\"></button>\n      </form>\n    </div>\n  }\n</mat-menu>\n", styles: [":host{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;--color-background: #ffffff;--color-light-background: #f2f2f2;--color-title-icon: #666666}.preset-title{text-align:center;margin-bottom:.125rem}.preset-groups-scroll-container{width:23.75rem;min-height:fit-content;max-height:24.375rem}.inbox-mat-expansion-panel-header{padding:0 .3125rem;height:2rem!important}.preset-start-container{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center;padding:1rem 1rem 0;font-weight:500}.presets-drop-lists{cursor:grabbing}.preset-items{position:relative;background:var(--color-background);height:2.25rem;margin-left:.875rem;border-radius:.1875rem;display:grid;grid-template-columns:93% 7%;grid-template-rows:1fr;grid-auto-flow:row}.preset-items:hover:not(.disable-hover){background:var(--color-light-background)}.preset-items:hover:not(.disable-hover) .preset-name-input{background:var(--color-light-background)}.preset-items-grab{display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto;align-self:center;justify-self:center}.preset-items-tag{display:flex;align-items:center;justify-content:space-between;height:1.5rem;width:100%;align-self:center;justify-self:center}.preset-items-tag:hover:not(.disable-hover){background:var(--color-light-background)}.preset-items-buttons{height:1.5rem;display:flex;align-items:center;flex-wrap:nowrap;flex-direction:row}.interaction-buttons{height:1.5rem}.no-padding{padding:0}.save-preset-form{display:flex;flex-direction:row;align-items:center;padding:0 1rem}.save-preset-input{width:20.3125rem}.preset-name-input{height:1.125rem;padding:0;border:none;outline:none;resize:none;border-radius:.25rem;margin-bottom:-.25rem;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;cursor:move;background:var(--color-background)}.preset-name-input:hover:not(.disable-hover){background:var(--color-light-background)}.preset-name-input-wide{flex-grow:1;max-width:100%}.custom-drag-preset-item-placeholder{margin-left:.875rem;background:var(--color-light-background);min-height:2.25rem;transition:transform .25s cubic-bezier(0,0,.2,1)}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em}.btn{padding:0;margin:0 .5rem}.check-button{margin-right:2.625rem}.preset-icon{color:var(--color-title-icon);font-size:1rem}.move-cursor{cursor:move}.move-cursor :active{cursor:grabbing}.text-cursor{cursor:text}.grabbing-cursor{cursor:grabbing}.default-cursor{cursor:default}.empty-preset-icon-placeholder{width:1.5rem;height:1.5rem}::ng-deep .mat-mdc-menu-panel.mat-mdc-menu-panel.talenra-inbox-toolbar-preset-menu{min-width:25rem;max-width:28.125rem;overflow:hidden}::ng-deep .remove-mat-expansion-panel-padding .mat-expansion-panel-content .mat-expansion-panel-body{padding:0;background-color:var(--color-background)}.remove-mat-expansion-panel-padding .mat-expansion-panel-header-title{padding-left:.625rem}.mat-accordion .mat-expansion-panel:last-of-type{border-bottom-right-radius:0;border-bottom-left-radius:0}.mat-expansion-panel:not([class*=mat-elevation-z]){box-shadow:none!important}.appearance--dark :host{--color-background: #333333;--color-light-background: #f2f2f2}\n"] }]
        }], propDecorators: { presetGroups: [{
                type: Input
            }], presetInteractions: [{
                type: Output
            }], talenraInboxPresetMenuTrigger: [{
                type: ViewChild,
                args: ['talenraInboxPresetMenuTrigger']
            }], savePresetInput: [{
                type: ViewChild,
                args: ['savePresetInput']
            }], saveNewPresetInput: [{
                type: ViewChild,
                args: ['saveNewPresetInput']
            }] } });

/**
 * The toolbar is an important component that allows to access needed data from the data items list faster and increase
 * the usability.
 *
 * ```html
 * <talenra-inbox-toolbar
 *   [disabledButtons]="disabledButtons"
 *   [checkedForm]="checkedForm"
 *   (iconBtn)="iconBtnFunction($event)"
 * ></talenra-inbox-toolbar>
 * ```
 */
class InboxToolbarComponent {
    constructor() {
        /**
         * Input to define the pre-set options group.
         */
        this.presetGroups = [];
        /**
         * Input to disable checkbox behavior and UI.
         */
        this.disableBulkInteractionButtons = false;
        /**
         * Input to disable the detail view tab change button in the toolbar and set it to a fixed state.
         * Used to set state if no data items are found.
         */
        this.fixDisableDetailViewToggle = false;
        /**
         * Number of marked data items.
         */
        this.numberMarkedDataItems = 0;
        /**
         * Boolean to show if the data is to be refreshed.
         */
        this.refreshing = false;
        /**
         * Checkbox state of the toolbar checkbox.
         */
        this.checkboxState = CheckboxState.Outline;
        /**
         * EventEmitter for icon button clicks.
         */
        this.iconBtn = new EventEmitter();
        /**
         * EventEmitter for icon button clicks.
         */
        this.presetInteractions = new EventEmitter();
        /**
         * EventEmitter to delete preset.
         */
        this.deletePreset = new EventEmitter();
        /**
         * EventEmitter to change preset name
         */
        this.changePresetName = new EventEmitter();
        /**
         * Emitter for the change in the checkbox state of the toolbar checkbox.
         */
        this.checkboxStateChange = new EventEmitter();
        /**
         * Emitter to reset the preset to the default preset.
         */
        this.resetPreset = output();
        /**
         * Form for checkbox interaction.
         */
        this.checkedForm = new FormGroup({
            check: new FormControl({ value: false, disabled: false }),
        });
        /**
         * List style for the checkbox behavior and UI.
         */
        this.checkboxIndeterminate = false;
        /**
         * Width of the toolbar.
         * Used to show compressed or toolbar buttons into menu.
         */
        this.toolbarWidth = signal(0);
        /**
         * The width of the line break setting.
         */
        this.LINEBREAKWIDTH = 659;
        /**
         * The inbox service.
         */
        this.inboxState = inject(InboxState);
        /**
         * The inbox service.
         */
        this.filterState = inject(FilterStateService);
        /**
         * The inbox detail view service.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
        /**
         * The data items service.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * The inbox toolbar service.
         */
        this.inboxToolbarService = inject(InboxToolbarService);
        /**
         * The preset change service.
         */
        this.changedPresetValuesService = inject(ChangedPresetValuesService);
        /**
         * The filter toolbar service.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        /**
         * The keyboard service.
         * @internal
         * @private
         */
        this.keyboardService = inject(KeyboardService);
        /**
         * Semaphore to stop accessing checkbox value a second time.
         * @internal
         */
        this.checkboxSemaphore = new BehaviorSubject(false);
        /**
         * The subscriptions of the inbox toolbar component.
         * @internal
         * @private
         */
        this.subscriptions = new Subscription();
        /**
         * The element reference.
         * @internal
         * @private
         */
        this.elementRef = inject(ElementRef);
        /**
         * The zone.
         * @internal
         * @private
         */
        this.zone = inject(NgZone);
        /**
         * Initializes the subscriptions of the resize observable.
         * @internal
         */
        this.observer = new ResizeObserver((entries) => {
            this.zone.run(() => {
                this.toolbarWidth.set(entries[0].contentRect.width);
            });
        });
        /**
         * Handles the click event of the condensed toolbar menu.
         * @param toolbarAction The menu component which is clicked.
         */
        this.condensedToolbarMenu = (toolbarAction) => {
            switch (toolbarAction.icon()) {
                case 'reorder':
                case 'vertical-split':
                    this.onDetailsClick(new MouseEvent('click'));
                    break;
                case 'unfold-less':
                case 'unfold-more':
                    this.onCompressClick(new MouseEvent('click'));
                    break;
                case 'edit-square':
                    this.openConfigurationPanel(new MouseEvent('click'), 'attribute-settings');
                    break;
                case 'sort':
                    this.openConfigurationPanel(new MouseEvent('click'), 'sort');
                    break;
                case 'filter-alt':
                    this.openConfigurationPanel(new MouseEvent('click'), 'filter');
                    break;
                case 'undo':
                    this.resetPresetToDefault();
                    break;
                case 'file-download':
                    this.onDownloadClick(new MouseEvent('click'));
                    break;
                default:
                    break;
            }
        };
    }
    /**
     * Initializes the inbox toolbar component.
     * @internal
     */
    ngOnInit() {
        // subscription for the checkbox state change by the user
        this.subscriptions.add(this.checkedForm.get('check')?.valueChanges.subscribe((value) => {
            if (value && !this.checkboxSemaphore.value) {
                // emit checkbox state change for default inbox functionality
                this.checkboxStateChange.emit(CheckboxState.Checked);
                // set checkbox state to checked in service
                this.inboxToolbarService.setCheckboxState(CheckboxState.Checked);
            }
            else if (!value && !this.checkboxSemaphore.value) {
                // emit checkbox state change for default inbox functionality
                this.checkboxStateChange.emit(CheckboxState.Outline);
                // set checkbox state to checked in service
                this.inboxToolbarService.setCheckboxState(CheckboxState.Outline);
            }
            // set semaphore to false
            this.checkboxSemaphore.next(false);
        }));
        // subscription for the checkbox change by the consuming application through the service
        this.subscriptions.add(this.inboxToolbarService.checkboxState$.subscribe((value) => {
            this.changeCheckboxState(value);
        }));
        this.subscriptions.add(this.keyboardService.escapeKeyPressed.subscribe((value) => {
            // unsubscribe from window resizing event, for performance reasons
            if (value && this.resizeSubscription$) {
                this.resizeSubscription$.unsubscribe();
            }
            value && this.talenraInboxToolbarMenuTrigger?.closeMenu();
        }));
        // subscription if the public api is used to open/close the actions menu
        this.subscriptions.add(this.inboxState.actionMenuExpanded$.subscribe((value) => {
            if (!this.inboxState.actionsMenuClickFlag.value) {
                this.interactionActionMenuSubscriptions(value);
            }
        }));
        // add first element of component (component itself) to resize observer
        this.observer.observe(this.elementRef.nativeElement.firstElementChild);
    }
    /**
     * Called when the component input is changed.
     * @internal
     * @param changes The changes of the component.
     */
    ngOnChanges(changes) {
        const checkboxStateChange = changes['checkboxState'];
        if (checkboxStateChange && !checkboxStateChange.firstChange) {
            this.changeCheckboxState(checkboxStateChange.currentValue);
        }
    }
    /**
     * Unsubscribes and unobserved from all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.observer.unobserve(this.elementRef.nativeElement.firstElementChild);
        this.subscriptions.unsubscribe();
    }
    /**
     * Click event emit that attribute settings side panel will open.
     * @param {MouseEvent} event Click event.
     * @param {string} tab The tab to open.
     */
    openConfigurationPanel(event, tab) {
        event?.stopPropagation();
        // set active tab in side panel
        this.inboxState.setSelectedSidePanelTab(tab);
        this.inboxToolbarService.setConfigurationPanelState(true);
    }
    /**
     * Click event emit that inbox detail view side panel will close.
     * @param {MouseEvent} event Click event.
     */
    onDetailsClick(event) {
        if (this.inboxDetailViewService.detailViewExpanded$.value && !this.fixDisableDetailViewToggle) {
            this.iconBtn.emit('vertical-split');
        }
        else if (!this.inboxDetailViewService.detailViewExpanded$.value && !this.fixDisableDetailViewToggle) {
            this.iconBtn.emit('reorder');
        }
        event.stopPropagation();
    }
    /**
     * Click event emit that 'unfold-less' and 'unfold-more' icon will switch.
     * @param {MouseEvent} event Click event.
     */
    onCompressClick(event) {
        this.iconBtn.emit('compress');
        event.stopPropagation();
    }
    /**
     * Click event emit that a CSV can be downloaded.
     * @param {MouseEvent} event Click event.
     */
    onDownloadClick(event) {
        this.iconBtn.emit('file-download');
        event.stopPropagation();
    }
    /**
     * Click event emit that more actions can be seen.
     * @param {string} source The source of the click event.
     */
    onGetActionsClick(source) {
        if (source === 'mouse') {
            // set action menu expanded to true
            this.inboxState.setActionsMenuClickFlag(true);
            this.inboxState.setActionMenuExpanded(true);
            this.inboxState.setActionsMenuClickFlag(false);
        }
        this.iconBtn.emit('more_vert-bulk');
        // subscribe to window resizing event to close when window is resized
        this.resizeObservable$ = fromEvent(window, 'resize');
        this.resizeSubscription$ = this.resizeObservable$.subscribe(() => {
            // close menu when window is resized and unsubscribe from window resizing event, for performance reasons
            this.talenraInboxToolbarMenuTrigger?.closeMenu();
            this.resizeSubscription$.unsubscribe();
        });
    }
    /**
     * Click event emit that the process can start.
     */
    onStartProcessClick() {
        this.iconBtn.emit('arrow-forward-bulk');
    }
    /**
     * Handler for the preset interactions.
     * @param event The event of the preset interactions.
     */
    onPresetInteractions(event) {
        this.presetInteractions.emit(event);
    }
    /**
     * Click event emit that the refresh btn is clicked.
     */
    onRefreshClick() {
        if (!this.refreshing) {
            this.refreshing = true;
            this.iconBtn.emit('refresh');
        }
    }
    /**
     * Handles the closing of the action menu.
     * Sets the value for the public api.
     */
    onActionsMenuClosed() {
        this.inboxState.setActionMenuExpanded(false);
    }
    /**
     * Function to reset the preset to the default preset.
     */
    resetPresetToDefault() {
        // reset active icon filters
        this.deleteIconFilters();
        // reset simple filter selection
        this.filterState.resetSimpleFilterSelection();
        // reset sort selection
        this.filterState.resetSortSelection();
        // reset the buffer filter and sort (to preset standard)
        this.inboxState.resetBufferFilterSort();
        // reset the preset to the default preset
        this.resetPreset.emit();
    }
    /**
     * Handles the opening of the action menu if accessed by a subscription.
     * @param value The value of the subscription.
     */
    interactionActionMenuSubscriptions(value) {
        if (value && (!this.disableBulkInteractionButtons || this.inboxToolbarService.selectedItemsCount$.value > 1)) {
            // set action menu expanded to true
            this.inboxState.setActionsMenuClickFlag(true);
            this.inboxState.setActionMenuExpanded(true);
            this.inboxState.setActionsMenuClickFlag(false);
            this.talenraInboxToolbarMenuTrigger?.openMenu();
            this.onGetActionsClick();
        }
        else if (!value && this.disableBulkInteractionButtons && this.talenraInboxToolbarMenuTrigger) {
            // unsubscribe from window resizing event, for performance reasons
            if (this.resizeSubscription$) {
                this.resizeSubscription$.unsubscribe();
            }
            this.talenraInboxToolbarMenuTrigger.closeMenu();
        }
        else if (!value) {
            this.talenraInboxToolbarMenuTrigger &&
                this.talenraInboxToolbarMenuTrigger.menuOpen &&
                this.talenraInboxToolbarMenuTrigger.closeMenu();
        }
    }
    /**
     * Changes the checkbox state in the form.
     * @param value The value of the checkbox state.
     * @private
     */
    changeCheckboxState(value) {
        this.checkboxSemaphore.next(true);
        switch (value) {
            case CheckboxState.Outline:
                this.checkedForm.get('check')?.setValue(false);
                this.checkboxIndeterminate = false;
                break;
            case CheckboxState.Indeterminate:
                this.checkedForm.get('check')?.setValue(false);
                this.checkboxIndeterminate = true;
                break;
            case CheckboxState.Checked:
                this.checkedForm.get('check')?.setValue(true);
                this.checkboxIndeterminate = false;
                break;
            default:
                break;
        }
    }
    /**
     * Delete all icon filters.
     */
    deleteIconFilters() {
        this.filterState.iconFilterSubject$.value.forEach((iconFilter) => {
            iconFilter.active = false;
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxToolbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: InboxToolbarComponent, isStandalone: true, selector: "talenra-inbox-toolbar", inputs: { presetGroups: "presetGroups", disableBulkInteractionButtons: "disableBulkInteractionButtons", fixDisableDetailViewToggle: "fixDisableDetailViewToggle", numberMarkedDataItems: "numberMarkedDataItems", refreshing: "refreshing", checkboxState: "checkboxState" }, outputs: { iconBtn: "iconBtn", presetInteractions: "presetInteractions", deletePreset: "deletePreset", changePresetName: "changePresetName", checkboxStateChange: "checkboxStateChange", resetPreset: "resetPreset" }, viewQueries: [{ propertyName: "talenraInboxToolbarMenuTrigger", first: true, predicate: ["talenraInboxToolbarMenuTrigger"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div class=\"main-container\">\n  <div class=\"action-buttons\">\n    <div #inboxToolbarCustomSpace>\n      <ng-content select=\"[custom-toolbar-space]\"></ng-content>\n    </div>\n\n    @if (inboxToolbarCustomSpace.children.length) {\n      <div class=\"vertical-divider collapsed\"></div>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <button\n        (click)=\"openConfigurationPanel($event, 'attribute-settings')\"\n        class=\"btn\"\n        data-testid=\"inbox-attributes-button\"\n        icon=\"edit-square\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Anzeige Fall-Informationen\"\n        size=\"m\"></button>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableFilterSelection) {\n      <button\n        (click)=\"openConfigurationPanel($event, 'filter')\"\n        class=\"btn\"\n        data-testid=\"inbox-filter-selection-button\"\n        icon=\"filter-alt\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Filterung\"\n        size=\"m\"></button>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableSortSelection) {\n      <button\n        (click)=\"openConfigurationPanel($event, 'sort')\"\n        class=\"btn\"\n        data-testid=\"inbox-sort-selection-button\"\n        icon=\"sort\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Sortierung\"\n        size=\"m\"></button>\n    }\n\n    @if (!inboxState.inboxConfiguration$.value.disablePresetMenuToolbar && presetGroups !== undefined) {\n      <talenra-presets (presetInteractions)=\"onPresetInteractions($event)\" [presetGroups]=\"presetGroups\"></talenra-presets>\n    }\n\n    @if (\n      ((!inboxState.inboxConfiguration$.value.disablePresetMenuToolbar && presetGroups !== undefined) ||\n        !inboxState.inboxConfiguration$.value.disableSortSelection ||\n        !inboxState.inboxConfiguration$.value.disableFilterSelection ||\n        !inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) &&\n      toolbarWidth() > LINEBREAKWIDTH\n    ) {\n      <button\n        [disabled]=\"(changedPresetValuesService.filterSortChangedSubject$ | async) === false\"\n        (click)=\"resetPresetToDefault()\"\n        [class.undo-btn-active]=\"changedPresetValuesService.filterSortChangedSubject$ | async\"\n        class=\"btn\"\n        talenra-button\n        kind=\"ghost\"\n        icon=\"undo\"\n        talenraTooltip=\"Alle zur\u00FCcksetzen\"\n        data-testid=\"inbox-filter-sort-undo-button\"></button>\n    }\n\n    @if (\n      !(\n        inboxState.inboxConfiguration$.value.disablePresetMenuToolbar &&\n        presetGroups !== undefined &&\n        inboxState.inboxConfiguration$.value.disableDetailViewToggleToolbar &&\n        inboxState.inboxConfiguration$.value.disableCompressedDataListItemsToolbar\n      ) && !inboxState.inboxConfiguration$.value.disableRefreshToolbar\n    ) {\n      <div class=\"vertical-divider collapsed\"></div>\n    }\n\n    @if (toolbarWidth() <= LINEBREAKWIDTH) {\n      <div\n        [triggerFor]=\"condensedMenu\"\n        class=\"btn condensed-menu-anchor\"\n        data-testid=\"inbox-advanced-menu-button\"\n        talenraMenuAnchor\n        talenraTooltip=\"Erweitertes Menu\">\n        <talenra-icon name=\"more-horiz\"></talenra-icon>\n      </div>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH &&\n      !inboxState.inboxConfiguration$.value.disablePresetMenuToolbar &&\n      presetGroups !== undefined\n    ) {\n      <button\n        [kind]=\"'ghost'\"\n        [size]=\"'m'\"\n        [waiting]=\"refreshing\"\n        class=\"btn talenra-btn\"\n        icon=\"list\"\n        disabled=\"true\"\n        talenra-button\n        talenraTooltip=\"View \u00E4ndern\"></button>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH &&\n      !inboxState.inboxConfiguration$.value.disableDetailViewToggleToolbar &&\n      !inboxState.inboxConfiguration$.value.disableDetailView\n    ) {\n      <button\n        (click)=\"onDetailsClick($event)\"\n        [disabled]=\"refreshing || fixDisableDetailViewToggle\"\n        [icon]=\"\n          (inboxDetailViewService.detailViewExpanded$ | async) || fixDisableDetailViewToggle\n            ? 'reorder'\n            : 'vertical-split'\n        \"\n        [talenraTooltip]=\"\n          (inboxDetailViewService.detailViewExpanded$ | async) || fixDisableDetailViewToggle\n            ? 'Detaileinsicht aus'\n            : 'Detaileinsicht ein'\n        \"\n        class=\"btn\"\n        data-testid=\"inbox-detail-view-toggle\"\n        kind=\"ghost\"\n        talenra-button\n        size=\"m\"></button>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableCompressedDataListItemsToolbar\n    ) {\n      <button\n        (click)=\"onCompressClick($event)\"\n        [disabled]=\"refreshing\"\n        [icon]=\"(dataItemsService.compressedDataItem$ | async) ? 'unfold-more' : 'unfold-less'\"\n        [talenraTooltip]=\"(dataItemsService.compressedDataItem$ | async) ? 'Hinweise ein' : 'Hinweise aus'\"\n        class=\"btn\"\n        data-testid=\"inbox-icon-notes-button\"\n        kind=\"ghost\"\n        talenra-button\n        size=\"m\"></button>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH &&\n      !(\n        inboxState.inboxConfiguration$.value.disableRefreshToolbar &&\n        inboxState.inboxConfiguration$.value.disableCSVExportToolbar\n      )\n    ) {\n      <div [class.collapsed]=\"toolbarWidth() > LINEBREAKWIDTH\" class=\"vertical-divider\"></div>\n    }\n\n    @if (!inboxState.inboxConfiguration$.value.disableRefreshToolbar) {\n      <button\n        (click)=\"onRefreshClick()\"\n        [kind]=\"'ghost'\"\n        [size]=\"'m'\"\n        [waiting]=\"refreshing\"\n        class=\"btn talenra-btn\"\n        data-testid=\"inbox-refresh-button\"\n        icon=\"refresh\"\n        talenra-button\n        talenraTooltip=\"Aktualisieren\"></button>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableCSVExportToolbar) {\n      <button\n        (click)=\"onDownloadClick($event)\"\n        [disabled]=\"refreshing\"\n        class=\"btn\"\n        data-testid=\"inbox-csv-button\"\n        icon=\"file-download\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"CSV herunterladen\"\n        size=\"m\"></button>\n    }\n\n    @if (!inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar) {\n      <div class=\"vertical-divider collapsed\"></div>\n    }\n\n    @if (\n      !inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar &&\n      !inboxState.inboxConfiguration$.value.disableCheckboxInteractionsToolbar\n    ) {\n      <div [formGroup]=\"checkedForm\" class=\"checkbox-wrapper\" data-testid=\"inbox-checkbox-select-all\">\n        <talenra-checkbox\n          [(indeterminate)]=\"checkboxIndeterminate\"\n          [talenraTooltip]=\"checkboxState === 'checked' ? 'Alle abw\u00E4hlen' : 'Alle ausw\u00E4hlen'\"\n          class=\"ui-checkbox\"\n          formControlName=\"check\">\n        </talenra-checkbox>\n        <talenra-badge\n          [counter]=\"\n            inboxToolbarService.selectedItemsCount$.value > -1\n              ? inboxToolbarService.selectedItemsCount$.value\n              : this.numberMarkedDataItems\n          \"\n          [maxVal]=\"inboxState.inboxConfiguration$.value.maxBadgeCounterToolbar\"\n          class=\"badge\"\n          data-testid=\"inbox-toolbar-checkbox-badge\"></talenra-badge>\n      </div>\n    }\n\n    @if (\n      !inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar &&\n      !inboxState.inboxConfiguration$.value.disableBulkFurtherInteractionsToolbar\n    ) {\n      <button\n        #talenraInboxToolbarMenuTrigger=\"matMenuTrigger\"\n        (click)=\"onGetActionsClick('mouse')\"\n        (menuClosed)=\"onActionsMenuClosed()\"\n        [disabled]=\"\n          (disableBulkInteractionButtons && -1 === inboxToolbarService.selectedItemsCount$.value) ||\n          (inboxToolbarService.selectedItemsCount$.value > -1 && inboxToolbarService.selectedItemsCount$.value <= 1) ||\n          refreshing\n        \"\n        [matMenuTriggerFor]=\"furtherActions\"\n        class=\"btn bulk-more-btn\"\n        icon=\"more-vert\"\n        id=\"talenraInboxToolbarMenuTrigger\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Sammelaktionen\"\n        size=\"m\"></button>\n    }\n\n    @if (\n      !inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar &&\n      !inboxState.inboxConfiguration$.value.disableBulkContinueButtonToolbar\n    ) {\n      <button\n        (click)=\"onStartProcessClick()\"\n        [class.hide-further-actions]=\"inboxState.inboxConfiguration$.value.disableBulkFurtherInteractionsToolbar\"\n        [disabled]=\"\n          (disableBulkInteractionButtons && -1 === inboxToolbarService.selectedItemsCount$.value) ||\n          (inboxToolbarService.selectedItemsCount$.value > -1 && inboxToolbarService.selectedItemsCount$.value <= 1) ||\n          refreshing\n        \"\n        class=\"btn bulk-process-btn\"\n        data-testid=\"inbox-process-toolbar-button\"\n        icon=\"arrow-forward\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Mehrere F\u00E4lle ausf\u00FChren\"\n        size=\"m\"></button>\n    }\n  </div>\n</div>\n\n<ng-template #condensedMenu>\n  <talenra-menu>\n    <talenra-menu-title label=\"Menu\" />\n    <talenra-menu-separator></talenra-menu-separator>\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link\n        icon=\"edit-square\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        label=\"Anzeige Fall-Informationen \u00E4ndern\"\n        shortcut=\"X\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link icon=\"filter-alt\" [selectCallback]=\"condensedToolbarMenu\" label=\"Filter\" shortcut=\"F\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link icon=\"sort\" [selectCallback]=\"condensedToolbarMenu\" label=\"Sort\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link\n        [disabled]=\"(changedPresetValuesService.filterSortChangedSubject$ | async) === false\"\n        icon=\"undo\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        label=\"\u00C4nderungen zur\u00FCcksetzen\" />\n    }\n    <talenra-menu-separator></talenra-menu-separator>\n    @if (\n      !inboxState.inboxConfiguration$.value.disableDetailViewToggleToolbar &&\n      !inboxState.inboxConfiguration$.value.disableDetailView\n    ) {\n      <talenra-menu-link\n        [disabled]=\"fixDisableDetailViewToggle\"\n        [icon]=\"inboxDetailViewService.detailViewExpanded$.value ? 'vertical-split' : 'reorder'\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        [label]=\"inboxDetailViewService.detailViewExpanded$.value ? 'Detailansicht aus' : 'Detailansicht ein'\"\n        shortcut=\"Y\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableCompressedDataListItemsToolbar) {\n      <talenra-menu-link\n        [icon]=\"inboxDetailViewService.detailViewExpanded$.value ? 'unfold-less' : 'unfold-more'\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        [label]=\"dataItemsService.compressedDataItem$.value ? 'Hinweise aus' : 'Hinweise ein'\"\n        shortcut=\"I\" />\n    }\n    <talenra-menu-separator></talenra-menu-separator>\n    @if (!inboxState.inboxConfiguration$.value.disableCSVExportToolbar) {\n      <talenra-menu-link icon=\"file-download\" [selectCallback]=\"condensedToolbarMenu\" label=\"CSV herunterladen\" />\n    }\n    <talenra-menu-separator></talenra-menu-separator>\n  </talenra-menu>\n</ng-template>\n\n<mat-menu #furtherActions hasBackdrop=\"true\" xPosition=\"before\">\n  <ng-content select=\"[further-actions-menu]\"></ng-content>\n</mat-menu>\n", styles: [":host{--color-background: #ffffff;--color-vertical-divider: #e6e6e6;--color-primary: #0099a8}div[matExpansionPanelBody].test{padding:0}.main-container{height:3.125rem;background:var(--color-background);padding-left:1.5rem;border-radius:.1875rem}.action-buttons{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:flex-end;align-items:center;margin-right:1rem}.vertical-divider{border-left:.0625rem solid var(--color-vertical-divider);border-radius:.0625rem;opacity:0;height:0;margin:0;transition:opacity .3s,height .3s,margin .3s}.vertical-divider.collapsed{opacity:1;height:32px;margin:9px 16px}.checkbox-wrapper{position:relative}.badge{position:absolute;top:0;right:0;transform:translateY(-.375rem) translate(.625rem)}.condensed-menu-anchor{color:#666}.condensed-menu-anchor :hover{background-color:#f2f2f2}.bulk-more-btn:focus{outline:none}.btn{padding:0;margin:0 .5rem}.talenra-btn{margin:0 6px}.undo-btn-active{color:var(--color-primary)}.ui-checkbox{margin:0 0 0 .5rem}.bulk-more-btn{margin:0 .5rem}.bulk-process-btn{margin:0}.hide-further-actions{margin:0 0 0 8px}.icon-deactivated{color:#b3b3b3}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-vertical-divider: #4d4d4d}\n"], dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "component", type: PresetsComponent, selector: "talenra-presets", inputs: ["presetGroups"], outputs: ["presetInteractions"] }, { kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "directive", type: MenuAnchorDirective, selector: "[talenraMenuAnchor]", outputs: ["menuOpen", "menuClose"] }, { kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: CheckboxComponent, selector: "talenra-checkbox", inputs: ["size", "labelPosition", "indeterminate", "pointerDisabled"], outputs: ["indeterminateChange", "checkedChange"] }, { kind: "component", type: BadgeComponent, selector: "talenra-badge", inputs: ["counter", "maxVal"] }, { kind: "directive", type: MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", inputs: ["mat-menu-trigger-for", "matMenuTriggerFor", "matMenuTriggerData", "matMenuTriggerRestoreFocus"], outputs: ["menuOpened", "onMenuOpen", "menuClosed", "onMenuClose"], exportAs: ["matMenuTrigger"] }, { kind: "component", type: MenuComponent, selector: "talenra-menu" }, { kind: "component", type: MenuTitleComponent, selector: "talenra-menu-title", inputs: ["label"] }, { kind: "component", type: MenuSeparatorComponent, selector: "talenra-menu-separator" }, { kind: "component", type: MenuLinkComponent, selector: "talenra-menu-link", inputs: ["label", "icon", "routerLink", "shortcut", "actionIcon", "selectCallback", "actionIconDisabled", "disabled"] }, { kind: "component", type: MatMenu, selector: "mat-menu", inputs: ["backdropClass", "aria-label", "aria-labelledby", "aria-describedby", "xPosition", "yPosition", "overlapTrigger", "hasBackdrop", "class", "classList"], outputs: ["closed", "close"], exportAs: ["matMenu"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-toolbar', standalone: true, imports: [
                        ButtonComponent,
                        TooltipDirective,
                        PresetsComponent,
                        AsyncPipe,
                        MenuAnchorDirective,
                        IconComponent,
                        ReactiveFormsModule,
                        CheckboxComponent,
                        BadgeComponent,
                        MatMenuTrigger,
                        MenuComponent,
                        MenuTitleComponent,
                        MenuSeparatorComponent,
                        MenuLinkComponent,
                        MatMenu,
                    ], template: "<div class=\"main-container\">\n  <div class=\"action-buttons\">\n    <div #inboxToolbarCustomSpace>\n      <ng-content select=\"[custom-toolbar-space]\"></ng-content>\n    </div>\n\n    @if (inboxToolbarCustomSpace.children.length) {\n      <div class=\"vertical-divider collapsed\"></div>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <button\n        (click)=\"openConfigurationPanel($event, 'attribute-settings')\"\n        class=\"btn\"\n        data-testid=\"inbox-attributes-button\"\n        icon=\"edit-square\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Anzeige Fall-Informationen\"\n        size=\"m\"></button>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableFilterSelection) {\n      <button\n        (click)=\"openConfigurationPanel($event, 'filter')\"\n        class=\"btn\"\n        data-testid=\"inbox-filter-selection-button\"\n        icon=\"filter-alt\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Filterung\"\n        size=\"m\"></button>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableSortSelection) {\n      <button\n        (click)=\"openConfigurationPanel($event, 'sort')\"\n        class=\"btn\"\n        data-testid=\"inbox-sort-selection-button\"\n        icon=\"sort\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Sortierung\"\n        size=\"m\"></button>\n    }\n\n    @if (!inboxState.inboxConfiguration$.value.disablePresetMenuToolbar && presetGroups !== undefined) {\n      <talenra-presets (presetInteractions)=\"onPresetInteractions($event)\" [presetGroups]=\"presetGroups\"></talenra-presets>\n    }\n\n    @if (\n      ((!inboxState.inboxConfiguration$.value.disablePresetMenuToolbar && presetGroups !== undefined) ||\n        !inboxState.inboxConfiguration$.value.disableSortSelection ||\n        !inboxState.inboxConfiguration$.value.disableFilterSelection ||\n        !inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) &&\n      toolbarWidth() > LINEBREAKWIDTH\n    ) {\n      <button\n        [disabled]=\"(changedPresetValuesService.filterSortChangedSubject$ | async) === false\"\n        (click)=\"resetPresetToDefault()\"\n        [class.undo-btn-active]=\"changedPresetValuesService.filterSortChangedSubject$ | async\"\n        class=\"btn\"\n        talenra-button\n        kind=\"ghost\"\n        icon=\"undo\"\n        talenraTooltip=\"Alle zur\u00FCcksetzen\"\n        data-testid=\"inbox-filter-sort-undo-button\"></button>\n    }\n\n    @if (\n      !(\n        inboxState.inboxConfiguration$.value.disablePresetMenuToolbar &&\n        presetGroups !== undefined &&\n        inboxState.inboxConfiguration$.value.disableDetailViewToggleToolbar &&\n        inboxState.inboxConfiguration$.value.disableCompressedDataListItemsToolbar\n      ) && !inboxState.inboxConfiguration$.value.disableRefreshToolbar\n    ) {\n      <div class=\"vertical-divider collapsed\"></div>\n    }\n\n    @if (toolbarWidth() <= LINEBREAKWIDTH) {\n      <div\n        [triggerFor]=\"condensedMenu\"\n        class=\"btn condensed-menu-anchor\"\n        data-testid=\"inbox-advanced-menu-button\"\n        talenraMenuAnchor\n        talenraTooltip=\"Erweitertes Menu\">\n        <talenra-icon name=\"more-horiz\"></talenra-icon>\n      </div>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH &&\n      !inboxState.inboxConfiguration$.value.disablePresetMenuToolbar &&\n      presetGroups !== undefined\n    ) {\n      <button\n        [kind]=\"'ghost'\"\n        [size]=\"'m'\"\n        [waiting]=\"refreshing\"\n        class=\"btn talenra-btn\"\n        icon=\"list\"\n        disabled=\"true\"\n        talenra-button\n        talenraTooltip=\"View \u00E4ndern\"></button>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH &&\n      !inboxState.inboxConfiguration$.value.disableDetailViewToggleToolbar &&\n      !inboxState.inboxConfiguration$.value.disableDetailView\n    ) {\n      <button\n        (click)=\"onDetailsClick($event)\"\n        [disabled]=\"refreshing || fixDisableDetailViewToggle\"\n        [icon]=\"\n          (inboxDetailViewService.detailViewExpanded$ | async) || fixDisableDetailViewToggle\n            ? 'reorder'\n            : 'vertical-split'\n        \"\n        [talenraTooltip]=\"\n          (inboxDetailViewService.detailViewExpanded$ | async) || fixDisableDetailViewToggle\n            ? 'Detaileinsicht aus'\n            : 'Detaileinsicht ein'\n        \"\n        class=\"btn\"\n        data-testid=\"inbox-detail-view-toggle\"\n        kind=\"ghost\"\n        talenra-button\n        size=\"m\"></button>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableCompressedDataListItemsToolbar\n    ) {\n      <button\n        (click)=\"onCompressClick($event)\"\n        [disabled]=\"refreshing\"\n        [icon]=\"(dataItemsService.compressedDataItem$ | async) ? 'unfold-more' : 'unfold-less'\"\n        [talenraTooltip]=\"(dataItemsService.compressedDataItem$ | async) ? 'Hinweise ein' : 'Hinweise aus'\"\n        class=\"btn\"\n        data-testid=\"inbox-icon-notes-button\"\n        kind=\"ghost\"\n        talenra-button\n        size=\"m\"></button>\n    }\n\n    @if (\n      toolbarWidth() > LINEBREAKWIDTH &&\n      !(\n        inboxState.inboxConfiguration$.value.disableRefreshToolbar &&\n        inboxState.inboxConfiguration$.value.disableCSVExportToolbar\n      )\n    ) {\n      <div [class.collapsed]=\"toolbarWidth() > LINEBREAKWIDTH\" class=\"vertical-divider\"></div>\n    }\n\n    @if (!inboxState.inboxConfiguration$.value.disableRefreshToolbar) {\n      <button\n        (click)=\"onRefreshClick()\"\n        [kind]=\"'ghost'\"\n        [size]=\"'m'\"\n        [waiting]=\"refreshing\"\n        class=\"btn talenra-btn\"\n        data-testid=\"inbox-refresh-button\"\n        icon=\"refresh\"\n        talenra-button\n        talenraTooltip=\"Aktualisieren\"></button>\n    }\n\n    @if (toolbarWidth() > LINEBREAKWIDTH && !inboxState.inboxConfiguration$.value.disableCSVExportToolbar) {\n      <button\n        (click)=\"onDownloadClick($event)\"\n        [disabled]=\"refreshing\"\n        class=\"btn\"\n        data-testid=\"inbox-csv-button\"\n        icon=\"file-download\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"CSV herunterladen\"\n        size=\"m\"></button>\n    }\n\n    @if (!inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar) {\n      <div class=\"vertical-divider collapsed\"></div>\n    }\n\n    @if (\n      !inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar &&\n      !inboxState.inboxConfiguration$.value.disableCheckboxInteractionsToolbar\n    ) {\n      <div [formGroup]=\"checkedForm\" class=\"checkbox-wrapper\" data-testid=\"inbox-checkbox-select-all\">\n        <talenra-checkbox\n          [(indeterminate)]=\"checkboxIndeterminate\"\n          [talenraTooltip]=\"checkboxState === 'checked' ? 'Alle abw\u00E4hlen' : 'Alle ausw\u00E4hlen'\"\n          class=\"ui-checkbox\"\n          formControlName=\"check\">\n        </talenra-checkbox>\n        <talenra-badge\n          [counter]=\"\n            inboxToolbarService.selectedItemsCount$.value > -1\n              ? inboxToolbarService.selectedItemsCount$.value\n              : this.numberMarkedDataItems\n          \"\n          [maxVal]=\"inboxState.inboxConfiguration$.value.maxBadgeCounterToolbar\"\n          class=\"badge\"\n          data-testid=\"inbox-toolbar-checkbox-badge\"></talenra-badge>\n      </div>\n    }\n\n    @if (\n      !inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar &&\n      !inboxState.inboxConfiguration$.value.disableBulkFurtherInteractionsToolbar\n    ) {\n      <button\n        #talenraInboxToolbarMenuTrigger=\"matMenuTrigger\"\n        (click)=\"onGetActionsClick('mouse')\"\n        (menuClosed)=\"onActionsMenuClosed()\"\n        [disabled]=\"\n          (disableBulkInteractionButtons && -1 === inboxToolbarService.selectedItemsCount$.value) ||\n          (inboxToolbarService.selectedItemsCount$.value > -1 && inboxToolbarService.selectedItemsCount$.value <= 1) ||\n          refreshing\n        \"\n        [matMenuTriggerFor]=\"furtherActions\"\n        class=\"btn bulk-more-btn\"\n        icon=\"more-vert\"\n        id=\"talenraInboxToolbarMenuTrigger\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Sammelaktionen\"\n        size=\"m\"></button>\n    }\n\n    @if (\n      !inboxState.inboxConfiguration$.value.disableBulkInteractionsToolbar &&\n      !inboxState.inboxConfiguration$.value.disableBulkContinueButtonToolbar\n    ) {\n      <button\n        (click)=\"onStartProcessClick()\"\n        [class.hide-further-actions]=\"inboxState.inboxConfiguration$.value.disableBulkFurtherInteractionsToolbar\"\n        [disabled]=\"\n          (disableBulkInteractionButtons && -1 === inboxToolbarService.selectedItemsCount$.value) ||\n          (inboxToolbarService.selectedItemsCount$.value > -1 && inboxToolbarService.selectedItemsCount$.value <= 1) ||\n          refreshing\n        \"\n        class=\"btn bulk-process-btn\"\n        data-testid=\"inbox-process-toolbar-button\"\n        icon=\"arrow-forward\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Mehrere F\u00E4lle ausf\u00FChren\"\n        size=\"m\"></button>\n    }\n  </div>\n</div>\n\n<ng-template #condensedMenu>\n  <talenra-menu>\n    <talenra-menu-title label=\"Menu\" />\n    <talenra-menu-separator></talenra-menu-separator>\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link\n        icon=\"edit-square\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        label=\"Anzeige Fall-Informationen \u00E4ndern\"\n        shortcut=\"X\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link icon=\"filter-alt\" [selectCallback]=\"condensedToolbarMenu\" label=\"Filter\" shortcut=\"F\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link icon=\"sort\" [selectCallback]=\"condensedToolbarMenu\" label=\"Sort\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableAttributeSettingsToolbar) {\n      <talenra-menu-link\n        [disabled]=\"(changedPresetValuesService.filterSortChangedSubject$ | async) === false\"\n        icon=\"undo\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        label=\"\u00C4nderungen zur\u00FCcksetzen\" />\n    }\n    <talenra-menu-separator></talenra-menu-separator>\n    @if (\n      !inboxState.inboxConfiguration$.value.disableDetailViewToggleToolbar &&\n      !inboxState.inboxConfiguration$.value.disableDetailView\n    ) {\n      <talenra-menu-link\n        [disabled]=\"fixDisableDetailViewToggle\"\n        [icon]=\"inboxDetailViewService.detailViewExpanded$.value ? 'vertical-split' : 'reorder'\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        [label]=\"inboxDetailViewService.detailViewExpanded$.value ? 'Detailansicht aus' : 'Detailansicht ein'\"\n        shortcut=\"Y\" />\n    }\n    @if (!inboxState.inboxConfiguration$.value.disableCompressedDataListItemsToolbar) {\n      <talenra-menu-link\n        [icon]=\"inboxDetailViewService.detailViewExpanded$.value ? 'unfold-less' : 'unfold-more'\"\n        [selectCallback]=\"condensedToolbarMenu\"\n        [label]=\"dataItemsService.compressedDataItem$.value ? 'Hinweise aus' : 'Hinweise ein'\"\n        shortcut=\"I\" />\n    }\n    <talenra-menu-separator></talenra-menu-separator>\n    @if (!inboxState.inboxConfiguration$.value.disableCSVExportToolbar) {\n      <talenra-menu-link icon=\"file-download\" [selectCallback]=\"condensedToolbarMenu\" label=\"CSV herunterladen\" />\n    }\n    <talenra-menu-separator></talenra-menu-separator>\n  </talenra-menu>\n</ng-template>\n\n<mat-menu #furtherActions hasBackdrop=\"true\" xPosition=\"before\">\n  <ng-content select=\"[further-actions-menu]\"></ng-content>\n</mat-menu>\n", styles: [":host{--color-background: #ffffff;--color-vertical-divider: #e6e6e6;--color-primary: #0099a8}div[matExpansionPanelBody].test{padding:0}.main-container{height:3.125rem;background:var(--color-background);padding-left:1.5rem;border-radius:.1875rem}.action-buttons{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:flex-end;align-items:center;margin-right:1rem}.vertical-divider{border-left:.0625rem solid var(--color-vertical-divider);border-radius:.0625rem;opacity:0;height:0;margin:0;transition:opacity .3s,height .3s,margin .3s}.vertical-divider.collapsed{opacity:1;height:32px;margin:9px 16px}.checkbox-wrapper{position:relative}.badge{position:absolute;top:0;right:0;transform:translateY(-.375rem) translate(.625rem)}.condensed-menu-anchor{color:#666}.condensed-menu-anchor :hover{background-color:#f2f2f2}.bulk-more-btn:focus{outline:none}.btn{padding:0;margin:0 .5rem}.talenra-btn{margin:0 6px}.undo-btn-active{color:var(--color-primary)}.ui-checkbox{margin:0 0 0 .5rem}.bulk-more-btn{margin:0 .5rem}.bulk-process-btn{margin:0}.hide-further-actions{margin:0 0 0 8px}.icon-deactivated{color:#b3b3b3}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-vertical-divider: #4d4d4d}\n"] }]
        }], propDecorators: { presetGroups: [{
                type: Input
            }], disableBulkInteractionButtons: [{
                type: Input
            }], fixDisableDetailViewToggle: [{
                type: Input
            }], numberMarkedDataItems: [{
                type: Input
            }], refreshing: [{
                type: Input
            }], checkboxState: [{
                type: Input
            }], iconBtn: [{
                type: Output
            }], presetInteractions: [{
                type: Output
            }], deletePreset: [{
                type: Output
            }], changePresetName: [{
                type: Output
            }], checkboxStateChange: [{
                type: Output
            }], talenraInboxToolbarMenuTrigger: [{
                type: ViewChild,
                args: ['talenraInboxToolbarMenuTrigger']
            }] } });

/**
 * Main Component of the Inbox Library, gives an example layout and functionality for an inbox workspace.
 *
 * ```html
 * <talenra-inbox
 *   class="talenra-inbox"
 *   [dataItems]="dataItems"
 *   [loading]="false"
 *   [attributes]="attributes"
 *   [customShortcuts]="customShortcuts"
 *   [detailViewTabs]="detailViewTabs"
 *   [presets]="presets"
 *   [activePresetName]="activePresetName"
 *   (presetAction)="onPresetAction($event)"
 *   (presetsChange)="newPresets($event)"
 *   (clickedDataItemEmitter)="onClickedDataItem($event)"
 *   (dataItemsInteractions)="onDataItemsInteractions($event)"
 *   (virtualScrollerPosition)="onVirtualScrollerPosition($event)"
 * ></talenra-inbox>
 * ```
 */
class InboxComponent {
    /**
     * Constructor of the inbox component.
     * @internal
     * */
    constructor(elementRef) {
        /**
         * Different data items which are used in data items list items and data item information.
         * The data which should be displayed in the inbox.
         *
         * **Important information:**
         *
         * 1. **The Input type is "any[]" so that the inbox can be used with any flattened data structure:**
         * The keys will be used as displayed identifiers for the attributes of the items (the displayedName is able to be customized with the `attributes` input).
         *
         * 2. **The items are not required to have the same data structure:**
         * Attributes of individual items (see example "attribute2 / attribute3") may be missing from item to item.
         * Missing attributes will be displayed as an "–" value.
         *
         * 3. **Attributes with the same key (identifier) have to be of the same type:**
         * Attributes which have the same key (identifier) have to contain the same type of data (e.g. string, number, date). For example `attribute1` are of the same type, here `string`.
         *
         * 4. **The data-items-list has a limited number of attributes for each item:**
         * The `attributes` input can be used to define which attributes should be displayed in the data-items-list or in the detail-view.
         * Default: 12, customizable in the inboxConfiguration of by the presets.
         *
         * 5. **The list items are displayed in a Virtual Scroller:**
         * That means that only the list items which are visible are rendered. This is done to improve the performance of the inbox.
         *
         * 6. **Use attributes input for the complex structure:**
         * If the data has a 'complex' structure and is not flattened, the input `attributes` has to define the identifier to the attribute (see section `attributes`).
         *
         * 7. **If new `dataItems` have to be inputted:**
         * The "refresh" input has be used (set to true) to show the skeleton loading. Otherwise, the new data will not be shown correctly. After the new data is loaded and inputed, the "refresh" input has to be set to false.
         *
         * 8. **The data items are used to fill the single- and multi-select filters:**
         *  If not otherwise specified in the `attributes` input, the data items are used to fill the single- and multi-select filters options.
         *
         * @example
         * <talenra-inbox [attributes]="attributes" [dataItems]="dataItems"></talenra-inbox>
         *
         * @example flattened structure
         * dataItems = [{
         *   attribute1: 'Direkt eingegangene Beschwerde',
         *   attribute2: 'ZH-20230510-0014648',
         *   ...,
         * },
         *   {
         *     attribute1: 'Direkt eingegangene Beschwerde',
         *     attribute3: 'Janssens Mila',
         *     ...,
         *   },
         * ];
         *
         * @example complex structure
         * dataItems = [{
         *   attribute1: 'Direkt eingegangene Beschwerde',
         *   attribute2: 'ZH-20230510-0014648',
         *   attribute3: {
         *     attribute4: 'Janssens Mila',
         *     attribute5: '756.8396.7741.70',
         *   },
         *   ...,
         * },
         *   {
         *     attribute1: 'Direkt eingegangene Beschwerde',
         *     attribute2: 'Janssens Mila',
         *     ...,
         *   },
         * ];
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.dataItems = [];
        /**
         *
         * The presets input is necessary to create and show different presets in the inbox.
         * The user has the possibility to choose between the presets.
         * If the consuming application used the app without the presets input, the inbox won't be able to save or manipulate new presets and existing presets.
         *
         * **Important information:**
         *
         * 1. **The naming of the input type has changed: current `Preset` to `IPreset`**.
         *  The `Preset` has the same properties as the `IPreset`.
         *
         * 2. **Minimum one preset has to be defined with `changeable`: false. That is the default view.**
         *
         * @example
         * <talenra-inbox [attributes]="attributes" [presets]="presets" [activePresetName]="activePresetName"></talenra-inbox>
         *
         * @example
         * const activePresetName = ['Meine Inbox', 'View 1'];
         *
         * @example
         * // Import
         * import { IPreset } from '@talenra/ngx-inbox';
         *
         * const presets: IPreset[] = [{
         *   identifier: '121bd936-ce20-4ea9-9dc1-6cdaf61f9c3d',
         *   name:
         *     'Meine Inbox',
         *   changeable:
         *     false,
         *   selectedAttributes:
         *     [
         *       { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
         *       { identifier: 'case.caseID', defaultAttribute: 'main' },
         *       { identifier: 'processStep', defaultAttribute: 'main' },
         *       { identifier: 'insuree.partnerFlags', defaultAttribute: 'detail' },
         *       { identifier: 'insuree.pvRoles', defaultAttribute: 'detail' },
         *       { identifier: 'case.leadingKpvPartID', defaultAttribute: 'detail' },
         *       { identifier: 'insuree.kpvPartID', defaultAttribute: 'detail' },
         *     ],
         *   children:
         *     [
         *       {
         *         name: 'View 1',
         *         numberMainAttributesChosenByUser: 4,
         *         selectedAttributes: [
         *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
         *           { identifier: 'case.caseID', defaultAttribute: 'main' },
         *           { identifier: 'processStep', defaultAttribute: 'detail' },
         *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
         *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
         *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
         *           { identifier: 'insuree.socialSecurityNumber', defaultAttribute: 'detail' },
         *           { identifier: 'case.casePriority', defaultAttribute: 'main' },
         *         ],
         *         sortAttributes: [
         *           { identifier: 'case.caseTypeName', sort: 'asc' },
         *           { identifier: 'insuree.socialSecurityNumber', sort: 'desc' },
         *         ],
         *         filterAttributes: [
         *           {
         *             identifier: 'case.caseTypeName',
         *             value: ['Direkt eingegangene Beschwerde'],
         *           },
         *           {
         *             identifier: 'case.caseStartDate',
         *             value: [new Date('01.15.2020'), new Date('12.30.2023')],
         *           },
         *           { identifier: 'case.casePriority', value: [1, 2] },
         *         ],
         *         iconAttributes: [],
         *       },
         *       {
         *         name: 'View 2',
         *         numberMainAttributesChosenByUser: 4,
         *         selectedAttributes: [
         *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
         *           { identifier: 'case.caseID', defaultAttribute: 'main' },
         *           { identifier: 'processStep', defaultAttribute: 'detail' },
         *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
         *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
         *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
         *         ],
         *         sortAttributes: [{ identifier: 'case.caseTypeName', sort: 'asc' }],
         *         filterAttributes: [
         *           {
         *             identifier: 'case.caseTypeName',
         *             value: ['Direkt eingegangene Beschwerde'],
         *           },
         *         ],
         *         iconAttributes: [],
         *       },
         *     ],
         * }];
         */
        this.presets = [];
        /**
         * Input `activePresetName` is used to let the inbox know which group or preset was clicked in the app.
         * As the inbox needs to know which group or preset is currently active, activePresetName is provided as an input.
         *
         * If a group is active, then only the group name is filled in the activePresetName input.
         *
         * If a preset is active, then the group name and preset name is filled in the activePresetName input.
         *
         * Most of the time, the active state of the main navigation also have to be set in the consuming app.
         *
         * **Important Information:**
         *
         * 1. **In many cases, `activePresetName` has to be updated after `presets` have been changed.**
         *  The consuming app receives information about what happened to the presets via the presetAction emitter.
         * 2. Also note that the reset button will not work properly if activePresetName is not set correctly.
         *
         * @example
         * <talenra-inbox [attributes]="attributes" [presets]="presets" [activePresetName]="activePresetName"></talenra-inbox>
         *
         * @example
         * // if group is active
         * const activePresetName = ['Meine Inbox'];
         *
         * // if preset in group is active
         * const activePresetName = ['Meine Inbox', 'View 1'];
         */
        this.activePresetName = [];
        /**
         * The detailViewTabs input is used to add tabs to the detail-view.
         *
         * **Important information:**
         *
         * 1. **The naming of the input type has changed: current `DetailViewItemModel[]` to `IInboxTabBarItem[]`**.
         *  The `IInboxTabBarItem` has the same properties as the `DetailViewItemModel`.
         *
         * 2. **The "detailViewTabs" <u>will not be displayed</u> in the inbox, if the html tag of the inbox is contained in an `*ngIf` statement.**
         *
         * 3. **The `counter` attribute has to be a behavior subject, because the counter is updated in the inbox component and the detail view component.**
         *
         * 4. **The `counter` has a maximum value of 99. If the counter is higher than 99, the badge will display "99+".**
         *
         * 5. **Because of the Angular lifecycle, the `detailViewTabs` input has a special declaration in the consuming application.**
         *  The IInboxTabBarItem has a TemplateRef as a property, which is only initialized in `afterViewInit` of the consuming app
         *  The consuming application has to declare the TemplateRef as a ViewChild and pass it to the `detailViewTabs` in the ngAfterViewInit method
         *  For more information about the Angular lifecycle, please visit the [Angular documentation](https://angular.io/guide/lifecycle-hooks)
         *  The input property icon is limited by the talenra-icon library (https://gitlab.svanet.ch/talenra/talenra-workspace)
         *
         * 6. **The `useScroll` attribute is used to define if the content of the tab should be scrollable or not.**
         *  If a custom scroll container should be used, the `useScroll` attribute should be set to false.
         *  And the style of the scroll container should be set like in the example.
         *
         * 7. **The recommended number of custom tabs are 5. Otherwise, it would mess with the design.**
         *
         * ```html
         * <talenra-inbox [attributes]="attributes" [detailViewTabs]="detailViewTabs"></talenra-inbox>
         *
         * <ng-template #talenraInboxDocuments>
         *   <talenra-scroll-container class="custom-scroll">
         *     <h1 class="panel-title">Dokumente</h1>
         *     <div [formGroup]="exampleCheckboxForm" class="inline-documents">
         *       <talenra-checkbox fcn="check_1" size="s"></talenra-checkbox>
         *       <p class="pair">
         *         <span class="documents">Lohnbescheinigung</span>
         *         <span class="documents-entry">hinzugefügt am 12.03.2021</span>
         *       </p>
         *     </div>
         *   </talenra-scroll-container>
         * </ng-template>
         * <ng-template #talenraInboxComments>
         *   ...
         * </ng-template>
         * <ng-template #talenraInboxHistory>
         *   ...
         * </ng-template>
         * ```
         *
         * ```typescript
         * import { IInboxTabBarItem } from '@talenra/ngx-inbox';
         *
         * @ViewChild('talenraInboxDocuments', { read: TemplateRef }) talenraInboxDocuments!: TemplateRef<any>;
         * @ViewChild('talenraInboxComments', { read: TemplateRef }) talenraInboxComments!: TemplateRef<any>;
         * @ViewChild('talenraInboxHistory', { read: TemplateRef }) talenraInboxHistory!: TemplateRef<any>;
         *
         * public detailViewTabs: IInboxTabBarItem[] = [];
         *
         * ngAfterViewInit(): void {
         *     // get the template in the next lifecycle hook, because the viewChild is not available yet
         *     Promise.resolve().then(() => {
         *       // create the detail view tabs
         *       this.detailViewTabs: IInboxTabBarItem[] = [
         *         {
         *           label: 'documents',
         *           icon: 'description',
         *           counter: new BehaviorSubject<number>(8),
         *           useScroll: false,
         *           detailViewTabContentTemplate: this.talenraInboxDocuments,
         *         },
         *         {
         *           label: 'comments',
         *           icon: 'chat-bubble-outline',
         *           counter: new BehaviorSubject<number>(100),
         *           useScroll: true,
         *           detailViewTabContentTemplate: this.talenraInboxComments,
         *         },
         *         {
         *           label: 'history',
         *           icon: 'history',
         *           useScroll: false,
         *           detailViewTabContentTemplate: this.talenraInboxHistory,
         *         },
         *       ];
         *     });
         *   }
         *   ```
         *
         *  ```scss
         * .custom-scroll {
         *   position: absolute;
         *   inset: 0;
         * }
         * ```
         */
        this.detailViewTabs = input([]);
        /**
         * The inboxConfigurationPanelTabs input is used to add tabs to the inboxConfigurationPanel.
         *
         * **Important information:**
         *
         * 1. **The "inboxConfigurationPanelTabs" <u>will not be displayed</u> in the inbox, if the html tag of the inbox is contained in an `*ngIf` statement.**
         *
         * 2. **The `counter` attribute has to be a behavior subject, because the counter is updated in the inbox component and the inbox-configuration-panel component.**
         *
         * 3. **The `counter` has a maximum value of 99. If the counter is higher than 99, the badge will display "99+".**
         *
         * 4. **Because of the Angular lifecycle, the `inboxConfigurationPanelTabs` input has a special declaration in the consuming application.**
         *  The IInboxTabBarItem has a TemplateRef as a property, which is only initialized in `afterViewInit` of the consuming app
         *  The consuming application has to declare the TemplateRef as a ViewChild and pass it to the `inboxConfigurationPanelTabs` in the ngAfterViewInit method
         *  For more information about the Angular lifecycle, please visit the [Angular documentation](https://angular.io/guide/lifecycle-hooks)
         *  The input property icon is limited by the talenra-icon library (https://gitlab.svanet.ch/talenra/talenra-workspace)
         *
         * 5. **The `useScroll` attribute is used to define if the content of the tab should be scrollable or not.**
         *  If a custom scroll container should be used, the `useScroll` attribute should be set to false.
         *  And the style of the scroll container should be set like in the example.
         *
         * ```html
         * <talenra-inbox [attributes]="attributes" [inboxConfigurationPanelTabs]="inboxConfigurationPanelTabs"></talenra-inbox>
         *
         * <ng-template #talenraInboxEnhancedConfiguration>
         *   <talenra-scroll-container class="custom-scroll">
         *     <h1 class="panel-title">Further Configuration</h1>
         *     <div [formGroup]="exampleCheckboxForm" class="inline-documents">
         *       <talenra-checkbox fcn="check_1" size="s"></talenra-checkbox>
         *       <p class="pair">
         *         <span class="documents">Set name</span>
         *         <span class="documents-entry">Enhance Priority Levels</span>
         *       </p>
         *     </div>
         *   </talenra-scroll-container>
         * </ng-template>
         * ```
         *
         * ```typescript
         * import { IInboxTabBarItem } from '@talenra/ngx-inbox';
         *
         * @ViewChild('talenraInboxEnhancedConfiguration', { read: TemplateRef }) talenraInboxEnhancedConfiguration!: TemplateRef<any>;
         *
         * public inboxConfigurationPanelTabs: IInboxTabBarItem[] = [];
         *
         * ngAfterViewInit(): void {
         *     // get the template in the next lifecycle hook, because the viewChild is not available yet
         *     Promise.resolve().then(() => {
         *       // create the inboxConfigurationPanelTabs
         *       this.detailViewTabs: IInboxTabBarItem[] = [
         *         {
         *           label: 'documents',
         *           icon: 'description',
         *           counter: new BehaviorSubject<number>(8),
         *           useScroll: false,
         *           detailViewTabContentTemplate: this.talenraInboxEnhancedConfiguration,
         *         },
         *         ...
         *       ];
         *     });
         *   }
         *   ```
         *
         *  ```scss
         * .custom-scroll {
         *   position: absolute;
         *   inset: 0;
         * }
         * ```
         */
        this.inboxConfigurationPanelTabs = input([]);
        /**
         * Boolean to show if skeleton loading is to be shown.
         *
         * **Important information:**
         *
         * 1. The inbox can **not** detect the loading state of the data items, so the "refresh" input has to be used.
         */
        this.loading = false;
        /**
         * The pairing attributes which combine two attributes to one attribute.
         *
         * The pairingAttributes input is used to combine two attributes to one attribute.
         *
         * **Important information:**
         *
         * 1. **The naming of the input type has changed: current `PairingAttributesModel` to `IPairingAttributes`**.
         *  The `PairingAttributesModel` has the same properties as the `IPairingAttributes`.
         *
         * @example
         * <talenra-inbox [attributes]="attributes" [pairingAttributes]="pairingAttributes"></talenra-inbox>
         *
         * @example
         * import { IPairingAttributes } from '@talenra/ngx-inbox';
         *
         * pairingAttributes: IPairingAttributes[] = [
         *     {
         *       identifier: 'combinedName',
         *       displayedName: 'First/Last Name',
         *       firstAttribute: 'firstNameOrgNameAddOn',
         *       secondAttribute: 'lastNameOrgName',
         *       commaSeparation: false,
         *     },
         *     {
         *       identifier: 'member.combinedName',
         *       displayedName: 'Member First/Last Name',
         *       firstAttribute: 'member.lastNameOrgName',
         *       secondAttribute: 'member.firstNameOrgNameAddOn',
         *       commaSeparation: true,
         *     },
         *   ];
         */
        this.pairingAttributes = [];
        /**
         * The `refreshing` input boolean allows the consuming application to set the inbox into a refreshing state.
         * If the value `true` is injected and the inbox is filled with data (data items), the skeleton loading will be shown.
         * The consuming app can now load new data (dataItems) and input it to the inbox.
         * After the refreshing value can be set to `false` again.
         * Set, if necessary, the `selectedDataItem` input to the data item which was selected before the refresh.
         * The new data (dataItems) will be shown and all filter and sort will be reset to the default value.
         *
         * #### Important information
         *
         * 1. **The consuming app has to save the selected data Item (`clickedDataItemEmitter` Output) and set it again after the refresh with the `selectedDataItem` Input.**
         */
        this.refreshing = false;
        /**
         * The input is used to lock specific data items in the inbox. The input is an array of `DataItemIdModel`.
         * The items will be locked visually in the inbox and the user can not interact with them.
         * Additionally, because the data item is not selectable the detail view will not show any information of the data item.
         *
         * **Important information:**
         *
         * 1. **The naming of the input type has changed: current `DataItemIdModel` to `IDataItemId`**.
         *  The `DataItemIdModel` has the same properties as the `IDataItemId`.
         *
         * @example
         * <talenra-inbox [attributes]="attributes" [lockedDataItems]="lockedDataItems"></talenra-inbox>
         *
         * @example
         * import { DataItemIdModel } from '@talenra/ngx-inbox';
         *
         * lockedDataItems: DataItemIdModel[] = [
         *  {
         *    identifier: 'case.caseID',
         *    value: 'ZH-20230510-0014648',
         *  },
         *  {
         *    identifier: 'case.caseID',
         *    value: 'ZH-20230510-0014649',
         *  },
         * ];
         */
        this.lockedDataItems = [];
        /**
         * If true, the pagination feature is enabled.
         *
         * @example
         * <talenra-inbox [attributes]="attributes" usePagination>
         *   ...
         * </talenra-inbox>
         */
        this.usePagination = false;
        /**
         * The number of items per page in the pagination.
         *
         * @example
         * <talenra-inbox [attributes]="attributes" [paginatorState]="paginatorState" usePagination></talenra-inbox>
         */
        this.paginatorState = {
            currentPage: 1,
            itemsPerPage: 10,
            totalItems: 1,
            itemsPerPageOptions: [5, 10, 20, 50],
        };
        /**
         * The query that is currently selected.
         */
        this.query = model({
            identifier: 'head',
            rules: [],
            condition: QueryBuilderCondition.And,
            hierarchyLevel: 1,
        });
        /**
         * The possible rules that can be selected.
         */
        this.possibleRules = input([]);
        /**
         * The values that can be selected in connection to each rule identifier.
         */
        this.possibleOptions = input([]);
        /**
         * Emits the active item, enables the consuming app to call appropriate api calls etc. (e.g. to change the content of the detail-view tabs).
         *
         * The clickedDataItemEmitter is used to get the clicked/active item, which is emitted as an object.
         * The intended purpose is to allow the consuming app get detail-view-data of the specific item.
         *
         * **Important information:**
         *
         * 1. **If the emitter returns the value undefined no data item is selected (no data item for selection available).**
         * 2. **The consuming application should adjust the detail view accordingly.**
         */
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.clickedDataItemEmitter = new EventEmitter();
        /**
         * The event which is emitted when a dataItems is interacted with by the further-actions and the proceed button.
         *
         * The Messages correlate with the buttons in the toolbar and the list view.
         * Process: The process button was clicked (arrow-right icon).
         * More: The further actions button was clicked (three-dots icon).
         *
         * The More message is intended to allow the consuming app to customize the further actions menu and specify which item opened the menu.
         *
         * **Important information:**
         *
         * 1. **The naming of the input type has changed: current `InteractedDataItemsModel` to `IInteractedDataItems`**.
         *  The `InteractedDataItemsModel` has the same properties as the `IInteractedDataItems`.
         *
         */
        this.dataItemsInteractions = new EventEmitter();
        /**
         * The event which is emitted when a preset is created, updated or deleted.
         *
         * The consuming application receives information about which operation is used with the preset and the modified presets.
         * The consuming app should save the presets and make the preset accessible through SidenavItems in the app.component (talenra-app-frame).
         *
         * **Important information:**
         *
         * 1. **The naming of the input type has changed: current `PresetAction` to `IPresetAction`**.
         *  The `PresetAction` has the same properties as the `IPresetAction`.
         *
         * 2. **The consuming app has to input the modified presets to the inbox.**
         *
         * 3. **`activePresetName` input has to be updated in following cases.**
         *
         * - create --> switch to the new preset (presetName sent in the `presetAction` emitter)
         * - update --> switch to the updated preset (presetName sent in the `presetAction` emitter)
         * - update & rename --> switch to the updated preset (presetName sent in the `presetAction` emitter)
         * - delete --> switch to the first <u>unchangeable</u> preset of the `presets`. For example, activate group of the preset.
         * - visibility-off --> switch to the first <u>unchangeable</u> preset of the `presets`. For example, activate group of the preset.
         */
        this.presetAction = new EventEmitter();
        /**
         * The event which is emitted when the virtual scroller position changes.
         *
         * The virtualScrollerPosition is used to get the position of the virtual scroll.
         * The position is emitted as a number value ranging from -2 to x.
         *
         * - Values from 1 to x are the position of the virtual scroll.
         * - The value 0 indicates that the virtual scroll is at the top.
         * - The value -1 indicates that the virtual scroll has no scrollable content.
         * - The value -2 indicates that the virtual scroll has detected a buggy behaviour (loop scroll).
         * - If the value -2 the consuming app hast to stop the possible resizing of the inbox.
         *
         * @example
         * <talenra-workspace-simple>
         *   <div class="inbox-app">
         *     <talenra-workspace-header
         *       [path]="workspacePath"
         *       [title]="workspaceTitle"
         *       class="page-header"
         *       [class.header-hidden]="!headerEdgeCase && headerHidden && !noScroll"></talenra-workspace-header>
         *     <talenra-inbox [attributes]="attributes" class="talenra-inbox" (virtualScrollerPosition)="onVirtualScrollerPosition($event)"></talenra-inbox>
         *   </div>
         * </talenra-workspace-simple>
         *
         * @example
         * .inbox-app {
         *   display: flex;
         *   flex-wrap: nowrap;
         *   flex-direction: column;
         *   height: 100%;
         *   width: 100%;
         * }
         *
         * .page-header {
         *   margin-left: 20px;
         *   opacity: 1;
         *   height: 92px;
         *
         *   transition: height 0.3s, opacity 0.3s;
         *
         *   &.header-hidden {
         *     opacity: 0;
         *     height: 0;
         *   }
         * }
         *
         * .talenra-inbox {
         *   position: relative;
         *   flex-grow: 1;
         * }
         *
         * @example
         *
         * headerHidden = false;
         * noScroll = false;
         * headerEdgeCase = false;
         *
         * onVirtualScrollerPosition(event: number): void {
         *     switch (event) {
         *       case -2:
         *         // if the value -2 is emitted, the inbox has a buggy loop, the header should be fixed and not be trying to hide for the remaining usage
         *         this.headerEdgeCase = true;
         *         break;
         *       default:
         *         // if the value -1 is emitted, the inbox has a buggy loop, the header should be fixed because the inbox is not scrollable (to few items)
         *         this.noScroll = event === -1;
         *         // if the value 0 is emitted, the inbox is at the top and the header should be fixed
         *         // if the value > 0 is emitted, the inbox is not at the top and the header should be hidden
         *         this.headerHidden = event > 0;
         *         break;
         *     }
         *   }
         */
        this.virtualScrollerPosition = new EventEmitter();
        /**
         * The event which is emitted when the selected main attributes change
         *
         * The consuming application receives information about which main attributes (the ones above the line in the attribute-settings).
         * The attributes are emitted as an array of strings with the correct order as chosen by the user. The strings are the identifiers of the attributes.
         */
        this.selectedMainAttributesEmitter = new EventEmitter();
        /**
         * The event which is emitted when the selected detail attributes changes
         *
         * The consuming application receives information about which detail attributes (the ones below the line in the attribute-settings).
         * The attributes are emitted as an array of strings with the correct order as chosen by the user. The strings are the identifiers of the attributes.
         */
        this.selectedDetailAttributesEmitter = new EventEmitter();
        /**
         * The event which is emitted when the all selected attributes changes
         *
         * The consuming application receives information about which attributes have been selected.
         */
        this.selectedAllAttributesEmitter = new EventEmitter();
        /**
         * The event which is emitted when the filter, sort or the search input changes
         *
         * The consuming application receives information about which filter, sort or search input is used.
         *
         * **Important information:**
         *
         * 1. **The naming of the input type has changed: current `FilterSortSearchModel` to `IFilterSortSearch`**.
         *  The `FilterSortSearchModel` has the same properties as the `IFilterSortSearch`.
         */
        this.filterSortSearchEmitter = new EventEmitter();
        /**
         * The value that the refresh button is clicked.
         *
         * It will emit the value `true` when the refresh button is clicked.
         * The consuming application can load the data and set the value to `false` again.
         */
        this.refreshingChange = new EventEmitter();
        /**
         * The event which is emitted when the page changes in the pagination.
         * The consuming application receives information about which page is selected.
         * The consuming application can load the data for the selected page by using the `refresh`.
         */
        this.paginatorStateChange = new EventEmitter();
        /**
         * Class to interact with data items.
         */
        this.dataItemsClass = new DataItemsClass();
        /**
         * Number of marked data items in data items list.
         */
        this.numberMarkedDataItems = 0;
        /**
         * Number of marked data items in data items list.
         */
        this.mainCheckboxState = CheckboxState.Outline;
        /**
         * information if in attributes, attributesDetails, numberMainAttributesChosenByUser, sortFilter or filter changes are made.
         * string: attributes, attributesDetails, numberMainAttributesChosenByUser, sortFilter or filter
         * boolean: true if changes are made, false if no changes are made
         */
        this.changedValuesInPresetGroups = new Map();
        /**
         * flag to check, if all attributes are selected or not in attributeSettings.
         * If the flag is the same as the length of the attributes, then the setBufferFilterSort is not updated.
         */
        this.allSelectedAttributesIdentifiers = [];
        /**
         * Injected inbox toolbar service.
         */
        this.inboxToolbarService = inject(InboxToolbarService);
        /**
         * Injected keyboard service.
         */
        this.keyboardService = inject(KeyboardService);
        /**
         * Injected changed values service.
         */
        this.changedValuesService = inject(ChangedPresetValuesService);
        /**
         * Injected filter toolbar service.
         */
        this.filterToolbarService = inject(FilterToolbarService);
        /**
         * Injected update preset service.
         */
        this.updatePresetsService = inject(UpdatePresetsService);
        /**
         * Injected set inbox configuration service.
         */
        this.mainFacadeSetterService = inject(MainFacadeSetterService);
        /**
         * Injected csv service.
         */
        this.csvService = inject(CsvService);
        /**
         * Injected inbox helper service.
         */
        this.inboxHelperService = inject(InboxHelperService);
        /**
         * Injected presets service.
         */
        this.presetsService = inject(PresetsService);
        /**
         * Injected inbox state.
         */
        this.inboxState = inject(InboxState);
        /**
         * Injected filter state.
         */
        this.filterState = inject(FilterStateService);
        /**
         * Injected inbox detail view service.
         */
        this.inboxDetailViewService = inject(InboxDetailViewService);
        /**
         * Injected inbox data items service.
         */
        this.dataItemsService = inject(DataItemsService);
        /**
         * The change detector reference.
         * @internal
         */
        this.changeDetectorRef = inject(ChangeDetectorRef);
        /**
         * The computed inbox detail view tabs. Resets the detail view tabs and sets the proper values.
         */
        this.inboxDetailViewTabs = computed(() => this.mainFacadeSetterService.resetDetailViewTabs(this.detailViewTabs()));
        /**
         * The subscription for the inbox.
         * @internal
         */
        this.subscriptions = new Subscription();
        /**
         * The subscriptions for the presets.
         * @internal
         */
        this.presetSubscriptions = new Subscription();
        /**
         * The subscriptions of the detail view.
         * @internal
         */
        this.detailViewSubscriptions = new Subscription();
        /**
         * The subscriptions of the inbox to handle the change in the state of loading and the preset change by the active preset name.
         * @internal
         */
        this.initializationSubscriptions = new Subscription();
        // Deprecation warning for old selector
        elementRef.nativeElement.tagName.toLowerCase() === 'talenra-workspace-inbox' &&
            deprecationWarning({
                packageName: '@talenra/ngx-inbox',
                className: this.constructor.name,
                member: 'Selector <talenra-workspace-inbox>',
                instructions: 'Use <talenra-inbox> instead.',
            });
    }
    /**
     * Initializes the inbox component.
     * @internal
     */
    ngOnInit() {
        // check if the presets are used
        if (this.presets.length > 0) {
            this.initializeComponentForViewUsage();
        }
        // initialize the inbox for paginator usage
        this.initializeComponentForPaginatorUsage();
        // initialize the component
        this.initializeComponent();
    }
    /**
     * Initializes the component for the view usage.
     */
    initializeComponentForViewUsage() {
        // reset preset subscriptions
        this.presetSubscriptions.unsubscribe();
        this.presetSubscriptions.closed = false;
        // transfer the presets to the necessary format
        this.transformedPresetGroups = this.transformPresetsToPresetGroups(this.presets);
        // set the preset groups in the inbox state
        if (this.transformedPresetGroups) {
            this.inboxState.setPresetGroups(this.transformedPresetGroups);
            // set the active preset name in the inbox component, if no active preset name is set, the first preset is set as active
            if (this.activePresetName.length === 0 || !this.activePresetName) {
                this.activePresetName = [this.transformedPresetGroups[0].groupName, this.transformedPresetGroups[0].groupName];
            }
            // set the active preset name in the inbox component, if only the group is chosen, the first preset of the group is set as active
            if (this.activePresetName.length === 1) {
                this.activePresetName = [this.activePresetName[0], this.activePresetName[0]];
            }
            // set the active preset in the inbox state
            this.inboxState.setActivePresetName(this.activePresetName);
            // subscribe to changes in the active preset name
            // subscription is used to trigger the reset of the component via the filter toolbar undo and new preset creation
            this.presetSubscriptions.add(this.inboxState.activePresetName$.subscribe((activePresetName) => {
                // initialize the change methods for the filter, sort and attributes
                const changeMethods = {
                    attributesMain: this.changedValuesService.setAttributesMainChangedSubject,
                    attributesDetail: this.changedValuesService.setAttributesDetailChangedSubject,
                    numberMainAttributesChosenByUser: this.changedValuesService.setNumberMainAttributesChosenByUserChangedSubject,
                    sort: this.changedValuesService.setSortChangedSubject,
                    iconFilter: this.changedValuesService.setIconFilterChangedSubject,
                    filter: this.changedValuesService.setFilterChangedSubject,
                };
                [
                    'attributesMain',
                    'attributesDetail',
                    'numberMainAttributesChosenByUser',
                    'sort',
                    'iconFilter',
                    'filter',
                ].forEach((change) => {
                    const setChangeMethod = changeMethods[change];
                    if (setChangeMethod) {
                        setChangeMethod.call(this.changedValuesService, { identifier: change, changed: false });
                    }
                });
                // search the active preset in the preset groups
                const matchingGroup = this.transformedPresetGroups?.find((presetGroup) => presetGroup.groupName === activePresetName[0]);
                if (matchingGroup) {
                    const filteredPreset = matchingGroup.presets.find((preset) => preset.name === activePresetName[1]);
                    if (filteredPreset) {
                        this.inboxState.setActivePreset(filteredPreset);
                        this.activePresetName = [matchingGroup.groupName, filteredPreset.name];
                    }
                }
            }));
        }
        // reset to the default state of the changed values to false
        ['attributesMain', 'attributesDetail', 'numberMainAttributesChosenByUser', 'sort', 'iconFilter', 'filter'].forEach((change) => this.changedValuesInPresetGroups.set(change, false));
    }
    /**
     * Functions to initialize the component.
     */
    initializeComponent() {
        // reset subscriptions
        this.subscriptions.unsubscribe();
        this.subscriptions.closed = false;
        // set emitter for FilterSearchSort in helper service
        this.mainFacadeSetterService.setFilterSortSearchEmitter(this.filterSortSearchEmitter);
        // resets the detail view tabs given by the consuming application
        this.mainFacadeSetterService.resetDetailViewTabs(this.detailViewTabs());
        // reset the attributes and set the default attributes
        this.mainFacadeSetterService.setAllAttributes([]);
        this.mainFacadeSetterService.setAllUntransformedAttributes(this.attributes);
        // set the picked attributes and transform the attributes for the attributes settings
        this.mainFacadeSetterService.setPickedAttributes();
        // data items are available prepare them for the inbox usage
        if (this.dataItems !== undefined && this.dataItems !== null && this.dataItems.length > 0) {
            this.mainFacadeSetterService.initializeDataItemsList(this.dataItems);
        }
        // set the keyboard service configuration, used to call functions of the inbox component via keyboard service
        const dataItemsAvailable = this.dataItems !== undefined && this.dataItems !== null;
        this.mainFacadeSetterService.setKeyboardServiceConfiguration(this.iconBtnFunction, this.dataItemsInteractions, dataItemsAvailable, this.clickedDataItemFunction, this.clickedDataItemEmitter, this.lockedDataItems);
        // set the selected attribute list inside the attribute settings service
        this.mainFacadeSetterService.setSelectedAttributeListInsideAttributesSettingsService();
        // set the default state of the inbox layout
        this.mainFacadeSetterService.setDefaultStateOfInboxLayout(this.dataItems, this.clickedDataItemEmitter);
        // set the original data items and the filtered sorted data items
        if (this.dataItems !== undefined && this.dataItems !== null) {
            this.filterToolbarService.setOriginalDataItems(this.dataItems);
            this.filterToolbarService.setFilteredSortedDataItems(this.dataItems);
        }
        // set the filter and search subscriptions, to recognize changes in the filter and search and apply them to the data items
        this.mainFacadeSetterService.setFilterAndSearchSubscriptions(this.clickedDataItemEmitter);
        // check if the presets are used
        if ((this.transformedPresetGroups !== undefined || null) && this.activePresetName.length !== undefined) {
            // set the filter and sort state for the inbox from the preset
            this.mainFacadeSetterService.initializeFilterSortStateFromPreset();
            this.subscriptions.add(this.inboxState.presetGroups$.subscribe((result) => {
                const matchingGroup = result.find((presetGroup) => presetGroup.groupName === this.activePresetName[0]);
                if (matchingGroup) {
                    const filteredPreset = matchingGroup.presets.find((preset) => preset.name === this.activePresetName[1]);
                    // set changes in filter, sort and search from preset
                    this.inboxState.setActiveFilterSortSearch({
                        selectedMainAttributes: this.inboxState.selectedMainAttributesSubject$.value,
                        selectedDetailAttributes: this.inboxState.selectedDetailAttributesSubject$.value,
                        filterAttributes: this.filterToolbarService.transformFilterAttributeIntoInboxInterface(filteredPreset?.filterAttributes || [], this.inboxState.selectedAllAttributesSubject$.value),
                        iconAttributes: filteredPreset?.iconAttributes || [],
                        searchText: '',
                        sortAttributes: filteredPreset?.sortAttributes || [],
                    });
                }
            }));
        }
        // subscribes to the changes in the inbox
        this.recognizeChangesInInbox();
        // subscribe to the virtual scroller position
        this.subscriptions.add(this.mainFacadeSetterService.virtualScrollerPosition$.subscribe((result) => {
            this.virtualScrollerPosition.emit(result);
        }));
        // subscribe to changes in the inbox configuration
        this.subscriptions.add(this.inboxState.inboxConfiguration$.subscribe((result) => {
            // resets the detail view tabs if the main tab is disabled or enabled
            if (result.disableDetailViewMainTab !== undefined) {
                this.mainFacadeSetterService.resetDetailViewTabs(this.detailViewTabs());
            }
        }));
    }
    /**
     * Detects changes in the input values.
     * @param changes The changes.
     * @internal
     **/
    ngOnChanges(changes) {
        // get possible changes
        const attributesChanges = changes['attributes'];
        const presetsChanges = changes['presets'];
        const activePresetNameChanges = changes['activePresetName'];
        const dataItemsChanges = changes['dataItems'];
        const refreshingChanges = changes['refreshing'];
        const lockedDataItemsChanges = changes['lockedDataItems'];
        const selectDataItemChange = changes['selectDataItem'];
        const loadingChanges = changes['loading'];
        const usePaginationChanges = changes['usePagination'];
        // Handle changes to 'presets'
        if (presetsChanges && !presetsChanges.firstChange) {
            this.transformedPresetGroups = this.transformPresetsToPresetGroups(presetsChanges.currentValue);
            this.inboxState.setPresetGroups(this.transformedPresetGroups);
            this.recognizeChangesInInbox();
        }
        // Handle changes to 'activePresetName'
        if (activePresetNameChanges && !activePresetNameChanges.firstChange) {
            if (activePresetNameChanges.currentValue.length === 1) {
                this.activePresetName = activePresetNameChanges.currentValue.concat(activePresetNameChanges.currentValue);
            }
            if (this.activePresetName &&
                (activePresetNameChanges.currentValue[0] !== activePresetNameChanges.previousValue[0] ||
                    activePresetNameChanges.currentValue[1] !== activePresetNameChanges.previousValue[1])) {
                this.allSelectedAttributesIdentifiers = [];
                const [group, presetName] = this.activePresetName;
                const matchingGroup = this.transformedPresetGroups?.find((presetGroup) => presetGroup.groupName === group);
                if (matchingGroup) {
                    const filteredPreset = matchingGroup.presets.find((preset) => preset.name === presetName);
                    if (filteredPreset) {
                        this.inboxState.setActivePreset(filteredPreset);
                        if (activePresetNameChanges.currentValue.toString() !== this.inboxState.activePresetName$.value.toString()) {
                            // reset subscriptions
                            this.initializationSubscriptions.unsubscribe();
                            this.initializationSubscriptions.closed = false;
                            this.initializationSubscriptions.add(this.changedValuesService.filterSortChangedSubject$.subscribe((value) => {
                                if (!value) {
                                    // stop subscriptions after one time usage
                                    this.initializationSubscriptions.unsubscribe();
                                    this.initializationSubscriptions.closed = false;
                                }
                            }));
                            this.resetComponent();
                            // emit the FilterSortSearch to the consuming application after the initialization
                            this.mainFacadeSetterService.publishFilterSortSearch(this.inboxState.activeFilterSortSearch.value);
                        }
                    }
                }
            }
        }
        // Handle changes to 'dataItems'
        if (dataItemsChanges && !dataItemsChanges.firstChange) {
            // data items are available prepare them for the inbox usage
            if (this.dataItems !== undefined && this.dataItems !== null && this.dataItems.length > 0) {
                this.mainFacadeSetterService.initializeDataItemsList(this.dataItems);
            }
            // set the keyboard service configuration, used to call functions of the inbox component via keyboard service
            const dataItemsAvailable = this.dataItems !== undefined && this.dataItems !== null;
            this.mainFacadeSetterService.setKeyboardServiceConfiguration(this.iconBtnFunction, this.dataItemsInteractions, dataItemsAvailable, this.clickedDataItemFunction, this.clickedDataItemEmitter, this.lockedDataItems);
            // set the default state of the inbox layout
            this.mainFacadeSetterService.setDefaultStateOfInboxLayout(this.dataItems, this.clickedDataItemEmitter);
            // set the original data items and the filtered sorted data items
            if (this.dataItems !== undefined && this.dataItems !== null) {
                this.filterToolbarService.setOriginalDataItems(this.dataItems);
                this.filterToolbarService.setFilteredSortedDataItems(this.dataItems);
            }
        }
        // Handle changes to 'refreshing'
        if (refreshingChanges && !refreshingChanges.firstChange) {
            // reset the component if the refresh is set to false (dataItems active again) and no dataItems have been changed
            if (!refreshingChanges.currentValue && dataItemsChanges === undefined) {
                this.resetComponent();
            }
            // enable keyboard shortcuts after refreshing
            this.keyboardService.refreshing = refreshingChanges.currentValue;
        }
        // Handle changes to 'lockedDataItems'
        if (lockedDataItemsChanges && !lockedDataItemsChanges.firstChange) {
            this.keyboardService.lockedDataItems = lockedDataItemsChanges.currentValue;
        }
        // Handle changes to 'selectDataItem'
        if (selectDataItemChange && !selectDataItemChange.firstChange) {
            const index = this.inboxState.filteredDataItemsSubject$.value.findIndex((value) => this.dataItemsClass.getElemFromDataItemDisplayed(value, selectDataItemChange.currentValue.identifier) ===
                selectDataItemChange.currentValue.value);
            if (index !== -1) {
                // check if item is locked and if so, do not scroll to it or select it
                if (this.lockedDataItems.filter((item) => item.identifier === selectDataItemChange.currentValue.identifier &&
                    item.value === selectDataItemChange.currentValue.value).length > 0) {
                    // warning that data item is locked
                    console.warn('@talenra/ngx-inbox: The found data item with identifier: ' +
                        selectDataItemChange.currentValue.identifier +
                        ' and value: ' +
                        selectDataItemChange.currentValue.value +
                        ' is locked.');
                }
                else {
                    this.keyboardService.scrollToIndex = index;
                    this.clickedDataItemFunction(this.inboxState.filteredDataItemsSubject$.value[index]);
                }
            }
            else {
                // warning that no data item is found
                console.warn('@talenra/ngx-inbox: No filtered data item found with identifier: ' +
                    selectDataItemChange.currentValue.identifier +
                    ' and value: ' +
                    selectDataItemChange.currentValue.value +
                    '.');
            }
        }
        // Handle changes to 'usePagination'
        if (usePaginationChanges && !usePaginationChanges.firstChange) {
            // reset component
            this.resetComponent();
        }
        // Handle changes to 'attributes'
        if (attributesChanges && !attributesChanges.firstChange) {
            // reset component
            this.resetComponent();
        }
        // Handle changes to 'loading'
        if (loadingChanges && !loadingChanges.firstChange) {
            if (!loadingChanges.currentValue) {
                // reset subscriptions
                this.initializationSubscriptions.unsubscribe();
                this.initializationSubscriptions.closed = false;
                this.initializationSubscriptions.add(this.changedValuesService.filterSortChangedSubject$.subscribe((value) => {
                    if (!value) {
                        // stop subscriptions after one time usage
                        this.initializationSubscriptions.unsubscribe();
                        this.initializationSubscriptions.closed = false;
                    }
                }));
                this.resetComponent();
            }
        }
    }
    /**
     * Unsubscribes from all subscriptions.
     * @internal
     **/
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
        this.detailViewSubscriptions.unsubscribe();
        this.mainFacadeSetterService.subscriptions.unsubscribe();
        this.mainFacadeSetterService.detailViewSubscriptions.unsubscribe();
    }
    /**
     * Main function to handle interactions with clicked icon buttons.
     * @param btn The clicked button.
     */
    iconBtnFunction(btn) {
        switch (btn) {
            case 'close':
                this.inboxDetailViewService.setDetailViewExpanded(false);
                break;
            case 'reorder':
            case 'vertical-split':
                this.inboxDetailViewService.setDetailViewExpanded(!this.inboxDetailViewService.detailViewExpanded$.value);
                this.inboxDetailViewService.setSelectedDetailViewTab('1');
                break;
            case 'compress':
                this.dataItemsService.setCompressedDataItem(!this.dataItemsService.compressedDataItem$.value);
                break;
            case 'more_vert-bulk':
                this.onDataItemsInteractions({
                    message: InteractedDataItemsMessageTypes.More,
                    dataItems: this.inboxHelperService.getBulkDataItemsList(this.dataItems, this.dataItemsService.selectedDataItemsIdList$.value),
                });
                break;
            case 'arrow-forward-bulk':
                this.onDataItemsInteractions({
                    message: InteractedDataItemsMessageTypes.Process,
                    dataItems: this.inboxHelperService.getBulkDataItemsList(this.dataItems, this.dataItemsService.selectedDataItemsIdList$.value),
                });
                break;
            case 'arrow-forward':
                this.dataItemsInteractions.emit({
                    dataItems: [this.dataItemsService.activeDataItem$.value],
                    message: InteractedDataItemsMessageTypes.Process,
                });
                break;
            case 'file-download':
                if (this.dataItems) {
                    this.csvService.downloadCSV();
                }
                break;
            case 'refresh':
                this.refreshing = true;
                this.keyboardService.refreshing = this.refreshing;
                this.mainFacadeSetterService.reOpenDetailViewAfterRefresh =
                    this.inboxDetailViewService.detailViewExpanded$.value;
                this.refreshingChange.emit(this.refreshing);
                break;
            default:
                break;
        }
    }
    handleChangesOnPreset(btn, attributesUsed) {
        const { updatePresetsService } = this;
        switch (btn) {
            case 'drag-drop':
                updatePresetsService.dragDropPresetInPresets(this.presetsService.dragDropGroupAndPreset$.value);
                break;
            case 'create-new-preset':
                updatePresetsService.setAllNewSettingsForPreset('create');
                break;
            case 'overwrite-preset':
                updatePresetsService.setAllNewSettingsForPreset('overwrite', attributesUsed);
                break;
            case 'visbility-off':
            case 'visbility-on':
                updatePresetsService.changeVisibilityOfPresetInPresets(updatePresetsService.newPresetName$.value, btn === 'visbility-on');
                break;
            case 'position-up':
            case 'position-down':
                const [group, preset] = updatePresetsService.newPresetName$.value;
                updatePresetsService.changePositionOfPresetInPresets(group, preset, btn === 'position-down');
                break;
            case 'delete-preset':
                updatePresetsService.deletePresetInPresets(updatePresetsService.newPresetName$.value);
                break;
            case 'rename-preset':
                updatePresetsService.renamePresetInPresets(updatePresetsService.currentRenamedPreset$.value);
                break;
            default:
                break;
        }
        this.callbackFunctionForPresetChanges();
    }
    /**
     * Event emitter for changes in the preset.
     */
    callbackFunctionForPresetChanges() {
        const presets = this.transformPresetGroupsToPresets(this.updatePresetsService.currentPresetGroup$.value);
        this.presetAction.emit({
            groupName: this.updatePresetsService.currentPresetAction$.value.groupName,
            newPresetName: this.updatePresetsService.currentPresetAction$.value.newPresetName,
            operation: this.updatePresetsService.currentPresetAction$.value.operation,
            presetName: this.updatePresetsService.currentPresetAction$.value.presetName,
            presets: presets,
        });
    }
    /**
     * Depending on the clicked data item button the corresponding event actions will be shown.
     * @param {IInteractedDataItems} event The interacted data items event.
     */
    onDataItemsInteractions(event) {
        this.dataItemsInteractions.emit(event);
    }
    /**
     * Auxiliary method to set the attributeSortOrFilterUsedSubject.
     */
    setAttributeSortOrFilterUsedSubjectFunction() {
        // check if there are changes in filter or sort
        const boolFilterSort = this.changedValuesInPresetGroups.get('sort') == true ||
            this.changedValuesInPresetGroups.get('iconFilter') == true ||
            this.changedValuesInPresetGroups.get('filter') == true;
        // check if there are changes in filter or sort and set the changed values
        if (this.changedValuesService.filterSortChangedSubject$.value !== boolFilterSort) {
            this.changedValuesService.setFilterSortChangedSubject$(boolFilterSort);
        }
    }
    /**
     * Handler for the selected main attributes.
     * @param selectedMainAttributes Selected main attributes.
     */
    selectedMainAttributesEmitterHandler(selectedMainAttributes) {
        this.inboxState.setSelectedMainAttributesSubject(selectedMainAttributes);
        this.selectedMainAttributesEmitter.emit(selectedMainAttributes.map((element) => element.identifier));
    }
    /**
     * Handler for the selected detail attributes.
     * @param selectedDetailAttributes Selected detail attributes.
     */
    selectedDetailAttributesEmitterHandler(selectedDetailAttributes) {
        this.inboxState.setSelectedDetailAttributesSubject(selectedDetailAttributes);
        this.selectedDetailAttributesEmitter.emit(selectedDetailAttributes.map((element) => element.identifier));
    }
    /**
     * Handler for the selected all attributes.
     * @param selectedAllAttributes Selected all attributes.
     */
    selectedAllAttributesHandler(selectedAllAttributes) {
        // create attributes array of the identifier
        const selectedAttributesStringArray = selectedAllAttributes.map((element) => element.identifier);
        // BUFFER HANDLER:
        // check if there are changes in attributes or attributesDetail,
        // necessary in click on select/deselect all attributes
        if (selectedAttributesStringArray !== this.allSelectedAttributesIdentifiers) {
            //the buffer will be created here with filter, iconFilter and sortFilter
            this.inboxState.setBufferFilterSort({
                filterAttributes: this.inboxState.activeFilterSortSearch.value.filterAttributes,
                iconFilterAttributes: this.inboxState.activeFilterSortSearch.value.iconAttributes,
                sortAttributes: this.inboxState.activeFilterSortSearch.value.sortAttributes,
            });
            this.allSelectedAttributesIdentifiers = selectedAttributesStringArray;
        }
        this.inboxState.setSelectedAllAttributesSubject(selectedAllAttributes);
        this.selectedAllAttributesEmitter.emit(selectedAttributesStringArray);
        this.updatePresetsService.updateAttributeInPresets(this.activePresetName, selectedAttributesStringArray);
        // check if views are available
        if (this.presets.length > 0) {
            this.handleChangesOnPreset('overwrite-preset', true);
        }
        //check if attributes are changed compared to active preset saved in preset
        this.changedValuesService.setPresetGroupsAndCompareIfChangedAttributes(this.inboxState.selectedMainAttributesSubject$.value, this.inboxState.selectedDetailAttributesSubject$.value, this.mainFacadeSetterService.numberMainAttributesChosenByUser$.value, this.inboxState.presetGroups$.value);
    }
    /**
     * Sets the number of main attributes chosen by the user.-
     * @param $event The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserHandler($event) {
        this.mainFacadeSetterService.setNumberMainAttributesChosenByUser($event);
    }
    /**
     * Handler if the inbox is to be reset.
     */
    resetPresetEmitterHandler() {
        // trigger subscription of presets to reset the preset
        this.inboxState.setActivePresetName(this.inboxState.activePresetName$.value);
        // reset the component
        this.initializeComponent();
        // publish the filter sort search
        this.mainFacadeSetterService.publishFilterSortSearch(this.inboxState.activeFilterSortSearch.value);
    }
    /**
     * Handler for the clicked data item.
     * @param dataItem The clicked data item.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    clickedDataItemFunction(dataItem) {
        if (dataItem &&
            this.dataItemsService.activeDataItem$.value &&
            dataItem['inboxId'] !== undefined &&
            this.dataItemsService.activeDataItem$.value['inboxId'] !== undefined &&
            dataItem['inboxId'] !== this.dataItemsService.activeDataItem$.value['inboxId']) {
            this.clickedDataItemEmitter.emit(dataItem);
        }
        else if (dataItem === undefined && this.dataItemsService.activeDataItem$.value !== undefined) {
            this.clickedDataItemEmitter.emit(dataItem);
        }
        else if (dataItem !== undefined && this.dataItemsService.activeDataItem$.value === undefined) {
            this.clickedDataItemEmitter.emit(dataItem);
        }
        this.dataItemsService.setActiveDataItem(dataItem);
    }
    /**
     * Handler for the change of number of marked data items.
     * @param $event
     */
    numberMarkedDataItemsChange($event) {
        this.numberMarkedDataItems = $event;
        this.changeDetectorRef.detectChanges();
    }
    /**
     * An interface to transform the delivered presets: Preset[] into the necessary PresetGroup[] format.
     * @param presets The presets which are delivered.
     * @param parentGroupName The name of the parent group.
     * @returns The transformed presets.
     */
    transformPresetsToPresetGroups(presets, parentGroupName = null) {
        return presets.map((option) => {
            const transformedOption = {
                identifier: option.identifier,
                name: option.name,
                visible: option.visible !== undefined ? option.visible : true,
                changeable: option.changeable !== undefined ? option.changeable : false,
                numberMainAttributesChosenByUser: option.numberMainAttributesChosenByUser !== undefined ? option.numberMainAttributesChosenByUser : 12,
                selectedAttributes: option.selectedAttributes || [],
                sortAttributes: option.sortAttributes || [],
                filterAttributes: option.filterAttributes || [],
                iconAttributes: option.iconAttributes || [],
            };
            const groupName = parentGroupName || option.name;
            let childOptions = [];
            if (option.children && option.children.length > 0) {
                childOptions = option.children.map((childOption) => ({
                    identifier: childOption.identifier,
                    name: childOption.name,
                    visible: childOption.visible !== undefined ? childOption.visible : true,
                    changeable: childOption.changeable !== undefined ? childOption.changeable : true,
                    numberMainAttributesChosenByUser: childOption.numberMainAttributesChosenByUser !== undefined
                        ? childOption.numberMainAttributesChosenByUser
                        : 12,
                    selectedAttributes: childOption.selectedAttributes || [],
                    sortAttributes: childOption.sortAttributes || [],
                    filterAttributes: childOption.filterAttributes || [],
                    iconAttributes: childOption.iconAttributes || [],
                }));
            }
            return {
                groupName,
                presets: [transformedOption, ...childOptions],
            };
        });
    }
    /**
     * An interface to transform the preset: PresetGroup[] into the necessary Preset[] format
     * to send it to the consuming application.
     * @param presetGroups The preset which are delivered.
     * @returns The transformed preset.
     */
    transformPresetGroupsToPresets(presetGroups) {
        if (!presetGroups || presetGroups.length === 0) {
            return [];
        }
        // the transformed presets
        const transformedPresets = [];
        // iterate over every preset group to get the presets
        presetGroups.forEach((group) => {
            // get the first preset of the group which is the parent preset
            const transformedGroupToPreset = group.presets[0];
            // add the remaining children as presets of the parent preset
            transformedGroupToPreset.children = group.presets.slice(1, group.presets.length);
            // add the parent preset to the transformed presets
            transformedPresets.push(transformedGroupToPreset);
        });
        return transformedPresets;
    }
    /**
     * Subscribes to the changes in the inbox. Values are provided by the changed values service.
     */
    recognizeChangesInInbox() {
        // all the possible subjects to subscribe to
        const subjects = [
            this.changedValuesService.attributesMainChangedSubject$,
            this.changedValuesService.attributesDetailChangedSubject$,
            this.changedValuesService.numberMainAttributesChosenByUserChangedSubject$,
            this.changedValuesService.sortChangedSubject$,
            this.changedValuesService.iconFilterChangedSubject$,
            this.changedValuesService.filterChangedSubject$,
        ];
        subjects.forEach((subject) => {
            this.subscriptions.add(subject.subscribe((result) => {
                // get if the changed values are in the preset groups
                const key = subject === this.changedValuesService.attributesMainChangedSubject$
                    ? 'attributesMain'
                    : subject === this.changedValuesService.attributesDetailChangedSubject$
                        ? 'attributesDetail'
                        : subject === this.changedValuesService.numberMainAttributesChosenByUserChangedSubject$
                            ? 'numberMainAttributesChosenByUser'
                            : subject === this.changedValuesService.sortChangedSubject$
                                ? 'sort'
                                : subject === this.changedValuesService.iconFilterChangedSubject$
                                    ? 'iconFilter'
                                    : subject === this.changedValuesService.filterChangedSubject$
                                        ? 'filter'
                                        : '';
                // set the changed values in the preset groups
                if (key) {
                    this.changedValuesInPresetGroups.set(key, result.changed);
                    // checks if the filter or sort is used and sets special subject for filter toolbar ui
                    this.setAttributeSortOrFilterUsedSubjectFunction();
                }
            }));
        });
    }
    /**
     * Handler for the paginator state change.
     * @param paginatorState The paginator state.
     */
    onPaginatorStateChange(paginatorState) {
        this.paginatorState = paginatorState;
        const filterSortSearch = {
            selectedMainAttributes: this.inboxState.selectedMainAttributesSubject$.value,
            selectedDetailAttributes: this.inboxState.selectedDetailAttributesSubject$.value,
            filterAttributes: this.inboxState.activeFilterSortSearch.value.filterAttributes,
            iconAttributes: this.inboxState.activeFilterSortSearch.value.iconAttributes,
            searchText: this.inboxState.activeFilterSortSearch.value.searchText,
            sortAttributes: this.inboxState.activeFilterSortSearch.value.sortAttributes,
        };
        this.mainFacadeSetterService.publishFilterSortSearch(filterSortSearch);
        this.paginatorStateChange.emit(paginatorState);
    }
    /**
     * Actions performed on button action.
     * Should emit filterSearchSort event.
     * @param action The performed action.
     */
    onInboxConfigurationPanelButtonAction(action) {
        if (action === 'confirm') {
            // emit the changes in filter, sort and search to the consuming application
            const filterSortSearch = {
                selectedMainAttributes: this.inboxState.selectedMainAttributesSubject$.value,
                selectedDetailAttributes: this.inboxState.selectedDetailAttributesSubject$.value,
                filterAttributes: this.inboxState.activeFilterSortSearch.value.filterAttributes,
                iconAttributes: this.inboxState.activeFilterSortSearch.value.iconAttributes,
                searchText: this.inboxState.activeFilterSortSearch.value.searchText,
                sortAttributes: this.inboxState.activeFilterSortSearch.value.sortAttributes,
            };
            // emit the changes in filter, sort and search to the consuming application
            this.mainFacadeSetterService.publishFilterSortSearch(filterSortSearch);
            // check if the filter changed in regard to the emitted buffer
            this.filterState.setFilterAndSortChangedInComparisonToEmittedState(this.mainFacadeSetterService.compareFilterSort(this.inboxState.activeFilterSortSearch.value, this.mainFacadeSetterService.filterSortSearchEmitterBuffer));
            // close the panel
            this.inboxToolbarService.setConfigurationPanelState(!this.inboxToolbarService.configurationPanelExpanded$.value);
        }
    }
    /**
     * Handler for changes in the icon filter state.
     * @param icons All the icons with the updated active state.
     */
    onIconFilterChange(icons) {
        // set value in filter state
        this.filterState.setIconFilterSubject(icons);
        // check if values has changed in regard to preset
        this.changedValuesService.setPresetGroupsAndCompareIfChangedIconFilter();
        // set filterSortSearch state
        const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
        const iconsType = [];
        icons.forEach((icon) => {
            if (icon.active) {
                iconsType.push({ identifier: this.filterToolbarService.getIconFilterCombinedKey(icon), icon: icon.icon });
            }
        });
        activeFilterSortSearch.iconAttributes = iconsType;
        this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
        // emit the changes in filter, sort and search to the consuming application
        this.mainFacadeSetterService.publishFilterSortSearch(activeFilterSortSearch);
    }
    /**
     * The action that is to be performed in for the items.
     * @param filterAttributes The selected filter attributes.
     */
    onSelectedFilters(filterAttributes) {
        // set value in filter state
        this.filterState.setSimpleFilterSubject(filterAttributes);
        // check for changes in filter in regard to preset
        this.changedValuesService.checkFilterValuesChangedComparedToValuesInPreset();
        // set filterSortSearch state
        const filterState = [];
        filterAttributes.forEach((filter) => {
            filterState.push({ identifier: filter.identifier, operator: filter.operator, value: filter.value });
        });
        const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
        activeFilterSortSearch.filterAttributes = filterState;
        this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
        // check if the filter changed in regard to the emitted buffer
        this.filterState.setFilterAndSortChangedInComparisonToEmittedState(this.mainFacadeSetterService.compareFilterSort(this.inboxState.activeFilterSortSearch.value, this.mainFacadeSetterService.filterSortSearchEmitterBuffer));
    }
    /**
     * Handles the selected sorts.
     * @param sorts
     */
    onSelectedSorts(sorts) {
        // set value in filter state
        this.filterState.setSortSubject(sorts);
        // check for changes in sort in regard to preset
        this.changedValuesService.checkSortValuesChangedComparedToValuesInPreset();
        // set filterSortSearch state
        const sortState = [];
        sorts.forEach((sort) => {
            sortState.push({ identifier: sort.identifier, sort: sort.sort });
        });
        const activeFilterSortSearch = this.inboxState.activeFilterSortSearch.value;
        activeFilterSortSearch.sortAttributes = sortState;
        this.inboxState.setActiveFilterSortSearch(activeFilterSortSearch);
        // check if the filter changed in regard to the emitted buffer
        this.filterState.setFilterAndSortChangedInComparisonToEmittedState(this.mainFacadeSetterService.compareFilterSort(this.inboxState.activeFilterSortSearch.value, this.mainFacadeSetterService.filterSortSearchEmitterBuffer));
    }
    /**
     * Initializes the component for paginator usage.
     * @private
     */
    initializeComponentForPaginatorUsage() {
        // check if the inbox configuration values are set else disable inbox and sorting if pagination is used
        if (this.inboxState.inboxConfiguration$.value.disableInboxSorting === undefined) {
            this.inboxState.inboxConfiguration$.value.disableInboxSorting = this.usePagination;
        }
    }
    /**
     * Resets the inbox component.
     */
    resetComponent() {
        this.subscriptions.unsubscribe();
        this.subscriptions.closed = false;
        // check if the presets are used
        if (this.presets.length > 0) {
            this.initializeComponentForViewUsage();
        }
        // initialize the inbox for paginator usage
        this.initializeComponentForPaginatorUsage();
        // initialize the component
        this.initializeComponent();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: InboxComponent, isStandalone: true, selector: "talenra-inbox, talenra-workspace-inbox", inputs: { dataItems: { classPropertyName: "dataItems", publicName: "dataItems", isSignal: false, isRequired: false, transformFunction: null }, attributes: { classPropertyName: "attributes", publicName: "attributes", isSignal: false, isRequired: true, transformFunction: null }, presets: { classPropertyName: "presets", publicName: "presets", isSignal: false, isRequired: false, transformFunction: null }, activePresetName: { classPropertyName: "activePresetName", publicName: "activePresetName", isSignal: false, isRequired: false, transformFunction: null }, detailViewTabs: { classPropertyName: "detailViewTabs", publicName: "detailViewTabs", isSignal: true, isRequired: false, transformFunction: null }, inboxConfigurationPanelTabs: { classPropertyName: "inboxConfigurationPanelTabs", publicName: "inboxConfigurationPanelTabs", isSignal: true, isRequired: false, transformFunction: null }, loading: { classPropertyName: "loading", publicName: "loading", isSignal: false, isRequired: false, transformFunction: null }, pairingAttributes: { classPropertyName: "pairingAttributes", publicName: "pairingAttributes", isSignal: false, isRequired: false, transformFunction: null }, noteBoxItems: { classPropertyName: "noteBoxItems", publicName: "noteBoxItems", isSignal: false, isRequired: false, transformFunction: null }, refreshing: { classPropertyName: "refreshing", publicName: "refreshing", isSignal: false, isRequired: false, transformFunction: null }, selectDataItem: { classPropertyName: "selectDataItem", publicName: "selectDataItem", isSignal: false, isRequired: false, transformFunction: null }, lockedDataItems: { classPropertyName: "lockedDataItems", publicName: "lockedDataItems", isSignal: false, isRequired: false, transformFunction: null }, usePagination: { classPropertyName: "usePagination", publicName: "usePagination", isSignal: false, isRequired: false, transformFunction: booleanAttribute }, paginatorState: { classPropertyName: "paginatorState", publicName: "paginatorState", isSignal: false, isRequired: false, transformFunction: null }, query: { classPropertyName: "query", publicName: "query", isSignal: true, isRequired: false, transformFunction: null }, possibleRules: { classPropertyName: "possibleRules", publicName: "possibleRules", isSignal: true, isRequired: false, transformFunction: null }, possibleOptions: { classPropertyName: "possibleOptions", publicName: "possibleOptions", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { query: "queryChange", clickedDataItemEmitter: "clickedDataItemEmitter", dataItemsInteractions: "dataItemsInteractions", presetAction: "presetAction", virtualScrollerPosition: "virtualScrollerPosition", selectedMainAttributesEmitter: "selectedMainAttributesEmitter", selectedDetailAttributesEmitter: "selectedDetailAttributesEmitter", selectedAllAttributesEmitter: "selectedAllAttributesEmitter", filterSortSearchEmitter: "filterSortSearchEmitter", refreshingChange: "refreshingChange", paginatorStateChange: "paginatorStateChange" }, usesOnChanges: true, ngImport: i0, template: "@if (!loading && (mainFacadeSetterService.allAttributes$ | async); as attributeList) {\n  <talenra-inbox-configuration-panel\n    (buttonAction)=\"onInboxConfigurationPanelButtonAction($event)\"\n    (isExpandedChange)=\"inboxToolbarService.setConfigurationPanelState($event)\"\n    (numberMainAttributesChosenByUserEmitter)=\"numberMainAttributesChosenByUserHandler($event)\"\n    (selectedAllAttributesEmitter)=\"selectedAllAttributesHandler($event)\"\n    (selectedDetailAttributesEmitter)=\"selectedDetailAttributesEmitterHandler($event)\"\n    (selectedMainAttributesEmitter)=\"selectedMainAttributesEmitterHandler($event)\"\n    (selectedFilters)=\"onSelectedFilters($event)\"\n    (selectedSorts)=\"onSelectedSorts($event)\"\n    [(query)]=\"query\"\n    [(selectedTab)]=\"inboxState.selectedSidePanelTab\"\n    [attributesSettingsList]=\"attributeList\"\n    [customTabs]=\"inboxConfigurationPanelTabs()\"\n    [isExpanded]=\"(inboxToolbarService.configurationPanelExpanded$ | async) === true\"\n    [maxAttributesShown]=\"mainFacadeSetterService.maxMainAttributes\"\n    [numberMainAttributesChosenByUser]=\"mainFacadeSetterService.numberMainAttributesChosenByUser$.value\"\n    [possibleOptions]=\"possibleOptions()\"\n    [possibleRules]=\"possibleRules()\"\n    [filterSelections]=\"mainFacadeSetterService.filterSelection\"\n    [sortSelections]=\"mainFacadeSetterService.sortSelection\"\n    [selectedDetailAttributes]=\"inboxState.selectedDetailAttributesSubject$.value\"\n    [selectedMainAttributes]=\"inboxState.selectedMainAttributesSubject$.value\">\n    <div\n      [class.toolbar-scroll-shadow]=\"inboxHelperService.startIndexDataItemsListSubject$.value > 1\"\n      class=\"toolbar-group\">\n      @if (!inboxState.inboxConfiguration$.value.disableToolbar) {\n        <talenra-inbox-toolbar\n          (iconBtn)=\"iconBtnFunction($event)\"\n          (presetInteractions)=\"handleChangesOnPreset($event)\"\n          (resetPreset)=\"resetPresetEmitterHandler()\"\n          [(checkboxState)]=\"mainCheckboxState\"\n          [disableBulkInteractionButtons]=\"numberMarkedDataItems <= 1\"\n          [fixDisableDetailViewToggle]=\"keyboardService.disabledButtonNoDataItemFound\"\n          [numberMarkedDataItems]=\"numberMarkedDataItems\"\n          [presetGroups]=\"inboxState.presetGroups$.value\"\n          [refreshing]=\"refreshing\">\n          <ng-content ngProjectAs=\"[further-actions-menu]\" select=\"[further-actions-toolbar-menu]\"></ng-content>\n          <ng-content ngProjectAs=\"[custom-toolbar-space]\" select=\"[custom-toolbar-space]\"></ng-content>\n        </talenra-inbox-toolbar>\n      }\n      @if (!inboxState.inboxConfiguration$.value.disableFilterToolbar) {\n        <talenra-filter-toolbar\n          (iconFiltersChange)=\"onIconFilterChange($event)\"\n          [iconFilters]=\"mainFacadeSetterService.iconSelection\"></talenra-filter-toolbar>\n      }\n    </div>\n    @if (!refreshing) {\n      <talenra-inbox-layout\n        [class.header-hide]=\"inboxHelperService.startIndexDataItemsListSubject$.value > 1\"\n        [detailViewInformationTabBarItems]=\"inboxDetailViewTabs()\"\n        [usePagination]=\"usePagination\">\n        @if (!inboxState.inboxConfiguration$.value.disableDataItemsList || dataItems === (undefined || null)) {\n          <div>\n            <talenra-data-items-list\n              (clickedDataItem)=\"clickedDataItemFunction($event)\"\n              (dataItemsInteractions)=\"onDataItemsInteractions($event)\"\n              (numberMarkedDataItemsChange)=\"numberMarkedDataItemsChange($event)\"\n              (virtualScrollChange)=\"inboxHelperService.onScrollChange($event)\"\n              [(mainCheckboxState)]=\"mainCheckboxState\"\n              [dataItems]=\"inboxState.filteredDataItemsSubject$.value\"\n              [lockedDataItems]=\"lockedDataItems\"\n              [pairingAttributes]=\"pairingAttributes\"\n              [scrollToIndex]=\"keyboardService.scrollToIndex\"\n              [selectedDataItem]=\"dataItemsService.activeDataItem$ | async\"\n              [selectedMainAttributes]=\"inboxState.selectedMainAttributesSubject$.value\">\n              <ng-content ngProjectAs=\"[further-actions-menu]\" select=\"[further-actions-data-item-menu]\"></ng-content>\n            </talenra-data-items-list>\n          </div>\n        }\n        @if (usePagination) {\n          <div inbox-paginator>\n            <div class=\"pagination-container\">\n              <talenra-paginator\n                (stateChange)=\"onPaginatorStateChange($event)\"\n                [state]=\"paginatorState\"\n                showMoveFirstLastButtons\n                useResponsiveMode></talenra-paginator>\n            </div>\n          </div>\n        }\n        @if (inboxState.inboxConfiguration$.value.disableDataItemsList) {\n          <div>\n            @if (!inboxState.inboxConfiguration$.value.disableDataItemsList) {\n            } @else {\n              <ng-content *ngTemplateOutlet=\"customDataItemsList\"></ng-content>\n            }\n          </div>\n        }\n        <div inbox-note-box>\n          @if (\n            inboxState.inboxConfiguration$.value.useCustomNoteBox &&\n            !inboxState.inboxConfiguration$.value.disableNoteBox\n          ) {\n            <div>\n              <ng-content select=\"[inbox-note-box]\"></ng-content>\n            </div>\n          } @else {\n            @if (\n              !inboxState.inboxConfiguration$.value.disableNoteBox &&\n              !inboxState.inboxConfiguration$.value.useCustomNoteBox\n            ) {\n              <talenra-inbox-note-box [noteBoxItems]=\"inboxHelperService.getSelectedDataItemNotes(noteBoxItems)\">\n              </talenra-inbox-note-box>\n            }\n          }\n        </div>\n        <ng-container ngProjectAs=\"[data-item-information-outlet]\">\n          @for (\n            dataItemInformationItem of inboxDetailViewTabs();\n            track dataItemInformationItem.label;\n            let index = $index\n          ) {\n            <talenra-detail-view-information [detailViewTab]=\"dataItemInformationItem\">\n              @if (\n                dataItemInformationItem['key'] === '1' &&\n                inboxState.inboxConfiguration$.value.disableDetailViewMainTab !== true\n              ) {\n                <div>\n                  <p class=\"panel-title\">\n                    {{\n                      inboxState.inboxConfiguration$.value.detailViewMainTabTitle\n                        ? inboxState.inboxConfiguration$.value.detailViewMainTabTitle\n                        : 'Informationen zum Fall'\n                    }}\n                  </p>\n                  <p class=\"pairs\">\n                    @for (\n                      dataItemInformationItem of inboxState.selectedDetailAttributesSubject$ | async;\n                      track dataItemInformationItem.identifier;\n                      let index = $index\n                    ) {\n                      <div class=\"pair\">\n                        @if (\n                          dataItemsService.activeDataItem$.value && index <= mainFacadeSetterService.maxAttributesDetail\n                        ) {\n                          <div class=\"label\">\n                            {{ dataItemInformationItem.label }}\n                          </div>\n                        }\n                        @if (\n                          dataItemsService.activeDataItem$.value && index <= mainFacadeSetterService.maxAttributesDetail\n                        ) {\n                          <div\n                            [textToCopy]=\"\n                              dataItemsClass.getElemFromDataItemDisplayed(\n                                dataItemsService.activeDataItem$.value,\n                                dataItemInformationItem.identifier\n                              )\n                            \"\n                            class=\"value\">\n                            {{\n                              dataItemsClass.getElemFromDataItemDisplayed(\n                                dataItemsService.activeDataItem$.value,\n                                dataItemInformationItem.identifier\n                              )\n                            }}\n                          </div>\n                        }\n                      </div>\n                    }\n                  </p>\n                </div>\n              }\n              @for (detailViewTabs of detailViewTabs(); track detailViewTabs.label; let index1 = $index) {\n                @if (\n                  (dataItemInformationItem['key'] === (index1 + 2).toString() &&\n                    !inboxState.inboxConfiguration$.value.disableDetailViewMainTab) ||\n                  (inboxState.inboxConfiguration$.value.disableDetailViewMainTab &&\n                    dataItemInformationItem['key'] === (index1 + 1).toString())\n                ) {\n                  <ng-container\n                    *ngTemplateOutlet=\"\n                      detailViewTabs.detailViewTabContentTemplate\n                        ? detailViewTabs.detailViewTabContentTemplate\n                        : detailViewTabContent\n                    \"></ng-container>\n                }\n              }\n            </talenra-detail-view-information>\n          }\n        </ng-container>\n      </talenra-inbox-layout>\n    }\n    @if (refreshing) {\n      @if (inboxState.inboxConfiguration$.value.disableDataItemsList) {\n        <div class=\"data-items-list-skeleton-loaders\">\n          <ng-content *ngTemplateOutlet=\"customDataItemsList\"></ng-content>\n        </div>\n      } @else {\n        <talenra-skeleton-loading-data-items-list\n          class=\"skeleton-loading-data-items-list\"></talenra-skeleton-loading-data-items-list>\n      }\n    }\n  </talenra-inbox-configuration-panel>\n} @else {\n  <talenra-inbox-skeleton-loading></talenra-inbox-skeleton-loading>\n}\n\n<ng-template #detailViewTabContent></ng-template>\n\n<ng-template #customDataItemsList>\n  <ng-content select=\"[custom-data-items-list]\"></ng-content>\n</ng-template>\n", styles: [":host ::ng-deep .ng-dropdown-panel.ng-select-bottom{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;top:100%;--color-background: #ffffff;--color-label: #666666;--color-text: #000000}.toolbar-group{margin-right:1rem}.toolbar-scroll-shadow{box-shadow:0 2px 5px #0003}.pagination-container{background-color:var(--color-background);color:var(--color-text);margin:.125rem 0 0;padding:.25rem 1rem 0}.panel-title{font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;margin-top:1.3125rem;margin-bottom:.8125rem;padding-bottom:.3125rem}.pairs{margin:0 0 .8125rem;cursor:pointer}.pair{display:flex;flex-direction:column;flex-wrap:nowrap;margin-bottom:.625rem}.label{font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-label);width:fit-content}.value{font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;width:fit-content}.data-items-list-skeleton-loaders{position:relative;flex-grow:1}.skeleton-loading-data-items-list{padding:.5rem .5rem 0 0;margin-right:.5rem}.appearance--dark :host{--color-background: #cccccc;--color-label: #666666;--color-text: #cccccc}\n"], dependencies: [{ kind: "component", type: InboxSkeletonLoadingComponent, selector: "talenra-inbox-skeleton-loading" }, { kind: "component", type: SkeletonLoadingDataItemsListComponent, selector: "talenra-skeleton-loading-data-items-list" }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: CopyContentDirective, selector: "[textToCopy]", inputs: ["textToCopy", "copyContentPosition", "copyContentNegativeColor", "copyContentTooltip"] }, { kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "component", type: DetailViewInformationComponent, selector: "talenra-detail-view-information", inputs: ["detailViewTab"] }, { kind: "component", type: InboxNoteBoxComponent, selector: "talenra-inbox-note-box", inputs: ["noteBoxItems"] }, { kind: "component", type: PaginatorComponent, selector: "talenra-paginator", inputs: ["state", "dynamicLocale", "showFirstLastButtons", "hideItemsPerPage", "useResponsiveMode", "align"], outputs: ["stateChange"] }, { kind: "component", type: DataItemsListComponent, selector: "talenra-data-items-list", inputs: ["dataItems", "selectedDataItem", "selectedMainAttributes", "pairingAttributes", "scrollToIndex", "lockedDataItems", "mainCheckboxState"], outputs: ["clickedDataItem", "dataItemsInteractions", "virtualScrollChange", "numberMarkedDataItemsChange", "mainCheckboxStateChange"] }, { kind: "component", type: InboxLayoutComponent, selector: "talenra-inbox-layout", inputs: ["detailViewInformationTabBarItems", "usePagination"] }, { kind: "component", type: FilterToolbarComponent, selector: "talenra-filter-toolbar", inputs: ["iconFilters"], outputs: ["iconFiltersChange"] }, { kind: "component", type: InboxToolbarComponent, selector: "talenra-inbox-toolbar", inputs: ["presetGroups", "disableBulkInteractionButtons", "fixDisableDetailViewToggle", "numberMarkedDataItems", "refreshing", "checkboxState"], outputs: ["iconBtn", "presetInteractions", "deletePreset", "changePresetName", "checkboxStateChange", "resetPreset"] }, { kind: "component", type: InboxConfigurationPanelComponent, selector: "talenra-inbox-configuration-panel", inputs: ["attributesSettingsList", "maxAttributesShown", "numberMainAttributesChosenByUser", "isExpanded", "selectedMainAttributes", "selectedDetailAttributes", "selectedTab", "query", "possibleRules", "possibleOptions", "customTabs", "filterSelections", "sortSelections"], outputs: ["selectedTabChange", "queryChange", "filterSelectionsChange", "sortSelectionsChange", "selectedMainAttributesEmitter", "selectedDetailAttributesEmitter", "selectedAllAttributesEmitter", "isExpandedChange", "numberMainAttributesChosenByUserEmitter", "buttonAction", "selectedFilters", "selectedSorts"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox, talenra-workspace-inbox', standalone: true, imports: [
                        InboxSkeletonLoadingComponent,
                        SkeletonLoadingDataItemsListComponent,
                        NgTemplateOutlet,
                        CopyContentDirective,
                        AsyncPipe,
                        DetailViewInformationComponent,
                        InboxNoteBoxComponent,
                        PaginatorComponent,
                        DataItemsListComponent,
                        InboxLayoutComponent,
                        FilterToolbarComponent,
                        InboxToolbarComponent,
                        InboxConfigurationPanelComponent,
                    ], template: "@if (!loading && (mainFacadeSetterService.allAttributes$ | async); as attributeList) {\n  <talenra-inbox-configuration-panel\n    (buttonAction)=\"onInboxConfigurationPanelButtonAction($event)\"\n    (isExpandedChange)=\"inboxToolbarService.setConfigurationPanelState($event)\"\n    (numberMainAttributesChosenByUserEmitter)=\"numberMainAttributesChosenByUserHandler($event)\"\n    (selectedAllAttributesEmitter)=\"selectedAllAttributesHandler($event)\"\n    (selectedDetailAttributesEmitter)=\"selectedDetailAttributesEmitterHandler($event)\"\n    (selectedMainAttributesEmitter)=\"selectedMainAttributesEmitterHandler($event)\"\n    (selectedFilters)=\"onSelectedFilters($event)\"\n    (selectedSorts)=\"onSelectedSorts($event)\"\n    [(query)]=\"query\"\n    [(selectedTab)]=\"inboxState.selectedSidePanelTab\"\n    [attributesSettingsList]=\"attributeList\"\n    [customTabs]=\"inboxConfigurationPanelTabs()\"\n    [isExpanded]=\"(inboxToolbarService.configurationPanelExpanded$ | async) === true\"\n    [maxAttributesShown]=\"mainFacadeSetterService.maxMainAttributes\"\n    [numberMainAttributesChosenByUser]=\"mainFacadeSetterService.numberMainAttributesChosenByUser$.value\"\n    [possibleOptions]=\"possibleOptions()\"\n    [possibleRules]=\"possibleRules()\"\n    [filterSelections]=\"mainFacadeSetterService.filterSelection\"\n    [sortSelections]=\"mainFacadeSetterService.sortSelection\"\n    [selectedDetailAttributes]=\"inboxState.selectedDetailAttributesSubject$.value\"\n    [selectedMainAttributes]=\"inboxState.selectedMainAttributesSubject$.value\">\n    <div\n      [class.toolbar-scroll-shadow]=\"inboxHelperService.startIndexDataItemsListSubject$.value > 1\"\n      class=\"toolbar-group\">\n      @if (!inboxState.inboxConfiguration$.value.disableToolbar) {\n        <talenra-inbox-toolbar\n          (iconBtn)=\"iconBtnFunction($event)\"\n          (presetInteractions)=\"handleChangesOnPreset($event)\"\n          (resetPreset)=\"resetPresetEmitterHandler()\"\n          [(checkboxState)]=\"mainCheckboxState\"\n          [disableBulkInteractionButtons]=\"numberMarkedDataItems <= 1\"\n          [fixDisableDetailViewToggle]=\"keyboardService.disabledButtonNoDataItemFound\"\n          [numberMarkedDataItems]=\"numberMarkedDataItems\"\n          [presetGroups]=\"inboxState.presetGroups$.value\"\n          [refreshing]=\"refreshing\">\n          <ng-content ngProjectAs=\"[further-actions-menu]\" select=\"[further-actions-toolbar-menu]\"></ng-content>\n          <ng-content ngProjectAs=\"[custom-toolbar-space]\" select=\"[custom-toolbar-space]\"></ng-content>\n        </talenra-inbox-toolbar>\n      }\n      @if (!inboxState.inboxConfiguration$.value.disableFilterToolbar) {\n        <talenra-filter-toolbar\n          (iconFiltersChange)=\"onIconFilterChange($event)\"\n          [iconFilters]=\"mainFacadeSetterService.iconSelection\"></talenra-filter-toolbar>\n      }\n    </div>\n    @if (!refreshing) {\n      <talenra-inbox-layout\n        [class.header-hide]=\"inboxHelperService.startIndexDataItemsListSubject$.value > 1\"\n        [detailViewInformationTabBarItems]=\"inboxDetailViewTabs()\"\n        [usePagination]=\"usePagination\">\n        @if (!inboxState.inboxConfiguration$.value.disableDataItemsList || dataItems === (undefined || null)) {\n          <div>\n            <talenra-data-items-list\n              (clickedDataItem)=\"clickedDataItemFunction($event)\"\n              (dataItemsInteractions)=\"onDataItemsInteractions($event)\"\n              (numberMarkedDataItemsChange)=\"numberMarkedDataItemsChange($event)\"\n              (virtualScrollChange)=\"inboxHelperService.onScrollChange($event)\"\n              [(mainCheckboxState)]=\"mainCheckboxState\"\n              [dataItems]=\"inboxState.filteredDataItemsSubject$.value\"\n              [lockedDataItems]=\"lockedDataItems\"\n              [pairingAttributes]=\"pairingAttributes\"\n              [scrollToIndex]=\"keyboardService.scrollToIndex\"\n              [selectedDataItem]=\"dataItemsService.activeDataItem$ | async\"\n              [selectedMainAttributes]=\"inboxState.selectedMainAttributesSubject$.value\">\n              <ng-content ngProjectAs=\"[further-actions-menu]\" select=\"[further-actions-data-item-menu]\"></ng-content>\n            </talenra-data-items-list>\n          </div>\n        }\n        @if (usePagination) {\n          <div inbox-paginator>\n            <div class=\"pagination-container\">\n              <talenra-paginator\n                (stateChange)=\"onPaginatorStateChange($event)\"\n                [state]=\"paginatorState\"\n                showMoveFirstLastButtons\n                useResponsiveMode></talenra-paginator>\n            </div>\n          </div>\n        }\n        @if (inboxState.inboxConfiguration$.value.disableDataItemsList) {\n          <div>\n            @if (!inboxState.inboxConfiguration$.value.disableDataItemsList) {\n            } @else {\n              <ng-content *ngTemplateOutlet=\"customDataItemsList\"></ng-content>\n            }\n          </div>\n        }\n        <div inbox-note-box>\n          @if (\n            inboxState.inboxConfiguration$.value.useCustomNoteBox &&\n            !inboxState.inboxConfiguration$.value.disableNoteBox\n          ) {\n            <div>\n              <ng-content select=\"[inbox-note-box]\"></ng-content>\n            </div>\n          } @else {\n            @if (\n              !inboxState.inboxConfiguration$.value.disableNoteBox &&\n              !inboxState.inboxConfiguration$.value.useCustomNoteBox\n            ) {\n              <talenra-inbox-note-box [noteBoxItems]=\"inboxHelperService.getSelectedDataItemNotes(noteBoxItems)\">\n              </talenra-inbox-note-box>\n            }\n          }\n        </div>\n        <ng-container ngProjectAs=\"[data-item-information-outlet]\">\n          @for (\n            dataItemInformationItem of inboxDetailViewTabs();\n            track dataItemInformationItem.label;\n            let index = $index\n          ) {\n            <talenra-detail-view-information [detailViewTab]=\"dataItemInformationItem\">\n              @if (\n                dataItemInformationItem['key'] === '1' &&\n                inboxState.inboxConfiguration$.value.disableDetailViewMainTab !== true\n              ) {\n                <div>\n                  <p class=\"panel-title\">\n                    {{\n                      inboxState.inboxConfiguration$.value.detailViewMainTabTitle\n                        ? inboxState.inboxConfiguration$.value.detailViewMainTabTitle\n                        : 'Informationen zum Fall'\n                    }}\n                  </p>\n                  <p class=\"pairs\">\n                    @for (\n                      dataItemInformationItem of inboxState.selectedDetailAttributesSubject$ | async;\n                      track dataItemInformationItem.identifier;\n                      let index = $index\n                    ) {\n                      <div class=\"pair\">\n                        @if (\n                          dataItemsService.activeDataItem$.value && index <= mainFacadeSetterService.maxAttributesDetail\n                        ) {\n                          <div class=\"label\">\n                            {{ dataItemInformationItem.label }}\n                          </div>\n                        }\n                        @if (\n                          dataItemsService.activeDataItem$.value && index <= mainFacadeSetterService.maxAttributesDetail\n                        ) {\n                          <div\n                            [textToCopy]=\"\n                              dataItemsClass.getElemFromDataItemDisplayed(\n                                dataItemsService.activeDataItem$.value,\n                                dataItemInformationItem.identifier\n                              )\n                            \"\n                            class=\"value\">\n                            {{\n                              dataItemsClass.getElemFromDataItemDisplayed(\n                                dataItemsService.activeDataItem$.value,\n                                dataItemInformationItem.identifier\n                              )\n                            }}\n                          </div>\n                        }\n                      </div>\n                    }\n                  </p>\n                </div>\n              }\n              @for (detailViewTabs of detailViewTabs(); track detailViewTabs.label; let index1 = $index) {\n                @if (\n                  (dataItemInformationItem['key'] === (index1 + 2).toString() &&\n                    !inboxState.inboxConfiguration$.value.disableDetailViewMainTab) ||\n                  (inboxState.inboxConfiguration$.value.disableDetailViewMainTab &&\n                    dataItemInformationItem['key'] === (index1 + 1).toString())\n                ) {\n                  <ng-container\n                    *ngTemplateOutlet=\"\n                      detailViewTabs.detailViewTabContentTemplate\n                        ? detailViewTabs.detailViewTabContentTemplate\n                        : detailViewTabContent\n                    \"></ng-container>\n                }\n              }\n            </talenra-detail-view-information>\n          }\n        </ng-container>\n      </talenra-inbox-layout>\n    }\n    @if (refreshing) {\n      @if (inboxState.inboxConfiguration$.value.disableDataItemsList) {\n        <div class=\"data-items-list-skeleton-loaders\">\n          <ng-content *ngTemplateOutlet=\"customDataItemsList\"></ng-content>\n        </div>\n      } @else {\n        <talenra-skeleton-loading-data-items-list\n          class=\"skeleton-loading-data-items-list\"></talenra-skeleton-loading-data-items-list>\n      }\n    }\n  </talenra-inbox-configuration-panel>\n} @else {\n  <talenra-inbox-skeleton-loading></talenra-inbox-skeleton-loading>\n}\n\n<ng-template #detailViewTabContent></ng-template>\n\n<ng-template #customDataItemsList>\n  <ng-content select=\"[custom-data-items-list]\"></ng-content>\n</ng-template>\n", styles: [":host ::ng-deep .ng-dropdown-panel.ng-select-bottom{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;top:100%;--color-background: #ffffff;--color-label: #666666;--color-text: #000000}.toolbar-group{margin-right:1rem}.toolbar-scroll-shadow{box-shadow:0 2px 5px #0003}.pagination-container{background-color:var(--color-background);color:var(--color-text);margin:.125rem 0 0;padding:.25rem 1rem 0}.panel-title{font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;margin-top:1.3125rem;margin-bottom:.8125rem;padding-bottom:.3125rem}.pairs{margin:0 0 .8125rem;cursor:pointer}.pair{display:flex;flex-direction:column;flex-wrap:nowrap;margin-bottom:.625rem}.label{font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-label);width:fit-content}.value{font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;width:fit-content}.data-items-list-skeleton-loaders{position:relative;flex-grow:1}.skeleton-loading-data-items-list{padding:.5rem .5rem 0 0;margin-right:.5rem}.appearance--dark :host{--color-background: #cccccc;--color-label: #666666;--color-text: #cccccc}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { dataItems: [{
                type: Input
            }], attributes: [{
                type: Input,
                args: [{ required: true }]
            }], presets: [{
                type: Input
            }], activePresetName: [{
                type: Input
            }], loading: [{
                type: Input
            }], pairingAttributes: [{
                type: Input
            }], noteBoxItems: [{
                type: Input
            }], refreshing: [{
                type: Input
            }], selectDataItem: [{
                type: Input
            }], lockedDataItems: [{
                type: Input
            }], usePagination: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], paginatorState: [{
                type: Input
            }], clickedDataItemEmitter: [{
                type: Output
            }], dataItemsInteractions: [{
                type: Output
            }], presetAction: [{
                type: Output
            }], virtualScrollerPosition: [{
                type: Output
            }], selectedMainAttributesEmitter: [{
                type: Output
            }], selectedDetailAttributesEmitter: [{
                type: Output
            }], selectedAllAttributesEmitter: [{
                type: Output
            }], filterSortSearchEmitter: [{
                type: Output
            }], refreshingChange: [{
                type: Output
            }], paginatorStateChange: [{
                type: Output
            }] } });

/**
 *  InboxShortcutsComponent is used to display the shortcuts in the inbox toolbar.
 *  @example
 * <talenra-inbox-shortcuts [customShortcuts]="customShortcuts"></talenra-inbox-shortcuts>
 *
 */
class InboxShortcutsComponent {
    constructor() {
        /**
         * The list of shortcuts to display.
         */
        this.customShortcuts = [];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxShortcutsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: InboxShortcutsComponent, isStandalone: true, selector: "talenra-inbox-shortcuts", inputs: { customShortcuts: "customShortcuts" }, ngImport: i0, template: "<div class=\"shortcuts-main-title\">Tastaturbefehle</div>\n<talenra-scroll-container class=\"shortcuts-text\">\n  <div class=\"shortcuts-scroll-main-title\">Inbox</div>\n  <div class=\"shortcuts-scroll-sub-title\"></div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">\n      <talenra-icon class=\"arrow-icon\" name=\"expand-less\"></talenra-icon>\n      <talenra-icon class=\"arrow-icon\" name=\"expand-more\"></talenra-icon>\n    </span>\n    <span class=\"value\">Mit Pfeiltaste runter/hoch durch Fallliste navigieren</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">a</span>\n    <span class=\"value\">\n      Aktionen-Menu aufrufen <br />\n      Erg\u00E4nzender Buchstabe beim Link ruft Aktion auf\n    </span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">x</span>\n    <span class=\"value\"> Fall-Informationen \u00F6ffnen/schliessen </span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">i</span>\n    <span class=\"value\">Fall-Icons ein-/ausblenden</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing short-margin-top-item\">\n    <span class=\"label\">d</span>\n    <span class=\"value\">Detailinformationen zum Fall \u00F6ffnen/schliessen</span>\n  </div>\n  <div class=\"pairing short-margin-bottom-item\">\n    <span class=\"label\">b</span>\n    <span class=\"value\">Breite der Detailinformationen maximieren</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">\n      <talenra-icon class=\"arrow-icon\" name=\"chevron-left\"></talenra-icon>\n      <talenra-icon class=\"arrow-icon\" name=\"chevron-right\"></talenra-icon>\n    </span>\n    <span class=\"value\">\n      Detailinformationen ge\u00F6ffnet: mit Tastaturpfeilen links/rechts durch die Reiter navigieren\n    </span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">f</span>\n    <span class=\"value\">Erweiterte Filteransicht \u00F6ffnen/schliessen (Filterung muss aktiviert sein)</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">v</span>\n    <span class=\"value\">View-Menu \u00F6ffnen/schliessen</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">Enter</span>\n    <span class=\"value\">Aktiven Fall mit Enter starten (Prozess ausf\u00FChren)</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"shortcuts-scroll-title\">F\u00E4lle f\u00FCr Sammelaktion markieren</div>\n  <div class=\"shortcuts-scroll-sub-title\">(Alternative zu Checkbox anw\u00E4hlen)</div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">Command + Fall-Klick</span>\n    <span class=\"value\">F\u00E4lle einzeln markieren/demarkieren</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">Shift + Fall-Klick</span>\n    <span class=\"value\">Mehrere F\u00E4lle vom aktiven Fall bis zum geklickten Fall markieren</span>\n  </div>\n  <div class=\"line\"></div>\n  @if (customShortcuts.length !== 0) {\n    <div class=\"shortcuts-scroll-title\">Weitere Tastaturbefehle</div>\n  }\n  @if (customShortcuts.length !== 0) {\n    <div class=\"shortcuts-scroll-sub-title\"></div>\n  }\n  @if (customShortcuts.length !== 0) {\n    <div class=\"line\"></div>\n  }\n  @for (shortcut of customShortcuts; track shortcut) {\n    <div>\n      <div class=\"pairing\">\n        <span class=\"label\">{{ shortcut.key }}</span>\n        <span class=\"value\">{{ shortcut.behavior }}</span>\n      </div>\n      <div class=\"line\"></div>\n    </div>\n  }\n</talenra-scroll-container>\n", styles: [".shortcuts-main-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:8px 24px 16px}.shortcuts-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:8px 8px 8px 16px}.shortcuts-scroll-main-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:8px 0 0}.shortcuts-scroll-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:24px 0 0}.shortcuts-scroll-sub-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;margin:0 0 8px}.shortcuts-text{max-width:410px;max-height:570px;margin:8px 24px;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased}.pairing{display:flex;flex-direction:row;flex-wrap:nowrap;width:100%;margin:8px 0 4px}.short-margin-top-item{margin:8px 0 0}.short-margin-bottom-item{margin:0 0 4px}.label{font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;width:85px}.value{font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;width:315px;margin-left:10px}.line{border-bottom:1px solid #e6e6e6;display:block}.arrow-icon{font-size:18px}\n"], dependencies: [{ kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }, { kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: InboxShortcutsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-inbox-shortcuts', standalone: true, imports: [ScrollContainerComponent, IconComponent], template: "<div class=\"shortcuts-main-title\">Tastaturbefehle</div>\n<talenra-scroll-container class=\"shortcuts-text\">\n  <div class=\"shortcuts-scroll-main-title\">Inbox</div>\n  <div class=\"shortcuts-scroll-sub-title\"></div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">\n      <talenra-icon class=\"arrow-icon\" name=\"expand-less\"></talenra-icon>\n      <talenra-icon class=\"arrow-icon\" name=\"expand-more\"></talenra-icon>\n    </span>\n    <span class=\"value\">Mit Pfeiltaste runter/hoch durch Fallliste navigieren</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">a</span>\n    <span class=\"value\">\n      Aktionen-Menu aufrufen <br />\n      Erg\u00E4nzender Buchstabe beim Link ruft Aktion auf\n    </span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">x</span>\n    <span class=\"value\"> Fall-Informationen \u00F6ffnen/schliessen </span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">i</span>\n    <span class=\"value\">Fall-Icons ein-/ausblenden</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing short-margin-top-item\">\n    <span class=\"label\">d</span>\n    <span class=\"value\">Detailinformationen zum Fall \u00F6ffnen/schliessen</span>\n  </div>\n  <div class=\"pairing short-margin-bottom-item\">\n    <span class=\"label\">b</span>\n    <span class=\"value\">Breite der Detailinformationen maximieren</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">\n      <talenra-icon class=\"arrow-icon\" name=\"chevron-left\"></talenra-icon>\n      <talenra-icon class=\"arrow-icon\" name=\"chevron-right\"></talenra-icon>\n    </span>\n    <span class=\"value\">\n      Detailinformationen ge\u00F6ffnet: mit Tastaturpfeilen links/rechts durch die Reiter navigieren\n    </span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">f</span>\n    <span class=\"value\">Erweiterte Filteransicht \u00F6ffnen/schliessen (Filterung muss aktiviert sein)</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">v</span>\n    <span class=\"value\">View-Menu \u00F6ffnen/schliessen</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">Enter</span>\n    <span class=\"value\">Aktiven Fall mit Enter starten (Prozess ausf\u00FChren)</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"shortcuts-scroll-title\">F\u00E4lle f\u00FCr Sammelaktion markieren</div>\n  <div class=\"shortcuts-scroll-sub-title\">(Alternative zu Checkbox anw\u00E4hlen)</div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">Command + Fall-Klick</span>\n    <span class=\"value\">F\u00E4lle einzeln markieren/demarkieren</span>\n  </div>\n  <div class=\"line\"></div>\n  <div class=\"pairing\">\n    <span class=\"label\">Shift + Fall-Klick</span>\n    <span class=\"value\">Mehrere F\u00E4lle vom aktiven Fall bis zum geklickten Fall markieren</span>\n  </div>\n  <div class=\"line\"></div>\n  @if (customShortcuts.length !== 0) {\n    <div class=\"shortcuts-scroll-title\">Weitere Tastaturbefehle</div>\n  }\n  @if (customShortcuts.length !== 0) {\n    <div class=\"shortcuts-scroll-sub-title\"></div>\n  }\n  @if (customShortcuts.length !== 0) {\n    <div class=\"line\"></div>\n  }\n  @for (shortcut of customShortcuts; track shortcut) {\n    <div>\n      <div class=\"pairing\">\n        <span class=\"label\">{{ shortcut.key }}</span>\n        <span class=\"value\">{{ shortcut.behavior }}</span>\n      </div>\n      <div class=\"line\"></div>\n    </div>\n  }\n</talenra-scroll-container>\n", styles: [".shortcuts-main-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:8px 24px 16px}.shortcuts-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:8px 8px 8px 16px}.shortcuts-scroll-main-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:8px 0 0}.shortcuts-scroll-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;margin:24px 0 0}.shortcuts-scroll-sub-title{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;margin:0 0 8px}.shortcuts-text{max-width:410px;max-height:570px;margin:8px 24px;font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased}.pairing{display:flex;flex-direction:row;flex-wrap:nowrap;width:100%;margin:8px 0 4px}.short-margin-top-item{margin:8px 0 0}.short-margin-bottom-item{margin:0 0 4px}.label{font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;width:85px}.value{font-size:.875rem;line-height:1rem;font-weight:400;font-style:normal;letter-spacing:.01em;width:315px;margin-left:10px}.line{border-bottom:1px solid #e6e6e6;display:block}.arrow-icon{font-size:18px}\n"] }]
        }], propDecorators: { customShortcuts: [{
                type: Input
            }] } });

/**
 * Menu for configuration of the inbox, able to show and alter any flattened object data.
 *
 * ```html
 * <talenra-configuration-menu
 *   [positionBottom]="'18'"
 *   [positionRight]="'0'"
 *   [title]="'Konfiguration'"
 *   [data]="inboxConfiguration"
 *   (dataChange)="configChange($event)">
 * </talenra-configuration-menu>
 * ```
 */
class ConfigurationMenuComponent {
    constructor() {
        /**
         * The data which is passed from the dialog
         */
        this.dataChange = new EventEmitter();
        /**
         * The boolean which controls the opening and closing of the dialog
         */
        this.open = false;
    }
    /**
     * Opens the dialog
     * @param event
     */
    openDialog(event) {
        this.open = true;
        event.stopPropagation();
    }
    /**
     * Closes the dialog
     */
    closeDialog() {
        this.open = false;
    }
    /**
     * Saves the configurations
     */
    saveConfigurations() {
        this.dataChange.emit(this.data);
        this.open = false;
    }
    /**
     * Changes the value of the data
     * @param event
     * @param key
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    changeValue(event, key) {
        this.data[key] = event;
    }
    /**
     * Returns the type of the value
     * @param value
     */
    typeof(value) {
        return typeof value;
    }
    /**
     * Closes the dialog when clicking outside of it
     */
    clickOutside() {
        if (this.open) {
            this.open = false;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ConfigurationMenuComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: ConfigurationMenuComponent, isStandalone: true, selector: "talenra-configuration-menu", inputs: { title: "title", positionTop: "positionTop", positionLeft: "positionLeft", positionBottom: "positionBottom", positionRight: "positionRight", data: "data" }, outputs: { dataChange: "dataChange" }, ngImport: i0, template: "<div\n  (clickOutside)=\"clickOutside()\"\n  [class.open-dialog]=\"!open\"\n  [style.bottom]=\"positionBottom + 'px'\"\n  [style.left]=\"positionLeft + 'px'\"\n  [style.right]=\"positionRight + 'px'\"\n  [style.top]=\"positionTop + 'px'\"\n  class=\"configuration-dialog\">\n  @if (!open) {\n    <button\n      (click)=\"openDialog($event)\"\n      [class.open-dialog]=\"open\"\n      class=\"btn open-dialog-btn\"\n      talenraTooltip=\"Konfiguration \u00F6ffnen\">\n      <talenra-icon name=\"settings\"></talenra-icon>\n    </button>\n  }\n  <div [class.open-dialog]=\"!open\" class=\"dialog-content\">\n    <div class=\"dialog-header\">\n      <span>\n        {{ title }}\n      </span>\n      <span>\n        @if (open) {\n          <button (click)=\"closeDialog()\" class=\"btn\" talenraTooltip=\"Konfiguration schlie\u00DFen\">\n            <talenra-icon name=\"close\"></talenra-icon>\n          </button>\n        }\n        @if (open) {\n          <button (click)=\"saveConfigurations()\" class=\"btn\" talenraTooltip=\"Konfiguration schlie\u00DFen\">\n            <talenra-icon name=\"check\"></talenra-icon>\n          </button>\n        }\n      </span>\n    </div>\n    <div class=\"dialog-main\">\n      @for (conf of data | keyvalue; track conf) {\n        <div class=\"dialog-main-items\">\n          <div class=\"dialog-main-item\">\n            <div class=\"dialog-main-item-label\">\n              {{ conf.key }}\n            </div>\n            <div class=\"dialog-main-item-input\">\n              @if (typeof conf.value === 'boolean') {\n                <div>\n                  <input\n                    (ngModelChange)=\"changeValue($event, conf.key)\"\n                    [ngModel]=\"conf.value\"\n                    class=\"ui-checkbox\"\n                    type=\"checkbox\" />\n                </div>\n              }\n              @if (typeof conf.value === 'number') {\n                <div>\n                  <input\n                    (ngModelChange)=\"changeValue($event, conf.key)\"\n                    [ngModelOptions]=\"{ updateOn: 'blur' }\"\n                    [ngModel]=\"conf.value\"\n                    type=\"number\" />\n                </div>\n              }\n              @if (typeof conf.value === 'string') {\n                <div>\n                  <input\n                    (ngModelChange)=\"changeValue($event, conf.key)\"\n                    [(ngModel)]=\"conf.value\"\n                    [ngModelOptions]=\"{ updateOn: 'blur' }\"\n                    type=\"text\" />\n                </div>\n              }\n            </div>\n          </div>\n        </div>\n      }\n    </div>\n  </div>\n</div>\n", styles: [".configuration-dialog{z-index:1000;position:absolute;background:#fff;width:400px;height:max-content;max-height:750px;transition:width .3s,max-height .3s;box-shadow:0 2px 5px #0003}.configuration-dialog.open-dialog{width:34px;max-height:34px}.dialog-content{opacity:1;transition:opacity .3s}.dialog-content.open-dialog{opacity:0;pointer-events:none}.dialog-header{display:flex;justify-content:space-between;align-items:center;padding:5px 10px;border-bottom:1px solid #cccccc}.dialog-main{padding:10px;height:100%}.dialog-main-items{display:flex;flex-direction:column;flex-wrap:nowrap;justify-content:space-between;height:100%}.dialog-main-item{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between;align-items:center;padding:5px 0}.dialog-main-item-label,.dialog-main-item-input{font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:#4d4d4d}.btn:disabled{color:#ccc}.btn{border:none;color:#4d4d4d;background:#fff;padding:0;opacity:1;transition:opacity .3s}.btn:hover:not([disabled]){cursor:pointer}.btn.open-dialog{opacity:0}.open-dialog-btn{margin:5px 0 0 5px}.ui-checkbox{accent-color:#0099a8;cursor:pointer}\n"], dependencies: [{ kind: "directive", type: ClickOutsideDirective, selector: "[clickOutside]", outputs: ["clickOutside"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }, { kind: "pipe", type: KeyValuePipe, name: "keyvalue" }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i1.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: ConfigurationMenuComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-configuration-menu', standalone: true, imports: [ClickOutsideDirective, TooltipDirective, IconComponent, KeyValuePipe, FormsModule], template: "<div\n  (clickOutside)=\"clickOutside()\"\n  [class.open-dialog]=\"!open\"\n  [style.bottom]=\"positionBottom + 'px'\"\n  [style.left]=\"positionLeft + 'px'\"\n  [style.right]=\"positionRight + 'px'\"\n  [style.top]=\"positionTop + 'px'\"\n  class=\"configuration-dialog\">\n  @if (!open) {\n    <button\n      (click)=\"openDialog($event)\"\n      [class.open-dialog]=\"open\"\n      class=\"btn open-dialog-btn\"\n      talenraTooltip=\"Konfiguration \u00F6ffnen\">\n      <talenra-icon name=\"settings\"></talenra-icon>\n    </button>\n  }\n  <div [class.open-dialog]=\"!open\" class=\"dialog-content\">\n    <div class=\"dialog-header\">\n      <span>\n        {{ title }}\n      </span>\n      <span>\n        @if (open) {\n          <button (click)=\"closeDialog()\" class=\"btn\" talenraTooltip=\"Konfiguration schlie\u00DFen\">\n            <talenra-icon name=\"close\"></talenra-icon>\n          </button>\n        }\n        @if (open) {\n          <button (click)=\"saveConfigurations()\" class=\"btn\" talenraTooltip=\"Konfiguration schlie\u00DFen\">\n            <talenra-icon name=\"check\"></talenra-icon>\n          </button>\n        }\n      </span>\n    </div>\n    <div class=\"dialog-main\">\n      @for (conf of data | keyvalue; track conf) {\n        <div class=\"dialog-main-items\">\n          <div class=\"dialog-main-item\">\n            <div class=\"dialog-main-item-label\">\n              {{ conf.key }}\n            </div>\n            <div class=\"dialog-main-item-input\">\n              @if (typeof conf.value === 'boolean') {\n                <div>\n                  <input\n                    (ngModelChange)=\"changeValue($event, conf.key)\"\n                    [ngModel]=\"conf.value\"\n                    class=\"ui-checkbox\"\n                    type=\"checkbox\" />\n                </div>\n              }\n              @if (typeof conf.value === 'number') {\n                <div>\n                  <input\n                    (ngModelChange)=\"changeValue($event, conf.key)\"\n                    [ngModelOptions]=\"{ updateOn: 'blur' }\"\n                    [ngModel]=\"conf.value\"\n                    type=\"number\" />\n                </div>\n              }\n              @if (typeof conf.value === 'string') {\n                <div>\n                  <input\n                    (ngModelChange)=\"changeValue($event, conf.key)\"\n                    [(ngModel)]=\"conf.value\"\n                    [ngModelOptions]=\"{ updateOn: 'blur' }\"\n                    type=\"text\" />\n                </div>\n              }\n            </div>\n          </div>\n        </div>\n      }\n    </div>\n  </div>\n</div>\n", styles: [".configuration-dialog{z-index:1000;position:absolute;background:#fff;width:400px;height:max-content;max-height:750px;transition:width .3s,max-height .3s;box-shadow:0 2px 5px #0003}.configuration-dialog.open-dialog{width:34px;max-height:34px}.dialog-content{opacity:1;transition:opacity .3s}.dialog-content.open-dialog{opacity:0;pointer-events:none}.dialog-header{display:flex;justify-content:space-between;align-items:center;padding:5px 10px;border-bottom:1px solid #cccccc}.dialog-main{padding:10px;height:100%}.dialog-main-items{display:flex;flex-direction:column;flex-wrap:nowrap;justify-content:space-between;height:100%}.dialog-main-item{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between;align-items:center;padding:5px 0}.dialog-main-item-label,.dialog-main-item-input{font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:#4d4d4d}.btn:disabled{color:#ccc}.btn{border:none;color:#4d4d4d;background:#fff;padding:0;opacity:1;transition:opacity .3s}.btn:hover:not([disabled]){cursor:pointer}.btn.open-dialog{opacity:0}.open-dialog-btn{margin:5px 0 0 5px}.ui-checkbox{accent-color:#0099a8;cursor:pointer}\n"] }]
        }], propDecorators: { title: [{
                type: Input
            }], positionTop: [{
                type: Input
            }], positionLeft: [{
                type: Input
            }], positionBottom: [{
                type: Input
            }], positionRight: [{
                type: Input
            }], data: [{
                type: Input
            }], dataChange: [{
                type: Output
            }] } });

class AttributeSelectorComponent {
    constructor() {
        /**
         * The list of available attributes to be selected and deselected.
         */
        this.allAttributes = [];
        /**
         * The list of selected attributes.
         */
        this.selectedAttributes = [];
        /**
         * The maximum number of selected attributes.
         * Default value is 30.
         */
        this.maxSelectedAttributes = 30;
        /**
         * The title of the attribute selector, displayed above the lists.
         */
        this.title = 'Attributselector';
        /**
         * The icon in the title of the attribute selector, displayed above the lists.
         * Has to be one of the available icons from the talenra icon library.
         */
        this.titleIcon = '';
        /**
         * The reset attribute selection.
         * If true, the attribute selection will be reset.
         * Will be set to false after the reset.
         */
        this.resetAttributeSelection = false;
        /**
         * The reset attribute selection emitter.
         * If true, the attribute selection will be reset.
         * Will be set to false after the reset.
         */
        this.resetAttributeSelectionChange = new EventEmitter();
        /**
         * The event emitter for the selected attributes.
         */
        this.selectedAttributesChange = new EventEmitter();
        /**
         * The event emitter for which specific custom space is clicked correlating with the attribute.
         */
        this.selectedAttributeIconClickEmitter = new EventEmitter();
        /**
         * The event emitter for the click of the close button.
         */
        this.closeClick = output();
        /**
         * List of searched attributes, not selected.
         */
        this.searchedAttributesList = [];
        /**
         * Form group for the search field
         */
        this.searchField = new FormGroup({
            searchField: new FormControl(''),
        });
        /**
         * Value if placeholder in selected sort list is shown.
         * If nothing selected yet, then placeholder is shown.
         */
        this.placeholderSelectionAttributesListShown = false;
        /**
         * Subscriptions for the filter toolbar component.
         * @internal
         */
        this.subscriptions = new Subscription();
    }
    /**
     * Standard initializer for the component.
     * @internal
     */
    ngOnInit() {
        this.initializeComponent();
    }
    /**
     * Detects changes in the attribute selector component.
     * @param changes The changes in the attribute selector component.
     * @internal
     */
    ngOnChanges(changes) {
        const resetAttributeSelectionChanges = changes['resetAttributeSelection'];
        if (resetAttributeSelectionChanges && !resetAttributeSelectionChanges.firstChange) {
            if (resetAttributeSelectionChanges.currentValue) {
                this.resetAttributes();
                this.resetAttributeSelectionChange.emit(false);
            }
        }
        // last position in change detection to reset the component
        const selectedAttributesChanges = changes['selectedAttributes'];
        if (selectedAttributesChanges && !selectedAttributesChanges.firstChange) {
            this.searchedAttributesList = this.allAttributes.filter((elem) => {
                // check if already selected
                return !selectedAttributesChanges.currentValue.some((e) => e.attribute.identifier === elem.attribute.identifier);
            });
        }
        // last position in change detection to reset the component
        const allAttributesChanges = changes['allAttributes'];
        if (allAttributesChanges && !allAttributesChanges.firstChange) {
            this.initializeComponent();
        }
    }
    /**
     * Unsubscribe from all subscriptions.
     * @internal
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
    }
    /**
     * To change the array place of dragged item.
     * Changes the order for the (selected) filters in the list of all filters (selected and not selected).
     * Updates the shown order in the dropdown list.
     * @param event The dragged item.
     * @internal
     */
    drop(event) {
        if (event.previousContainer === event.container) {
            moveItemInArray(event.container.data, event.previousIndex, event.currentIndex);
        }
        else {
            transferArrayItem(event.previousContainer.data, event.container.data, event.previousIndex, event.currentIndex);
        }
        // reset placeholder
        this.placeholderSelectionAttributesListShown = false;
        // emit the selected attributes, if the selected attributes list is changed (not emit if previous and current container are the searched attributes list)
        if (!(event.container.data === this.searchedAttributesList && event.previousContainer.data === event.container.data)) {
            this.selectedAttributesChange.emit(this.selectedAttributes);
        }
    }
    /**
     * Remove the chosen filter from the used attributes.
     * @param attribute The chosen attribute.
     * @param index The index of the chosen attribute.
     */
    removeAttribute(attribute, index) {
        // find index of attribute in the selected attributes settings order to place it back at right position
        const indexInSelectedAttributesSettingsList = this.allAttributes
            .filter((element) => element.attribute.filterMode !== undefined)
            .findIndex((e) => e.attribute.identifier === attribute.attribute.identifier);
        // move attribute to the bottom of the list
        transferArrayItem(this.selectedAttributes, this.searchedAttributesList, index, indexInSelectedAttributesSettingsList);
        // emit the selected attributes
        this.selectedAttributesChange.emit(this.selectedAttributes);
    }
    /**
     * Add the chosen attribute to the used attributes.
     * Moves chosen attribute to the top of the list.
     * @param index The index of the chosen attribute.
     */
    addAttribute(index) {
        // selects the filter
        transferArrayItem(this.searchedAttributesList, this.selectedAttributes, index, this.selectedAttributes.length);
        this.resetSearchText();
        // emit the selected attributes
        this.selectedAttributesChange.emit(this.selectedAttributes);
    }
    /**
     * Function to delete all attributes from the selected attributes.
     */
    resetAttributes() {
        this.selectedAttributes = [];
        this.searchedAttributesList = this.allAttributes;
        // emit the selected attributes
        this.selectedAttributesChange.emit(this.selectedAttributes);
    }
    /**
     * Sets that the placeholder in the start sort list shown.
     */
    dropListEntered() {
        this.placeholderSelectionAttributesListShown = true;
    }
    /**
     * Sets that the placeholder in the start sort list is not shown.
     */
    dropListExited() {
        this.placeholderSelectionAttributesListShown = false;
    }
    /**
     * Attributes icon click emitter to enable the tracking which attribute icon is clicked.
     */
    selectedAttributesIconClicked(attribute) {
        this.selectedAttributeIconClickEmitter.emit(attribute);
    }
    /**
     * Method to emit the close button and close the inbox detail view
     */
    onCloseClick() {
        this.closeClick.emit();
    }
    /**
     * Function to reset the search field.
     * @private
     */
    resetSearchText() {
        this.searchField.get('searchField')?.setValue('');
    }
    /**
     * Function to initialize the component.
     * @private
     */
    initializeComponent() {
        // reset subscriptions
        this.subscriptions.unsubscribe();
        this.subscriptions.closed = false;
        // reset lists
        if (this.selectedAttributes.length === 0) {
            this.selectedAttributes = [];
            this.searchedAttributesList = [...this.allAttributes];
        }
        else if (this.selectedAttributes.length > 0) {
            this.searchedAttributesList = this.allAttributes.filter((elem) => {
                // check if already selected
                return !this.selectedAttributes.some((e) => e.attribute.identifier === elem.attribute.identifier);
            });
        }
        // reset search field
        this.subscriptions.add(this.searchField.get('searchField')?.valueChanges.subscribe((value) => {
            // set searched value to '' if null, to avoid logic failure
            if (value === null) {
                this.searchField.get('searchField')?.setValue('');
            }
            else {
                this.searchedAttributesList = this.allAttributes.filter((elem) => {
                    // check if already selected
                    if (this.selectedAttributes.some((e) => e.attribute.identifier === elem.attribute.identifier)) {
                        return false;
                    }
                    else {
                        return elem.attribute.label.toLowerCase().startsWith(value.toLowerCase());
                    }
                });
            }
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributeSelectorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.1.6", type: AttributeSelectorComponent, isStandalone: true, selector: "talenra-attribute-selector", inputs: { allAttributes: "allAttributes", selectedAttributes: "selectedAttributes", maxSelectedAttributes: "maxSelectedAttributes", title: "title", titleIcon: "titleIcon", resetAttributeSelection: "resetAttributeSelection" }, outputs: { resetAttributeSelectionChange: "resetAttributeSelectionChange", selectedAttributesChange: "selectedAttributesChange", selectedAttributeIconClickEmitter: "selectedAttributeIconClickEmitter", closeClick: "closeClick" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"attributes-selector-menu\">\n  <div class=\"attribute-selector-selection-title medium-font\" data-testid=\"inbox-attribute-selector-menu-title\">\n    <div class=\"placeholder-title\"></div>\n    <div>\n      {{ title }}\n      <talenra-icon [name]=\"titleIcon\" class=\"attribute-selector-icon\"></talenra-icon>\n    </div>\n    <button (click)=\"onCloseClick()\" icon=\"close\" kind=\"ghost\" talenra-button size=\"s\"></button>\n  </div>\n  <div (click)=\"$event.stopPropagation()\" cdkDropListGroup class=\"attribute-selector-box light-font\">\n    <talenra-scroll-container class=\"selected-scroll-container\">\n      <div\n        (cdkDropListDropped)=\"drop($event)\"\n        (cdkDropListEntered)=\"dropListEntered()\"\n        (cdkDropListExited)=\"dropListExited()\"\n        [cdkDropListData]=\"selectedAttributes\"\n        cdkDropList\n        class=\"attribute-selector-list\"\n        data-testid=\"inbox-attribute-selector-selected-attributes-list\">\n        @if (selectedAttributes.length === 0 && !placeholderSelectionAttributesListShown) {\n          <div class=\"no-attributes-text\">Attribut hier rein ziehen</div>\n        }\n        @for (listItem of selectedAttributes; track $index) {\n          <div [cdkDragData]=\"listItem\" cdkDrag class=\"light-font\">\n            <div class=\"attribute-selector-items-main\">\n              <div class=\"attribute-selector-items-tag\">\n                <div class=\"attribute-selector-items-text move-cursor\">{{ listItem.attribute.label }}</div>\n                <div class=\"attribute-selector-items-buttons\">\n                  <button\n                    (click)=\"removeAttribute(listItem, $index)\"\n                    class=\"attributes-selector-items-tag-interaction-button\"\n                    data-testid=\"inbox-attribute-selector-remove-button\"\n                    icon=\"close\"\n                    kind=\"ghost\"\n                    talenra-button\n                    talenraTooltip=\"Entfernen\"\n                    size=\"s\"></button>\n                  @if (listItem.showIcon) {\n                    <button\n                      (click)=\"selectedAttributesIconClicked(listItem)\"\n                      [disabled]=\"listItem.iconDisabled\"\n                      [icon]=\"listItem.icon\"\n                      [talenraTooltip]=\"listItem.iconTooltip\"\n                      class=\"attributes-selector-items-tag-interaction-button\"\n                      kind=\"ghost\"\n                      talenra-button\n                      size=\"s\"></button>\n                  }\n                </div>\n              </div>\n              <div class=\"attribute-selector-items-grab\">\n                <button class=\"drag-icon\" icon=\"drag-indicator\" kind=\"ghost\" talenra-button size=\"s\"></button>\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n    </talenra-scroll-container>\n\n    <div class=\"attribute-selector-selection-title\">\n      @if (selectedAttributes.length >= maxSelectedAttributes) {\n        <span class=\"light-font\"> Maximale Attributanzahl erreicht </span>\n      }\n    </div>\n\n    <div class=\"line-with-icon\">\n      <div class=\"line-left\"></div>\n      <button\n        (click)=\"resetAttributes()\"\n        [disabled]=\"selectedAttributes.length === 0\"\n        class=\"attribute-selector-undo-button\"\n        data-testid=\"inbox-attribute-selector-undo-button\"\n        icon=\"undo\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n      <div class=\"line-right\"></div>\n    </div>\n\n    <div class=\"search-bar\">\n      <talenra-search-field [formGroup]=\"searchField\" showIcon>\n        <input\n          [formControlName]=\"'searchField'\"\n          data-testid=\"inbox-attribute-selector-search-button\"\n          kind=\"no-indent\"\n          talenra-search />\n      </talenra-search-field>\n    </div>\n    <talenra-scroll-container class=\"start-scroll-container\">\n      <div\n        (cdkDropListDropped)=\"drop($event)\"\n        [cdkDropListData]=\"searchedAttributesList\"\n        cdkDropList\n        class=\"attribute-selector-list move-cursor\"\n        data-testid=\"inbox-attribute-selector-searched-attributes-list\">\n        @for (item of searchedAttributesList; track item.attribute.identifier) {\n          <div>\n            <div\n              [cdkDragDisabled]=\"selectedAttributes.length >= maxSelectedAttributes\"\n              cdkDrag\n              class=\"attribute-selector-items-main light-font\">\n              <div\n                [class.not-draggable]=\"selectedAttributes.length === maxSelectedAttributes\"\n                class=\"attribute-selector-items-tag not-selected-items\">\n                <div\n                  [class.not-draggable]=\"selectedAttributes.length === maxSelectedAttributes\"\n                  class=\"attribute-selector-items-text move-cursor\">\n                  {{ item.attribute.label }}\n                </div>\n                <div class=\"attribute-selector-items-buttons move-cursor\">\n                  @if (selectedAttributes.length < maxSelectedAttributes) {\n                    <button\n                      (click)=\"addAttribute($index)\"\n                      class=\"attributes-selector-items-tag-interaction-button\"\n                      data-testid=\"inbox-attribute-selector-attribute-move\"\n                      icon=\"arrow-upward\"\n                      kind=\"ghost\"\n                      talenra-button\n                      talenraTooltip=\"Hinzuf\u00FCgen\"\n                      size=\"s\"></button>\n                  }\n                </div>\n              </div>\n              <div class=\"attribute-selector-items-grab\">\n                @if (selectedAttributes.length < maxSelectedAttributes) {\n                  <button class=\"drag-icon\" icon=\"drag-indicator\" kind=\"ghost\" talenra-button size=\"s\"></button>\n                }\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n    </talenra-scroll-container>\n  </div>\n</div>\n", styles: [":host{height:100%;width:100%;--color-background: #ffffff;--color-hover-background: #f2f2f2;--color-border: #b3b3b3;--color-text: #000000;--color-icon: #999999;--color-primary: #0099a8}.attributes-selector-menu{display:flex;flex-direction:column;height:100%}.attribute-selector-selection-title{display:flex;flex-direction:row;justify-content:space-between;align-items:center;margin-bottom:.125rem}.attribute-selector-icon{color:var(--color-icon);font-size:1rem}.placeholder-title{width:1.5rem;height:1.5rem}.attribute-selector-box{display:flex;flex-direction:column;flex-wrap:nowrap;overflow-y:clip;height:calc(100% - 1.25rem)}.attribute-selector-box :active{cursor:grabbing}.selected-scroll-container{width:100%;margin-bottom:.25rem;max-height:calc(80% - 5rem)}.no-attributes-text{padding:.8125rem 0 .1875rem;text-align:center}.attribute-selector-items-main{position:relative;background:none;padding:.25rem;display:flex;flex-wrap:nowrap;flex-direction:row;align-items:center;transition:background-color .3s ease}.attribute-selector-items-main:hover{background:var(--color-hover-background);overflow:hidden}.attribute-selector-items-tag{display:flex;align-items:center;margin-right:auto;height:1.5rem;border:.0625rem solid var(--color-primary);width:100%;border-radius:.75rem;transition:background-color .3s ease}.attribute-selector-items-tag:hover{background:var(--color-hover-background);overflow:hidden}.attribute-selector-items-tag.not-draggable{cursor:default}.attribute-selector-items-tag .attribute-selector-items-text{padding-left:.5rem;display:flex;flex-wrap:nowrap;flex-direction:row;align-items:center;margin-bottom:.0625rem}.attribute-selector-items-tag .attribute-selector-items-buttons{cursor:move;display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto}.attributes-selector-items-tag-interaction-button{height:1.25rem;margin:0 .25rem 0 0}.attribute-selector-items-grab{cursor:default;display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto}.start-scroll-container{width:100%;min-height:calc(20% - 5rem);margin:0 1.25rem 0 0}.attribute-selector-list{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%;background:none}.line-with-icon{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.line-left{border-bottom:.1875rem dotted var(--color-primary);flex-grow:1;display:block}.attribute-selector-undo-button{margin:0 .25rem}.line-right{border-bottom:.1875rem dotted var(--color-primary);flex-grow:1;display:block}.not-selected-items{border-color:var(--color-border);cursor:pointer}.not-selected-items.not-draggable{cursor:default}.search-bar{margin:0 0 .25rem}.move-cursor{cursor:move}.move-cursor.not-draggable{cursor:default}.drag-icon{margin:0 0 0 .25rem;cursor:move}.light-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-text)}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;color:var(--color-text)}.theme--denim :host .color--primary{color:#0069a3}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-hover-background: #262626;--color-text: #cccccc}\n"], dependencies: [{ kind: "component", type: IconComponent, selector: "talenra-icon", inputs: ["name"] }, { kind: "component", type: ScrollContainerComponent, selector: "talenra-scroll-container", inputs: ["useOverlay", "useOffset", "scrollYThreshold"], outputs: ["updatedScrollYOffset"] }, { kind: "directive", type: CdkDropList, selector: "[cdkDropList], cdk-drop-list", inputs: ["cdkDropListConnectedTo", "cdkDropListData", "cdkDropListOrientation", "id", "cdkDropListLockAxis", "cdkDropListDisabled", "cdkDropListSortingDisabled", "cdkDropListEnterPredicate", "cdkDropListSortPredicate", "cdkDropListAutoScrollDisabled", "cdkDropListAutoScrollStep", "cdkDropListElementContainer"], outputs: ["cdkDropListDropped", "cdkDropListEntered", "cdkDropListExited", "cdkDropListSorted"], exportAs: ["cdkDropList"] }, { kind: "component", type: ButtonComponent, selector: "button[talenra-button]", inputs: ["disabled", "kind", "size", "label", "waiting", "icon"] }, { kind: "directive", type: CdkDropListGroup, selector: "[cdkDropListGroup]", inputs: ["cdkDropListGroupDisabled"], exportAs: ["cdkDropListGroup"] }, { kind: "directive", type: CdkDrag, selector: "[cdkDrag]", inputs: ["cdkDragData", "cdkDragLockAxis", "cdkDragRootElement", "cdkDragBoundary", "cdkDragStartDelay", "cdkDragFreeDragPosition", "cdkDragDisabled", "cdkDragConstrainPosition", "cdkDragPreviewClass", "cdkDragPreviewContainer", "cdkDragScale"], outputs: ["cdkDragStarted", "cdkDragReleased", "cdkDragEnded", "cdkDragEntered", "cdkDragExited", "cdkDragDropped", "cdkDragMoved"], exportAs: ["cdkDrag"] }, { kind: "directive", type: TooltipDirective, selector: "[talenraTooltip]", inputs: ["talenraTooltip", "talenraTooltipPosition", "talenraTooltipDisabled"] }, { kind: "component", type: SearchFieldComponent, selector: "talenra-search-field", inputs: ["showIcon", "showButton", "size"], outputs: ["search", "clear"] }, { kind: "component", type: SearchInputComponent, selector: "input[talenra-search]", inputs: ["kind", "disabled"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: AttributeSelectorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'talenra-attribute-selector', standalone: true, imports: [
                        IconComponent,
                        ScrollContainerComponent,
                        CdkDropList,
                        ButtonComponent,
                        CdkDropListGroup,
                        CdkDrag,
                        TooltipDirective,
                        SearchFieldComponent,
                        SearchInputComponent,
                        ReactiveFormsModule,
                    ], template: "<div class=\"attributes-selector-menu\">\n  <div class=\"attribute-selector-selection-title medium-font\" data-testid=\"inbox-attribute-selector-menu-title\">\n    <div class=\"placeholder-title\"></div>\n    <div>\n      {{ title }}\n      <talenra-icon [name]=\"titleIcon\" class=\"attribute-selector-icon\"></talenra-icon>\n    </div>\n    <button (click)=\"onCloseClick()\" icon=\"close\" kind=\"ghost\" talenra-button size=\"s\"></button>\n  </div>\n  <div (click)=\"$event.stopPropagation()\" cdkDropListGroup class=\"attribute-selector-box light-font\">\n    <talenra-scroll-container class=\"selected-scroll-container\">\n      <div\n        (cdkDropListDropped)=\"drop($event)\"\n        (cdkDropListEntered)=\"dropListEntered()\"\n        (cdkDropListExited)=\"dropListExited()\"\n        [cdkDropListData]=\"selectedAttributes\"\n        cdkDropList\n        class=\"attribute-selector-list\"\n        data-testid=\"inbox-attribute-selector-selected-attributes-list\">\n        @if (selectedAttributes.length === 0 && !placeholderSelectionAttributesListShown) {\n          <div class=\"no-attributes-text\">Attribut hier rein ziehen</div>\n        }\n        @for (listItem of selectedAttributes; track $index) {\n          <div [cdkDragData]=\"listItem\" cdkDrag class=\"light-font\">\n            <div class=\"attribute-selector-items-main\">\n              <div class=\"attribute-selector-items-tag\">\n                <div class=\"attribute-selector-items-text move-cursor\">{{ listItem.attribute.label }}</div>\n                <div class=\"attribute-selector-items-buttons\">\n                  <button\n                    (click)=\"removeAttribute(listItem, $index)\"\n                    class=\"attributes-selector-items-tag-interaction-button\"\n                    data-testid=\"inbox-attribute-selector-remove-button\"\n                    icon=\"close\"\n                    kind=\"ghost\"\n                    talenra-button\n                    talenraTooltip=\"Entfernen\"\n                    size=\"s\"></button>\n                  @if (listItem.showIcon) {\n                    <button\n                      (click)=\"selectedAttributesIconClicked(listItem)\"\n                      [disabled]=\"listItem.iconDisabled\"\n                      [icon]=\"listItem.icon\"\n                      [talenraTooltip]=\"listItem.iconTooltip\"\n                      class=\"attributes-selector-items-tag-interaction-button\"\n                      kind=\"ghost\"\n                      talenra-button\n                      size=\"s\"></button>\n                  }\n                </div>\n              </div>\n              <div class=\"attribute-selector-items-grab\">\n                <button class=\"drag-icon\" icon=\"drag-indicator\" kind=\"ghost\" talenra-button size=\"s\"></button>\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n    </talenra-scroll-container>\n\n    <div class=\"attribute-selector-selection-title\">\n      @if (selectedAttributes.length >= maxSelectedAttributes) {\n        <span class=\"light-font\"> Maximale Attributanzahl erreicht </span>\n      }\n    </div>\n\n    <div class=\"line-with-icon\">\n      <div class=\"line-left\"></div>\n      <button\n        (click)=\"resetAttributes()\"\n        [disabled]=\"selectedAttributes.length === 0\"\n        class=\"attribute-selector-undo-button\"\n        data-testid=\"inbox-attribute-selector-undo-button\"\n        icon=\"undo\"\n        kind=\"ghost\"\n        talenra-button\n        talenraTooltip=\"Zur\u00FCcksetzen\"></button>\n      <div class=\"line-right\"></div>\n    </div>\n\n    <div class=\"search-bar\">\n      <talenra-search-field [formGroup]=\"searchField\" showIcon>\n        <input\n          [formControlName]=\"'searchField'\"\n          data-testid=\"inbox-attribute-selector-search-button\"\n          kind=\"no-indent\"\n          talenra-search />\n      </talenra-search-field>\n    </div>\n    <talenra-scroll-container class=\"start-scroll-container\">\n      <div\n        (cdkDropListDropped)=\"drop($event)\"\n        [cdkDropListData]=\"searchedAttributesList\"\n        cdkDropList\n        class=\"attribute-selector-list move-cursor\"\n        data-testid=\"inbox-attribute-selector-searched-attributes-list\">\n        @for (item of searchedAttributesList; track item.attribute.identifier) {\n          <div>\n            <div\n              [cdkDragDisabled]=\"selectedAttributes.length >= maxSelectedAttributes\"\n              cdkDrag\n              class=\"attribute-selector-items-main light-font\">\n              <div\n                [class.not-draggable]=\"selectedAttributes.length === maxSelectedAttributes\"\n                class=\"attribute-selector-items-tag not-selected-items\">\n                <div\n                  [class.not-draggable]=\"selectedAttributes.length === maxSelectedAttributes\"\n                  class=\"attribute-selector-items-text move-cursor\">\n                  {{ item.attribute.label }}\n                </div>\n                <div class=\"attribute-selector-items-buttons move-cursor\">\n                  @if (selectedAttributes.length < maxSelectedAttributes) {\n                    <button\n                      (click)=\"addAttribute($index)\"\n                      class=\"attributes-selector-items-tag-interaction-button\"\n                      data-testid=\"inbox-attribute-selector-attribute-move\"\n                      icon=\"arrow-upward\"\n                      kind=\"ghost\"\n                      talenra-button\n                      talenraTooltip=\"Hinzuf\u00FCgen\"\n                      size=\"s\"></button>\n                  }\n                </div>\n              </div>\n              <div class=\"attribute-selector-items-grab\">\n                @if (selectedAttributes.length < maxSelectedAttributes) {\n                  <button class=\"drag-icon\" icon=\"drag-indicator\" kind=\"ghost\" talenra-button size=\"s\"></button>\n                }\n              </div>\n            </div>\n          </div>\n        }\n      </div>\n    </talenra-scroll-container>\n  </div>\n</div>\n", styles: [":host{height:100%;width:100%;--color-background: #ffffff;--color-hover-background: #f2f2f2;--color-border: #b3b3b3;--color-text: #000000;--color-icon: #999999;--color-primary: #0099a8}.attributes-selector-menu{display:flex;flex-direction:column;height:100%}.attribute-selector-selection-title{display:flex;flex-direction:row;justify-content:space-between;align-items:center;margin-bottom:.125rem}.attribute-selector-icon{color:var(--color-icon);font-size:1rem}.placeholder-title{width:1.5rem;height:1.5rem}.attribute-selector-box{display:flex;flex-direction:column;flex-wrap:nowrap;overflow-y:clip;height:calc(100% - 1.25rem)}.attribute-selector-box :active{cursor:grabbing}.selected-scroll-container{width:100%;margin-bottom:.25rem;max-height:calc(80% - 5rem)}.no-attributes-text{padding:.8125rem 0 .1875rem;text-align:center}.attribute-selector-items-main{position:relative;background:none;padding:.25rem;display:flex;flex-wrap:nowrap;flex-direction:row;align-items:center;transition:background-color .3s ease}.attribute-selector-items-main:hover{background:var(--color-hover-background);overflow:hidden}.attribute-selector-items-tag{display:flex;align-items:center;margin-right:auto;height:1.5rem;border:.0625rem solid var(--color-primary);width:100%;border-radius:.75rem;transition:background-color .3s ease}.attribute-selector-items-tag:hover{background:var(--color-hover-background);overflow:hidden}.attribute-selector-items-tag.not-draggable{cursor:default}.attribute-selector-items-tag .attribute-selector-items-text{padding-left:.5rem;display:flex;flex-wrap:nowrap;flex-direction:row;align-items:center;margin-bottom:.0625rem}.attribute-selector-items-tag .attribute-selector-items-buttons{cursor:move;display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto}.attributes-selector-items-tag-interaction-button{height:1.25rem;margin:0 .25rem 0 0}.attribute-selector-items-grab{cursor:default;display:flex;flex-wrap:nowrap;flex-direction:row-reverse;flex:1;margin-left:auto}.start-scroll-container{width:100%;min-height:calc(20% - 5rem);margin:0 1.25rem 0 0}.attribute-selector-list{display:flex;flex-direction:column;flex-wrap:nowrap;height:100%;background:none}.line-with-icon{display:flex;flex-direction:row;flex-wrap:nowrap;align-items:center}.line-left{border-bottom:.1875rem dotted var(--color-primary);flex-grow:1;display:block}.attribute-selector-undo-button{margin:0 .25rem}.line-right{border-bottom:.1875rem dotted var(--color-primary);flex-grow:1;display:block}.not-selected-items{border-color:var(--color-border);cursor:pointer}.not-selected-items.not-draggable{cursor:default}.search-bar{margin:0 0 .25rem}.move-cursor{cursor:move}.move-cursor.not-draggable{cursor:default}.drag-icon{margin:0 0 0 .25rem;cursor:move}.light-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:.875rem;line-height:1rem;font-weight:300;font-style:normal;letter-spacing:.02em;color:var(--color-text)}.medium-font{font-family:Roboto,Helvetica Neue,Helvetica,Arial,\"sans-serif\";font-feature-settings:\"liga\" 1,\"kern\" 1;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.125rem;font-weight:500;font-style:normal;letter-spacing:.01em;color:var(--color-text)}.theme--denim :host .color--primary{color:#0069a3}.theme--denim :host{--color-primary: #0069a3}.appearance--dark :host{--color-background: #333333;--color-hover-background: #262626;--color-text: #cccccc}\n"] }]
        }], propDecorators: { allAttributes: [{
                type: Input
            }], selectedAttributes: [{
                type: Input
            }], maxSelectedAttributes: [{
                type: Input
            }], title: [{
                type: Input
            }], titleIcon: [{
                type: Input
            }], resetAttributeSelection: [{
                type: Input
            }], resetAttributeSelectionChange: [{
                type: Output
            }], selectedAttributesChange: [{
                type: Output
            }], selectedAttributeIconClickEmitter: [{
                type: Output
            }] } });

/** @deprecated */
class talenraInboxModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: talenraInboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.1.6", ngImport: i0, type: talenraInboxModule, imports: [NgSwitch,
            FormsModule,
            ScrollContainerComponent,
            IconComponent,
            AttributesListComponent,
            ReactiveFormsModule,
            CdkDropList,
            CdkDrag,
            DragDropModule,
            TooltipDirective,
            ButtonComponent,
            AsyncPipe,
            NgIf,
            CopyContentDirective,
            PaginatorComponent,
            MatMenu,
            MatMenuTrigger,
            CheckboxComponent,
            QueryBuilderComponent,
            AngularDraggableModule,
            ToggleComponent,
            MenuAnchorDirective,
            MenuComponent,
            MenuTitleComponent,
            MenuSeparatorComponent,
            MenuLinkComponent,
            FormFieldComponent,
            FormErrorComponent,
            SelectComponent,
            MatAccordion,
            MatExpansionPanel,
            MatExpansionPanelTitle,
            MatExpansionPanelHeader,
            NgStyle,
            VirtualScrollerModule,
            MessageComponent,
            NgForOf,
            KeyValuePipe,
            NgTemplateOutlet,
            NgSwitchCase,
            InputComponent,
            DateComponent,
            BadgeComponent,
            InboxConfigurationPanelBottomBarComponent,
            TextFilterComponent,
            SortSelectionComponent,
            DetailViewInformationComponent,
            InboxNoteBoxComponent,
            InboxDetailViewComponent,
            DetailViewInformationTabBarComponent,
            DetailViewInformationBoxComponent,
            DetailViewInformationTabComponent,
            DataItemComponent,
            DataItemsListComponent,
            InboxLayoutComponent,
            SkeletonLoadingDataItemsListComponent,
            InboxSkeletonLoadingComponent,
            InboxShortcutsComponent,
            ConfigurationMenuComponent,
            IconFiltersComponent,
            PresetsComponent,
            AttributeSelectorComponent,
            SimpleFilterSelectionComponent,
            SelectionFilterComponent,
            RangeFilterComponent,
            InboxToolbarComponent,
            AttributesSettingsComponent,
            InboxConfigurationPanelComponent,
            FilterToolbarComponent,
            InboxComponent], exports: [InboxComponent,
            InboxSkeletonLoadingComponent,
            ConfigurationMenuComponent,
            InboxToolbarComponent,
            FilterToolbarComponent,
            DataItemsListComponent,
            InboxConfigurationPanelComponent,
            AttributeSelectorComponent,
            IconFiltersComponent,
            DataItemComponent,
            InboxLayoutComponent,
            DetailViewInformationComponent,
            InboxNoteBoxComponent,
            InboxDetailViewComponent,
            DetailViewInformationTabBarComponent,
            DetailViewInformationBoxComponent,
            DetailViewInformationTabComponent,
            SkeletonLoadingDataItemsListComponent,
            InboxSkeletonLoadingComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: talenraInboxModule, imports: [FormsModule,
            ScrollContainerComponent,
            IconComponent,
            AttributesListComponent,
            ReactiveFormsModule,
            DragDropModule,
            ButtonComponent,
            PaginatorComponent,
            MatMenu,
            CheckboxComponent,
            QueryBuilderComponent,
            AngularDraggableModule,
            ToggleComponent,
            MenuComponent,
            MenuTitleComponent,
            MenuSeparatorComponent,
            MenuLinkComponent,
            FormFieldComponent,
            FormErrorComponent,
            SelectComponent,
            MatExpansionPanel,
            MatExpansionPanelHeader,
            VirtualScrollerModule,
            MessageComponent,
            InputComponent,
            DateComponent,
            BadgeComponent,
            InboxConfigurationPanelBottomBarComponent,
            TextFilterComponent,
            SortSelectionComponent,
            DetailViewInformationComponent,
            InboxNoteBoxComponent,
            InboxDetailViewComponent,
            DetailViewInformationTabBarComponent,
            DetailViewInformationBoxComponent,
            DetailViewInformationTabComponent,
            DataItemComponent,
            DataItemsListComponent,
            InboxLayoutComponent,
            InboxShortcutsComponent,
            ConfigurationMenuComponent,
            IconFiltersComponent,
            PresetsComponent,
            AttributeSelectorComponent,
            SimpleFilterSelectionComponent,
            SelectionFilterComponent,
            RangeFilterComponent,
            InboxToolbarComponent,
            AttributesSettingsComponent,
            InboxConfigurationPanelComponent,
            FilterToolbarComponent,
            InboxComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: talenraInboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        NgSwitch,
                        FormsModule,
                        ScrollContainerComponent,
                        IconComponent,
                        AttributesListComponent,
                        ReactiveFormsModule,
                        CdkDropList,
                        CdkDrag,
                        DragDropModule,
                        TooltipDirective,
                        ButtonComponent,
                        AsyncPipe,
                        NgIf,
                        CopyContentDirective,
                        PaginatorComponent,
                        MatMenu,
                        MatMenuTrigger,
                        CheckboxComponent,
                        QueryBuilderComponent,
                        AngularDraggableModule,
                        ToggleComponent,
                        MenuAnchorDirective,
                        MenuComponent,
                        MenuTitleComponent,
                        MenuSeparatorComponent,
                        MenuLinkComponent,
                        FormFieldComponent,
                        FormErrorComponent,
                        SelectComponent,
                        MatAccordion,
                        MatExpansionPanel,
                        MatExpansionPanelTitle,
                        MatExpansionPanelHeader,
                        NgStyle,
                        VirtualScrollerModule,
                        MessageComponent,
                        NgForOf,
                        KeyValuePipe,
                        NgTemplateOutlet,
                        NgSwitchCase,
                        InputComponent,
                        DateComponent,
                        BadgeComponent,
                        InboxConfigurationPanelBottomBarComponent,
                        TextFilterComponent,
                        SortSelectionComponent,
                        DetailViewInformationComponent,
                        InboxNoteBoxComponent,
                        InboxDetailViewComponent,
                        DetailViewInformationTabBarComponent,
                        DetailViewInformationBoxComponent,
                        DetailViewInformationTabComponent,
                        DataItemComponent,
                        DataItemsListComponent,
                        InboxLayoutComponent,
                        SkeletonLoadingDataItemsListComponent,
                        InboxSkeletonLoadingComponent,
                        InboxShortcutsComponent,
                        ConfigurationMenuComponent,
                        IconFiltersComponent,
                        PresetsComponent,
                        AttributeSelectorComponent,
                        SimpleFilterSelectionComponent,
                        SelectionFilterComponent,
                        RangeFilterComponent,
                        InboxToolbarComponent,
                        AttributesSettingsComponent,
                        InboxConfigurationPanelComponent,
                        FilterToolbarComponent,
                        InboxComponent,
                    ],
                    exports: [
                        InboxComponent,
                        InboxSkeletonLoadingComponent,
                        ConfigurationMenuComponent,
                        InboxToolbarComponent,
                        FilterToolbarComponent,
                        DataItemsListComponent,
                        InboxConfigurationPanelComponent,
                        AttributeSelectorComponent,
                        IconFiltersComponent,
                        DataItemComponent,
                        InboxLayoutComponent,
                        DetailViewInformationComponent,
                        InboxNoteBoxComponent,
                        InboxDetailViewComponent,
                        DetailViewInformationTabBarComponent,
                        DetailViewInformationBoxComponent,
                        DetailViewInformationTabComponent,
                        SkeletonLoadingDataItemsListComponent,
                        InboxSkeletonLoadingComponent,
                    ],
                }]
        }] });

/**
 * Attribute filter modes
 */
const AttributeFilterModes = {
    MultiSelect: 'multi-select',
    SingleSelect: 'single-select',
    DateRange: 'date-range',
    CharRange: 'char-range',
    NumberRange: 'number-range',
    TextField: 'text-field',
};
/**
 * Attribute filter modes
 */
const DateFilterRestrictions = {
    Birthday: 'birthday',
    OnlyFuture: 'only-future',
    OnlyPast: 'only-past',
};

/**
 * Attribute filter modes
 */
const PresetOperations = {
    Create: 'create',
    Update: 'update',
    Rename: 'rename',
    UpdateRename: 'update & rename',
    AttributeUpdate: 'attribute-update',
    Delete: 'delete',
    VisibilityOff: 'visibility-off',
    VisibilityOn: 'visibility-on',
    DragDrop: 'dragDrop',
    PositionUp: 'position-up',
    PositionDown: 'position-down',
    None: 'none',
};

/**
 * Const for the operator modes of the filter attributes.
 */
const FilterAttributeOperators = {
    Equal: 'equal',
    NotEqual: 'notEqual',
};

/**
 * Library version for internal usage. For external usage (consumers of the library), use the `version` property from
 * the public API.
 *
 * @internal
 */
const LIB_VERSION = '5.0.0';

/*
 * Public API Surface of ngx-inbox
 */
// modules
/**
 * Current version of the library (e.g. "1.0.0", "1.1.0-rc.0")
 *
 * ```typescript
 * import { version } from '@talenra/ngx-inbox';
 * console.log(version);
 * ```
 */
const version = LIB_VERSION;

/**
 * Generated bundle index. Do not edit.
 */

export { AttributeFilterModes, AttributeSelectorComponent, AttributesSettingsComponent, CheckboxState, ConfigurationMenuComponent, DataItemComponent, DataItemsClass, DataItemsListComponent, DataItemsService, DateFilterRestrictions, DetailViewInformationBoxComponent, DetailViewInformationComponent, DetailViewInformationTabBarComponent, DetailViewInformationTabComponent, FilterAttributeOperators, FilterToolbarComponent, FilterToolbarService, IconFiltersComponent, InboxComponent, InboxConfigurationPanelComponent, InboxDetailViewComponent, InboxDetailViewService, InboxLayoutComponent, InboxNoteBoxComponent, InboxSkeletonLoadingComponent, InboxState, InboxToolbarComponent, InboxToolbarService, InteractedDataItemsMessageTypes, PresetOperations, PresetsService, SimpleFilterSelectionComponent, SkeletonLoadingDataItemsListComponent, talenraInboxModule, version };
//# sourceMappingURL=talenra-ngx-inbox.mjs.map
